/* Generated by Cython 0.22 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "depends": []
    }
}
END: Cython Metadata */

#define PY_SSIZE_T_CLEAN
#ifndef CYTHON_USE_PYLONG_INTERNALS
#ifdef PYLONG_BITS_IN_DIGIT
#define CYTHON_USE_PYLONG_INTERNALS 0
#else
#include "pyconfig.h"
#ifdef PYLONG_BITS_IN_DIGIT
#define CYTHON_USE_PYLONG_INTERNALS 1
#else
#define CYTHON_USE_PYLONG_INTERNALS 0
#endif
#endif
#endif
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02060000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03020000)
    #error Cython requires Python 2.6+ or Python 3.2+.
#else
#define CYTHON_ABI "0_22"
#include <stddef.h>
#ifndef offsetof
#define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
#define CYTHON_COMPILING_IN_PYPY 1
#define CYTHON_COMPILING_IN_CPYTHON 0
#else
#define CYTHON_COMPILING_IN_PYPY 0
#define CYTHON_COMPILING_IN_CPYTHON 1
#endif
#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x02070600 && !defined(Py_OptimizeFlag)
#define Py_OptimizeFlag 0
#endif
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos) \
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyClass_Type
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos) \
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyType_Type
#endif
#if PY_MAJOR_VERSION >= 3
  #define Py_TPFLAGS_CHECKTYPES 0
  #define Py_TPFLAGS_HAVE_INDEX 0
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#if PY_VERSION_HEX < 0x030400a1 && !defined(Py_TPFLAGS_HAVE_FINALIZE)
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ? \
                                              0 : _PyUnicode_Ready((PyObject *)(op)))
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_KIND(u)         PyUnicode_KIND(u)
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
#else
  #define CYTHON_PEP393_ENABLED 0
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_KIND(u)         (sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
  #define __Pyx_PyFrozenSet_Size(s)         PyObject_Size(s)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ? \
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
  #define __Pyx_PyFrozenSet_Size(s)         PySet_Size(s)
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None)) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None)) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   PyInt_AsLong
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   PyInt_AsSsize_t
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyMethod_New(func, self, klass) ((self) ? PyMethod_New(func, self) : PyInstanceMethod_New(func))
#else
  #define __Pyx_PyMethod_New(func, self, klass) PyMethod_New(func, self, klass)
#endif
#ifndef CYTHON_INLINE
  #if defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  /* Initialize NaN. The sign is irrelevant, an exponent with all bits 1 and
   a nonzero mantissa means NaN. If the first bit in the mantissa is 1, it is
   a quiet NaN. */
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#define __Pyx_void_to_None(void_result) (void_result, Py_INCREF(Py_None), Py_None)
#ifdef __cplusplus
template<typename T>
void __Pyx_call_destructor(T* x) {
    x->~T();
}
template<typename T>
class __Pyx_FakeReference {
  public:
    __Pyx_FakeReference() : ptr(NULL) { }
    __Pyx_FakeReference(T& ref) : ptr(&ref) { }
    T *operator->() { return ptr; }
    operator T&() { return *ptr; }
  private:
    T *ptr;
};
#endif


#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#if defined(WIN32) || defined(MS_WINDOWS)
#define _USE_MATH_DEFINES
#endif
#include <math.h>
#define __PYX_HAVE__cymysql__packet
#define __PYX_HAVE_API__cymysql__packet
#include "stdint.h"
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#ifdef PYREX_WITHOUT_ASSERTIONS
#define CYTHON_WITHOUT_ASSERTIONS
#endif

#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
typedef struct {PyObject **p; char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT 0
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (    \
    (sizeof(type) < sizeof(Py_ssize_t))  ||             \
    (sizeof(type) > sizeof(Py_ssize_t) &&               \
          likely(v < (type)PY_SSIZE_T_MAX ||            \
                 v == (type)PY_SSIZE_T_MAX)  &&         \
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||       \
                                v == (type)PY_SSIZE_T_MIN)))  ||  \
    (sizeof(type) == sizeof(Py_ssize_t) &&              \
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||        \
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
#define __Pyx_PyByteArray_FromString(s) PyByteArray_FromStringAndSize((const char*)s, strlen((const char*)s))
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyObject_AsSString(s)    ((signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
#if PY_MAJOR_VERSION < 3
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u)
{
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#else
#define __Pyx_Py_UNICODE_strlen Py_UNICODE_strlen
#endif
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_Owned_Py_None(b) (Py_INCREF(Py_None), Py_None)
#define __Pyx_PyBool_FromLong(b) ((b) ? (Py_INCREF(Py_True), Py_True) : (Py_INCREF(Py_False), Py_False))
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Int(PyObject* x);
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
#if CYTHON_COMPILING_IN_CPYTHON
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c));
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */

static PyObject *__pyx_m;
static PyObject *__pyx_d;
static PyObject *__pyx_b;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;


static const char *__pyx_f[] = {
  "cymysql/packet.pyx",
};

/*--- Type declarations ---*/
struct __pyx_obj_7cymysql_6packet_MysqlPacket;
struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket;
struct __pyx_obj_7cymysql_6packet_MySQLResult;

/* "cymysql/packet.pyx":45
 *     return struct.unpack('<Q', n)[0]
 * 
 * cdef class MysqlPacket(object):             # <<<<<<<<<<<<<<
 *     """Representation of a MySQL response packet.  Reads in the packet
 *     from the network socket, removes packet header and provides an interface
 */
struct __pyx_obj_7cymysql_6packet_MysqlPacket {
  PyObject_HEAD
  struct __pyx_vtabstruct_7cymysql_6packet_MysqlPacket *__pyx_vtab;
  PyObject *connection;
  PyObject *_socket;
  PyObject *_charset;
  PyObject *_use_unicode;
  PyObject *__pyx___data;
  int __pyx___position;
};


/* "cymysql/packet.pyx":187
 * 
 * 
 * cdef class FieldDescriptorPacket(MysqlPacket):             # <<<<<<<<<<<<<<
 *     """A MysqlPacket that represents a specific column's metadata in the result.
 * 
 */
struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket {
  struct __pyx_obj_7cymysql_6packet_MysqlPacket __pyx_base;
  PyObject *catalog;
  PyObject *db;
  PyObject *table_name;
  PyObject *org_table;
  PyObject *name;
  PyObject *org_name;
  int charsetnr;
  int length;
  int type_code;
  int flags;
  int scale;
  int is_set;
  int is_binary;
  PyObject *charset;
};


/* "cymysql/packet.pyx":253
 * # TODO: move OK and EOF packet parsing/logic into a proper subclass
 * #       of MysqlPacket like has been done with FieldDescriptorPacket.
 * cdef class MySQLResult(object):             # <<<<<<<<<<<<<<
 *     cdef public object affected_rows, insert_id, rest_rows, has_result
 *     cdef public object message, description
 */
struct __pyx_obj_7cymysql_6packet_MySQLResult {
  PyObject_HEAD
  struct __pyx_vtabstruct_7cymysql_6packet_MySQLResult *__pyx_vtab;
  PyObject *affected_rows;
  PyObject *insert_id;
  PyObject *rest_rows;
  PyObject *has_result;
  PyObject *message;
  PyObject *description;
  PyObject *connection;
  PyObject *first_packet;
  PyObject *fields;
  int has_next;
  int rest_row_index;
  int server_status;
  int warning_count;
  int field_count;
};



/* "cymysql/packet.pyx":45
 *     return struct.unpack('<Q', n)[0]
 * 
 * cdef class MysqlPacket(object):             # <<<<<<<<<<<<<<
 *     """Representation of a MySQL response packet.  Reads in the packet
 *     from the network socket, removes packet header and provides an interface
 */

struct __pyx_vtabstruct_7cymysql_6packet_MysqlPacket {
  PyObject *(*__pyx___recv_from_socket)(struct __pyx_obj_7cymysql_6packet_MysqlPacket *, int);
  PyObject *(*__pyx___recv_packet)(struct __pyx_obj_7cymysql_6packet_MysqlPacket *);
  PyObject *(*read)(struct __pyx_obj_7cymysql_6packet_MysqlPacket *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*_read)(struct __pyx_obj_7cymysql_6packet_MysqlPacket *, int);
  void (*_skip)(struct __pyx_obj_7cymysql_6packet_MysqlPacket *, int);
  PyObject *(*_read_all)(struct __pyx_obj_7cymysql_6packet_MysqlPacket *);
  int (*read_length_coded_binary)(struct __pyx_obj_7cymysql_6packet_MysqlPacket *);
  PyObject *(*_read_length_coded_string)(struct __pyx_obj_7cymysql_6packet_MysqlPacket *);
  PyObject *(*read_decode_data)(struct __pyx_obj_7cymysql_6packet_MysqlPacket *, PyObject *, PyObject *);
  PyObject *(*is_ok_packet)(struct __pyx_obj_7cymysql_6packet_MysqlPacket *, int __pyx_skip_dispatch);
  PyObject *(*is_eof_packet)(struct __pyx_obj_7cymysql_6packet_MysqlPacket *, int __pyx_skip_dispatch);
  PyObject *(*is_eof_and_status)(struct __pyx_obj_7cymysql_6packet_MysqlPacket *, int __pyx_skip_dispatch);
  PyObject *(*read_ok_packet)(struct __pyx_obj_7cymysql_6packet_MysqlPacket *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_7cymysql_6packet_MysqlPacket *__pyx_vtabptr_7cymysql_6packet_MysqlPacket;


/* "cymysql/packet.pyx":187
 * 
 * 
 * cdef class FieldDescriptorPacket(MysqlPacket):             # <<<<<<<<<<<<<<
 *     """A MysqlPacket that represents a specific column's metadata in the result.
 * 
 */

struct __pyx_vtabstruct_7cymysql_6packet_FieldDescriptorPacket {
  struct __pyx_vtabstruct_7cymysql_6packet_MysqlPacket __pyx_base;
};
static struct __pyx_vtabstruct_7cymysql_6packet_FieldDescriptorPacket *__pyx_vtabptr_7cymysql_6packet_FieldDescriptorPacket;


/* "cymysql/packet.pyx":253
 * # TODO: move OK and EOF packet parsing/logic into a proper subclass
 * #       of MysqlPacket like has been done with FieldDescriptorPacket.
 * cdef class MySQLResult(object):             # <<<<<<<<<<<<<<
 *     cdef public object affected_rows, insert_id, rest_rows, has_result
 *     cdef public object message, description
 */

struct __pyx_vtabstruct_7cymysql_6packet_MySQLResult {
  void (*_get_descriptions)(struct __pyx_obj_7cymysql_6packet_MySQLResult *);
};
static struct __pyx_vtabstruct_7cymysql_6packet_MySQLResult *__pyx_vtabptr_7cymysql_6packet_MySQLResult;

/* --- Runtime support code (head) --- */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil) \
          if (acquire_gil) { \
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure(); \
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__); \
              PyGILState_Release(__pyx_gilstate_save); \
          } else { \
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__); \
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil) \
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext() \
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_XDECREF_SET(r, v) do {                            \
        PyObject *tmp = (PyObject *) r;                         \
        r = v; __Pyx_XDECREF(tmp);                              \
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {                             \
        PyObject *tmp = (PyObject *) r;                         \
        r = v; __Pyx_DECREF(tmp);                               \
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

static PyObject *__Pyx_GetBuiltinName(PyObject *name);

static CYTHON_INLINE void __Pyx_ErrRestore(PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetch(PyObject **type, PyObject **value, PyObject **tb);

static void __Pyx_WriteUnraisable(const char *name, int clineno,
                                  int lineno, const char *filename,
                                  int full_traceback);

static CYTHON_INLINE PyObject *__Pyx_GetModuleGlobalName(PyObject *name);

#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck) \
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ? \
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck) : \
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) : \
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck) \
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ? \
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) : \
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck) \
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ? \
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) : \
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck);

static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject **argnames[], \
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args, \
    const char* function_name);

static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

static CYTHON_INLINE char __Pyx_PyBytes_GetItemInt(PyObject* bytes, Py_ssize_t index, int check_bounds) {
    if (check_bounds) {
        Py_ssize_t size = PyBytes_GET_SIZE(bytes);
        if (unlikely(index >= size) | ((index < 0) & unlikely(index < -size))) {
            PyErr_SetString(PyExc_IndexError, "string index out of range");
            return -1;
        }
    }
    if (index < 0)
        index += PyBytes_GET_SIZE(bytes);
    return PyBytes_AS_STRING(bytes)[index];
}

#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE int __Pyx_ListComp_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len)) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        Py_SIZE(list) = len+1;
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_ListComp_Append(L,x) PyList_Append(L,x)
#endif

static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

static CYTHON_INLINE int __Pyx_IterFinish(void);

static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected);

#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);
#else
#define __Pyx_PyObject_CallNoArg(func) __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL)
#endif

static CYTHON_INLINE int __Pyx_CheckKeywordStrings(PyObject *kwdict, const char* function_name, int kw_allowed);

static CYTHON_INLINE long __Pyx_mod_long(long, long); /* proto */

static CYTHON_INLINE int __Pyx_div_int(int, int); /* proto */

#ifndef __PYX_FORCE_INIT_THREADS
  #define __PYX_FORCE_INIT_THREADS 0
#endif

#define UNARY_NEG_WOULD_OVERFLOW(x)            (((x) < 0) & ((unsigned long)(x) == 0-(unsigned long)(x)))

static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        Py_SIZE(list) = len+1;
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg);

static CYTHON_INLINE int __Pyx_PyObject_Append(PyObject* L, PyObject* x);

static int __Pyx_SetVtable(PyObject *dict, void *vtable);

typedef struct {
    int code_line;
    PyCodeObject* code_object;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level);

static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

static CYTHON_INLINE PY_LONG_LONG __Pyx_PyInt_As_PY_LONG_LONG(PyObject *);

static CYTHON_INLINE unsigned char __Pyx_PyInt_As_unsigned_char(PyObject *);

static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value);

static CYTHON_INLINE PyObject* __Pyx_PyInt_From_uint16_t(uint16_t value);

static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

static int __Pyx_check_binary_version(void);

static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);

static PyObject *__pyx_f_7cymysql_6packet_11MysqlPacket___recv_from_socket(struct __pyx_obj_7cymysql_6packet_MysqlPacket *__pyx_v_self, int __pyx_v_size); /* proto*/
static PyObject *__pyx_f_7cymysql_6packet_11MysqlPacket___recv_packet(struct __pyx_obj_7cymysql_6packet_MysqlPacket *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_7cymysql_6packet_11MysqlPacket_read(struct __pyx_obj_7cymysql_6packet_MysqlPacket *__pyx_v_self, PyObject *__pyx_v_size, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_7cymysql_6packet_11MysqlPacket__read(struct __pyx_obj_7cymysql_6packet_MysqlPacket *__pyx_v_self, int __pyx_v_size); /* proto*/
static void __pyx_f_7cymysql_6packet_11MysqlPacket__skip(struct __pyx_obj_7cymysql_6packet_MysqlPacket *__pyx_v_self, int __pyx_v_size); /* proto*/
static PyObject *__pyx_f_7cymysql_6packet_11MysqlPacket__read_all(struct __pyx_obj_7cymysql_6packet_MysqlPacket *__pyx_v_self); /* proto*/
static int __pyx_f_7cymysql_6packet_11MysqlPacket_read_length_coded_binary(struct __pyx_obj_7cymysql_6packet_MysqlPacket *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_7cymysql_6packet_11MysqlPacket__read_length_coded_string(struct __pyx_obj_7cymysql_6packet_MysqlPacket *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_7cymysql_6packet_11MysqlPacket_read_decode_data(struct __pyx_obj_7cymysql_6packet_MysqlPacket *__pyx_v_self, PyObject *__pyx_v_fields, PyObject *__pyx_v_decoders); /* proto*/
static PyObject *__pyx_f_7cymysql_6packet_11MysqlPacket_is_ok_packet(struct __pyx_obj_7cymysql_6packet_MysqlPacket *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_7cymysql_6packet_11MysqlPacket_is_eof_packet(struct __pyx_obj_7cymysql_6packet_MysqlPacket *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_7cymysql_6packet_11MysqlPacket_is_eof_and_status(struct __pyx_obj_7cymysql_6packet_MysqlPacket *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_7cymysql_6packet_11MysqlPacket_read_ok_packet(struct __pyx_obj_7cymysql_6packet_MysqlPacket *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static void __pyx_f_7cymysql_6packet_11MySQLResult__get_descriptions(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self); /* proto*/

/* Module declarations from 'libc.stdint' */

/* Module declarations from 'cymysql.packet' */
static PyTypeObject *__pyx_ptype_7cymysql_6packet_MysqlPacket = 0;
static PyTypeObject *__pyx_ptype_7cymysql_6packet_FieldDescriptorPacket = 0;
static PyTypeObject *__pyx_ptype_7cymysql_6packet_MySQLResult = 0;
static int __pyx_v_7cymysql_6packet_PYTHON3;
static int __pyx_v_7cymysql_6packet_FIELD_TYPE_VAR_STRING;
static int __pyx_v_7cymysql_6packet_UNSIGNED_CHAR_COLUMN;
static int __pyx_v_7cymysql_6packet_UNSIGNED_SHORT_COLUMN;
static int __pyx_v_7cymysql_6packet_UNSIGNED_INT24_COLUMN;
static int __pyx_v_7cymysql_6packet_UNSIGNED_INT64_COLUMN;
static int __pyx_v_7cymysql_6packet_SERVER_MORE_RESULTS_EXISTS;
static uint16_t __pyx_f_7cymysql_6packet_unpack_uint16(PyObject *); /*proto*/
static uint32_t __pyx_f_7cymysql_6packet_unpack_uint24(PyObject *); /*proto*/
static uint32_t __pyx_f_7cymysql_6packet_unpack_uint32(PyObject *); /*proto*/
static PY_LONG_LONG __pyx_f_7cymysql_6packet_unpack_uint64(PyObject *); /*proto*/
#define __Pyx_MODULE_NAME "cymysql.packet"
int __pyx_module_is_main_cymysql__packet = 0;

/* Implementation of 'cymysql.packet' */
static PyObject *__pyx_builtin_ord;
static PyObject *__pyx_builtin_range;
static int __pyx_pf_7cymysql_6packet_11MysqlPacket___init__(struct __pyx_obj_7cymysql_6packet_MysqlPacket *__pyx_v_self, PyObject *__pyx_v_connection); /* proto */
static PyObject *__pyx_pf_7cymysql_6packet_11MysqlPacket_2get_all_data(struct __pyx_obj_7cymysql_6packet_MysqlPacket *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7cymysql_6packet_11MysqlPacket_4read(struct __pyx_obj_7cymysql_6packet_MysqlPacket *__pyx_v_self, PyObject *__pyx_v_size); /* proto */
static PyObject *__pyx_pf_7cymysql_6packet_11MysqlPacket_6is_ok_packet(struct __pyx_obj_7cymysql_6packet_MysqlPacket *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7cymysql_6packet_11MysqlPacket_8is_eof_packet(struct __pyx_obj_7cymysql_6packet_MysqlPacket *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7cymysql_6packet_11MysqlPacket_10is_eof_and_status(struct __pyx_obj_7cymysql_6packet_MysqlPacket *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7cymysql_6packet_11MysqlPacket_12read_ok_packet(struct __pyx_obj_7cymysql_6packet_MysqlPacket *__pyx_v_self); /* proto */
static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket___init__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_2__parse_field_descriptor(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_4description(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_6get_column_length(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_8__str__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_7catalog___get__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self); /* proto */
static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_7catalog_2__set__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_7catalog_4__del__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_2db___get__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self); /* proto */
static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_2db_2__set__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_2db_4__del__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_10table_name___get__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self); /* proto */
static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_10table_name_2__set__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_10table_name_4__del__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_9org_table___get__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self); /* proto */
static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_9org_table_2__set__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_9org_table_4__del__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_4name___get__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self); /* proto */
static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_4name_2__set__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_4name_4__del__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_8org_name___get__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self); /* proto */
static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_8org_name_2__set__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_8org_name_4__del__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_9charsetnr___get__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self); /* proto */
static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_9charsetnr_2__set__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_6length___get__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self); /* proto */
static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_6length_2__set__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_9type_code___get__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self); /* proto */
static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_9type_code_2__set__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_5flags___get__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self); /* proto */
static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_5flags_2__set__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_5scale___get__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self); /* proto */
static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_5scale_2__set__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_6is_set___get__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self); /* proto */
static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_6is_set_2__set__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_9is_binary___get__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self); /* proto */
static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_9is_binary_2__set__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_7charset___get__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self); /* proto */
static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_7charset_2__set__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_7charset_4__del__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self); /* proto */
static int __pyx_pf_7cymysql_6packet_11MySQLResult___init__(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self, PyObject *__pyx_v_connection); /* proto */
static PyObject *__pyx_pf_7cymysql_6packet_11MySQLResult_2read_rest_rowdata_packet(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7cymysql_6packet_11MySQLResult_4fetchone(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7cymysql_6packet_11MySQLResult_13affected_rows___get__(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self); /* proto */
static int __pyx_pf_7cymysql_6packet_11MySQLResult_13affected_rows_2__set__(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_7cymysql_6packet_11MySQLResult_13affected_rows_4__del__(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7cymysql_6packet_11MySQLResult_9insert_id___get__(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self); /* proto */
static int __pyx_pf_7cymysql_6packet_11MySQLResult_9insert_id_2__set__(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_7cymysql_6packet_11MySQLResult_9insert_id_4__del__(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7cymysql_6packet_11MySQLResult_9rest_rows___get__(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self); /* proto */
static int __pyx_pf_7cymysql_6packet_11MySQLResult_9rest_rows_2__set__(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_7cymysql_6packet_11MySQLResult_9rest_rows_4__del__(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7cymysql_6packet_11MySQLResult_10has_result___get__(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self); /* proto */
static int __pyx_pf_7cymysql_6packet_11MySQLResult_10has_result_2__set__(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_7cymysql_6packet_11MySQLResult_10has_result_4__del__(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7cymysql_6packet_11MySQLResult_7message___get__(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self); /* proto */
static int __pyx_pf_7cymysql_6packet_11MySQLResult_7message_2__set__(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_7cymysql_6packet_11MySQLResult_7message_4__del__(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7cymysql_6packet_11MySQLResult_11description___get__(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self); /* proto */
static int __pyx_pf_7cymysql_6packet_11MySQLResult_11description_2__set__(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_7cymysql_6packet_11MySQLResult_11description_4__del__(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7cymysql_6packet_11MySQLResult_8has_next___get__(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self); /* proto */
static int __pyx_pf_7cymysql_6packet_11MySQLResult_8has_next_2__set__(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_tp_new_7cymysql_6packet_MysqlPacket(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_7cymysql_6packet_FieldDescriptorPacket(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_7cymysql_6packet_MySQLResult(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static char __pyx_k_[] = "";
static char __pyx_k_Q[] = "<Q";
static char __pyx_k_SET[] = "SET";
static char __pyx_k_get[] = "get";
static char __pyx_k_ord[] = "ord";
static char __pyx_k_sys[] = "sys";
static char __pyx_k_FLAG[] = "FLAG";
static char __pyx_k_conv[] = "conv";
static char __pyx_k_init[] = "__init__";
static char __pyx_k_main[] = "__main__";
static char __pyx_k_name[] = "name";
static char __pyx_k_read[] = "read";
static char __pyx_k_recv[] = "recv";
static char __pyx_k_test[] = "__test__";
static char __pyx_k_class[] = "__class__";
static char __pyx_k_proxy[] = "proxy";
static char __pyx_k_range[] = "range";
static char __pyx_k_BINARY[] = "BINARY";
static char __pyx_k_append[] = "append";
static char __pyx_k_decode[] = "decode";
static char __pyx_k_import[] = "__import__";
static char __pyx_k_socket[] = "socket";
static char __pyx_k_struct[] = "struct";
static char __pyx_k_unpack[] = "unpack";
static char __pyx_k_charset[] = "charset";
static char __pyx_k_weakref[] = "weakref";
static char __pyx_k_MBLENGTH[] = "MBLENGTH";
static char __pyx_k_type_code[] = "type_code";
static char __pyx_k_connection[] = "connection";
static char __pyx_k_pyx_vtable[] = "__pyx_vtable__";
static char __pyx_k_cymysql_err[] = "cymysql.err";
static char __pyx_k_description[] = "description";
static char __pyx_k_use_unicode[] = "use_unicode";
static char __pyx_k_is_ok_packet[] = "is_ok_packet";
static char __pyx_k_version_info[] = "version_info";
static char __pyx_k_SERVER_STATUS[] = "SERVER_STATUS";
static char __pyx_k_charset_by_id[] = "charset_by_id";
static char __pyx_k_is_eof_packet[] = "is_eof_packet";
static char __pyx_k_read_ok_packet[] = "read_ok_packet";
static char __pyx_k_s_s_s_s_type_s[] = "%s %s.%s.%s, type=%s";
static char __pyx_k_cymysql_charset[] = "cymysql.charset";
static char __pyx_k_OperationalError[] = "OperationalError";
static char __pyx_k_cymysql_constants[] = "cymysql.constants";
static char __pyx_k_get_column_length[] = "get_column_length";
static char __pyx_k_is_eof_and_status[] = "is_eof_and_status";
static char __pyx_k_convert_characters[] = "convert_characters";
static char __pyx_k_cymysql_converters[] = "cymysql.converters";
static char __pyx_k_raise_mysql_exception[] = "raise_mysql_exception";
static char __pyx_k_parse_field_descriptor[] = "__parse_field_descriptor";
static char __pyx_k_read_rest_rowdata_packet[] = "read_rest_rowdata_packet";
static char __pyx_k_SERVER_MORE_RESULTS_EXISTS[] = "SERVER_MORE_RESULTS_EXISTS";
static char __pyx_k_Protocol_error_expecting_EOF[] = "Protocol error, expecting EOF";
static char __pyx_k_Lost_connection_to_MySQL_server[] = "Lost connection to MySQL server during query";
static PyObject *__pyx_kp_b_;
static PyObject *__pyx_n_s_BINARY;
static PyObject *__pyx_n_s_FLAG;
static PyObject *__pyx_kp_s_Lost_connection_to_MySQL_server;
static PyObject *__pyx_n_s_MBLENGTH;
static PyObject *__pyx_n_s_OperationalError;
static PyObject *__pyx_kp_s_Protocol_error_expecting_EOF;
static PyObject *__pyx_kp_s_Q;
static PyObject *__pyx_n_s_SERVER_MORE_RESULTS_EXISTS;
static PyObject *__pyx_n_s_SERVER_STATUS;
static PyObject *__pyx_n_s_SET;
static PyObject *__pyx_n_s_append;
static PyObject *__pyx_n_s_charset;
static PyObject *__pyx_n_s_charset_by_id;
static PyObject *__pyx_n_s_class;
static PyObject *__pyx_n_s_connection;
static PyObject *__pyx_n_s_conv;
static PyObject *__pyx_n_s_convert_characters;
static PyObject *__pyx_n_s_cymysql_charset;
static PyObject *__pyx_n_s_cymysql_constants;
static PyObject *__pyx_n_s_cymysql_converters;
static PyObject *__pyx_n_s_cymysql_err;
static PyObject *__pyx_n_s_decode;
static PyObject *__pyx_n_s_description;
static PyObject *__pyx_n_s_get;
static PyObject *__pyx_n_s_get_column_length;
static PyObject *__pyx_n_s_import;
static PyObject *__pyx_n_s_init;
static PyObject *__pyx_n_s_is_eof_and_status;
static PyObject *__pyx_n_s_is_eof_packet;
static PyObject *__pyx_n_s_is_ok_packet;
static PyObject *__pyx_n_s_main;
static PyObject *__pyx_n_s_name;
static PyObject *__pyx_n_s_ord;
static PyObject *__pyx_n_s_parse_field_descriptor;
static PyObject *__pyx_n_s_proxy;
static PyObject *__pyx_n_s_pyx_vtable;
static PyObject *__pyx_n_s_raise_mysql_exception;
static PyObject *__pyx_n_s_range;
static PyObject *__pyx_n_s_read;
static PyObject *__pyx_n_s_read_ok_packet;
static PyObject *__pyx_n_s_read_rest_rowdata_packet;
static PyObject *__pyx_n_s_recv;
static PyObject *__pyx_kp_s_s_s_s_s_type_s;
static PyObject *__pyx_n_s_socket;
static PyObject *__pyx_n_s_struct;
static PyObject *__pyx_n_s_sys;
static PyObject *__pyx_n_s_test;
static PyObject *__pyx_n_s_type_code;
static PyObject *__pyx_n_s_unpack;
static PyObject *__pyx_n_s_use_unicode;
static PyObject *__pyx_n_s_version_info;
static PyObject *__pyx_n_s_weakref;
static PyObject *__pyx_int_0;
static PyObject *__pyx_int_1;
static PyObject *__pyx_int_2;
static PyObject *__pyx_int_3;
static PyObject *__pyx_int_4;
static PyObject *__pyx_int_8;
static PyObject *__pyx_int_33;
static PyObject *__pyx_int_88;
static PyObject *__pyx_int_91;
static PyObject *__pyx_int_2013;
static PyObject *__pyx_tuple__2;
static PyObject *__pyx_tuple__3;
static PyObject *__pyx_tuple__4;
static PyObject *__pyx_tuple__5;
static PyObject *__pyx_tuple__6;

/* "cymysql/packet.pyx":30
 * cdef int SERVER_MORE_RESULTS_EXISTS = SERVER_STATUS.SERVER_MORE_RESULTS_EXISTS
 * 
 * cdef uint16_t unpack_uint16(bytes s):             # <<<<<<<<<<<<<<
 *     cdef unsigned char* n = s
 *     return n[0] + (n[1] << 8)
 */

static uint16_t __pyx_f_7cymysql_6packet_unpack_uint16(PyObject *__pyx_v_s) {
  unsigned char *__pyx_v_n;
  uint16_t __pyx_r;
  __Pyx_RefNannyDeclarations
  unsigned char *__pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("unpack_uint16", 0);

  /* "cymysql/packet.pyx":31
 * 
 * cdef uint16_t unpack_uint16(bytes s):
 *     cdef unsigned char* n = s             # <<<<<<<<<<<<<<
 *     return n[0] + (n[1] << 8)
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_AsUString(__pyx_v_s); if (unlikely((!__pyx_t_1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 31; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_n = __pyx_t_1;

  /* "cymysql/packet.pyx":32
 * cdef uint16_t unpack_uint16(bytes s):
 *     cdef unsigned char* n = s
 *     return n[0] + (n[1] << 8)             # <<<<<<<<<<<<<<
 * 
 * cdef uint32_t unpack_uint24(bytes s):
 */
  __pyx_r = ((__pyx_v_n[0]) + ((__pyx_v_n[1]) << 8));
  goto __pyx_L0;

  /* "cymysql/packet.pyx":30
 * cdef int SERVER_MORE_RESULTS_EXISTS = SERVER_STATUS.SERVER_MORE_RESULTS_EXISTS
 * 
 * cdef uint16_t unpack_uint16(bytes s):             # <<<<<<<<<<<<<<
 *     cdef unsigned char* n = s
 *     return n[0] + (n[1] << 8)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_WriteUnraisable("cymysql.packet.unpack_uint16", __pyx_clineno, __pyx_lineno, __pyx_filename, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/packet.pyx":34
 *     return n[0] + (n[1] << 8)
 * 
 * cdef uint32_t unpack_uint24(bytes s):             # <<<<<<<<<<<<<<
 *     cdef unsigned char* n = s
 *     return n[0] + (n[1] << 8) + (n[2] << 16)
 */

static uint32_t __pyx_f_7cymysql_6packet_unpack_uint24(PyObject *__pyx_v_s) {
  unsigned char *__pyx_v_n;
  uint32_t __pyx_r;
  __Pyx_RefNannyDeclarations
  unsigned char *__pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("unpack_uint24", 0);

  /* "cymysql/packet.pyx":35
 * 
 * cdef uint32_t unpack_uint24(bytes s):
 *     cdef unsigned char* n = s             # <<<<<<<<<<<<<<
 *     return n[0] + (n[1] << 8) + (n[2] << 16)
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_AsUString(__pyx_v_s); if (unlikely((!__pyx_t_1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 35; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_n = __pyx_t_1;

  /* "cymysql/packet.pyx":36
 * cdef uint32_t unpack_uint24(bytes s):
 *     cdef unsigned char* n = s
 *     return n[0] + (n[1] << 8) + (n[2] << 16)             # <<<<<<<<<<<<<<
 * 
 * cdef uint32_t unpack_uint32(bytes s):
 */
  __pyx_r = (((__pyx_v_n[0]) + ((__pyx_v_n[1]) << 8)) + ((__pyx_v_n[2]) << 16));
  goto __pyx_L0;

  /* "cymysql/packet.pyx":34
 *     return n[0] + (n[1] << 8)
 * 
 * cdef uint32_t unpack_uint24(bytes s):             # <<<<<<<<<<<<<<
 *     cdef unsigned char* n = s
 *     return n[0] + (n[1] << 8) + (n[2] << 16)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_WriteUnraisable("cymysql.packet.unpack_uint24", __pyx_clineno, __pyx_lineno, __pyx_filename, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/packet.pyx":38
 *     return n[0] + (n[1] << 8) + (n[2] << 16)
 * 
 * cdef uint32_t unpack_uint32(bytes s):             # <<<<<<<<<<<<<<
 *     cdef unsigned char* n = s
 *     return n[0] + (n[1] << 8) + (n[2] << 16) + (n[3] << 24)
 */

static uint32_t __pyx_f_7cymysql_6packet_unpack_uint32(PyObject *__pyx_v_s) {
  unsigned char *__pyx_v_n;
  uint32_t __pyx_r;
  __Pyx_RefNannyDeclarations
  unsigned char *__pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("unpack_uint32", 0);

  /* "cymysql/packet.pyx":39
 * 
 * cdef uint32_t unpack_uint32(bytes s):
 *     cdef unsigned char* n = s             # <<<<<<<<<<<<<<
 *     return n[0] + (n[1] << 8) + (n[2] << 16) + (n[3] << 24)
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_AsUString(__pyx_v_s); if (unlikely((!__pyx_t_1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 39; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_n = __pyx_t_1;

  /* "cymysql/packet.pyx":40
 * cdef uint32_t unpack_uint32(bytes s):
 *     cdef unsigned char* n = s
 *     return n[0] + (n[1] << 8) + (n[2] << 16) + (n[3] << 24)             # <<<<<<<<<<<<<<
 * 
 * cdef long long unpack_uint64(bytes n):
 */
  __pyx_r = ((((__pyx_v_n[0]) + ((__pyx_v_n[1]) << 8)) + ((__pyx_v_n[2]) << 16)) + ((__pyx_v_n[3]) << 24));
  goto __pyx_L0;

  /* "cymysql/packet.pyx":38
 *     return n[0] + (n[1] << 8) + (n[2] << 16)
 * 
 * cdef uint32_t unpack_uint32(bytes s):             # <<<<<<<<<<<<<<
 *     cdef unsigned char* n = s
 *     return n[0] + (n[1] << 8) + (n[2] << 16) + (n[3] << 24)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_WriteUnraisable("cymysql.packet.unpack_uint32", __pyx_clineno, __pyx_lineno, __pyx_filename, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/packet.pyx":42
 *     return n[0] + (n[1] << 8) + (n[2] << 16) + (n[3] << 24)
 * 
 * cdef long long unpack_uint64(bytes n):             # <<<<<<<<<<<<<<
 *     return struct.unpack('<Q', n)[0]
 * 
 */

static PY_LONG_LONG __pyx_f_7cymysql_6packet_unpack_uint64(PyObject *__pyx_v_n) {
  PY_LONG_LONG __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PY_LONG_LONG __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("unpack_uint64", 0);

  /* "cymysql/packet.pyx":43
 * 
 * cdef long long unpack_uint64(bytes n):
 *     return struct.unpack('<Q', n)[0]             # <<<<<<<<<<<<<<
 * 
 * cdef class MysqlPacket(object):
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_struct); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 43; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_unpack); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 43; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_COMPILING_IN_CPYTHON && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  __pyx_t_5 = PyTuple_New(2+__pyx_t_4); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 43; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  if (__pyx_t_2) {
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2); __Pyx_GIVEREF(__pyx_t_2); __pyx_t_2 = NULL;
  }
  __Pyx_INCREF(__pyx_kp_s_Q);
  PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_4, __pyx_kp_s_Q);
  __Pyx_GIVEREF(__pyx_kp_s_Q);
  __Pyx_INCREF(__pyx_v_n);
  PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_4, __pyx_v_n);
  __Pyx_GIVEREF(__pyx_v_n);
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 43; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(__pyx_t_3 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 43; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = __Pyx_PyInt_As_PY_LONG_LONG(__pyx_t_3); if (unlikely((__pyx_t_6 == (PY_LONG_LONG)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 43; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_6;
  goto __pyx_L0;

  /* "cymysql/packet.pyx":42
 *     return n[0] + (n[1] << 8) + (n[2] << 16) + (n[3] << 24)
 * 
 * cdef long long unpack_uint64(bytes n):             # <<<<<<<<<<<<<<
 *     return struct.unpack('<Q', n)[0]
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_WriteUnraisable("cymysql.packet.unpack_uint64", __pyx_clineno, __pyx_lineno, __pyx_filename, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/packet.pyx":53
 *     cdef int __position
 * 
 *     def __init__(self, connection):             # <<<<<<<<<<<<<<
 *         cdef int is_error
 *         cdef int errno
 */

/* Python wrapper */
static int __pyx_pw_7cymysql_6packet_11MysqlPacket_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_7cymysql_6packet_11MysqlPacket_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_connection = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_connection,0};
    PyObject* values[1] = {0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_connection)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 53; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 1) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
    }
    __pyx_v_connection = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 53; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("cymysql.packet.MysqlPacket.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7cymysql_6packet_11MysqlPacket___init__(((struct __pyx_obj_7cymysql_6packet_MysqlPacket *)__pyx_v_self), __pyx_v_connection);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_6packet_11MysqlPacket___init__(struct __pyx_obj_7cymysql_6packet_MysqlPacket *__pyx_v_self, PyObject *__pyx_v_connection) {
  int __pyx_v_is_error;
  CYTHON_UNUSED int __pyx_v_errno;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  char __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cymysql/packet.pyx":56
 *         cdef int is_error
 *         cdef int errno
 *         self.connection = connection             # <<<<<<<<<<<<<<
 *         self._socket = connection.socket
 *         self._charset = connection.charset
 */
  __Pyx_INCREF(__pyx_v_connection);
  __Pyx_GIVEREF(__pyx_v_connection);
  __Pyx_GOTREF(__pyx_v_self->connection);
  __Pyx_DECREF(__pyx_v_self->connection);
  __pyx_v_self->connection = __pyx_v_connection;

  /* "cymysql/packet.pyx":57
 *         cdef int errno
 *         self.connection = connection
 *         self._socket = connection.socket             # <<<<<<<<<<<<<<
 *         self._charset = connection.charset
 *         self._use_unicode = connection.use_unicode
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_connection, __pyx_n_s_socket); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 57; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_socket);
  __Pyx_DECREF(__pyx_v_self->_socket);
  __pyx_v_self->_socket = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cymysql/packet.pyx":58
 *         self.connection = connection
 *         self._socket = connection.socket
 *         self._charset = connection.charset             # <<<<<<<<<<<<<<
 *         self._use_unicode = connection.use_unicode
 *         self.__position = 0
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_connection, __pyx_n_s_charset); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 58; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_charset);
  __Pyx_DECREF(__pyx_v_self->_charset);
  __pyx_v_self->_charset = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cymysql/packet.pyx":59
 *         self._socket = connection.socket
 *         self._charset = connection.charset
 *         self._use_unicode = connection.use_unicode             # <<<<<<<<<<<<<<
 *         self.__position = 0
 *         self.__recv_packet()
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_connection, __pyx_n_s_use_unicode); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 59; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_use_unicode);
  __Pyx_DECREF(__pyx_v_self->_use_unicode);
  __pyx_v_self->_use_unicode = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cymysql/packet.pyx":60
 *         self._charset = connection.charset
 *         self._use_unicode = connection.use_unicode
 *         self.__position = 0             # <<<<<<<<<<<<<<
 *         self.__recv_packet()
 *         is_error = (<unsigned char>(self.__data[0])) == 0xff
 */
  __pyx_v_self->__pyx___position = 0;

  /* "cymysql/packet.pyx":61
 *         self._use_unicode = connection.use_unicode
 *         self.__position = 0
 *         self.__recv_packet()             # <<<<<<<<<<<<<<
 *         is_error = (<unsigned char>(self.__data[0])) == 0xff
 *         if is_error:
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_6packet_MysqlPacket *)__pyx_v_self->__pyx_vtab)->__pyx___recv_packet(__pyx_v_self); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 61; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/packet.pyx":62
 *         self.__position = 0
 *         self.__recv_packet()
 *         is_error = (<unsigned char>(self.__data[0])) == 0xff             # <<<<<<<<<<<<<<
 *         if is_error:
 *             self.__position += 1  # field_count == error (we already know that)
 */
  if (unlikely(__pyx_v_self->__pyx___data == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 62; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_2 = __Pyx_PyBytes_GetItemInt(__pyx_v_self->__pyx___data, 0, 1); if (unlikely(__pyx_t_2 == ((char)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 62; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_is_error = (((unsigned char)__pyx_t_2) == 0xff);

  /* "cymysql/packet.pyx":63
 *         self.__recv_packet()
 *         is_error = (<unsigned char>(self.__data[0])) == 0xff
 *         if is_error:             # <<<<<<<<<<<<<<
 *             self.__position += 1  # field_count == error (we already know that)
 *             errno = unpack_uint16(self._read(2))
 */
  __pyx_t_3 = (__pyx_v_is_error != 0);
  if (__pyx_t_3) {

    /* "cymysql/packet.pyx":64
 *         is_error = (<unsigned char>(self.__data[0])) == 0xff
 *         if is_error:
 *             self.__position += 1  # field_count == error (we already know that)             # <<<<<<<<<<<<<<
 *             errno = unpack_uint16(self._read(2))
 *             raise_mysql_exception(self.__data)
 */
    __pyx_v_self->__pyx___position = (__pyx_v_self->__pyx___position + 1);

    /* "cymysql/packet.pyx":65
 *         if is_error:
 *             self.__position += 1  # field_count == error (we already know that)
 *             errno = unpack_uint16(self._read(2))             # <<<<<<<<<<<<<<
 *             raise_mysql_exception(self.__data)
 * 
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_6packet_MysqlPacket *)__pyx_v_self->__pyx_vtab)->_read(__pyx_v_self, 2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 65; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_errno = __pyx_f_7cymysql_6packet_unpack_uint16(((PyObject*)__pyx_t_1));
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "cymysql/packet.pyx":66
 *             self.__position += 1  # field_count == error (we already know that)
 *             errno = unpack_uint16(self._read(2))
 *             raise_mysql_exception(self.__data)             # <<<<<<<<<<<<<<
 * 
 *     cdef bytes __recv_from_socket(self, int size):
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_raise_mysql_exception); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 66; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    if (CYTHON_COMPILING_IN_CPYTHON && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (!__pyx_t_5) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_self->__pyx___data); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 66; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 66; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5); __Pyx_GIVEREF(__pyx_t_5); __pyx_t_5 = NULL;
      __Pyx_INCREF(__pyx_v_self->__pyx___data);
      PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_self->__pyx___data);
      __Pyx_GIVEREF(__pyx_v_self->__pyx___data);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 66; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "cymysql/packet.pyx":53
 *     cdef int __position
 * 
 *     def __init__(self, connection):             # <<<<<<<<<<<<<<
 *         cdef int is_error
 *         cdef int errno
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cymysql.packet.MysqlPacket.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/packet.pyx":68
 *             raise_mysql_exception(self.__data)
 * 
 *     cdef bytes __recv_from_socket(self, int size):             # <<<<<<<<<<<<<<
 *         cdef bytes r
 *         cdef int recieved
 */

static PyObject *__pyx_f_7cymysql_6packet_11MysqlPacket___recv_from_socket(struct __pyx_obj_7cymysql_6packet_MysqlPacket *__pyx_v_self, int __pyx_v_size) {
  PyObject *__pyx_v_r = 0;
  PyObject *__pyx_v_recv_data = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__recv_from_socket", 0);

  /* "cymysql/packet.pyx":72
 *         cdef int recieved
 * 
 *         r = b''             # <<<<<<<<<<<<<<
 *         while size:
 *             recv_data = self._socket.recv(size)
 */
  __Pyx_INCREF(__pyx_kp_b_);
  __pyx_v_r = __pyx_kp_b_;

  /* "cymysql/packet.pyx":73
 * 
 *         r = b''
 *         while size:             # <<<<<<<<<<<<<<
 *             recv_data = self._socket.recv(size)
 *             if not recv_data:
 */
  while (1) {
    __pyx_t_1 = (__pyx_v_size != 0);
    if (!__pyx_t_1) break;

    /* "cymysql/packet.pyx":74
 *         r = b''
 *         while size:
 *             recv_data = self._socket.recv(size)             # <<<<<<<<<<<<<<
 *             if not recv_data:
 *                 break
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_socket, __pyx_n_s_recv); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 74; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_size); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 74; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    if (CYTHON_COMPILING_IN_CPYTHON && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (!__pyx_t_5) {
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 74; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else {
      __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 74; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5); __Pyx_GIVEREF(__pyx_t_5); __pyx_t_5 = NULL;
      PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_4);
      __pyx_t_4 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 74; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF_SET(__pyx_v_recv_data, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "cymysql/packet.pyx":75
 *         while size:
 *             recv_data = self._socket.recv(size)
 *             if not recv_data:             # <<<<<<<<<<<<<<
 *                 break
 *             size -= len(recv_data)
 */
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_recv_data); if (unlikely(__pyx_t_1 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 75; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_7 = ((!__pyx_t_1) != 0);
    if (__pyx_t_7) {

      /* "cymysql/packet.pyx":76
 *             recv_data = self._socket.recv(size)
 *             if not recv_data:
 *                 break             # <<<<<<<<<<<<<<
 *             size -= len(recv_data)
 *             r += recv_data
 */
      goto __pyx_L4_break;
    }

    /* "cymysql/packet.pyx":77
 *             if not recv_data:
 *                 break
 *             size -= len(recv_data)             # <<<<<<<<<<<<<<
 *             r += recv_data
 *         return r
 */
    __pyx_t_8 = PyObject_Length(__pyx_v_recv_data); if (unlikely(__pyx_t_8 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 77; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_v_size = (__pyx_v_size - __pyx_t_8);

    /* "cymysql/packet.pyx":78
 *                 break
 *             size -= len(recv_data)
 *             r += recv_data             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
    __pyx_t_2 = PyNumber_InPlaceAdd(__pyx_v_r, __pyx_v_recv_data); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 78; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    if (!(likely(PyBytes_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "bytes", Py_TYPE(__pyx_t_2)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 78; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF_SET(__pyx_v_r, ((PyObject*)__pyx_t_2));
    __pyx_t_2 = 0;
  }
  __pyx_L4_break:;

  /* "cymysql/packet.pyx":79
 *             size -= len(recv_data)
 *             r += recv_data
 *         return r             # <<<<<<<<<<<<<<
 * 
 *     cdef __recv_packet(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_r);
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "cymysql/packet.pyx":68
 *             raise_mysql_exception(self.__data)
 * 
 *     cdef bytes __recv_from_socket(self, int size):             # <<<<<<<<<<<<<<
 *         cdef bytes r
 *         cdef int recieved
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cymysql.packet.MysqlPacket.__recv_from_socket", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_r);
  __Pyx_XDECREF(__pyx_v_recv_data);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/packet.pyx":81
 *         return r
 * 
 *     cdef __recv_packet(self):             # <<<<<<<<<<<<<<
 *         """Parse the packet header and read entire packet payload into buffer."""
 *         cdef bytes packet_header, r, recv_data
 */

static PyObject *__pyx_f_7cymysql_6packet_11MysqlPacket___recv_packet(struct __pyx_obj_7cymysql_6packet_MysqlPacket *__pyx_v_self) {
  PyObject *__pyx_v_packet_header = 0;
  PyObject *__pyx_v_r = 0;
  PyObject *__pyx_v_recv_data = 0;
  int __pyx_v_size;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__recv_packet", 0);

  /* "cymysql/packet.pyx":85
 *         cdef bytes packet_header, r, recv_data
 *         cdef int size
 *         packet_header = self._socket.recv(4)             # <<<<<<<<<<<<<<
 *         if len(packet_header) < 4:
 *             raise OperationalError(2013, "Lost connection to MySQL server during query")
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_socket, __pyx_n_s_recv); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 85; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__2, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 85; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(PyBytes_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "bytes", Py_TYPE(__pyx_t_2)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 85; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_packet_header = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "cymysql/packet.pyx":86
 *         cdef int size
 *         packet_header = self._socket.recv(4)
 *         if len(packet_header) < 4:             # <<<<<<<<<<<<<<
 *             raise OperationalError(2013, "Lost connection to MySQL server during query")
 * 
 */
  if (unlikely(__pyx_v_packet_header == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 86; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_3 = PyBytes_GET_SIZE(__pyx_v_packet_header); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 86; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_4 = ((__pyx_t_3 < 4) != 0);
  if (__pyx_t_4) {

    /* "cymysql/packet.pyx":87
 *         packet_header = self._socket.recv(4)
 *         if len(packet_header) < 4:
 *             raise OperationalError(2013, "Lost connection to MySQL server during query")             # <<<<<<<<<<<<<<
 * 
 *         size = unpack_uint24(packet_header)
 */
    __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_OperationalError); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 87; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__3, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 87; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 87; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }

  /* "cymysql/packet.pyx":89
 *             raise OperationalError(2013, "Lost connection to MySQL server during query")
 * 
 *         size = unpack_uint24(packet_header)             # <<<<<<<<<<<<<<
 *         r = b''
 *         while size:
 */
  __pyx_v_size = __pyx_f_7cymysql_6packet_unpack_uint24(__pyx_v_packet_header);

  /* "cymysql/packet.pyx":90
 * 
 *         size = unpack_uint24(packet_header)
 *         r = b''             # <<<<<<<<<<<<<<
 *         while size:
 *             recv_data = self._socket.recv(size)
 */
  __Pyx_INCREF(__pyx_kp_b_);
  __pyx_v_r = __pyx_kp_b_;

  /* "cymysql/packet.pyx":91
 *         size = unpack_uint24(packet_header)
 *         r = b''
 *         while size:             # <<<<<<<<<<<<<<
 *             recv_data = self._socket.recv(size)
 *             if not recv_data:
 */
  while (1) {
    __pyx_t_4 = (__pyx_v_size != 0);
    if (!__pyx_t_4) break;

    /* "cymysql/packet.pyx":92
 *         r = b''
 *         while size:
 *             recv_data = self._socket.recv(size)             # <<<<<<<<<<<<<<
 *             if not recv_data:
 *                 raise OperationalError(2013, "Lost connection to MySQL server during query")
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_socket, __pyx_n_s_recv); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 92; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_size); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 92; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    if (CYTHON_COMPILING_IN_CPYTHON && likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_5); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 92; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 92; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __Pyx_GIVEREF(__pyx_t_6); __pyx_t_6 = NULL;
      PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_5);
      __pyx_t_5 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_7, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 92; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (!(likely(PyBytes_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "bytes", Py_TYPE(__pyx_t_1)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 92; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_XDECREF_SET(__pyx_v_recv_data, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "cymysql/packet.pyx":93
 *         while size:
 *             recv_data = self._socket.recv(size)
 *             if not recv_data:             # <<<<<<<<<<<<<<
 *                 raise OperationalError(2013, "Lost connection to MySQL server during query")
 *             size -= len(recv_data)
 */
    __pyx_t_4 = (__pyx_v_recv_data != Py_None) && (PyBytes_GET_SIZE(__pyx_v_recv_data) != 0);
    __pyx_t_8 = ((!__pyx_t_4) != 0);
    if (__pyx_t_8) {

      /* "cymysql/packet.pyx":94
 *             recv_data = self._socket.recv(size)
 *             if not recv_data:
 *                 raise OperationalError(2013, "Lost connection to MySQL server during query")             # <<<<<<<<<<<<<<
 *             size -= len(recv_data)
 *             r += recv_data
 */
      __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_OperationalError); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 94; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__4, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 94; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 94; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }

    /* "cymysql/packet.pyx":95
 *             if not recv_data:
 *                 raise OperationalError(2013, "Lost connection to MySQL server during query")
 *             size -= len(recv_data)             # <<<<<<<<<<<<<<
 *             r += recv_data
 *         self.__data = r
 */
    if (unlikely(__pyx_v_recv_data == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 95; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_3 = PyBytes_GET_SIZE(__pyx_v_recv_data); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 95; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_v_size = (__pyx_v_size - __pyx_t_3);

    /* "cymysql/packet.pyx":96
 *                 raise OperationalError(2013, "Lost connection to MySQL server during query")
 *             size -= len(recv_data)
 *             r += recv_data             # <<<<<<<<<<<<<<
 *         self.__data = r
 * 
 */
    __pyx_t_2 = PyNumber_InPlaceAdd(__pyx_v_r, __pyx_v_recv_data); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 96; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF_SET(__pyx_v_r, ((PyObject*)__pyx_t_2));
    __pyx_t_2 = 0;
  }

  /* "cymysql/packet.pyx":97
 *             size -= len(recv_data)
 *             r += recv_data
 *         self.__data = r             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_INCREF(__pyx_v_r);
  __Pyx_GIVEREF(__pyx_v_r);
  __Pyx_GOTREF(__pyx_v_self->__pyx___data);
  __Pyx_DECREF(__pyx_v_self->__pyx___data);
  __pyx_v_self->__pyx___data = __pyx_v_r;

  /* "cymysql/packet.pyx":81
 *         return r
 * 
 *     cdef __recv_packet(self):             # <<<<<<<<<<<<<<
 *         """Parse the packet header and read entire packet payload into buffer."""
 *         cdef bytes packet_header, r, recv_data
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cymysql.packet.MysqlPacket.__recv_packet", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_packet_header);
  __Pyx_XDECREF(__pyx_v_r);
  __Pyx_XDECREF(__pyx_v_recv_data);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/packet.pyx":100
 * 
 * 
 *     def get_all_data(self): return self.__data             # <<<<<<<<<<<<<<
 * 
 *     cpdef read(self, size):
 */

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_6packet_11MysqlPacket_3get_all_data(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_7cymysql_6packet_11MysqlPacket_3get_all_data(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_all_data (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_11MysqlPacket_2get_all_data(((struct __pyx_obj_7cymysql_6packet_MysqlPacket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_6packet_11MysqlPacket_2get_all_data(struct __pyx_obj_7cymysql_6packet_MysqlPacket *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_all_data", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->__pyx___data);
  __pyx_r = __pyx_v_self->__pyx___data;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/packet.pyx":102
 *     def get_all_data(self): return self.__data
 * 
 *     cpdef read(self, size):             # <<<<<<<<<<<<<<
 *         return self._read(size)
 * 
 */

static PyObject *__pyx_pw_7cymysql_6packet_11MysqlPacket_5read(PyObject *__pyx_v_self, PyObject *__pyx_v_size); /*proto*/
static PyObject *__pyx_f_7cymysql_6packet_11MysqlPacket_read(struct __pyx_obj_7cymysql_6packet_MysqlPacket *__pyx_v_self, PyObject *__pyx_v_size, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("read", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0)) {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_read); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 102; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)__pyx_pw_7cymysql_6packet_11MysqlPacket_5read)) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
      if (CYTHON_COMPILING_IN_CPYTHON && unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      if (!__pyx_t_4) {
        __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_size); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 102; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_2);
      } else {
        __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 102; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __Pyx_GIVEREF(__pyx_t_4); __pyx_t_4 = NULL;
        __Pyx_INCREF(__pyx_v_size);
        PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_v_size);
        __Pyx_GIVEREF(__pyx_v_size);
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 102; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "cymysql/packet.pyx":103
 * 
 *     cpdef read(self, size):
 *         return self._read(size)             # <<<<<<<<<<<<<<
 * 
 *     cdef bytes _read(self, int size):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = __Pyx_PyInt_As_int(__pyx_v_size); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 103; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_6packet_MysqlPacket *)__pyx_v_self->__pyx_vtab)->_read(__pyx_v_self, __pyx_t_6); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 103; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cymysql/packet.pyx":102
 *     def get_all_data(self): return self.__data
 * 
 *     cpdef read(self, size):             # <<<<<<<<<<<<<<
 *         return self._read(size)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cymysql.packet.MysqlPacket.read", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_6packet_11MysqlPacket_5read(PyObject *__pyx_v_self, PyObject *__pyx_v_size); /*proto*/
static PyObject *__pyx_pw_7cymysql_6packet_11MysqlPacket_5read(PyObject *__pyx_v_self, PyObject *__pyx_v_size) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("read (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_11MysqlPacket_4read(((struct __pyx_obj_7cymysql_6packet_MysqlPacket *)__pyx_v_self), ((PyObject *)__pyx_v_size));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_6packet_11MysqlPacket_4read(struct __pyx_obj_7cymysql_6packet_MysqlPacket *__pyx_v_self, PyObject *__pyx_v_size) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("read", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_7cymysql_6packet_11MysqlPacket_read(__pyx_v_self, __pyx_v_size, 1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 102; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cymysql.packet.MysqlPacket.read", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/packet.pyx":105
 *         return self._read(size)
 * 
 *     cdef bytes _read(self, int size):             # <<<<<<<<<<<<<<
 *         """Read the first 'size' bytes in packet and advance cursor past them."""
 *         self.__position += size
 */

static PyObject *__pyx_f_7cymysql_6packet_11MysqlPacket__read(struct __pyx_obj_7cymysql_6packet_MysqlPacket *__pyx_v_self, int __pyx_v_size) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_read", 0);

  /* "cymysql/packet.pyx":107
 *     cdef bytes _read(self, int size):
 *         """Read the first 'size' bytes in packet and advance cursor past them."""
 *         self.__position += size             # <<<<<<<<<<<<<<
 *         return self.__data[self.__position-size:self.__position]
 * 
 */
  __pyx_v_self->__pyx___position = (__pyx_v_self->__pyx___position + __pyx_v_size);

  /* "cymysql/packet.pyx":108
 *         """Read the first 'size' bytes in packet and advance cursor past them."""
 *         self.__position += size
 *         return self.__data[self.__position-size:self.__position]             # <<<<<<<<<<<<<<
 * 
 *     cdef void _skip(self, int size):
 */
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(__pyx_v_self->__pyx___data == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 108; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = PySequence_GetSlice(__pyx_v_self->__pyx___data, (__pyx_v_self->__pyx___position - __pyx_v_size), __pyx_v_self->__pyx___position); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 108; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cymysql/packet.pyx":105
 *         return self._read(size)
 * 
 *     cdef bytes _read(self, int size):             # <<<<<<<<<<<<<<
 *         """Read the first 'size' bytes in packet and advance cursor past them."""
 *         self.__position += size
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cymysql.packet.MysqlPacket._read", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/packet.pyx":110
 *         return self.__data[self.__position-size:self.__position]
 * 
 *     cdef void _skip(self, int size):             # <<<<<<<<<<<<<<
 *         """Read the first 'size' bytes in packet and advance cursor past them."""
 *         self.__position += size
 */

static void __pyx_f_7cymysql_6packet_11MysqlPacket__skip(struct __pyx_obj_7cymysql_6packet_MysqlPacket *__pyx_v_self, int __pyx_v_size) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_skip", 0);

  /* "cymysql/packet.pyx":112
 *     cdef void _skip(self, int size):
 *         """Read the first 'size' bytes in packet and advance cursor past them."""
 *         self.__position += size             # <<<<<<<<<<<<<<
 * 
 *     cdef _read_all(self):
 */
  __pyx_v_self->__pyx___position = (__pyx_v_self->__pyx___position + __pyx_v_size);

  /* "cymysql/packet.pyx":110
 *         return self.__data[self.__position-size:self.__position]
 * 
 *     cdef void _skip(self, int size):             # <<<<<<<<<<<<<<
 *         """Read the first 'size' bytes in packet and advance cursor past them."""
 *         self.__position += size
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

/* "cymysql/packet.pyx":114
 *         self.__position += size
 * 
 *     cdef _read_all(self):             # <<<<<<<<<<<<<<
 *         """Read all remaining data in the packet.
 * 
 */

static PyObject *__pyx_f_7cymysql_6packet_11MysqlPacket__read_all(struct __pyx_obj_7cymysql_6packet_MysqlPacket *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_read_all", 0);

  /* "cymysql/packet.pyx":119
 *         (Subsequent read() or peek() will return errors.)
 *         """
 *         self.__position = -1  # ensure no subsequent read() or peek()             # <<<<<<<<<<<<<<
 *         return self.__data[self.__position:]
 * 
 */
  __pyx_v_self->__pyx___position = -1;

  /* "cymysql/packet.pyx":120
 *         """
 *         self.__position = -1  # ensure no subsequent read() or peek()
 *         return self.__data[self.__position:]             # <<<<<<<<<<<<<<
 * 
 *     cdef int read_length_coded_binary(self):
 */
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(__pyx_v_self->__pyx___data == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 120; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = PySequence_GetSlice(__pyx_v_self->__pyx___data, __pyx_v_self->__pyx___position, PY_SSIZE_T_MAX); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 120; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cymysql/packet.pyx":114
 *         self.__position += size
 * 
 *     cdef _read_all(self):             # <<<<<<<<<<<<<<
 *         """Read all remaining data in the packet.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cymysql.packet.MysqlPacket._read_all", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/packet.pyx":122
 *         return self.__data[self.__position:]
 * 
 *     cdef int read_length_coded_binary(self):             # <<<<<<<<<<<<<<
 *         """Read a 'Length Coded Binary' number from the data buffer.
 * 
 */

static int __pyx_f_7cymysql_6packet_11MysqlPacket_read_length_coded_binary(struct __pyx_obj_7cymysql_6packet_MysqlPacket *__pyx_v_self) {
  unsigned char __pyx_v_c;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  char __pyx_t_2;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("read_length_coded_binary", 0);

  /* "cymysql/packet.pyx":128
 *         on the value of the first byte.
 *         """
 *         cdef unsigned char c = self._read(1)[0]             # <<<<<<<<<<<<<<
 *         if c == UNSIGNED_CHAR_COLUMN:
 *             return -1
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_6packet_MysqlPacket *)__pyx_v_self->__pyx_vtab)->_read(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 128; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely(__pyx_t_1 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 128; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_2 = __Pyx_PyBytes_GetItemInt(((PyObject*)__pyx_t_1), 0, 1); if (unlikely(__pyx_t_2 == ((char)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 128; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_c = __pyx_t_2;

  /* "cymysql/packet.pyx":129
 *         """
 *         cdef unsigned char c = self._read(1)[0]
 *         if c == UNSIGNED_CHAR_COLUMN:             # <<<<<<<<<<<<<<
 *             return -1
 *         elif c == UNSIGNED_SHORT_COLUMN:
 */
  __pyx_t_3 = ((__pyx_v_c == __pyx_v_7cymysql_6packet_UNSIGNED_CHAR_COLUMN) != 0);
  if (__pyx_t_3) {

    /* "cymysql/packet.pyx":130
 *         cdef unsigned char c = self._read(1)[0]
 *         if c == UNSIGNED_CHAR_COLUMN:
 *             return -1             # <<<<<<<<<<<<<<
 *         elif c == UNSIGNED_SHORT_COLUMN:
 *             return unpack_uint16(self._read(2))
 */
    __pyx_r = -1;
    goto __pyx_L0;
  }

  /* "cymysql/packet.pyx":131
 *         if c == UNSIGNED_CHAR_COLUMN:
 *             return -1
 *         elif c == UNSIGNED_SHORT_COLUMN:             # <<<<<<<<<<<<<<
 *             return unpack_uint16(self._read(2))
 *         elif c == UNSIGNED_INT24_COLUMN:
 */
  __pyx_t_3 = ((__pyx_v_c == __pyx_v_7cymysql_6packet_UNSIGNED_SHORT_COLUMN) != 0);
  if (__pyx_t_3) {

    /* "cymysql/packet.pyx":132
 *             return -1
 *         elif c == UNSIGNED_SHORT_COLUMN:
 *             return unpack_uint16(self._read(2))             # <<<<<<<<<<<<<<
 *         elif c == UNSIGNED_INT24_COLUMN:
 *             return unpack_uint24(self._read(3))
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_6packet_MysqlPacket *)__pyx_v_self->__pyx_vtab)->_read(__pyx_v_self, 2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 132; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_f_7cymysql_6packet_unpack_uint16(((PyObject*)__pyx_t_1));
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L0;
  }

  /* "cymysql/packet.pyx":133
 *         elif c == UNSIGNED_SHORT_COLUMN:
 *             return unpack_uint16(self._read(2))
 *         elif c == UNSIGNED_INT24_COLUMN:             # <<<<<<<<<<<<<<
 *             return unpack_uint24(self._read(3))
 *         elif c == UNSIGNED_INT64_COLUMN:
 */
  __pyx_t_3 = ((__pyx_v_c == __pyx_v_7cymysql_6packet_UNSIGNED_INT24_COLUMN) != 0);
  if (__pyx_t_3) {

    /* "cymysql/packet.pyx":134
 *             return unpack_uint16(self._read(2))
 *         elif c == UNSIGNED_INT24_COLUMN:
 *             return unpack_uint24(self._read(3))             # <<<<<<<<<<<<<<
 *         elif c == UNSIGNED_INT64_COLUMN:
 *             return unpack_uint64(self._read(8))
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_6packet_MysqlPacket *)__pyx_v_self->__pyx_vtab)->_read(__pyx_v_self, 3); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 134; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_f_7cymysql_6packet_unpack_uint24(((PyObject*)__pyx_t_1));
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L0;
  }

  /* "cymysql/packet.pyx":135
 *         elif c == UNSIGNED_INT24_COLUMN:
 *             return unpack_uint24(self._read(3))
 *         elif c == UNSIGNED_INT64_COLUMN:             # <<<<<<<<<<<<<<
 *             return unpack_uint64(self._read(8))
 *         else:
 */
  __pyx_t_3 = ((__pyx_v_c == __pyx_v_7cymysql_6packet_UNSIGNED_INT64_COLUMN) != 0);
  if (__pyx_t_3) {

    /* "cymysql/packet.pyx":136
 *             return unpack_uint24(self._read(3))
 *         elif c == UNSIGNED_INT64_COLUMN:
 *             return unpack_uint64(self._read(8))             # <<<<<<<<<<<<<<
 *         else:
 *             return c
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_6packet_MysqlPacket *)__pyx_v_self->__pyx_vtab)->_read(__pyx_v_self, 8); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 136; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_f_7cymysql_6packet_unpack_uint64(((PyObject*)__pyx_t_1));
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L0;
  }
  /*else*/ {

    /* "cymysql/packet.pyx":138
 *             return unpack_uint64(self._read(8))
 *         else:
 *             return c             # <<<<<<<<<<<<<<
 * 
 *     cdef bytes _read_length_coded_string(self):
 */
    __pyx_r = __pyx_v_c;
    goto __pyx_L0;
  }

  /* "cymysql/packet.pyx":122
 *         return self.__data[self.__position:]
 * 
 *     cdef int read_length_coded_binary(self):             # <<<<<<<<<<<<<<
 *         """Read a 'Length Coded Binary' number from the data buffer.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_WriteUnraisable("cymysql.packet.MysqlPacket.read_length_coded_binary", __pyx_clineno, __pyx_lineno, __pyx_filename, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/packet.pyx":140
 *             return c
 * 
 *     cdef bytes _read_length_coded_string(self):             # <<<<<<<<<<<<<<
 *         """Read a 'Length Coded String' from the data buffer.
 * 
 */

static PyObject *__pyx_f_7cymysql_6packet_11MysqlPacket__read_length_coded_string(struct __pyx_obj_7cymysql_6packet_MysqlPacket *__pyx_v_self) {
  int __pyx_v_length;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_read_length_coded_string", 0);

  /* "cymysql/packet.pyx":148
 *         """
 *         cdef int length
 *         length = self.read_length_coded_binary()             # <<<<<<<<<<<<<<
 *         if length < 0:
 *             return None
 */
  __pyx_v_length = ((struct __pyx_vtabstruct_7cymysql_6packet_MysqlPacket *)__pyx_v_self->__pyx_vtab)->read_length_coded_binary(__pyx_v_self);

  /* "cymysql/packet.pyx":149
 *         cdef int length
 *         length = self.read_length_coded_binary()
 *         if length < 0:             # <<<<<<<<<<<<<<
 *             return None
 *         return self._read(length)
 */
  __pyx_t_1 = ((__pyx_v_length < 0) != 0);
  if (__pyx_t_1) {

    /* "cymysql/packet.pyx":150
 *         length = self.read_length_coded_binary()
 *         if length < 0:
 *             return None             # <<<<<<<<<<<<<<
 *         return self._read(length)
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_None);
    __pyx_r = ((PyObject*)Py_None);
    goto __pyx_L0;
  }

  /* "cymysql/packet.pyx":151
 *         if length < 0:
 *             return None
 *         return self._read(length)             # <<<<<<<<<<<<<<
 * 
 *     cdef read_decode_data(self, fields, decoders):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_6packet_MysqlPacket *)__pyx_v_self->__pyx_vtab)->_read(__pyx_v_self, __pyx_v_length); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 151; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cymysql/packet.pyx":140
 *             return c
 * 
 *     cdef bytes _read_length_coded_string(self):             # <<<<<<<<<<<<<<
 *         """Read a 'Length Coded String' from the data buffer.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cymysql.packet.MysqlPacket._read_length_coded_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/packet.pyx":153
 *         return self._read(length)
 * 
 *     cdef read_decode_data(self, fields, decoders):             # <<<<<<<<<<<<<<
 *         return tuple([
 *             None if value is None
 */

static PyObject *__pyx_f_7cymysql_6packet_11MysqlPacket_read_decode_data(struct __pyx_obj_7cymysql_6packet_MysqlPacket *__pyx_v_self, PyObject *__pyx_v_fields, PyObject *__pyx_v_decoders) {
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_v_field = NULL;
  PyObject *__pyx_v_decoder = NULL;
  PyObject *__pyx_v_f = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *(*__pyx_t_12)(PyObject *);
  int __pyx_t_13;
  int __pyx_t_14;
  Py_ssize_t __pyx_t_15;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("read_decode_data", 0);

  /* "cymysql/packet.pyx":154
 * 
 *     cdef read_decode_data(self, fields, decoders):
 *         return tuple([             # <<<<<<<<<<<<<<
 *             None if value is None
 *             else decoder(value, self._charset, field, self._use_unicode)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 154; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);

  /* "cymysql/packet.pyx":159
 *                 if decoder is convert_characters
 *                 else decoder(value)
 *             for value, field, decoder in [(self._read_length_coded_string(), f, decoders.get(f.type_code)) for f in fields]             # <<<<<<<<<<<<<<
 *         ])
 * 
 */
  __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 159; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (likely(PyList_CheckExact(__pyx_v_fields)) || PyTuple_CheckExact(__pyx_v_fields)) {
    __pyx_t_3 = __pyx_v_fields; __Pyx_INCREF(__pyx_t_3); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_v_fields); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 159; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = Py_TYPE(__pyx_t_3)->tp_iternext; if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 159; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  for (;;) {
    if (likely(!__pyx_t_5)) {
      if (likely(PyList_CheckExact(__pyx_t_3))) {
        if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_3)) break;
        #if CYTHON_COMPILING_IN_CPYTHON
        __pyx_t_6 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_6); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 159; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #else
        __pyx_t_6 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 159; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #endif
      } else {
        if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
        #if CYTHON_COMPILING_IN_CPYTHON
        __pyx_t_6 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_6); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 159; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #else
        __pyx_t_6 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 159; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #endif
      }
    } else {
      __pyx_t_6 = __pyx_t_5(__pyx_t_3);
      if (unlikely(!__pyx_t_6)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 159; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_6);
    }
    __Pyx_XDECREF_SET(__pyx_v_f, __pyx_t_6);
    __pyx_t_6 = 0;
    __pyx_t_6 = ((struct __pyx_vtabstruct_7cymysql_6packet_MysqlPacket *)__pyx_v_self->__pyx_vtab)->_read_length_coded_string(__pyx_v_self); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 159; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_decoders, __pyx_n_s_get); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 159; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_f, __pyx_n_s_type_code); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 159; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_10 = NULL;
    if (CYTHON_COMPILING_IN_CPYTHON && likely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_10)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
      }
    }
    if (!__pyx_t_10) {
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_9); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 159; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_GOTREF(__pyx_t_7);
    } else {
      __pyx_t_11 = PyTuple_New(1+1); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 159; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_11);
      PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_10); __Pyx_GIVEREF(__pyx_t_10); __pyx_t_10 = NULL;
      PyTuple_SET_ITEM(__pyx_t_11, 0+1, __pyx_t_9);
      __Pyx_GIVEREF(__pyx_t_9);
      __pyx_t_9 = 0;
      __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 159; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    }
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = PyTuple_New(3); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 159; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_8);
    PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    __Pyx_INCREF(__pyx_v_f);
    PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_v_f);
    __Pyx_GIVEREF(__pyx_v_f);
    PyTuple_SET_ITEM(__pyx_t_8, 2, __pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_7);
    __pyx_t_6 = 0;
    __pyx_t_7 = 0;
    if (unlikely(__Pyx_ListComp_Append(__pyx_t_2, (PyObject*)__pyx_t_8))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 159; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __pyx_t_2; __Pyx_INCREF(__pyx_t_3); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_3)) break;
    #if CYTHON_COMPILING_IN_CPYTHON
    __pyx_t_2 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 159; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    #else
    __pyx_t_2 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 159; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    #endif
    if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
      PyObject* sequence = __pyx_t_2;
      #if CYTHON_COMPILING_IN_CPYTHON
      Py_ssize_t size = Py_SIZE(sequence);
      #else
      Py_ssize_t size = PySequence_Size(sequence);
      #endif
      if (unlikely(size != 3)) {
        if (size > 3) __Pyx_RaiseTooManyValuesError(3);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 159; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      #if CYTHON_COMPILING_IN_CPYTHON
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_8 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_7 = PyTuple_GET_ITEM(sequence, 1); 
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 2); 
      } else {
        __pyx_t_8 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_7 = PyList_GET_ITEM(sequence, 1); 
        __pyx_t_6 = PyList_GET_ITEM(sequence, 2); 
      }
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_6);
      #else
      __pyx_t_8 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 159; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_7 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 159; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_6 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 159; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      #endif
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_11 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 159; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_12 = Py_TYPE(__pyx_t_11)->tp_iternext;
      index = 0; __pyx_t_8 = __pyx_t_12(__pyx_t_11); if (unlikely(!__pyx_t_8)) goto __pyx_L7_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_8);
      index = 1; __pyx_t_7 = __pyx_t_12(__pyx_t_11); if (unlikely(!__pyx_t_7)) goto __pyx_L7_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_7);
      index = 2; __pyx_t_6 = __pyx_t_12(__pyx_t_11); if (unlikely(!__pyx_t_6)) goto __pyx_L7_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_12(__pyx_t_11), 3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 159; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_12 = NULL;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      goto __pyx_L8_unpacking_done;
      __pyx_L7_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_12 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 159; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_L8_unpacking_done:;
    }
    __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_8);
    __pyx_t_8 = 0;
    __Pyx_XDECREF_SET(__pyx_v_field, __pyx_t_7);
    __pyx_t_7 = 0;
    __Pyx_XDECREF_SET(__pyx_v_decoder, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "cymysql/packet.pyx":155
 *     cdef read_decode_data(self, fields, decoders):
 *         return tuple([
 *             None if value is None             # <<<<<<<<<<<<<<
 *             else decoder(value, self._charset, field, self._use_unicode)
 *                 if decoder is convert_characters
 */
    __pyx_t_13 = (__pyx_v_value == Py_None);
    if ((__pyx_t_13 != 0)) {
      __Pyx_INCREF(Py_None);
      __pyx_t_2 = Py_None;
    } else {

      /* "cymysql/packet.pyx":158
 *             else decoder(value, self._charset, field, self._use_unicode)
 *                 if decoder is convert_characters
 *                 else decoder(value)             # <<<<<<<<<<<<<<
 *             for value, field, decoder in [(self._read_length_coded_string(), f, decoders.get(f.type_code)) for f in fields]
 *         ])
 */
      __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_convert_characters); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 158; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_14 = (__pyx_v_decoder == __pyx_t_7);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "cymysql/packet.pyx":157
 *             None if value is None
 *             else decoder(value, self._charset, field, self._use_unicode)
 *                 if decoder is convert_characters             # <<<<<<<<<<<<<<
 *                 else decoder(value)
 *             for value, field, decoder in [(self._read_length_coded_string(), f, decoders.get(f.type_code)) for f in fields]
 */
      if ((__pyx_t_14 != 0)) {

        /* "cymysql/packet.pyx":156
 *         return tuple([
 *             None if value is None
 *             else decoder(value, self._charset, field, self._use_unicode)             # <<<<<<<<<<<<<<
 *                 if decoder is convert_characters
 *                 else decoder(value)
 */
        __Pyx_INCREF(__pyx_v_decoder);
        __pyx_t_8 = __pyx_v_decoder; __pyx_t_11 = NULL;
        __pyx_t_15 = 0;
        if (CYTHON_COMPILING_IN_CPYTHON && unlikely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_8);
          if (likely(__pyx_t_11)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
            __Pyx_INCREF(__pyx_t_11);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_8, function);
            __pyx_t_15 = 1;
          }
        }
        __pyx_t_9 = PyTuple_New(4+__pyx_t_15); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 156; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_9);
        if (__pyx_t_11) {
          PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_11); __Pyx_GIVEREF(__pyx_t_11); __pyx_t_11 = NULL;
        }
        __Pyx_INCREF(__pyx_v_value);
        PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_15, __pyx_v_value);
        __Pyx_GIVEREF(__pyx_v_value);
        __Pyx_INCREF(__pyx_v_self->_charset);
        PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_15, __pyx_v_self->_charset);
        __Pyx_GIVEREF(__pyx_v_self->_charset);
        __Pyx_INCREF(__pyx_v_field);
        PyTuple_SET_ITEM(__pyx_t_9, 2+__pyx_t_15, __pyx_v_field);
        __Pyx_GIVEREF(__pyx_v_field);
        __Pyx_INCREF(__pyx_v_self->_use_unicode);
        PyTuple_SET_ITEM(__pyx_t_9, 3+__pyx_t_15, __pyx_v_self->_use_unicode);
        __Pyx_GIVEREF(__pyx_v_self->_use_unicode);
        __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_9, NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 156; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_6 = __pyx_t_7;
        __pyx_t_7 = 0;
      } else {

        /* "cymysql/packet.pyx":158
 *             else decoder(value, self._charset, field, self._use_unicode)
 *                 if decoder is convert_characters
 *                 else decoder(value)             # <<<<<<<<<<<<<<
 *             for value, field, decoder in [(self._read_length_coded_string(), f, decoders.get(f.type_code)) for f in fields]
 *         ])
 */
        __Pyx_INCREF(__pyx_v_decoder);
        __pyx_t_8 = __pyx_v_decoder; __pyx_t_9 = NULL;
        if (CYTHON_COMPILING_IN_CPYTHON && unlikely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
          if (likely(__pyx_t_9)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
            __Pyx_INCREF(__pyx_t_9);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_8, function);
          }
        }
        if (!__pyx_t_9) {
          __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_v_value); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 158; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_7);
        } else {
          __pyx_t_11 = PyTuple_New(1+1); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 158; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_11);
          PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __Pyx_GIVEREF(__pyx_t_9); __pyx_t_9 = NULL;
          __Pyx_INCREF(__pyx_v_value);
          PyTuple_SET_ITEM(__pyx_t_11, 0+1, __pyx_v_value);
          __Pyx_GIVEREF(__pyx_v_value);
          __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 158; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        }
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_6 = __pyx_t_7;
        __pyx_t_7 = 0;
      }
      __pyx_t_2 = __pyx_t_6;
      __pyx_t_6 = 0;
    }
    if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_2))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 154; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "cymysql/packet.pyx":159
 *                 if decoder is convert_characters
 *                 else decoder(value)
 *             for value, field, decoder in [(self._read_length_coded_string(), f, decoders.get(f.type_code)) for f in fields]             # <<<<<<<<<<<<<<
 *         ])
 * 
 */
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/packet.pyx":154
 * 
 *     cdef read_decode_data(self, fields, decoders):
 *         return tuple([             # <<<<<<<<<<<<<<
 *             None if value is None
 *             else decoder(value, self._charset, field, self._use_unicode)
 */
  __pyx_t_3 = PyList_AsTuple(((PyObject*)__pyx_t_1)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 154; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "cymysql/packet.pyx":153
 *         return self._read(length)
 * 
 *     cdef read_decode_data(self, fields, decoders):             # <<<<<<<<<<<<<<
 *         return tuple([
 *             None if value is None
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("cymysql.packet.MysqlPacket.read_decode_data", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_field);
  __Pyx_XDECREF(__pyx_v_decoder);
  __Pyx_XDECREF(__pyx_v_f);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/packet.pyx":162
 *         ])
 * 
 *     cpdef is_ok_packet(self):             # <<<<<<<<<<<<<<
 *         return (<unsigned char>(self.__data[0])) == 0
 * 
 */

static PyObject *__pyx_pw_7cymysql_6packet_11MysqlPacket_7is_ok_packet(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_7cymysql_6packet_11MysqlPacket_is_ok_packet(struct __pyx_obj_7cymysql_6packet_MysqlPacket *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  char __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_ok_packet", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0)) {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_is_ok_packet); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 162; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)__pyx_pw_7cymysql_6packet_11MysqlPacket_7is_ok_packet)) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
      if (CYTHON_COMPILING_IN_CPYTHON && unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      if (__pyx_t_4) {
        __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 162; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else {
        __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 162; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "cymysql/packet.pyx":163
 * 
 *     cpdef is_ok_packet(self):
 *         return (<unsigned char>(self.__data[0])) == 0             # <<<<<<<<<<<<<<
 * 
 *     cpdef is_eof_packet(self):
 */
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(__pyx_v_self->__pyx___data == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 163; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_5 = __Pyx_PyBytes_GetItemInt(__pyx_v_self->__pyx___data, 0, 1); if (unlikely(__pyx_t_5 == ((char)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 163; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_1 = __Pyx_PyBool_FromLong((((unsigned char)__pyx_t_5) == 0)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 163; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cymysql/packet.pyx":162
 *         ])
 * 
 *     cpdef is_ok_packet(self):             # <<<<<<<<<<<<<<
 *         return (<unsigned char>(self.__data[0])) == 0
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cymysql.packet.MysqlPacket.is_ok_packet", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_6packet_11MysqlPacket_7is_ok_packet(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_7cymysql_6packet_11MysqlPacket_7is_ok_packet(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_ok_packet (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_11MysqlPacket_6is_ok_packet(((struct __pyx_obj_7cymysql_6packet_MysqlPacket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_6packet_11MysqlPacket_6is_ok_packet(struct __pyx_obj_7cymysql_6packet_MysqlPacket *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_ok_packet", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_7cymysql_6packet_11MysqlPacket_is_ok_packet(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 162; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cymysql.packet.MysqlPacket.is_ok_packet", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/packet.pyx":165
 *         return (<unsigned char>(self.__data[0])) == 0
 * 
 *     cpdef is_eof_packet(self):             # <<<<<<<<<<<<<<
 *         return (<unsigned char>(self.__data[0])) == 0xfe
 * 
 */

static PyObject *__pyx_pw_7cymysql_6packet_11MysqlPacket_9is_eof_packet(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_7cymysql_6packet_11MysqlPacket_is_eof_packet(struct __pyx_obj_7cymysql_6packet_MysqlPacket *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  char __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_eof_packet", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0)) {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_is_eof_packet); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 165; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)__pyx_pw_7cymysql_6packet_11MysqlPacket_9is_eof_packet)) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
      if (CYTHON_COMPILING_IN_CPYTHON && unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      if (__pyx_t_4) {
        __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 165; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else {
        __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 165; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "cymysql/packet.pyx":166
 * 
 *     cpdef is_eof_packet(self):
 *         return (<unsigned char>(self.__data[0])) == 0xfe             # <<<<<<<<<<<<<<
 * 
 *     cpdef is_eof_and_status(self):
 */
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(__pyx_v_self->__pyx___data == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 166; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_5 = __Pyx_PyBytes_GetItemInt(__pyx_v_self->__pyx___data, 0, 1); if (unlikely(__pyx_t_5 == ((char)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 166; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_1 = __Pyx_PyBool_FromLong((((unsigned char)__pyx_t_5) == 0xfe)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 166; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cymysql/packet.pyx":165
 *         return (<unsigned char>(self.__data[0])) == 0
 * 
 *     cpdef is_eof_packet(self):             # <<<<<<<<<<<<<<
 *         return (<unsigned char>(self.__data[0])) == 0xfe
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cymysql.packet.MysqlPacket.is_eof_packet", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_6packet_11MysqlPacket_9is_eof_packet(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_7cymysql_6packet_11MysqlPacket_9is_eof_packet(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_eof_packet (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_11MysqlPacket_8is_eof_packet(((struct __pyx_obj_7cymysql_6packet_MysqlPacket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_6packet_11MysqlPacket_8is_eof_packet(struct __pyx_obj_7cymysql_6packet_MysqlPacket *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_eof_packet", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_7cymysql_6packet_11MysqlPacket_is_eof_packet(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 165; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cymysql.packet.MysqlPacket.is_eof_packet", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/packet.pyx":168
 *         return (<unsigned char>(self.__data[0])) == 0xfe
 * 
 *     cpdef is_eof_and_status(self):             # <<<<<<<<<<<<<<
 *         if (<unsigned char>(self.__data[0])) != 0xfe:
 *            return False, 0, 0
 */

static PyObject *__pyx_pw_7cymysql_6packet_11MysqlPacket_11is_eof_and_status(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_7cymysql_6packet_11MysqlPacket_is_eof_and_status(struct __pyx_obj_7cymysql_6packet_MysqlPacket *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  char __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_eof_and_status", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0)) {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_is_eof_and_status); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 168; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)__pyx_pw_7cymysql_6packet_11MysqlPacket_11is_eof_and_status)) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
      if (CYTHON_COMPILING_IN_CPYTHON && unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      if (__pyx_t_4) {
        __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 168; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else {
        __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 168; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "cymysql/packet.pyx":169
 * 
 *     cpdef is_eof_and_status(self):
 *         if (<unsigned char>(self.__data[0])) != 0xfe:             # <<<<<<<<<<<<<<
 *            return False, 0, 0
 *         return True, unpack_uint16(self._read(2)), unpack_uint16(self._read(2))
 */
  if (unlikely(__pyx_v_self->__pyx___data == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 169; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_5 = __Pyx_PyBytes_GetItemInt(__pyx_v_self->__pyx___data, 0, 1); if (unlikely(__pyx_t_5 == ((char)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 169; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_6 = ((((unsigned char)__pyx_t_5) != 0xfe) != 0);
  if (__pyx_t_6) {

    /* "cymysql/packet.pyx":170
 *     cpdef is_eof_and_status(self):
 *         if (<unsigned char>(self.__data[0])) != 0xfe:
 *            return False, 0, 0             # <<<<<<<<<<<<<<
 *         return True, unpack_uint16(self._read(2)), unpack_uint16(self._read(2))
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_tuple__5);
    __pyx_r = __pyx_tuple__5;
    goto __pyx_L0;
  }

  /* "cymysql/packet.pyx":171
 *         if (<unsigned char>(self.__data[0])) != 0xfe:
 *            return False, 0, 0
 *         return True, unpack_uint16(self._read(2)), unpack_uint16(self._read(2))             # <<<<<<<<<<<<<<
 * 
 *     cpdef read_ok_packet(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_6packet_MysqlPacket *)__pyx_v_self->__pyx_vtab)->_read(__pyx_v_self, 2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 171; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_From_uint16_t(__pyx_f_7cymysql_6packet_unpack_uint16(((PyObject*)__pyx_t_1))); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 171; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_6packet_MysqlPacket *)__pyx_v_self->__pyx_vtab)->_read(__pyx_v_self, 2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 171; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyInt_From_uint16_t(__pyx_f_7cymysql_6packet_unpack_uint16(((PyObject*)__pyx_t_1))); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 171; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 171; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(Py_True);
  PyTuple_SET_ITEM(__pyx_t_1, 0, Py_True);
  __Pyx_GIVEREF(Py_True);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cymysql/packet.pyx":168
 *         return (<unsigned char>(self.__data[0])) == 0xfe
 * 
 *     cpdef is_eof_and_status(self):             # <<<<<<<<<<<<<<
 *         if (<unsigned char>(self.__data[0])) != 0xfe:
 *            return False, 0, 0
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cymysql.packet.MysqlPacket.is_eof_and_status", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_6packet_11MysqlPacket_11is_eof_and_status(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_7cymysql_6packet_11MysqlPacket_11is_eof_and_status(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_eof_and_status (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_11MysqlPacket_10is_eof_and_status(((struct __pyx_obj_7cymysql_6packet_MysqlPacket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_6packet_11MysqlPacket_10is_eof_and_status(struct __pyx_obj_7cymysql_6packet_MysqlPacket *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_eof_and_status", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_7cymysql_6packet_11MysqlPacket_is_eof_and_status(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 168; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cymysql.packet.MysqlPacket.is_eof_and_status", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/packet.pyx":173
 *         return True, unpack_uint16(self._read(2)), unpack_uint16(self._read(2))
 * 
 *     cpdef read_ok_packet(self):             # <<<<<<<<<<<<<<
 *         cdef int affected_rows, insert_id, server_status, warning_count
 *         cdef message
 */

static PyObject *__pyx_pw_7cymysql_6packet_11MysqlPacket_13read_ok_packet(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_7cymysql_6packet_11MysqlPacket_read_ok_packet(struct __pyx_obj_7cymysql_6packet_MysqlPacket *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_v_affected_rows;
  int __pyx_v_insert_id;
  int __pyx_v_server_status;
  int __pyx_v_warning_count;
  PyObject *__pyx_v_message = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("read_ok_packet", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0)) {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_read_ok_packet); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 173; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)__pyx_pw_7cymysql_6packet_11MysqlPacket_13read_ok_packet)) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
      if (CYTHON_COMPILING_IN_CPYTHON && unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      if (__pyx_t_4) {
        __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 173; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else {
        __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 173; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "cymysql/packet.pyx":176
 *         cdef int affected_rows, insert_id, server_status, warning_count
 *         cdef message
 *         self._skip(1)  # field_count (always '0')             # <<<<<<<<<<<<<<
 *         affected_rows = self.read_length_coded_binary()
 *         insert_id = self.read_length_coded_binary()
 */
  ((struct __pyx_vtabstruct_7cymysql_6packet_MysqlPacket *)__pyx_v_self->__pyx_vtab)->_skip(__pyx_v_self, 1);

  /* "cymysql/packet.pyx":177
 *         cdef message
 *         self._skip(1)  # field_count (always '0')
 *         affected_rows = self.read_length_coded_binary()             # <<<<<<<<<<<<<<
 *         insert_id = self.read_length_coded_binary()
 *         server_status = unpack_uint16(self._read(2))
 */
  __pyx_v_affected_rows = ((struct __pyx_vtabstruct_7cymysql_6packet_MysqlPacket *)__pyx_v_self->__pyx_vtab)->read_length_coded_binary(__pyx_v_self);

  /* "cymysql/packet.pyx":178
 *         self._skip(1)  # field_count (always '0')
 *         affected_rows = self.read_length_coded_binary()
 *         insert_id = self.read_length_coded_binary()             # <<<<<<<<<<<<<<
 *         server_status = unpack_uint16(self._read(2))
 *         warning_count = unpack_uint16(self._read(2))
 */
  __pyx_v_insert_id = ((struct __pyx_vtabstruct_7cymysql_6packet_MysqlPacket *)__pyx_v_self->__pyx_vtab)->read_length_coded_binary(__pyx_v_self);

  /* "cymysql/packet.pyx":179
 *         affected_rows = self.read_length_coded_binary()
 *         insert_id = self.read_length_coded_binary()
 *         server_status = unpack_uint16(self._read(2))             # <<<<<<<<<<<<<<
 *         warning_count = unpack_uint16(self._read(2))
 *         message = self._read_all()
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_6packet_MysqlPacket *)__pyx_v_self->__pyx_vtab)->_read(__pyx_v_self, 2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 179; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_server_status = __pyx_f_7cymysql_6packet_unpack_uint16(((PyObject*)__pyx_t_1));
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/packet.pyx":180
 *         insert_id = self.read_length_coded_binary()
 *         server_status = unpack_uint16(self._read(2))
 *         warning_count = unpack_uint16(self._read(2))             # <<<<<<<<<<<<<<
 *         message = self._read_all()
 *         return (None if affected_rows < 0 else affected_rows,
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_6packet_MysqlPacket *)__pyx_v_self->__pyx_vtab)->_read(__pyx_v_self, 2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 180; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_warning_count = __pyx_f_7cymysql_6packet_unpack_uint16(((PyObject*)__pyx_t_1));
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/packet.pyx":181
 *         server_status = unpack_uint16(self._read(2))
 *         warning_count = unpack_uint16(self._read(2))
 *         message = self._read_all()             # <<<<<<<<<<<<<<
 *         return (None if affected_rows < 0 else affected_rows,
 *                 None if insert_id < 0 else insert_id,
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_6packet_MysqlPacket *)__pyx_v_self->__pyx_vtab)->_read_all(__pyx_v_self); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 181; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_message = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cymysql/packet.pyx":182
 *         warning_count = unpack_uint16(self._read(2))
 *         message = self._read_all()
 *         return (None if affected_rows < 0 else affected_rows,             # <<<<<<<<<<<<<<
 *                 None if insert_id < 0 else insert_id,
 *                 server_status, warning_count, message)
 */
  __Pyx_XDECREF(__pyx_r);
  if (((__pyx_v_affected_rows < 0) != 0)) {
    __Pyx_INCREF(Py_None);
    __pyx_t_1 = Py_None;
  } else {
    __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_affected_rows); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 182; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __pyx_t_2;
    __pyx_t_2 = 0;
  }

  /* "cymysql/packet.pyx":183
 *         message = self._read_all()
 *         return (None if affected_rows < 0 else affected_rows,
 *                 None if insert_id < 0 else insert_id,             # <<<<<<<<<<<<<<
 *                 server_status, warning_count, message)
 * 
 */
  if (((__pyx_v_insert_id < 0) != 0)) {
    __Pyx_INCREF(Py_None);
    __pyx_t_2 = Py_None;
  } else {
    __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_insert_id); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 183; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __pyx_t_3;
    __pyx_t_3 = 0;
  }

  /* "cymysql/packet.pyx":184
 *         return (None if affected_rows < 0 else affected_rows,
 *                 None if insert_id < 0 else insert_id,
 *                 server_status, warning_count, message)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_server_status); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 184; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_warning_count); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 184; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);

  /* "cymysql/packet.pyx":182
 *         warning_count = unpack_uint16(self._read(2))
 *         message = self._read_all()
 *         return (None if affected_rows < 0 else affected_rows,             # <<<<<<<<<<<<<<
 *                 None if insert_id < 0 else insert_id,
 *                 server_status, warning_count, message)
 */
  __pyx_t_5 = PyTuple_New(5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 182; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_5, 3, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_v_message);
  PyTuple_SET_ITEM(__pyx_t_5, 4, __pyx_v_message);
  __Pyx_GIVEREF(__pyx_v_message);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "cymysql/packet.pyx":173
 *         return True, unpack_uint16(self._read(2)), unpack_uint16(self._read(2))
 * 
 *     cpdef read_ok_packet(self):             # <<<<<<<<<<<<<<
 *         cdef int affected_rows, insert_id, server_status, warning_count
 *         cdef message
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cymysql.packet.MysqlPacket.read_ok_packet", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_message);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_6packet_11MysqlPacket_13read_ok_packet(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_7cymysql_6packet_11MysqlPacket_13read_ok_packet(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("read_ok_packet (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_11MysqlPacket_12read_ok_packet(((struct __pyx_obj_7cymysql_6packet_MysqlPacket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_6packet_11MysqlPacket_12read_ok_packet(struct __pyx_obj_7cymysql_6packet_MysqlPacket *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("read_ok_packet", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_7cymysql_6packet_11MysqlPacket_read_ok_packet(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 173; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cymysql.packet.MysqlPacket.read_ok_packet", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/packet.pyx":197
 *     cdef public str charset
 * 
 *     def __init__(self, *args):             # <<<<<<<<<<<<<<
 *         MysqlPacket.__init__(self, *args)
 *         self.__parse_field_descriptor()
 */

/* Python wrapper */
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__init__", 0))) return -1;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket___init__(((struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket___init__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self, PyObject *__pyx_v_args) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cymysql/packet.pyx":198
 * 
 *     def __init__(self, *args):
 *         MysqlPacket.__init__(self, *args)             # <<<<<<<<<<<<<<
 *         self.__parse_field_descriptor()
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_6packet_MysqlPacket)), __pyx_n_s_init); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 198; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 198; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_v_self));
  PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_self));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
  __pyx_t_3 = PySequence_Tuple(__pyx_v_args); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 198; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyNumber_Add(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 198; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 198; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/packet.pyx":199
 *     def __init__(self, *args):
 *         MysqlPacket.__init__(self, *args)
 *         self.__parse_field_descriptor()             # <<<<<<<<<<<<<<
 * 
 *     def __parse_field_descriptor(self):
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_parse_field_descriptor); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 199; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = NULL;
  if (CYTHON_COMPILING_IN_CPYTHON && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (__pyx_t_1) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 199; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 199; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/packet.pyx":197
 *     cdef public str charset
 * 
 *     def __init__(self, *args):             # <<<<<<<<<<<<<<
 *         MysqlPacket.__init__(self, *args)
 *         self.__parse_field_descriptor()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("cymysql.packet.FieldDescriptorPacket.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/packet.pyx":201
 *         self.__parse_field_descriptor()
 * 
 *     def __parse_field_descriptor(self):             # <<<<<<<<<<<<<<
 *         """Parse the 'Field Descriptor' (Metadata) packet.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_3__parse_field_descriptor(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_7cymysql_6packet_21FieldDescriptorPacket_2__parse_field_descriptor[] = "Parse the 'Field Descriptor' (Metadata) packet.\n    \n        This is compatible with MySQL 4.1+ (not compatible with MySQL 4.0).\n        ";
static PyObject *__pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_3__parse_field_descriptor(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__parse_field_descriptor (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_2__parse_field_descriptor(((struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_2__parse_field_descriptor(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__parse_field_descriptor", 0);

  /* "cymysql/packet.pyx":206
 *         This is compatible with MySQL 4.1+ (not compatible with MySQL 4.0).
 *         """
 *         self.catalog = self._read_length_coded_string()             # <<<<<<<<<<<<<<
 *         self.db = self._read_length_coded_string()
 *         self.table_name = self._read_length_coded_string()
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._read_length_coded_string(((struct __pyx_obj_7cymysql_6packet_MysqlPacket *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 206; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->catalog);
  __Pyx_DECREF(__pyx_v_self->catalog);
  __pyx_v_self->catalog = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cymysql/packet.pyx":207
 *         """
 *         self.catalog = self._read_length_coded_string()
 *         self.db = self._read_length_coded_string()             # <<<<<<<<<<<<<<
 *         self.table_name = self._read_length_coded_string()
 *         self.org_table = self._read_length_coded_string()
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._read_length_coded_string(((struct __pyx_obj_7cymysql_6packet_MysqlPacket *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 207; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->db);
  __Pyx_DECREF(__pyx_v_self->db);
  __pyx_v_self->db = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cymysql/packet.pyx":208
 *         self.catalog = self._read_length_coded_string()
 *         self.db = self._read_length_coded_string()
 *         self.table_name = self._read_length_coded_string()             # <<<<<<<<<<<<<<
 *         self.org_table = self._read_length_coded_string()
 *         self.name = self._read_length_coded_string().decode(self.connection.charset)
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._read_length_coded_string(((struct __pyx_obj_7cymysql_6packet_MysqlPacket *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 208; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->table_name);
  __Pyx_DECREF(__pyx_v_self->table_name);
  __pyx_v_self->table_name = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cymysql/packet.pyx":209
 *         self.db = self._read_length_coded_string()
 *         self.table_name = self._read_length_coded_string()
 *         self.org_table = self._read_length_coded_string()             # <<<<<<<<<<<<<<
 *         self.name = self._read_length_coded_string().decode(self.connection.charset)
 *         self.org_name = self._read_length_coded_string()
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._read_length_coded_string(((struct __pyx_obj_7cymysql_6packet_MysqlPacket *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 209; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->org_table);
  __Pyx_DECREF(__pyx_v_self->org_table);
  __pyx_v_self->org_table = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cymysql/packet.pyx":210
 *         self.table_name = self._read_length_coded_string()
 *         self.org_table = self._read_length_coded_string()
 *         self.name = self._read_length_coded_string().decode(self.connection.charset)             # <<<<<<<<<<<<<<
 *         self.org_name = self._read_length_coded_string()
 *         self._skip(1)  # non-null filler
 */
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._read_length_coded_string(((struct __pyx_obj_7cymysql_6packet_MysqlPacket *)__pyx_v_self)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 210; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_decode); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 210; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->__pyx_base.connection, __pyx_n_s_charset); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 210; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_COMPILING_IN_CPYTHON && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_4) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 210; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 210; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __Pyx_GIVEREF(__pyx_t_4); __pyx_t_4 = NULL;
    PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __pyx_t_2 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 210; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(__pyx_v_self->name);
  __pyx_v_self->name = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cymysql/packet.pyx":211
 *         self.org_table = self._read_length_coded_string()
 *         self.name = self._read_length_coded_string().decode(self.connection.charset)
 *         self.org_name = self._read_length_coded_string()             # <<<<<<<<<<<<<<
 *         self._skip(1)  # non-null filler
 *         self.charsetnr = unpack_uint16(self._read(2))
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._read_length_coded_string(((struct __pyx_obj_7cymysql_6packet_MysqlPacket *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 211; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->org_name);
  __Pyx_DECREF(__pyx_v_self->org_name);
  __pyx_v_self->org_name = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cymysql/packet.pyx":212
 *         self.name = self._read_length_coded_string().decode(self.connection.charset)
 *         self.org_name = self._read_length_coded_string()
 *         self._skip(1)  # non-null filler             # <<<<<<<<<<<<<<
 *         self.charsetnr = unpack_uint16(self._read(2))
 *         self.charset = charset_by_id(self.charsetnr).name
 */
  ((struct __pyx_vtabstruct_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._skip(((struct __pyx_obj_7cymysql_6packet_MysqlPacket *)__pyx_v_self), 1);

  /* "cymysql/packet.pyx":213
 *         self.org_name = self._read_length_coded_string()
 *         self._skip(1)  # non-null filler
 *         self.charsetnr = unpack_uint16(self._read(2))             # <<<<<<<<<<<<<<
 *         self.charset = charset_by_id(self.charsetnr).name
 *         self.length = unpack_uint32(self._read(4))
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._read(((struct __pyx_obj_7cymysql_6packet_MysqlPacket *)__pyx_v_self), 2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 213; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_self->charsetnr = __pyx_f_7cymysql_6packet_unpack_uint16(((PyObject*)__pyx_t_1));
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/packet.pyx":214
 *         self._skip(1)  # non-null filler
 *         self.charsetnr = unpack_uint16(self._read(2))
 *         self.charset = charset_by_id(self.charsetnr).name             # <<<<<<<<<<<<<<
 *         self.length = unpack_uint32(self._read(4))
 *         self.type_code = ord(self._read(1))
 */
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_charset_by_id); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 214; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_self->charsetnr); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 214; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = NULL;
  if (CYTHON_COMPILING_IN_CPYTHON && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_5); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 214; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 214; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2); __Pyx_GIVEREF(__pyx_t_2); __pyx_t_2 = NULL;
    PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_5);
    __pyx_t_5 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 214; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_name); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 214; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(PyString_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_t_3)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 214; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GIVEREF(__pyx_t_3);
  __Pyx_GOTREF(__pyx_v_self->charset);
  __Pyx_DECREF(__pyx_v_self->charset);
  __pyx_v_self->charset = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "cymysql/packet.pyx":215
 *         self.charsetnr = unpack_uint16(self._read(2))
 *         self.charset = charset_by_id(self.charsetnr).name
 *         self.length = unpack_uint32(self._read(4))             # <<<<<<<<<<<<<<
 *         self.type_code = ord(self._read(1))
 *         self.flags = unpack_uint16(self._read(2))
 */
  __pyx_t_3 = ((struct __pyx_vtabstruct_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._read(((struct __pyx_obj_7cymysql_6packet_MysqlPacket *)__pyx_v_self), 4); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 215; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_self->length = __pyx_f_7cymysql_6packet_unpack_uint32(((PyObject*)__pyx_t_3));
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/packet.pyx":216
 *         self.charset = charset_by_id(self.charsetnr).name
 *         self.length = unpack_uint32(self._read(4))
 *         self.type_code = ord(self._read(1))             # <<<<<<<<<<<<<<
 *         self.flags = unpack_uint16(self._read(2))
 *         self.is_set = self.flags & FLAG.SET
 */
  __pyx_t_3 = ((struct __pyx_vtabstruct_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._read(((struct __pyx_obj_7cymysql_6packet_MysqlPacket *)__pyx_v_self), 1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 216; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 216; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ord, __pyx_t_1, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 216; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = __Pyx_PyInt_As_int(__pyx_t_3); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 216; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_self->type_code = __pyx_t_6;

  /* "cymysql/packet.pyx":217
 *         self.length = unpack_uint32(self._read(4))
 *         self.type_code = ord(self._read(1))
 *         self.flags = unpack_uint16(self._read(2))             # <<<<<<<<<<<<<<
 *         self.is_set = self.flags & FLAG.SET
 *         self.is_binary = self.flags & FLAG.BINARY
 */
  __pyx_t_3 = ((struct __pyx_vtabstruct_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._read(((struct __pyx_obj_7cymysql_6packet_MysqlPacket *)__pyx_v_self), 2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 217; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_self->flags = __pyx_f_7cymysql_6packet_unpack_uint16(((PyObject*)__pyx_t_3));
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/packet.pyx":218
 *         self.type_code = ord(self._read(1))
 *         self.flags = unpack_uint16(self._read(2))
 *         self.is_set = self.flags & FLAG.SET             # <<<<<<<<<<<<<<
 *         self.is_binary = self.flags & FLAG.BINARY
 *         self.scale = ord(self._read(1))  # "decimals"
 */
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_self->flags); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 218; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_FLAG); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 218; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_SET); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 218; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_And(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 218; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_6 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 218; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_self->is_set = __pyx_t_6;

  /* "cymysql/packet.pyx":219
 *         self.flags = unpack_uint16(self._read(2))
 *         self.is_set = self.flags & FLAG.SET
 *         self.is_binary = self.flags & FLAG.BINARY             # <<<<<<<<<<<<<<
 *         self.scale = ord(self._read(1))  # "decimals"
 *         self._skip(2)  # filler (always 0x00)
 */
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->flags); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 219; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_FLAG); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 219; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_BINARY); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 219; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyNumber_And(__pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 219; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_6 = __Pyx_PyInt_As_int(__pyx_t_4); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 219; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_self->is_binary = __pyx_t_6;

  /* "cymysql/packet.pyx":220
 *         self.is_set = self.flags & FLAG.SET
 *         self.is_binary = self.flags & FLAG.BINARY
 *         self.scale = ord(self._read(1))  # "decimals"             # <<<<<<<<<<<<<<
 *         self._skip(2)  # filler (always 0x00)
 * 
 */
  __pyx_t_4 = ((struct __pyx_vtabstruct_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._read(((struct __pyx_obj_7cymysql_6packet_MysqlPacket *)__pyx_v_self), 1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 220; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 220; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_ord, __pyx_t_3, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 220; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_6 = __Pyx_PyInt_As_int(__pyx_t_4); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 220; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_self->scale = __pyx_t_6;

  /* "cymysql/packet.pyx":221
 *         self.is_binary = self.flags & FLAG.BINARY
 *         self.scale = ord(self._read(1))  # "decimals"
 *         self._skip(2)  # filler (always 0x00)             # <<<<<<<<<<<<<<
 * 
 *         # 'default' is a length coded binary and is still in the buffer?
 */
  ((struct __pyx_vtabstruct_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._skip(((struct __pyx_obj_7cymysql_6packet_MysqlPacket *)__pyx_v_self), 2);

  /* "cymysql/packet.pyx":201
 *         self.__parse_field_descriptor()
 * 
 *     def __parse_field_descriptor(self):             # <<<<<<<<<<<<<<
 *         """Parse the 'Field Descriptor' (Metadata) packet.
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cymysql.packet.FieldDescriptorPacket.__parse_field_descriptor", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/packet.pyx":226
 *         # not used for normal result sets...
 * 
 *     def description(self):             # <<<<<<<<<<<<<<
 *         """Provides a 7-item tuple compatible with the Python PEP249 DB Spec."""
 *         return (
 */

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_5description(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_7cymysql_6packet_21FieldDescriptorPacket_4description[] = "Provides a 7-item tuple compatible with the Python PEP249 DB Spec.";
static PyObject *__pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_5description(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("description (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_4description(((struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_4description(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("description", 0);

  /* "cymysql/packet.pyx":228
 *     def description(self):
 *         """Provides a 7-item tuple compatible with the Python PEP249 DB Spec."""
 *         return (             # <<<<<<<<<<<<<<
 *             self.name,
 *             self.type_code,
 */
  __Pyx_XDECREF(__pyx_r);

  /* "cymysql/packet.pyx":230
 *         return (
 *             self.name,
 *             self.type_code,             # <<<<<<<<<<<<<<
 *             None,
 *             self.get_column_length(),
 */
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->type_code); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 230; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);

  /* "cymysql/packet.pyx":232
 *             self.type_code,
 *             None,
 *             self.get_column_length(),             # <<<<<<<<<<<<<<
 *             self.get_column_length(),
 *             self.scale,
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_column_length); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 232; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_COMPILING_IN_CPYTHON && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_4) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 232; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 232; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "cymysql/packet.pyx":233
 *             None,
 *             self.get_column_length(),
 *             self.get_column_length(),             # <<<<<<<<<<<<<<
 *             self.scale,
 *             <int>(self.flags % 2 == 0),
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_column_length); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 233; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  if (CYTHON_COMPILING_IN_CPYTHON && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (__pyx_t_5) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 233; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else {
    __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 233; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "cymysql/packet.pyx":234
 *             self.get_column_length(),
 *             self.get_column_length(),
 *             self.scale,             # <<<<<<<<<<<<<<
 *             <int>(self.flags % 2 == 0),
 *         )
 */
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_self->scale); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 234; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);

  /* "cymysql/packet.pyx":235
 *             self.get_column_length(),
 *             self.scale,
 *             <int>(self.flags % 2 == 0),             # <<<<<<<<<<<<<<
 *         )
 * 
 */
  __pyx_t_5 = __Pyx_PyInt_From_int(((int)(__Pyx_mod_long(__pyx_v_self->flags, 2) == 0))); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 235; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);

  /* "cymysql/packet.pyx":229
 *         """Provides a 7-item tuple compatible with the Python PEP249 DB Spec."""
 *         return (
 *             self.name,             # <<<<<<<<<<<<<<
 *             self.type_code,
 *             None,
 */
  __pyx_t_6 = PyTuple_New(7); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 229; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_v_self->name);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_v_self->name);
  __Pyx_GIVEREF(__pyx_v_self->name);
  PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_INCREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_6, 2, Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_6, 3, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_6, 4, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_6, 5, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_6, 6, __pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;
  __pyx_t_5 = 0;
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "cymysql/packet.pyx":226
 *         # not used for normal result sets...
 * 
 *     def description(self):             # <<<<<<<<<<<<<<
 *         """Provides a 7-item tuple compatible with the Python PEP249 DB Spec."""
 *         return (
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("cymysql.packet.FieldDescriptorPacket.description", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/packet.pyx":238
 *         )
 * 
 *     def get_column_length(self):             # <<<<<<<<<<<<<<
 *         cdef int mblen
 *         if self.type_code == FIELD_TYPE_VAR_STRING:
 */

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_7get_column_length(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_7get_column_length(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_column_length (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_6get_column_length(((struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_6get_column_length(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self) {
  int __pyx_v_mblen;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_column_length", 0);

  /* "cymysql/packet.pyx":240
 *     def get_column_length(self):
 *         cdef int mblen
 *         if self.type_code == FIELD_TYPE_VAR_STRING:             # <<<<<<<<<<<<<<
 *             mblen = MBLENGTH.get(self.charsetnr, 1)
 *             return self.length // mblen
 */
  __pyx_t_1 = ((__pyx_v_self->type_code == __pyx_v_7cymysql_6packet_FIELD_TYPE_VAR_STRING) != 0);
  if (__pyx_t_1) {

    /* "cymysql/packet.pyx":241
 *         cdef int mblen
 *         if self.type_code == FIELD_TYPE_VAR_STRING:
 *             mblen = MBLENGTH.get(self.charsetnr, 1)             # <<<<<<<<<<<<<<
 *             return self.length // mblen
 *         return self.length
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_MBLENGTH); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 241; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_get); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 241; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_self->charsetnr); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 241; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    if (CYTHON_COMPILING_IN_CPYTHON && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    __pyx_t_7 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 241; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    if (__pyx_t_5) {
      PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __Pyx_GIVEREF(__pyx_t_5); __pyx_t_5 = NULL;
    }
    PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_int_1);
    PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, __pyx_int_1);
    __Pyx_GIVEREF(__pyx_int_1);
    __pyx_t_3 = 0;
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 241; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_8 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_8 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 241; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_mblen = __pyx_t_8;

    /* "cymysql/packet.pyx":242
 *         if self.type_code == FIELD_TYPE_VAR_STRING:
 *             mblen = MBLENGTH.get(self.charsetnr, 1)
 *             return self.length // mblen             # <<<<<<<<<<<<<<
 *         return self.length
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    if (unlikely(__pyx_v_mblen == 0)) {
      #ifdef WITH_THREAD
      PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();
      #endif
      PyErr_SetString(PyExc_ZeroDivisionError, "integer division or modulo by zero");
      #ifdef WITH_THREAD
      PyGILState_Release(__pyx_gilstate_save);
      #endif
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 242; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    else if (sizeof(int) == sizeof(long) && (!(((int)-1) > 0)) && unlikely(__pyx_v_mblen == (int)-1)  && unlikely(UNARY_NEG_WOULD_OVERFLOW(__pyx_v_self->length))) {
      #ifdef WITH_THREAD
      PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();
      #endif
      PyErr_SetString(PyExc_OverflowError, "value too large to perform division");
      #ifdef WITH_THREAD
      PyGILState_Release(__pyx_gilstate_save);
      #endif
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 242; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_2 = __Pyx_PyInt_From_int(__Pyx_div_int(__pyx_v_self->length, __pyx_v_mblen)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 242; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;
  }

  /* "cymysql/packet.pyx":243
 *             mblen = MBLENGTH.get(self.charsetnr, 1)
 *             return self.length // mblen
 *         return self.length             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_self->length); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 243; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cymysql/packet.pyx":238
 *         )
 * 
 *     def get_column_length(self):             # <<<<<<<<<<<<<<
 *         cdef int mblen
 *         if self.type_code == FIELD_TYPE_VAR_STRING:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cymysql.packet.FieldDescriptorPacket.get_column_length", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/packet.pyx":245
 *         return self.length
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return ('%s %s.%s.%s, type=%s'
 *             % (self.__class__, self.db, self.table_name, self.name,
 */

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_9__str__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_9__str__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_8__str__(((struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_8__str__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 0);

  /* "cymysql/packet.pyx":246
 * 
 *     def __str__(self):
 *         return ('%s %s.%s.%s, type=%s'             # <<<<<<<<<<<<<<
 *             % (self.__class__, self.db, self.table_name, self.name,
 *                self.type_code))
 */
  __Pyx_XDECREF(__pyx_r);

  /* "cymysql/packet.pyx":247
 *     def __str__(self):
 *         return ('%s %s.%s.%s, type=%s'
 *             % (self.__class__, self.db, self.table_name, self.name,             # <<<<<<<<<<<<<<
 *                self.type_code))
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_class); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 247; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);

  /* "cymysql/packet.pyx":248
 *         return ('%s %s.%s.%s, type=%s'
 *             % (self.__class__, self.db, self.table_name, self.name,
 *                self.type_code))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_self->type_code); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 248; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);

  /* "cymysql/packet.pyx":247
 *     def __str__(self):
 *         return ('%s %s.%s.%s, type=%s'
 *             % (self.__class__, self.db, self.table_name, self.name,             # <<<<<<<<<<<<<<
 *                self.type_code))
 * 
 */
  __pyx_t_3 = PyTuple_New(5); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 247; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_self->db);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self->db);
  __Pyx_GIVEREF(__pyx_v_self->db);
  __Pyx_INCREF(__pyx_v_self->table_name);
  PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_v_self->table_name);
  __Pyx_GIVEREF(__pyx_v_self->table_name);
  __Pyx_INCREF(__pyx_v_self->name);
  PyTuple_SET_ITEM(__pyx_t_3, 3, __pyx_v_self->name);
  __Pyx_GIVEREF(__pyx_v_self->name);
  PyTuple_SET_ITEM(__pyx_t_3, 4, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyString_Format(__pyx_kp_s_s_s_s_s_type_s, __pyx_t_3); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 247; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cymysql/packet.pyx":245
 *         return self.length
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return ('%s %s.%s.%s, type=%s'
 *             % (self.__class__, self.db, self.table_name, self.name,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cymysql.packet.FieldDescriptorPacket.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/packet.pyx":193
 *     attributes on the class such as: db, table_name, name, length, type_code.
 *     """
 *     cdef public object catalog, db, table_name, org_table, name, org_name             # <<<<<<<<<<<<<<
 *     cdef public int charsetnr, length, type_code, flags, scale, is_set, is_binary
 *     cdef public str charset
 */

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_7catalog_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_7catalog_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_7catalog___get__(((struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_7catalog___get__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->catalog);
  __pyx_r = __pyx_v_self->catalog;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_7catalog_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_7catalog_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_7catalog_2__set__(((struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_7catalog_2__set__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->catalog);
  __Pyx_DECREF(__pyx_v_self->catalog);
  __pyx_v_self->catalog = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_7catalog_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_7catalog_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_7catalog_4__del__(((struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_7catalog_4__del__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->catalog);
  __Pyx_DECREF(__pyx_v_self->catalog);
  __pyx_v_self->catalog = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_2db_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_2db_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_2db___get__(((struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_2db___get__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->db);
  __pyx_r = __pyx_v_self->db;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_2db_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_2db_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_2db_2__set__(((struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_2db_2__set__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->db);
  __Pyx_DECREF(__pyx_v_self->db);
  __pyx_v_self->db = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_2db_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_2db_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_2db_4__del__(((struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_2db_4__del__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->db);
  __Pyx_DECREF(__pyx_v_self->db);
  __pyx_v_self->db = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_10table_name_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_10table_name_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_10table_name___get__(((struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_10table_name___get__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->table_name);
  __pyx_r = __pyx_v_self->table_name;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_10table_name_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_10table_name_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_10table_name_2__set__(((struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_10table_name_2__set__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->table_name);
  __Pyx_DECREF(__pyx_v_self->table_name);
  __pyx_v_self->table_name = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_10table_name_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_10table_name_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_10table_name_4__del__(((struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_10table_name_4__del__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->table_name);
  __Pyx_DECREF(__pyx_v_self->table_name);
  __pyx_v_self->table_name = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_9org_table_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_9org_table_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_9org_table___get__(((struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_9org_table___get__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->org_table);
  __pyx_r = __pyx_v_self->org_table;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_9org_table_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_9org_table_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_9org_table_2__set__(((struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_9org_table_2__set__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->org_table);
  __Pyx_DECREF(__pyx_v_self->org_table);
  __pyx_v_self->org_table = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_9org_table_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_9org_table_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_9org_table_4__del__(((struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_9org_table_4__del__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->org_table);
  __Pyx_DECREF(__pyx_v_self->org_table);
  __pyx_v_self->org_table = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_4name_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_4name_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_4name___get__(((struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_4name___get__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->name);
  __pyx_r = __pyx_v_self->name;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_4name_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_4name_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_4name_2__set__(((struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_4name_2__set__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(__pyx_v_self->name);
  __pyx_v_self->name = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_4name_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_4name_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_4name_4__del__(((struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_4name_4__del__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(__pyx_v_self->name);
  __pyx_v_self->name = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_8org_name_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_8org_name_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_8org_name___get__(((struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_8org_name___get__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->org_name);
  __pyx_r = __pyx_v_self->org_name;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_8org_name_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_8org_name_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_8org_name_2__set__(((struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_8org_name_2__set__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->org_name);
  __Pyx_DECREF(__pyx_v_self->org_name);
  __pyx_v_self->org_name = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_8org_name_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_8org_name_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_8org_name_4__del__(((struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_8org_name_4__del__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->org_name);
  __Pyx_DECREF(__pyx_v_self->org_name);
  __pyx_v_self->org_name = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/packet.pyx":194
 *     """
 *     cdef public object catalog, db, table_name, org_table, name, org_name
 *     cdef public int charsetnr, length, type_code, flags, scale, is_set, is_binary             # <<<<<<<<<<<<<<
 *     cdef public str charset
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_9charsetnr_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_9charsetnr_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_9charsetnr___get__(((struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_9charsetnr___get__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->charsetnr); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 194; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cymysql.packet.FieldDescriptorPacket.charsetnr.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_9charsetnr_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_9charsetnr_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_9charsetnr_2__set__(((struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_9charsetnr_2__set__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 194; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_self->charsetnr = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cymysql.packet.FieldDescriptorPacket.charsetnr.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_6length_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_6length_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_6length___get__(((struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_6length___get__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->length); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 194; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cymysql.packet.FieldDescriptorPacket.length.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_6length_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_6length_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_6length_2__set__(((struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_6length_2__set__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 194; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_self->length = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cymysql.packet.FieldDescriptorPacket.length.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_9type_code_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_9type_code_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_9type_code___get__(((struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_9type_code___get__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->type_code); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 194; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cymysql.packet.FieldDescriptorPacket.type_code.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_9type_code_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_9type_code_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_9type_code_2__set__(((struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_9type_code_2__set__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 194; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_self->type_code = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cymysql.packet.FieldDescriptorPacket.type_code.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_5flags_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_5flags_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_5flags___get__(((struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_5flags___get__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->flags); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 194; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cymysql.packet.FieldDescriptorPacket.flags.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_5flags_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_5flags_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_5flags_2__set__(((struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_5flags_2__set__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 194; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_self->flags = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cymysql.packet.FieldDescriptorPacket.flags.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_5scale_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_5scale_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_5scale___get__(((struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_5scale___get__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->scale); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 194; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cymysql.packet.FieldDescriptorPacket.scale.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_5scale_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_5scale_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_5scale_2__set__(((struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_5scale_2__set__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 194; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_self->scale = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cymysql.packet.FieldDescriptorPacket.scale.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_6is_set_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_6is_set_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_6is_set___get__(((struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_6is_set___get__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->is_set); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 194; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cymysql.packet.FieldDescriptorPacket.is_set.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_6is_set_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_6is_set_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_6is_set_2__set__(((struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_6is_set_2__set__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 194; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_self->is_set = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cymysql.packet.FieldDescriptorPacket.is_set.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_9is_binary_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_9is_binary_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_9is_binary___get__(((struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_9is_binary___get__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->is_binary); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 194; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cymysql.packet.FieldDescriptorPacket.is_binary.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_9is_binary_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_9is_binary_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_9is_binary_2__set__(((struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_9is_binary_2__set__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 194; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_self->is_binary = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cymysql.packet.FieldDescriptorPacket.is_binary.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/packet.pyx":195
 *     cdef public object catalog, db, table_name, org_table, name, org_name
 *     cdef public int charsetnr, length, type_code, flags, scale, is_set, is_binary
 *     cdef public str charset             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, *args):
 */

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_7charset_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_7charset_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_7charset___get__(((struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_7charset___get__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->charset);
  __pyx_r = __pyx_v_self->charset;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_7charset_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_7charset_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_7charset_2__set__(((struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_7charset_2__set__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(PyString_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_v_value)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 195; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->charset);
  __Pyx_DECREF(__pyx_v_self->charset);
  __pyx_v_self->charset = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cymysql.packet.FieldDescriptorPacket.charset.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_7charset_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_7charset_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_7charset_4__del__(((struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_6packet_21FieldDescriptorPacket_7charset_4__del__(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->charset);
  __Pyx_DECREF(__pyx_v_self->charset);
  __pyx_v_self->charset = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/packet.pyx":260
 *     cdef int rest_row_index, server_status, warning_count, field_count
 * 
 *     def __init__(self, connection):             # <<<<<<<<<<<<<<
 *         from weakref import proxy
 *         self.connection = proxy(connection)
 */

/* Python wrapper */
static int __pyx_pw_7cymysql_6packet_11MySQLResult_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_7cymysql_6packet_11MySQLResult_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_connection = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_connection,0};
    PyObject* values[1] = {0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_connection)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 260; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 1) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
    }
    __pyx_v_connection = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 260; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("cymysql.packet.MySQLResult.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7cymysql_6packet_11MySQLResult___init__(((struct __pyx_obj_7cymysql_6packet_MySQLResult *)__pyx_v_self), __pyx_v_connection);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_6packet_11MySQLResult___init__(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self, PyObject *__pyx_v_connection) {
  PyObject *__pyx_v_proxy = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *(*__pyx_t_9)(PyObject *);
  int __pyx_t_10;
  int __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cymysql/packet.pyx":261
 * 
 *     def __init__(self, connection):
 *         from weakref import proxy             # <<<<<<<<<<<<<<
 *         self.connection = proxy(connection)
 *         self.affected_rows = None
 */
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 261; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_proxy);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_proxy);
  __Pyx_GIVEREF(__pyx_n_s_proxy);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_weakref, __pyx_t_1, -1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 261; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_proxy); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 261; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_proxy = __pyx_t_1;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/packet.pyx":262
 *     def __init__(self, connection):
 *         from weakref import proxy
 *         self.connection = proxy(connection)             # <<<<<<<<<<<<<<
 *         self.affected_rows = None
 *         self.insert_id = None
 */
  __Pyx_INCREF(__pyx_v_proxy);
  __pyx_t_1 = __pyx_v_proxy; __pyx_t_3 = NULL;
  if (CYTHON_COMPILING_IN_CPYTHON && unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  if (!__pyx_t_3) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_connection); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 262; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
  } else {
    __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 262; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3); __Pyx_GIVEREF(__pyx_t_3); __pyx_t_3 = NULL;
    __Pyx_INCREF(__pyx_v_connection);
    PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v_connection);
    __Pyx_GIVEREF(__pyx_v_connection);
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_4, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 262; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->connection);
  __Pyx_DECREF(__pyx_v_self->connection);
  __pyx_v_self->connection = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "cymysql/packet.pyx":263
 *         from weakref import proxy
 *         self.connection = proxy(connection)
 *         self.affected_rows = None             # <<<<<<<<<<<<<<
 *         self.insert_id = None
 *         self.server_status = 0
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->affected_rows);
  __Pyx_DECREF(__pyx_v_self->affected_rows);
  __pyx_v_self->affected_rows = Py_None;

  /* "cymysql/packet.pyx":264
 *         self.connection = proxy(connection)
 *         self.affected_rows = None
 *         self.insert_id = None             # <<<<<<<<<<<<<<
 *         self.server_status = 0
 *         self.warning_count = 0
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->insert_id);
  __Pyx_DECREF(__pyx_v_self->insert_id);
  __pyx_v_self->insert_id = Py_None;

  /* "cymysql/packet.pyx":265
 *         self.affected_rows = None
 *         self.insert_id = None
 *         self.server_status = 0             # <<<<<<<<<<<<<<
 *         self.warning_count = 0
 *         self.message = None
 */
  __pyx_v_self->server_status = 0;

  /* "cymysql/packet.pyx":266
 *         self.insert_id = None
 *         self.server_status = 0
 *         self.warning_count = 0             # <<<<<<<<<<<<<<
 *         self.message = None
 *         self.field_count = 0
 */
  __pyx_v_self->warning_count = 0;

  /* "cymysql/packet.pyx":267
 *         self.server_status = 0
 *         self.warning_count = 0
 *         self.message = None             # <<<<<<<<<<<<<<
 *         self.field_count = 0
 *         self.description = None
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->message);
  __Pyx_DECREF(__pyx_v_self->message);
  __pyx_v_self->message = Py_None;

  /* "cymysql/packet.pyx":268
 *         self.warning_count = 0
 *         self.message = None
 *         self.field_count = 0             # <<<<<<<<<<<<<<
 *         self.description = None
 *         self.has_next = 0
 */
  __pyx_v_self->field_count = 0;

  /* "cymysql/packet.pyx":269
 *         self.message = None
 *         self.field_count = 0
 *         self.description = None             # <<<<<<<<<<<<<<
 *         self.has_next = 0
 *         self.has_result = False
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->description);
  __Pyx_DECREF(__pyx_v_self->description);
  __pyx_v_self->description = Py_None;

  /* "cymysql/packet.pyx":270
 *         self.field_count = 0
 *         self.description = None
 *         self.has_next = 0             # <<<<<<<<<<<<<<
 *         self.has_result = False
 *         self.rest_rows = None
 */
  __pyx_v_self->has_next = 0;

  /* "cymysql/packet.pyx":271
 *         self.description = None
 *         self.has_next = 0
 *         self.has_result = False             # <<<<<<<<<<<<<<
 *         self.rest_rows = None
 *         self.rest_row_index = 0
 */
  __Pyx_INCREF(Py_False);
  __Pyx_GIVEREF(Py_False);
  __Pyx_GOTREF(__pyx_v_self->has_result);
  __Pyx_DECREF(__pyx_v_self->has_result);
  __pyx_v_self->has_result = Py_False;

  /* "cymysql/packet.pyx":272
 *         self.has_next = 0
 *         self.has_result = False
 *         self.rest_rows = None             # <<<<<<<<<<<<<<
 *         self.rest_row_index = 0
 *         self.first_packet = MysqlPacket(self.connection)
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->rest_rows);
  __Pyx_DECREF(__pyx_v_self->rest_rows);
  __pyx_v_self->rest_rows = Py_None;

  /* "cymysql/packet.pyx":273
 *         self.has_result = False
 *         self.rest_rows = None
 *         self.rest_row_index = 0             # <<<<<<<<<<<<<<
 *         self.first_packet = MysqlPacket(self.connection)
 * 
 */
  __pyx_v_self->rest_row_index = 0;

  /* "cymysql/packet.pyx":274
 *         self.rest_rows = None
 *         self.rest_row_index = 0
 *         self.first_packet = MysqlPacket(self.connection)             # <<<<<<<<<<<<<<
 * 
 *         if self.first_packet.is_ok_packet():
 */
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 274; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_self->connection);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_self->connection);
  __Pyx_GIVEREF(__pyx_v_self->connection);
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_6packet_MysqlPacket)), __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 274; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->first_packet);
  __Pyx_DECREF(__pyx_v_self->first_packet);
  __pyx_v_self->first_packet = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cymysql/packet.pyx":276
 *         self.first_packet = MysqlPacket(self.connection)
 * 
 *         if self.first_packet.is_ok_packet():             # <<<<<<<<<<<<<<
 *             (self.affected_rows, self.insert_id,
 *                 self.server_status, self.warning_count,
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->first_packet, __pyx_n_s_is_ok_packet); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 276; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_COMPILING_IN_CPYTHON && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_4) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 276; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 276; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_5 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 276; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "cymysql/packet.pyx":279
 *             (self.affected_rows, self.insert_id,
 *                 self.server_status, self.warning_count,
 *                 self.message) = self.first_packet.read_ok_packet()             # <<<<<<<<<<<<<<
 *             self.has_result = False
 *         else:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->first_packet, __pyx_n_s_read_ok_packet); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 279; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = NULL;
    if (CYTHON_COMPILING_IN_CPYTHON && likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    if (__pyx_t_4) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 279; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 279; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
      PyObject* sequence = __pyx_t_1;
      #if CYTHON_COMPILING_IN_CPYTHON
      Py_ssize_t size = Py_SIZE(sequence);
      #else
      Py_ssize_t size = PySequence_Size(sequence);
      #endif
      if (unlikely(size != 5)) {
        if (size > 5) __Pyx_RaiseTooManyValuesError(5);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 277; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      #if CYTHON_COMPILING_IN_CPYTHON
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
        __pyx_t_3 = PyTuple_GET_ITEM(sequence, 2); 
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 3); 
        __pyx_t_7 = PyTuple_GET_ITEM(sequence, 4); 
      } else {
        __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
        __pyx_t_3 = PyList_GET_ITEM(sequence, 2); 
        __pyx_t_6 = PyList_GET_ITEM(sequence, 3); 
        __pyx_t_7 = PyList_GET_ITEM(sequence, 4); 
      }
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      #else
      {
        Py_ssize_t i;
        PyObject** temps[5] = {&__pyx_t_2,&__pyx_t_4,&__pyx_t_3,&__pyx_t_6,&__pyx_t_7};
        for (i=0; i < 5; i++) {
          PyObject* item = PySequence_ITEM(sequence, i); if (unlikely(!item)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 277; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(item);
          *(temps[i]) = item;
        }
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else {
      Py_ssize_t index = -1;
      PyObject** temps[5] = {&__pyx_t_2,&__pyx_t_4,&__pyx_t_3,&__pyx_t_6,&__pyx_t_7};
      __pyx_t_8 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 277; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_9 = Py_TYPE(__pyx_t_8)->tp_iternext;
      for (index=0; index < 5; index++) {
        PyObject* item = __pyx_t_9(__pyx_t_8); if (unlikely(!item)) goto __pyx_L4_unpacking_failed;
        __Pyx_GOTREF(item);
        *(temps[index]) = item;
      }
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_9(__pyx_t_8), 5) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 277; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_9 = NULL;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L5_unpacking_done;
      __pyx_L4_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_9 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 277; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_L5_unpacking_done:;
    }

    /* "cymysql/packet.pyx":277
 * 
 *         if self.first_packet.is_ok_packet():
 *             (self.affected_rows, self.insert_id,             # <<<<<<<<<<<<<<
 *                 self.server_status, self.warning_count,
 *                 self.message) = self.first_packet.read_ok_packet()
 */
    __pyx_t_10 = __Pyx_PyInt_As_int(__pyx_t_3); if (unlikely((__pyx_t_10 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 277; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_11 = __Pyx_PyInt_As_int(__pyx_t_6); if (unlikely((__pyx_t_11 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 277; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GIVEREF(__pyx_t_2);
    __Pyx_GOTREF(__pyx_v_self->affected_rows);
    __Pyx_DECREF(__pyx_v_self->affected_rows);
    __pyx_v_self->affected_rows = __pyx_t_2;
    __pyx_t_2 = 0;
    __Pyx_GIVEREF(__pyx_t_4);
    __Pyx_GOTREF(__pyx_v_self->insert_id);
    __Pyx_DECREF(__pyx_v_self->insert_id);
    __pyx_v_self->insert_id = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "cymysql/packet.pyx":278
 *         if self.first_packet.is_ok_packet():
 *             (self.affected_rows, self.insert_id,
 *                 self.server_status, self.warning_count,             # <<<<<<<<<<<<<<
 *                 self.message) = self.first_packet.read_ok_packet()
 *             self.has_result = False
 */
    __pyx_v_self->server_status = __pyx_t_10;
    __pyx_v_self->warning_count = __pyx_t_11;

    /* "cymysql/packet.pyx":279
 *             (self.affected_rows, self.insert_id,
 *                 self.server_status, self.warning_count,
 *                 self.message) = self.first_packet.read_ok_packet()             # <<<<<<<<<<<<<<
 *             self.has_result = False
 *         else:
 */
    __Pyx_GIVEREF(__pyx_t_7);
    __Pyx_GOTREF(__pyx_v_self->message);
    __Pyx_DECREF(__pyx_v_self->message);
    __pyx_v_self->message = __pyx_t_7;
    __pyx_t_7 = 0;

    /* "cymysql/packet.pyx":280
 *                 self.server_status, self.warning_count,
 *                 self.message) = self.first_packet.read_ok_packet()
 *             self.has_result = False             # <<<<<<<<<<<<<<
 *         else:
 *             self.field_count = ord(self.first_packet.read(1))
 */
    __Pyx_INCREF(Py_False);
    __Pyx_GIVEREF(Py_False);
    __Pyx_GOTREF(__pyx_v_self->has_result);
    __Pyx_DECREF(__pyx_v_self->has_result);
    __pyx_v_self->has_result = Py_False;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "cymysql/packet.pyx":282
 *             self.has_result = False
 *         else:
 *             self.field_count = ord(self.first_packet.read(1))             # <<<<<<<<<<<<<<
 *             self._get_descriptions()
 *             self.has_result = True
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->first_packet, __pyx_n_s_read); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 282; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__6, NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 282; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 282; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_7);
    __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_builtin_ord, __pyx_t_1, NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 282; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_11 = __Pyx_PyInt_As_int(__pyx_t_7); if (unlikely((__pyx_t_11 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 282; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_v_self->field_count = __pyx_t_11;

    /* "cymysql/packet.pyx":283
 *         else:
 *             self.field_count = ord(self.first_packet.read(1))
 *             self._get_descriptions()             # <<<<<<<<<<<<<<
 *             self.has_result = True
 *             self.read_rest_rowdata_packet()
 */
    ((struct __pyx_vtabstruct_7cymysql_6packet_MySQLResult *)__pyx_v_self->__pyx_vtab)->_get_descriptions(__pyx_v_self);

    /* "cymysql/packet.pyx":284
 *             self.field_count = ord(self.first_packet.read(1))
 *             self._get_descriptions()
 *             self.has_result = True             # <<<<<<<<<<<<<<
 *             self.read_rest_rowdata_packet()
 * 
 */
    __Pyx_INCREF(Py_True);
    __Pyx_GIVEREF(Py_True);
    __Pyx_GOTREF(__pyx_v_self->has_result);
    __Pyx_DECREF(__pyx_v_self->has_result);
    __pyx_v_self->has_result = Py_True;

    /* "cymysql/packet.pyx":285
 *             self._get_descriptions()
 *             self.has_result = True
 *             self.read_rest_rowdata_packet()             # <<<<<<<<<<<<<<
 * 
 *     def read_rest_rowdata_packet(self):
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_read_rest_rowdata_packet); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 285; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = NULL;
    if (CYTHON_COMPILING_IN_CPYTHON && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    if (__pyx_t_6) {
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_6); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 285; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else {
      __pyx_t_7 = __Pyx_PyObject_CallNoArg(__pyx_t_1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 285; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __pyx_L3:;

  /* "cymysql/packet.pyx":260
 *     cdef int rest_row_index, server_status, warning_count, field_count
 * 
 *     def __init__(self, connection):             # <<<<<<<<<<<<<<
 *         from weakref import proxy
 *         self.connection = proxy(connection)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("cymysql.packet.MySQLResult.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_proxy);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/packet.pyx":287
 *             self.read_rest_rowdata_packet()
 * 
 *     def read_rest_rowdata_packet(self):             # <<<<<<<<<<<<<<
 *         """Read rest rowdata packets for each data row in the result set."""
 *         cdef int is_eof, warning_count, server_status
 */

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_6packet_11MySQLResult_3read_rest_rowdata_packet(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_7cymysql_6packet_11MySQLResult_2read_rest_rowdata_packet[] = "Read rest rowdata packets for each data row in the result set.";
static PyObject *__pyx_pw_7cymysql_6packet_11MySQLResult_3read_rest_rowdata_packet(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("read_rest_rowdata_packet (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_11MySQLResult_2read_rest_rowdata_packet(((struct __pyx_obj_7cymysql_6packet_MySQLResult *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_6packet_11MySQLResult_2read_rest_rowdata_packet(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self) {
  int __pyx_v_is_eof;
  int __pyx_v_warning_count;
  int __pyx_v_server_status;
  PyObject *__pyx_v_rest_rows = NULL;
  PyObject *__pyx_v_decoder = NULL;
  struct __pyx_obj_7cymysql_6packet_MysqlPacket *__pyx_v_packet = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *(*__pyx_t_9)(PyObject *);
  int __pyx_t_10;
  int __pyx_t_11;
  int __pyx_t_12;
  int __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("read_rest_rowdata_packet", 0);

  /* "cymysql/packet.pyx":290
 *         """Read rest rowdata packets for each data row in the result set."""
 *         cdef int is_eof, warning_count, server_status
 *         if (not self.has_result) or (self.rest_rows is not None):             # <<<<<<<<<<<<<<
 *             return
 *         rest_rows = []
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_self->has_result); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 290; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_3 = ((!__pyx_t_2) != 0);
  if (!__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (__pyx_v_self->rest_rows != Py_None);
  __pyx_t_2 = (__pyx_t_3 != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "cymysql/packet.pyx":291
 *         cdef int is_eof, warning_count, server_status
 *         if (not self.has_result) or (self.rest_rows is not None):
 *             return             # <<<<<<<<<<<<<<
 *         rest_rows = []
 *         decoder = self.connection.conv
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;
  }

  /* "cymysql/packet.pyx":292
 *         if (not self.has_result) or (self.rest_rows is not None):
 *             return
 *         rest_rows = []             # <<<<<<<<<<<<<<
 *         decoder = self.connection.conv
 *         while True:
 */
  __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 292; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_rest_rows = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "cymysql/packet.pyx":293
 *             return
 *         rest_rows = []
 *         decoder = self.connection.conv             # <<<<<<<<<<<<<<
 *         while True:
 *             packet = MysqlPacket(self.connection)
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->connection, __pyx_n_s_conv); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 293; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_decoder = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "cymysql/packet.pyx":294
 *         rest_rows = []
 *         decoder = self.connection.conv
 *         while True:             # <<<<<<<<<<<<<<
 *             packet = MysqlPacket(self.connection)
 *             is_eof, warning_count, server_status = packet.is_eof_and_status()
 */
  while (1) {

    /* "cymysql/packet.pyx":295
 *         decoder = self.connection.conv
 *         while True:
 *             packet = MysqlPacket(self.connection)             # <<<<<<<<<<<<<<
 *             is_eof, warning_count, server_status = packet.is_eof_and_status()
 *             if is_eof:
 */
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 295; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_v_self->connection);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_self->connection);
    __Pyx_GIVEREF(__pyx_v_self->connection);
    __pyx_t_5 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_6packet_MysqlPacket)), __pyx_t_4, NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 295; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF_SET(__pyx_v_packet, ((struct __pyx_obj_7cymysql_6packet_MysqlPacket *)__pyx_t_5));
    __pyx_t_5 = 0;

    /* "cymysql/packet.pyx":296
 *         while True:
 *             packet = MysqlPacket(self.connection)
 *             is_eof, warning_count, server_status = packet.is_eof_and_status()             # <<<<<<<<<<<<<<
 *             if is_eof:
 *                 self.warning_count = warning_count
 */
    __pyx_t_5 = ((struct __pyx_vtabstruct_7cymysql_6packet_MysqlPacket *)__pyx_v_packet->__pyx_vtab)->is_eof_and_status(__pyx_v_packet, 0); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 296; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    if ((likely(PyTuple_CheckExact(__pyx_t_5))) || (PyList_CheckExact(__pyx_t_5))) {
      PyObject* sequence = __pyx_t_5;
      #if CYTHON_COMPILING_IN_CPYTHON
      Py_ssize_t size = Py_SIZE(sequence);
      #else
      Py_ssize_t size = PySequence_Size(sequence);
      #endif
      if (unlikely(size != 3)) {
        if (size > 3) __Pyx_RaiseTooManyValuesError(3);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 296; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      #if CYTHON_COMPILING_IN_CPYTHON
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_4 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1); 
        __pyx_t_7 = PyTuple_GET_ITEM(sequence, 2); 
      } else {
        __pyx_t_4 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_6 = PyList_GET_ITEM(sequence, 1); 
        __pyx_t_7 = PyList_GET_ITEM(sequence, 2); 
      }
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      #else
      __pyx_t_4 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 296; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_6 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 296; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 296; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      #endif
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_8 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 296; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_9 = Py_TYPE(__pyx_t_8)->tp_iternext;
      index = 0; __pyx_t_4 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_4)) goto __pyx_L8_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_4);
      index = 1; __pyx_t_6 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_6)) goto __pyx_L8_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_6);
      index = 2; __pyx_t_7 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_7)) goto __pyx_L8_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_7);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_9(__pyx_t_8), 3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 296; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_9 = NULL;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L9_unpacking_done;
      __pyx_L8_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_9 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 296; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_L9_unpacking_done:;
    }
    __pyx_t_10 = __Pyx_PyInt_As_int(__pyx_t_4); if (unlikely((__pyx_t_10 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 296; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_11 = __Pyx_PyInt_As_int(__pyx_t_6); if (unlikely((__pyx_t_11 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 296; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_12 = __Pyx_PyInt_As_int(__pyx_t_7); if (unlikely((__pyx_t_12 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 296; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_v_is_eof = __pyx_t_10;
    __pyx_v_warning_count = __pyx_t_11;
    __pyx_v_server_status = __pyx_t_12;

    /* "cymysql/packet.pyx":297
 *             packet = MysqlPacket(self.connection)
 *             is_eof, warning_count, server_status = packet.is_eof_and_status()
 *             if is_eof:             # <<<<<<<<<<<<<<
 *                 self.warning_count = warning_count
 *                 self.server_status = server_status
 */
    __pyx_t_1 = (__pyx_v_is_eof != 0);
    if (__pyx_t_1) {

      /* "cymysql/packet.pyx":298
 *             is_eof, warning_count, server_status = packet.is_eof_and_status()
 *             if is_eof:
 *                 self.warning_count = warning_count             # <<<<<<<<<<<<<<
 *                 self.server_status = server_status
 *                 self.has_next = (server_status & SERVER_MORE_RESULTS_EXISTS)
 */
      __pyx_v_self->warning_count = __pyx_v_warning_count;

      /* "cymysql/packet.pyx":299
 *             if is_eof:
 *                 self.warning_count = warning_count
 *                 self.server_status = server_status             # <<<<<<<<<<<<<<
 *                 self.has_next = (server_status & SERVER_MORE_RESULTS_EXISTS)
 *                 break
 */
      __pyx_v_self->server_status = __pyx_v_server_status;

      /* "cymysql/packet.pyx":300
 *                 self.warning_count = warning_count
 *                 self.server_status = server_status
 *                 self.has_next = (server_status & SERVER_MORE_RESULTS_EXISTS)             # <<<<<<<<<<<<<<
 *                 break
 *             rest_rows.append(packet.read_decode_data(self.fields, decoder))
 */
      __pyx_v_self->has_next = (__pyx_v_server_status & __pyx_v_7cymysql_6packet_SERVER_MORE_RESULTS_EXISTS);

      /* "cymysql/packet.pyx":301
 *                 self.server_status = server_status
 *                 self.has_next = (server_status & SERVER_MORE_RESULTS_EXISTS)
 *                 break             # <<<<<<<<<<<<<<
 *             rest_rows.append(packet.read_decode_data(self.fields, decoder))
 *         self.rest_rows = rest_rows
 */
      goto __pyx_L7_break;
    }

    /* "cymysql/packet.pyx":302
 *                 self.has_next = (server_status & SERVER_MORE_RESULTS_EXISTS)
 *                 break
 *             rest_rows.append(packet.read_decode_data(self.fields, decoder))             # <<<<<<<<<<<<<<
 *         self.rest_rows = rest_rows
 *         self.rest_row_index = 0
 */
    __pyx_t_5 = __pyx_v_self->fields;
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_7 = ((struct __pyx_vtabstruct_7cymysql_6packet_MysqlPacket *)__pyx_v_packet->__pyx_vtab)->read_decode_data(__pyx_v_packet, __pyx_t_5, __pyx_v_decoder); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 302; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_13 = __Pyx_PyList_Append(__pyx_v_rest_rows, __pyx_t_7); if (unlikely(__pyx_t_13 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 302; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __pyx_L7_break:;

  /* "cymysql/packet.pyx":303
 *                 break
 *             rest_rows.append(packet.read_decode_data(self.fields, decoder))
 *         self.rest_rows = rest_rows             # <<<<<<<<<<<<<<
 *         self.rest_row_index = 0
 * 
 */
  __Pyx_INCREF(__pyx_v_rest_rows);
  __Pyx_GIVEREF(__pyx_v_rest_rows);
  __Pyx_GOTREF(__pyx_v_self->rest_rows);
  __Pyx_DECREF(__pyx_v_self->rest_rows);
  __pyx_v_self->rest_rows = __pyx_v_rest_rows;

  /* "cymysql/packet.pyx":304
 *             rest_rows.append(packet.read_decode_data(self.fields, decoder))
 *         self.rest_rows = rest_rows
 *         self.rest_row_index = 0             # <<<<<<<<<<<<<<
 * 
 *     cdef void _get_descriptions(self):
 */
  __pyx_v_self->rest_row_index = 0;

  /* "cymysql/packet.pyx":287
 *             self.read_rest_rowdata_packet()
 * 
 *     def read_rest_rowdata_packet(self):             # <<<<<<<<<<<<<<
 *         """Read rest rowdata packets for each data row in the result set."""
 *         cdef int is_eof, warning_count, server_status
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("cymysql.packet.MySQLResult.read_rest_rowdata_packet", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_rest_rows);
  __Pyx_XDECREF(__pyx_v_decoder);
  __Pyx_XDECREF((PyObject *)__pyx_v_packet);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/packet.pyx":306
 *         self.rest_row_index = 0
 * 
 *     cdef void _get_descriptions(self):             # <<<<<<<<<<<<<<
 *         """Read a column descriptor packet for each column in the result."""
 *         cdef int i
 */

static void __pyx_f_7cymysql_6packet_11MySQLResult__get_descriptions(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self) {
  CYTHON_UNUSED int __pyx_v_i;
  PyObject *__pyx_v_eof_packet = 0;
  PyObject *__pyx_v_description = NULL;
  struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *__pyx_v_field = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_get_descriptions", 0);

  /* "cymysql/packet.pyx":310
 *         cdef int i
 *         cdef object eof_packet
 *         self.fields = []             # <<<<<<<<<<<<<<
 *         description = []
 *         for i in range(self.field_count):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 310; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->fields);
  __Pyx_DECREF(__pyx_v_self->fields);
  __pyx_v_self->fields = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cymysql/packet.pyx":311
 *         cdef object eof_packet
 *         self.fields = []
 *         description = []             # <<<<<<<<<<<<<<
 *         for i in range(self.field_count):
 *             field = FieldDescriptorPacket(self.connection)
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 311; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_description = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "cymysql/packet.pyx":312
 *         self.fields = []
 *         description = []
 *         for i in range(self.field_count):             # <<<<<<<<<<<<<<
 *             field = FieldDescriptorPacket(self.connection)
 *             self.fields.append(field)
 */
  __pyx_t_2 = __pyx_v_self->field_count;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "cymysql/packet.pyx":313
 *         description = []
 *         for i in range(self.field_count):
 *             field = FieldDescriptorPacket(self.connection)             # <<<<<<<<<<<<<<
 *             self.fields.append(field)
 *             description.append(field.description())
 */
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 313; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_self->connection);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_self->connection);
    __Pyx_GIVEREF(__pyx_v_self->connection);
    __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_6packet_FieldDescriptorPacket)), __pyx_t_1, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 313; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF_SET(__pyx_v_field, ((struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)__pyx_t_4));
    __pyx_t_4 = 0;

    /* "cymysql/packet.pyx":314
 *         for i in range(self.field_count):
 *             field = FieldDescriptorPacket(self.connection)
 *             self.fields.append(field)             # <<<<<<<<<<<<<<
 *             description.append(field.description())
 * 
 */
    __pyx_t_5 = __Pyx_PyObject_Append(__pyx_v_self->fields, ((PyObject *)__pyx_v_field)); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 314; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "cymysql/packet.pyx":315
 *             field = FieldDescriptorPacket(self.connection)
 *             self.fields.append(field)
 *             description.append(field.description())             # <<<<<<<<<<<<<<
 * 
 *         eof_packet = MysqlPacket(self.connection)
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_field), __pyx_n_s_description); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 315; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = NULL;
    if (CYTHON_COMPILING_IN_CPYTHON && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    if (__pyx_t_6) {
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_6); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 315; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else {
      __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 315; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_5 = __Pyx_PyList_Append(__pyx_v_description, __pyx_t_4); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 315; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }

  /* "cymysql/packet.pyx":317
 *             description.append(field.description())
 * 
 *         eof_packet = MysqlPacket(self.connection)             # <<<<<<<<<<<<<<
 *         assert eof_packet.is_eof_packet(), 'Protocol error, expecting EOF'
 *         self.description = tuple(description)
 */
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 317; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_v_self->connection);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_self->connection);
  __Pyx_GIVEREF(__pyx_v_self->connection);
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_6packet_MysqlPacket)), __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 317; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_eof_packet = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cymysql/packet.pyx":318
 * 
 *         eof_packet = MysqlPacket(self.connection)
 *         assert eof_packet.is_eof_packet(), 'Protocol error, expecting EOF'             # <<<<<<<<<<<<<<
 *         self.description = tuple(description)
 * 
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(!Py_OptimizeFlag)) {
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_eof_packet, __pyx_n_s_is_eof_packet); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 318; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = NULL;
    if (CYTHON_COMPILING_IN_CPYTHON && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (__pyx_t_6) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_6); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 318; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else {
      __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 318; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 318; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_7)) {
      PyErr_SetObject(PyExc_AssertionError, __pyx_kp_s_Protocol_error_expecting_EOF);
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 318; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
  }
  #endif

  /* "cymysql/packet.pyx":319
 *         eof_packet = MysqlPacket(self.connection)
 *         assert eof_packet.is_eof_packet(), 'Protocol error, expecting EOF'
 *         self.description = tuple(description)             # <<<<<<<<<<<<<<
 * 
 *     def fetchone(self):
 */
  __pyx_t_1 = PyList_AsTuple(__pyx_v_description); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 319; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->description);
  __Pyx_DECREF(__pyx_v_self->description);
  __pyx_v_self->description = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cymysql/packet.pyx":306
 *         self.rest_row_index = 0
 * 
 *     cdef void _get_descriptions(self):             # <<<<<<<<<<<<<<
 *         """Read a column descriptor packet for each column in the result."""
 *         cdef int i
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_WriteUnraisable("cymysql.packet.MySQLResult._get_descriptions", __pyx_clineno, __pyx_lineno, __pyx_filename, 0);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_eof_packet);
  __Pyx_XDECREF(__pyx_v_description);
  __Pyx_XDECREF((PyObject *)__pyx_v_field);
  __Pyx_RefNannyFinishContext();
}

/* "cymysql/packet.pyx":321
 *         self.description = tuple(description)
 * 
 *     def fetchone(self):             # <<<<<<<<<<<<<<
 *         cdef int is_eof, warning_count, server_status
 *         if not self.has_result:
 */

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_6packet_11MySQLResult_5fetchone(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_7cymysql_6packet_11MySQLResult_5fetchone(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("fetchone (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_11MySQLResult_4fetchone(((struct __pyx_obj_7cymysql_6packet_MySQLResult *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_6packet_11MySQLResult_4fetchone(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self) {
  int __pyx_v_is_eof;
  int __pyx_v_warning_count;
  int __pyx_v_server_status;
  struct __pyx_obj_7cymysql_6packet_MysqlPacket *__pyx_v_packet = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  long __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("fetchone", 0);

  /* "cymysql/packet.pyx":323
 *     def fetchone(self):
 *         cdef int is_eof, warning_count, server_status
 *         if not self.has_result:             # <<<<<<<<<<<<<<
 *             return None
 *         if self.rest_rows is None:
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_self->has_result); if (unlikely(__pyx_t_1 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 323; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = ((!__pyx_t_1) != 0);
  if (__pyx_t_2) {

    /* "cymysql/packet.pyx":324
 *         cdef int is_eof, warning_count, server_status
 *         if not self.has_result:
 *             return None             # <<<<<<<<<<<<<<
 *         if self.rest_rows is None:
 *             packet = MysqlPacket(self.connection)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_None);
    __pyx_r = Py_None;
    goto __pyx_L0;
  }

  /* "cymysql/packet.pyx":325
 *         if not self.has_result:
 *             return None
 *         if self.rest_rows is None:             # <<<<<<<<<<<<<<
 *             packet = MysqlPacket(self.connection)
 *             is_eof, warning_count, server_status = packet.is_eof_and_status()
 */
  __pyx_t_2 = (__pyx_v_self->rest_rows == Py_None);
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "cymysql/packet.pyx":326
 *             return None
 *         if self.rest_rows is None:
 *             packet = MysqlPacket(self.connection)             # <<<<<<<<<<<<<<
 *             is_eof, warning_count, server_status = packet.is_eof_and_status()
 *             if is_eof:
 */
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 326; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_self->connection);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_self->connection);
    __Pyx_GIVEREF(__pyx_v_self->connection);
    __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_6packet_MysqlPacket)), __pyx_t_3, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 326; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_packet = ((struct __pyx_obj_7cymysql_6packet_MysqlPacket *)__pyx_t_4);
    __pyx_t_4 = 0;

    /* "cymysql/packet.pyx":327
 *         if self.rest_rows is None:
 *             packet = MysqlPacket(self.connection)
 *             is_eof, warning_count, server_status = packet.is_eof_and_status()             # <<<<<<<<<<<<<<
 *             if is_eof:
 *                 self.warning_count = warning_count
 */
    __pyx_t_4 = ((struct __pyx_vtabstruct_7cymysql_6packet_MysqlPacket *)__pyx_v_packet->__pyx_vtab)->is_eof_and_status(__pyx_v_packet, 0); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 327; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
      PyObject* sequence = __pyx_t_4;
      #if CYTHON_COMPILING_IN_CPYTHON
      Py_ssize_t size = Py_SIZE(sequence);
      #else
      Py_ssize_t size = PySequence_Size(sequence);
      #endif
      if (unlikely(size != 3)) {
        if (size > 3) __Pyx_RaiseTooManyValuesError(3);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 327; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      #if CYTHON_COMPILING_IN_CPYTHON
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1); 
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 2); 
      } else {
        __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_5 = PyList_GET_ITEM(sequence, 1); 
        __pyx_t_6 = PyList_GET_ITEM(sequence, 2); 
      }
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      #else
      __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 327; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 327; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 327; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      #endif
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_7 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 327; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_8 = Py_TYPE(__pyx_t_7)->tp_iternext;
      index = 0; __pyx_t_3 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_3)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_3);
      index = 1; __pyx_t_5 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_5)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_5);
      index = 2; __pyx_t_6 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_6)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_7), 3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 327; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_8 = NULL;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_unpacking_done;
      __pyx_L5_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_8 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 327; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_L6_unpacking_done:;
    }
    __pyx_t_9 = __Pyx_PyInt_As_int(__pyx_t_3); if (unlikely((__pyx_t_9 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 327; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_10 = __Pyx_PyInt_As_int(__pyx_t_5); if (unlikely((__pyx_t_10 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 327; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_11 = __Pyx_PyInt_As_int(__pyx_t_6); if (unlikely((__pyx_t_11 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 327; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_v_is_eof = __pyx_t_9;
    __pyx_v_warning_count = __pyx_t_10;
    __pyx_v_server_status = __pyx_t_11;

    /* "cymysql/packet.pyx":328
 *             packet = MysqlPacket(self.connection)
 *             is_eof, warning_count, server_status = packet.is_eof_and_status()
 *             if is_eof:             # <<<<<<<<<<<<<<
 *                 self.warning_count = warning_count
 *                 self.server_status = server_status
 */
    __pyx_t_1 = (__pyx_v_is_eof != 0);
    if (__pyx_t_1) {

      /* "cymysql/packet.pyx":329
 *             is_eof, warning_count, server_status = packet.is_eof_and_status()
 *             if is_eof:
 *                 self.warning_count = warning_count             # <<<<<<<<<<<<<<
 *                 self.server_status = server_status
 *                 self.has_next = (server_status & SERVER_MORE_RESULTS_EXISTS)
 */
      __pyx_v_self->warning_count = __pyx_v_warning_count;

      /* "cymysql/packet.pyx":330
 *             if is_eof:
 *                 self.warning_count = warning_count
 *                 self.server_status = server_status             # <<<<<<<<<<<<<<
 *                 self.has_next = (server_status & SERVER_MORE_RESULTS_EXISTS)
 *                 self.rest_rows = []
 */
      __pyx_v_self->server_status = __pyx_v_server_status;

      /* "cymysql/packet.pyx":331
 *                 self.warning_count = warning_count
 *                 self.server_status = server_status
 *                 self.has_next = (server_status & SERVER_MORE_RESULTS_EXISTS)             # <<<<<<<<<<<<<<
 *                 self.rest_rows = []
 *                 return None
 */
      __pyx_v_self->has_next = (__pyx_v_server_status & __pyx_v_7cymysql_6packet_SERVER_MORE_RESULTS_EXISTS);

      /* "cymysql/packet.pyx":332
 *                 self.server_status = server_status
 *                 self.has_next = (server_status & SERVER_MORE_RESULTS_EXISTS)
 *                 self.rest_rows = []             # <<<<<<<<<<<<<<
 *                 return None
 *             return packet.read_decode_data(self.fields, self.connection.conv)
 */
      __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 332; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_v_self->rest_rows);
      __Pyx_DECREF(__pyx_v_self->rest_rows);
      __pyx_v_self->rest_rows = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "cymysql/packet.pyx":333
 *                 self.has_next = (server_status & SERVER_MORE_RESULTS_EXISTS)
 *                 self.rest_rows = []
 *                 return None             # <<<<<<<<<<<<<<
 *             return packet.read_decode_data(self.fields, self.connection.conv)
 *         elif len(self.rest_rows) != self.rest_row_index:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_None);
      __pyx_r = Py_None;
      goto __pyx_L0;
    }

    /* "cymysql/packet.pyx":334
 *                 self.rest_rows = []
 *                 return None
 *             return packet.read_decode_data(self.fields, self.connection.conv)             # <<<<<<<<<<<<<<
 *         elif len(self.rest_rows) != self.rest_row_index:
 *             self.rest_row_index += 1
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = __pyx_v_self->fields;
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->connection, __pyx_n_s_conv); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 334; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = ((struct __pyx_vtabstruct_7cymysql_6packet_MysqlPacket *)__pyx_v_packet->__pyx_vtab)->read_decode_data(__pyx_v_packet, __pyx_t_4, __pyx_t_6); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 334; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;
  }

  /* "cymysql/packet.pyx":335
 *                 return None
 *             return packet.read_decode_data(self.fields, self.connection.conv)
 *         elif len(self.rest_rows) != self.rest_row_index:             # <<<<<<<<<<<<<<
 *             self.rest_row_index += 1
 *             return self.rest_rows[self.rest_row_index-1]
 */
  __pyx_t_5 = __pyx_v_self->rest_rows;
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_12 = PyObject_Length(__pyx_t_5); if (unlikely(__pyx_t_12 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 335; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_1 = ((__pyx_t_12 != __pyx_v_self->rest_row_index) != 0);
  if (__pyx_t_1) {

    /* "cymysql/packet.pyx":336
 *             return packet.read_decode_data(self.fields, self.connection.conv)
 *         elif len(self.rest_rows) != self.rest_row_index:
 *             self.rest_row_index += 1             # <<<<<<<<<<<<<<
 *             return self.rest_rows[self.rest_row_index-1]
 *         return None
 */
    __pyx_v_self->rest_row_index = (__pyx_v_self->rest_row_index + 1);

    /* "cymysql/packet.pyx":337
 *         elif len(self.rest_rows) != self.rest_row_index:
 *             self.rest_row_index += 1
 *             return self.rest_rows[self.rest_row_index-1]             # <<<<<<<<<<<<<<
 *         return None
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_13 = (__pyx_v_self->rest_row_index - 1);
    __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_self->rest_rows, __pyx_t_13, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(__pyx_t_5 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 337; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;
  }

  /* "cymysql/packet.pyx":338
 *             self.rest_row_index += 1
 *             return self.rest_rows[self.rest_row_index-1]
 *         return None             # <<<<<<<<<<<<<<
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_None);
  __pyx_r = Py_None;
  goto __pyx_L0;

  /* "cymysql/packet.pyx":321
 *         self.description = tuple(description)
 * 
 *     def fetchone(self):             # <<<<<<<<<<<<<<
 *         cdef int is_eof, warning_count, server_status
 *         if not self.has_result:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("cymysql.packet.MySQLResult.fetchone", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_packet);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/packet.pyx":254
 * #       of MysqlPacket like has been done with FieldDescriptorPacket.
 * cdef class MySQLResult(object):
 *     cdef public object affected_rows, insert_id, rest_rows, has_result             # <<<<<<<<<<<<<<
 *     cdef public object message, description
 *     cdef object connection, first_packet, fields
 */

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_6packet_11MySQLResult_13affected_rows_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_7cymysql_6packet_11MySQLResult_13affected_rows_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_11MySQLResult_13affected_rows___get__(((struct __pyx_obj_7cymysql_6packet_MySQLResult *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_6packet_11MySQLResult_13affected_rows___get__(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->affected_rows);
  __pyx_r = __pyx_v_self->affected_rows;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_6packet_11MySQLResult_13affected_rows_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_7cymysql_6packet_11MySQLResult_13affected_rows_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_11MySQLResult_13affected_rows_2__set__(((struct __pyx_obj_7cymysql_6packet_MySQLResult *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_6packet_11MySQLResult_13affected_rows_2__set__(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->affected_rows);
  __Pyx_DECREF(__pyx_v_self->affected_rows);
  __pyx_v_self->affected_rows = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_6packet_11MySQLResult_13affected_rows_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_7cymysql_6packet_11MySQLResult_13affected_rows_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_11MySQLResult_13affected_rows_4__del__(((struct __pyx_obj_7cymysql_6packet_MySQLResult *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_6packet_11MySQLResult_13affected_rows_4__del__(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->affected_rows);
  __Pyx_DECREF(__pyx_v_self->affected_rows);
  __pyx_v_self->affected_rows = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_6packet_11MySQLResult_9insert_id_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_7cymysql_6packet_11MySQLResult_9insert_id_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_11MySQLResult_9insert_id___get__(((struct __pyx_obj_7cymysql_6packet_MySQLResult *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_6packet_11MySQLResult_9insert_id___get__(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->insert_id);
  __pyx_r = __pyx_v_self->insert_id;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_6packet_11MySQLResult_9insert_id_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_7cymysql_6packet_11MySQLResult_9insert_id_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_11MySQLResult_9insert_id_2__set__(((struct __pyx_obj_7cymysql_6packet_MySQLResult *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_6packet_11MySQLResult_9insert_id_2__set__(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->insert_id);
  __Pyx_DECREF(__pyx_v_self->insert_id);
  __pyx_v_self->insert_id = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_6packet_11MySQLResult_9insert_id_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_7cymysql_6packet_11MySQLResult_9insert_id_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_11MySQLResult_9insert_id_4__del__(((struct __pyx_obj_7cymysql_6packet_MySQLResult *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_6packet_11MySQLResult_9insert_id_4__del__(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->insert_id);
  __Pyx_DECREF(__pyx_v_self->insert_id);
  __pyx_v_self->insert_id = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_6packet_11MySQLResult_9rest_rows_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_7cymysql_6packet_11MySQLResult_9rest_rows_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_11MySQLResult_9rest_rows___get__(((struct __pyx_obj_7cymysql_6packet_MySQLResult *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_6packet_11MySQLResult_9rest_rows___get__(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->rest_rows);
  __pyx_r = __pyx_v_self->rest_rows;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_6packet_11MySQLResult_9rest_rows_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_7cymysql_6packet_11MySQLResult_9rest_rows_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_11MySQLResult_9rest_rows_2__set__(((struct __pyx_obj_7cymysql_6packet_MySQLResult *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_6packet_11MySQLResult_9rest_rows_2__set__(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->rest_rows);
  __Pyx_DECREF(__pyx_v_self->rest_rows);
  __pyx_v_self->rest_rows = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_6packet_11MySQLResult_9rest_rows_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_7cymysql_6packet_11MySQLResult_9rest_rows_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_11MySQLResult_9rest_rows_4__del__(((struct __pyx_obj_7cymysql_6packet_MySQLResult *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_6packet_11MySQLResult_9rest_rows_4__del__(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->rest_rows);
  __Pyx_DECREF(__pyx_v_self->rest_rows);
  __pyx_v_self->rest_rows = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_6packet_11MySQLResult_10has_result_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_7cymysql_6packet_11MySQLResult_10has_result_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_11MySQLResult_10has_result___get__(((struct __pyx_obj_7cymysql_6packet_MySQLResult *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_6packet_11MySQLResult_10has_result___get__(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->has_result);
  __pyx_r = __pyx_v_self->has_result;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_6packet_11MySQLResult_10has_result_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_7cymysql_6packet_11MySQLResult_10has_result_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_11MySQLResult_10has_result_2__set__(((struct __pyx_obj_7cymysql_6packet_MySQLResult *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_6packet_11MySQLResult_10has_result_2__set__(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->has_result);
  __Pyx_DECREF(__pyx_v_self->has_result);
  __pyx_v_self->has_result = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_6packet_11MySQLResult_10has_result_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_7cymysql_6packet_11MySQLResult_10has_result_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_11MySQLResult_10has_result_4__del__(((struct __pyx_obj_7cymysql_6packet_MySQLResult *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_6packet_11MySQLResult_10has_result_4__del__(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->has_result);
  __Pyx_DECREF(__pyx_v_self->has_result);
  __pyx_v_self->has_result = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/packet.pyx":255
 * cdef class MySQLResult(object):
 *     cdef public object affected_rows, insert_id, rest_rows, has_result
 *     cdef public object message, description             # <<<<<<<<<<<<<<
 *     cdef object connection, first_packet, fields
 *     cdef public int has_next
 */

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_6packet_11MySQLResult_7message_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_7cymysql_6packet_11MySQLResult_7message_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_11MySQLResult_7message___get__(((struct __pyx_obj_7cymysql_6packet_MySQLResult *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_6packet_11MySQLResult_7message___get__(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->message);
  __pyx_r = __pyx_v_self->message;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_6packet_11MySQLResult_7message_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_7cymysql_6packet_11MySQLResult_7message_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_11MySQLResult_7message_2__set__(((struct __pyx_obj_7cymysql_6packet_MySQLResult *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_6packet_11MySQLResult_7message_2__set__(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->message);
  __Pyx_DECREF(__pyx_v_self->message);
  __pyx_v_self->message = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_6packet_11MySQLResult_7message_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_7cymysql_6packet_11MySQLResult_7message_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_11MySQLResult_7message_4__del__(((struct __pyx_obj_7cymysql_6packet_MySQLResult *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_6packet_11MySQLResult_7message_4__del__(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->message);
  __Pyx_DECREF(__pyx_v_self->message);
  __pyx_v_self->message = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_6packet_11MySQLResult_11description_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_7cymysql_6packet_11MySQLResult_11description_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_11MySQLResult_11description___get__(((struct __pyx_obj_7cymysql_6packet_MySQLResult *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_6packet_11MySQLResult_11description___get__(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->description);
  __pyx_r = __pyx_v_self->description;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_6packet_11MySQLResult_11description_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_7cymysql_6packet_11MySQLResult_11description_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_11MySQLResult_11description_2__set__(((struct __pyx_obj_7cymysql_6packet_MySQLResult *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_6packet_11MySQLResult_11description_2__set__(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->description);
  __Pyx_DECREF(__pyx_v_self->description);
  __pyx_v_self->description = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_6packet_11MySQLResult_11description_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_7cymysql_6packet_11MySQLResult_11description_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_11MySQLResult_11description_4__del__(((struct __pyx_obj_7cymysql_6packet_MySQLResult *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_6packet_11MySQLResult_11description_4__del__(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->description);
  __Pyx_DECREF(__pyx_v_self->description);
  __pyx_v_self->description = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/packet.pyx":257
 *     cdef public object message, description
 *     cdef object connection, first_packet, fields
 *     cdef public int has_next             # <<<<<<<<<<<<<<
 *     cdef int rest_row_index, server_status, warning_count, field_count
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_6packet_11MySQLResult_8has_next_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_7cymysql_6packet_11MySQLResult_8has_next_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_11MySQLResult_8has_next___get__(((struct __pyx_obj_7cymysql_6packet_MySQLResult *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_6packet_11MySQLResult_8has_next___get__(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->has_next); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 257; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cymysql.packet.MySQLResult.has_next.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_6packet_11MySQLResult_8has_next_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_7cymysql_6packet_11MySQLResult_8has_next_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_6packet_11MySQLResult_8has_next_2__set__(((struct __pyx_obj_7cymysql_6packet_MySQLResult *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_6packet_11MySQLResult_8has_next_2__set__(struct __pyx_obj_7cymysql_6packet_MySQLResult *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 257; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_self->has_next = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cymysql.packet.MySQLResult.has_next.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static struct __pyx_vtabstruct_7cymysql_6packet_MysqlPacket __pyx_vtable_7cymysql_6packet_MysqlPacket;

static PyObject *__pyx_tp_new_7cymysql_6packet_MysqlPacket(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_7cymysql_6packet_MysqlPacket *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_7cymysql_6packet_MysqlPacket *)o);
  p->__pyx_vtab = __pyx_vtabptr_7cymysql_6packet_MysqlPacket;
  p->connection = Py_None; Py_INCREF(Py_None);
  p->_socket = Py_None; Py_INCREF(Py_None);
  p->_charset = Py_None; Py_INCREF(Py_None);
  p->_use_unicode = Py_None; Py_INCREF(Py_None);
  p->__pyx___data = ((PyObject*)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_7cymysql_6packet_MysqlPacket(PyObject *o) {
  struct __pyx_obj_7cymysql_6packet_MysqlPacket *p = (struct __pyx_obj_7cymysql_6packet_MysqlPacket *)o;
  #if PY_VERSION_HEX >= 0x030400a1
  if (unlikely(Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->connection);
  Py_CLEAR(p->_socket);
  Py_CLEAR(p->_charset);
  Py_CLEAR(p->_use_unicode);
  Py_CLEAR(p->__pyx___data);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_7cymysql_6packet_MysqlPacket(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_7cymysql_6packet_MysqlPacket *p = (struct __pyx_obj_7cymysql_6packet_MysqlPacket *)o;
  if (p->connection) {
    e = (*v)(p->connection, a); if (e) return e;
  }
  if (p->_socket) {
    e = (*v)(p->_socket, a); if (e) return e;
  }
  if (p->_charset) {
    e = (*v)(p->_charset, a); if (e) return e;
  }
  if (p->_use_unicode) {
    e = (*v)(p->_use_unicode, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_7cymysql_6packet_MysqlPacket(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_7cymysql_6packet_MysqlPacket *p = (struct __pyx_obj_7cymysql_6packet_MysqlPacket *)o;
  tmp = ((PyObject*)p->connection);
  p->connection = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_socket);
  p->_socket = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_charset);
  p->_charset = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_use_unicode);
  p->_use_unicode = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_7cymysql_6packet_MysqlPacket[] = {
  {"get_all_data", (PyCFunction)__pyx_pw_7cymysql_6packet_11MysqlPacket_3get_all_data, METH_NOARGS, 0},
  {"read", (PyCFunction)__pyx_pw_7cymysql_6packet_11MysqlPacket_5read, METH_O, 0},
  {"is_ok_packet", (PyCFunction)__pyx_pw_7cymysql_6packet_11MysqlPacket_7is_ok_packet, METH_NOARGS, 0},
  {"is_eof_packet", (PyCFunction)__pyx_pw_7cymysql_6packet_11MysqlPacket_9is_eof_packet, METH_NOARGS, 0},
  {"is_eof_and_status", (PyCFunction)__pyx_pw_7cymysql_6packet_11MysqlPacket_11is_eof_and_status, METH_NOARGS, 0},
  {"read_ok_packet", (PyCFunction)__pyx_pw_7cymysql_6packet_11MysqlPacket_13read_ok_packet, METH_NOARGS, 0},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_7cymysql_6packet_MysqlPacket = {
  PyVarObject_HEAD_INIT(0, 0)
  "cymysql.packet.MysqlPacket", /*tp_name*/
  sizeof(struct __pyx_obj_7cymysql_6packet_MysqlPacket), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_7cymysql_6packet_MysqlPacket, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  "Representation of a MySQL response packet.  Reads in the packet\n    from the network socket, removes packet header and provides an interface\n    for reading/parsing the packet results.", /*tp_doc*/
  __pyx_tp_traverse_7cymysql_6packet_MysqlPacket, /*tp_traverse*/
  __pyx_tp_clear_7cymysql_6packet_MysqlPacket, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_7cymysql_6packet_MysqlPacket, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_7cymysql_6packet_11MysqlPacket_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_7cymysql_6packet_MysqlPacket, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_7cymysql_6packet_FieldDescriptorPacket __pyx_vtable_7cymysql_6packet_FieldDescriptorPacket;

static PyObject *__pyx_tp_new_7cymysql_6packet_FieldDescriptorPacket(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *p;
  PyObject *o = __pyx_tp_new_7cymysql_6packet_MysqlPacket(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_7cymysql_6packet_MysqlPacket*)__pyx_vtabptr_7cymysql_6packet_FieldDescriptorPacket;
  p->catalog = Py_None; Py_INCREF(Py_None);
  p->db = Py_None; Py_INCREF(Py_None);
  p->table_name = Py_None; Py_INCREF(Py_None);
  p->org_table = Py_None; Py_INCREF(Py_None);
  p->name = Py_None; Py_INCREF(Py_None);
  p->org_name = Py_None; Py_INCREF(Py_None);
  p->charset = ((PyObject*)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_7cymysql_6packet_FieldDescriptorPacket(PyObject *o) {
  struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *p = (struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)o;
  #if PY_VERSION_HEX >= 0x030400a1
  if (unlikely(Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->catalog);
  Py_CLEAR(p->db);
  Py_CLEAR(p->table_name);
  Py_CLEAR(p->org_table);
  Py_CLEAR(p->name);
  Py_CLEAR(p->org_name);
  Py_CLEAR(p->charset);
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_7cymysql_6packet_MysqlPacket(o);
}

static int __pyx_tp_traverse_7cymysql_6packet_FieldDescriptorPacket(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *p = (struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)o;
  e = __pyx_tp_traverse_7cymysql_6packet_MysqlPacket(o, v, a); if (e) return e;
  if (p->catalog) {
    e = (*v)(p->catalog, a); if (e) return e;
  }
  if (p->db) {
    e = (*v)(p->db, a); if (e) return e;
  }
  if (p->table_name) {
    e = (*v)(p->table_name, a); if (e) return e;
  }
  if (p->org_table) {
    e = (*v)(p->org_table, a); if (e) return e;
  }
  if (p->name) {
    e = (*v)(p->name, a); if (e) return e;
  }
  if (p->org_name) {
    e = (*v)(p->org_name, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_7cymysql_6packet_FieldDescriptorPacket(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *p = (struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket *)o;
  __pyx_tp_clear_7cymysql_6packet_MysqlPacket(o);
  tmp = ((PyObject*)p->catalog);
  p->catalog = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->db);
  p->db = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->table_name);
  p->table_name = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->org_table);
  p->org_table = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->name);
  p->name = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->org_name);
  p->org_name = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_7cymysql_6packet_21FieldDescriptorPacket_catalog(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_7catalog_1__get__(o);
}

static int __pyx_setprop_7cymysql_6packet_21FieldDescriptorPacket_catalog(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_7catalog_3__set__(o, v);
  }
  else {
    return __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_7catalog_5__del__(o);
  }
}

static PyObject *__pyx_getprop_7cymysql_6packet_21FieldDescriptorPacket_db(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_2db_1__get__(o);
}

static int __pyx_setprop_7cymysql_6packet_21FieldDescriptorPacket_db(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_2db_3__set__(o, v);
  }
  else {
    return __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_2db_5__del__(o);
  }
}

static PyObject *__pyx_getprop_7cymysql_6packet_21FieldDescriptorPacket_table_name(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_10table_name_1__get__(o);
}

static int __pyx_setprop_7cymysql_6packet_21FieldDescriptorPacket_table_name(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_10table_name_3__set__(o, v);
  }
  else {
    return __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_10table_name_5__del__(o);
  }
}

static PyObject *__pyx_getprop_7cymysql_6packet_21FieldDescriptorPacket_org_table(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_9org_table_1__get__(o);
}

static int __pyx_setprop_7cymysql_6packet_21FieldDescriptorPacket_org_table(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_9org_table_3__set__(o, v);
  }
  else {
    return __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_9org_table_5__del__(o);
  }
}

static PyObject *__pyx_getprop_7cymysql_6packet_21FieldDescriptorPacket_name(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_4name_1__get__(o);
}

static int __pyx_setprop_7cymysql_6packet_21FieldDescriptorPacket_name(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_4name_3__set__(o, v);
  }
  else {
    return __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_4name_5__del__(o);
  }
}

static PyObject *__pyx_getprop_7cymysql_6packet_21FieldDescriptorPacket_org_name(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_8org_name_1__get__(o);
}

static int __pyx_setprop_7cymysql_6packet_21FieldDescriptorPacket_org_name(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_8org_name_3__set__(o, v);
  }
  else {
    return __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_8org_name_5__del__(o);
  }
}

static PyObject *__pyx_getprop_7cymysql_6packet_21FieldDescriptorPacket_charsetnr(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_9charsetnr_1__get__(o);
}

static int __pyx_setprop_7cymysql_6packet_21FieldDescriptorPacket_charsetnr(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_9charsetnr_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_7cymysql_6packet_21FieldDescriptorPacket_length(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_6length_1__get__(o);
}

static int __pyx_setprop_7cymysql_6packet_21FieldDescriptorPacket_length(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_6length_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_7cymysql_6packet_21FieldDescriptorPacket_type_code(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_9type_code_1__get__(o);
}

static int __pyx_setprop_7cymysql_6packet_21FieldDescriptorPacket_type_code(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_9type_code_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_7cymysql_6packet_21FieldDescriptorPacket_flags(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_5flags_1__get__(o);
}

static int __pyx_setprop_7cymysql_6packet_21FieldDescriptorPacket_flags(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_5flags_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_7cymysql_6packet_21FieldDescriptorPacket_scale(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_5scale_1__get__(o);
}

static int __pyx_setprop_7cymysql_6packet_21FieldDescriptorPacket_scale(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_5scale_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_7cymysql_6packet_21FieldDescriptorPacket_is_set(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_6is_set_1__get__(o);
}

static int __pyx_setprop_7cymysql_6packet_21FieldDescriptorPacket_is_set(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_6is_set_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_7cymysql_6packet_21FieldDescriptorPacket_is_binary(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_9is_binary_1__get__(o);
}

static int __pyx_setprop_7cymysql_6packet_21FieldDescriptorPacket_is_binary(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_9is_binary_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_7cymysql_6packet_21FieldDescriptorPacket_charset(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_7charset_1__get__(o);
}

static int __pyx_setprop_7cymysql_6packet_21FieldDescriptorPacket_charset(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_7charset_3__set__(o, v);
  }
  else {
    return __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_7charset_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_7cymysql_6packet_FieldDescriptorPacket[] = {
  {"__parse_field_descriptor", (PyCFunction)__pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_3__parse_field_descriptor, METH_NOARGS, __pyx_doc_7cymysql_6packet_21FieldDescriptorPacket_2__parse_field_descriptor},
  {"description", (PyCFunction)__pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_5description, METH_NOARGS, __pyx_doc_7cymysql_6packet_21FieldDescriptorPacket_4description},
  {"get_column_length", (PyCFunction)__pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_7get_column_length, METH_NOARGS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_7cymysql_6packet_FieldDescriptorPacket[] = {
  {(char *)"catalog", __pyx_getprop_7cymysql_6packet_21FieldDescriptorPacket_catalog, __pyx_setprop_7cymysql_6packet_21FieldDescriptorPacket_catalog, 0, 0},
  {(char *)"db", __pyx_getprop_7cymysql_6packet_21FieldDescriptorPacket_db, __pyx_setprop_7cymysql_6packet_21FieldDescriptorPacket_db, 0, 0},
  {(char *)"table_name", __pyx_getprop_7cymysql_6packet_21FieldDescriptorPacket_table_name, __pyx_setprop_7cymysql_6packet_21FieldDescriptorPacket_table_name, 0, 0},
  {(char *)"org_table", __pyx_getprop_7cymysql_6packet_21FieldDescriptorPacket_org_table, __pyx_setprop_7cymysql_6packet_21FieldDescriptorPacket_org_table, 0, 0},
  {(char *)"name", __pyx_getprop_7cymysql_6packet_21FieldDescriptorPacket_name, __pyx_setprop_7cymysql_6packet_21FieldDescriptorPacket_name, 0, 0},
  {(char *)"org_name", __pyx_getprop_7cymysql_6packet_21FieldDescriptorPacket_org_name, __pyx_setprop_7cymysql_6packet_21FieldDescriptorPacket_org_name, 0, 0},
  {(char *)"charsetnr", __pyx_getprop_7cymysql_6packet_21FieldDescriptorPacket_charsetnr, __pyx_setprop_7cymysql_6packet_21FieldDescriptorPacket_charsetnr, 0, 0},
  {(char *)"length", __pyx_getprop_7cymysql_6packet_21FieldDescriptorPacket_length, __pyx_setprop_7cymysql_6packet_21FieldDescriptorPacket_length, 0, 0},
  {(char *)"type_code", __pyx_getprop_7cymysql_6packet_21FieldDescriptorPacket_type_code, __pyx_setprop_7cymysql_6packet_21FieldDescriptorPacket_type_code, 0, 0},
  {(char *)"flags", __pyx_getprop_7cymysql_6packet_21FieldDescriptorPacket_flags, __pyx_setprop_7cymysql_6packet_21FieldDescriptorPacket_flags, 0, 0},
  {(char *)"scale", __pyx_getprop_7cymysql_6packet_21FieldDescriptorPacket_scale, __pyx_setprop_7cymysql_6packet_21FieldDescriptorPacket_scale, 0, 0},
  {(char *)"is_set", __pyx_getprop_7cymysql_6packet_21FieldDescriptorPacket_is_set, __pyx_setprop_7cymysql_6packet_21FieldDescriptorPacket_is_set, 0, 0},
  {(char *)"is_binary", __pyx_getprop_7cymysql_6packet_21FieldDescriptorPacket_is_binary, __pyx_setprop_7cymysql_6packet_21FieldDescriptorPacket_is_binary, 0, 0},
  {(char *)"charset", __pyx_getprop_7cymysql_6packet_21FieldDescriptorPacket_charset, __pyx_setprop_7cymysql_6packet_21FieldDescriptorPacket_charset, 0, 0},
  {0, 0, 0, 0, 0}
};

static PyTypeObject __pyx_type_7cymysql_6packet_FieldDescriptorPacket = {
  PyVarObject_HEAD_INIT(0, 0)
  "cymysql.packet.FieldDescriptorPacket", /*tp_name*/
  sizeof(struct __pyx_obj_7cymysql_6packet_FieldDescriptorPacket), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_7cymysql_6packet_FieldDescriptorPacket, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_9__str__, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  "A MysqlPacket that represents a specific column's metadata in the result.\n\n    Parsing is automatically done and the results are exported via public\n    attributes on the class such as: db, table_name, name, length, type_code.\n    ", /*tp_doc*/
  __pyx_tp_traverse_7cymysql_6packet_FieldDescriptorPacket, /*tp_traverse*/
  __pyx_tp_clear_7cymysql_6packet_FieldDescriptorPacket, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_7cymysql_6packet_FieldDescriptorPacket, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_7cymysql_6packet_FieldDescriptorPacket, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_7cymysql_6packet_21FieldDescriptorPacket_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_7cymysql_6packet_FieldDescriptorPacket, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_7cymysql_6packet_MySQLResult __pyx_vtable_7cymysql_6packet_MySQLResult;

static PyObject *__pyx_tp_new_7cymysql_6packet_MySQLResult(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_7cymysql_6packet_MySQLResult *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_7cymysql_6packet_MySQLResult *)o);
  p->__pyx_vtab = __pyx_vtabptr_7cymysql_6packet_MySQLResult;
  p->affected_rows = Py_None; Py_INCREF(Py_None);
  p->insert_id = Py_None; Py_INCREF(Py_None);
  p->rest_rows = Py_None; Py_INCREF(Py_None);
  p->has_result = Py_None; Py_INCREF(Py_None);
  p->message = Py_None; Py_INCREF(Py_None);
  p->description = Py_None; Py_INCREF(Py_None);
  p->connection = Py_None; Py_INCREF(Py_None);
  p->first_packet = Py_None; Py_INCREF(Py_None);
  p->fields = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_7cymysql_6packet_MySQLResult(PyObject *o) {
  struct __pyx_obj_7cymysql_6packet_MySQLResult *p = (struct __pyx_obj_7cymysql_6packet_MySQLResult *)o;
  #if PY_VERSION_HEX >= 0x030400a1
  if (unlikely(Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->affected_rows);
  Py_CLEAR(p->insert_id);
  Py_CLEAR(p->rest_rows);
  Py_CLEAR(p->has_result);
  Py_CLEAR(p->message);
  Py_CLEAR(p->description);
  Py_CLEAR(p->connection);
  Py_CLEAR(p->first_packet);
  Py_CLEAR(p->fields);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_7cymysql_6packet_MySQLResult(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_7cymysql_6packet_MySQLResult *p = (struct __pyx_obj_7cymysql_6packet_MySQLResult *)o;
  if (p->affected_rows) {
    e = (*v)(p->affected_rows, a); if (e) return e;
  }
  if (p->insert_id) {
    e = (*v)(p->insert_id, a); if (e) return e;
  }
  if (p->rest_rows) {
    e = (*v)(p->rest_rows, a); if (e) return e;
  }
  if (p->has_result) {
    e = (*v)(p->has_result, a); if (e) return e;
  }
  if (p->message) {
    e = (*v)(p->message, a); if (e) return e;
  }
  if (p->description) {
    e = (*v)(p->description, a); if (e) return e;
  }
  if (p->connection) {
    e = (*v)(p->connection, a); if (e) return e;
  }
  if (p->first_packet) {
    e = (*v)(p->first_packet, a); if (e) return e;
  }
  if (p->fields) {
    e = (*v)(p->fields, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_7cymysql_6packet_MySQLResult(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_7cymysql_6packet_MySQLResult *p = (struct __pyx_obj_7cymysql_6packet_MySQLResult *)o;
  tmp = ((PyObject*)p->affected_rows);
  p->affected_rows = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->insert_id);
  p->insert_id = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->rest_rows);
  p->rest_rows = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->has_result);
  p->has_result = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->message);
  p->message = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->description);
  p->description = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->connection);
  p->connection = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->first_packet);
  p->first_packet = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->fields);
  p->fields = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_7cymysql_6packet_11MySQLResult_affected_rows(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_7cymysql_6packet_11MySQLResult_13affected_rows_1__get__(o);
}

static int __pyx_setprop_7cymysql_6packet_11MySQLResult_affected_rows(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_7cymysql_6packet_11MySQLResult_13affected_rows_3__set__(o, v);
  }
  else {
    return __pyx_pw_7cymysql_6packet_11MySQLResult_13affected_rows_5__del__(o);
  }
}

static PyObject *__pyx_getprop_7cymysql_6packet_11MySQLResult_insert_id(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_7cymysql_6packet_11MySQLResult_9insert_id_1__get__(o);
}

static int __pyx_setprop_7cymysql_6packet_11MySQLResult_insert_id(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_7cymysql_6packet_11MySQLResult_9insert_id_3__set__(o, v);
  }
  else {
    return __pyx_pw_7cymysql_6packet_11MySQLResult_9insert_id_5__del__(o);
  }
}

static PyObject *__pyx_getprop_7cymysql_6packet_11MySQLResult_rest_rows(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_7cymysql_6packet_11MySQLResult_9rest_rows_1__get__(o);
}

static int __pyx_setprop_7cymysql_6packet_11MySQLResult_rest_rows(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_7cymysql_6packet_11MySQLResult_9rest_rows_3__set__(o, v);
  }
  else {
    return __pyx_pw_7cymysql_6packet_11MySQLResult_9rest_rows_5__del__(o);
  }
}

static PyObject *__pyx_getprop_7cymysql_6packet_11MySQLResult_has_result(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_7cymysql_6packet_11MySQLResult_10has_result_1__get__(o);
}

static int __pyx_setprop_7cymysql_6packet_11MySQLResult_has_result(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_7cymysql_6packet_11MySQLResult_10has_result_3__set__(o, v);
  }
  else {
    return __pyx_pw_7cymysql_6packet_11MySQLResult_10has_result_5__del__(o);
  }
}

static PyObject *__pyx_getprop_7cymysql_6packet_11MySQLResult_message(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_7cymysql_6packet_11MySQLResult_7message_1__get__(o);
}

static int __pyx_setprop_7cymysql_6packet_11MySQLResult_message(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_7cymysql_6packet_11MySQLResult_7message_3__set__(o, v);
  }
  else {
    return __pyx_pw_7cymysql_6packet_11MySQLResult_7message_5__del__(o);
  }
}

static PyObject *__pyx_getprop_7cymysql_6packet_11MySQLResult_description(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_7cymysql_6packet_11MySQLResult_11description_1__get__(o);
}

static int __pyx_setprop_7cymysql_6packet_11MySQLResult_description(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_7cymysql_6packet_11MySQLResult_11description_3__set__(o, v);
  }
  else {
    return __pyx_pw_7cymysql_6packet_11MySQLResult_11description_5__del__(o);
  }
}

static PyObject *__pyx_getprop_7cymysql_6packet_11MySQLResult_has_next(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_7cymysql_6packet_11MySQLResult_8has_next_1__get__(o);
}

static int __pyx_setprop_7cymysql_6packet_11MySQLResult_has_next(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_7cymysql_6packet_11MySQLResult_8has_next_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyMethodDef __pyx_methods_7cymysql_6packet_MySQLResult[] = {
  {"read_rest_rowdata_packet", (PyCFunction)__pyx_pw_7cymysql_6packet_11MySQLResult_3read_rest_rowdata_packet, METH_NOARGS, __pyx_doc_7cymysql_6packet_11MySQLResult_2read_rest_rowdata_packet},
  {"fetchone", (PyCFunction)__pyx_pw_7cymysql_6packet_11MySQLResult_5fetchone, METH_NOARGS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_7cymysql_6packet_MySQLResult[] = {
  {(char *)"affected_rows", __pyx_getprop_7cymysql_6packet_11MySQLResult_affected_rows, __pyx_setprop_7cymysql_6packet_11MySQLResult_affected_rows, 0, 0},
  {(char *)"insert_id", __pyx_getprop_7cymysql_6packet_11MySQLResult_insert_id, __pyx_setprop_7cymysql_6packet_11MySQLResult_insert_id, 0, 0},
  {(char *)"rest_rows", __pyx_getprop_7cymysql_6packet_11MySQLResult_rest_rows, __pyx_setprop_7cymysql_6packet_11MySQLResult_rest_rows, 0, 0},
  {(char *)"has_result", __pyx_getprop_7cymysql_6packet_11MySQLResult_has_result, __pyx_setprop_7cymysql_6packet_11MySQLResult_has_result, 0, 0},
  {(char *)"message", __pyx_getprop_7cymysql_6packet_11MySQLResult_message, __pyx_setprop_7cymysql_6packet_11MySQLResult_message, 0, 0},
  {(char *)"description", __pyx_getprop_7cymysql_6packet_11MySQLResult_description, __pyx_setprop_7cymysql_6packet_11MySQLResult_description, 0, 0},
  {(char *)"has_next", __pyx_getprop_7cymysql_6packet_11MySQLResult_has_next, __pyx_setprop_7cymysql_6packet_11MySQLResult_has_next, 0, 0},
  {0, 0, 0, 0, 0}
};

static PyTypeObject __pyx_type_7cymysql_6packet_MySQLResult = {
  PyVarObject_HEAD_INIT(0, 0)
  "cymysql.packet.MySQLResult", /*tp_name*/
  sizeof(struct __pyx_obj_7cymysql_6packet_MySQLResult), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_7cymysql_6packet_MySQLResult, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_7cymysql_6packet_MySQLResult, /*tp_traverse*/
  __pyx_tp_clear_7cymysql_6packet_MySQLResult, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_7cymysql_6packet_MySQLResult, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_7cymysql_6packet_MySQLResult, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_7cymysql_6packet_11MySQLResult_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_7cymysql_6packet_MySQLResult, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
static struct PyModuleDef __pyx_moduledef = {
  #if PY_VERSION_HEX < 0x03020000
    { PyObject_HEAD_INIT(NULL) NULL, 0, NULL },
  #else
    PyModuleDef_HEAD_INIT,
  #endif
    "packet",
    0, /* m_doc */
    -1, /* m_size */
    __pyx_methods /* m_methods */,
    NULL, /* m_reload */
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_kp_b_, __pyx_k_, sizeof(__pyx_k_), 0, 0, 0, 0},
  {&__pyx_n_s_BINARY, __pyx_k_BINARY, sizeof(__pyx_k_BINARY), 0, 0, 1, 1},
  {&__pyx_n_s_FLAG, __pyx_k_FLAG, sizeof(__pyx_k_FLAG), 0, 0, 1, 1},
  {&__pyx_kp_s_Lost_connection_to_MySQL_server, __pyx_k_Lost_connection_to_MySQL_server, sizeof(__pyx_k_Lost_connection_to_MySQL_server), 0, 0, 1, 0},
  {&__pyx_n_s_MBLENGTH, __pyx_k_MBLENGTH, sizeof(__pyx_k_MBLENGTH), 0, 0, 1, 1},
  {&__pyx_n_s_OperationalError, __pyx_k_OperationalError, sizeof(__pyx_k_OperationalError), 0, 0, 1, 1},
  {&__pyx_kp_s_Protocol_error_expecting_EOF, __pyx_k_Protocol_error_expecting_EOF, sizeof(__pyx_k_Protocol_error_expecting_EOF), 0, 0, 1, 0},
  {&__pyx_kp_s_Q, __pyx_k_Q, sizeof(__pyx_k_Q), 0, 0, 1, 0},
  {&__pyx_n_s_SERVER_MORE_RESULTS_EXISTS, __pyx_k_SERVER_MORE_RESULTS_EXISTS, sizeof(__pyx_k_SERVER_MORE_RESULTS_EXISTS), 0, 0, 1, 1},
  {&__pyx_n_s_SERVER_STATUS, __pyx_k_SERVER_STATUS, sizeof(__pyx_k_SERVER_STATUS), 0, 0, 1, 1},
  {&__pyx_n_s_SET, __pyx_k_SET, sizeof(__pyx_k_SET), 0, 0, 1, 1},
  {&__pyx_n_s_append, __pyx_k_append, sizeof(__pyx_k_append), 0, 0, 1, 1},
  {&__pyx_n_s_charset, __pyx_k_charset, sizeof(__pyx_k_charset), 0, 0, 1, 1},
  {&__pyx_n_s_charset_by_id, __pyx_k_charset_by_id, sizeof(__pyx_k_charset_by_id), 0, 0, 1, 1},
  {&__pyx_n_s_class, __pyx_k_class, sizeof(__pyx_k_class), 0, 0, 1, 1},
  {&__pyx_n_s_connection, __pyx_k_connection, sizeof(__pyx_k_connection), 0, 0, 1, 1},
  {&__pyx_n_s_conv, __pyx_k_conv, sizeof(__pyx_k_conv), 0, 0, 1, 1},
  {&__pyx_n_s_convert_characters, __pyx_k_convert_characters, sizeof(__pyx_k_convert_characters), 0, 0, 1, 1},
  {&__pyx_n_s_cymysql_charset, __pyx_k_cymysql_charset, sizeof(__pyx_k_cymysql_charset), 0, 0, 1, 1},
  {&__pyx_n_s_cymysql_constants, __pyx_k_cymysql_constants, sizeof(__pyx_k_cymysql_constants), 0, 0, 1, 1},
  {&__pyx_n_s_cymysql_converters, __pyx_k_cymysql_converters, sizeof(__pyx_k_cymysql_converters), 0, 0, 1, 1},
  {&__pyx_n_s_cymysql_err, __pyx_k_cymysql_err, sizeof(__pyx_k_cymysql_err), 0, 0, 1, 1},
  {&__pyx_n_s_decode, __pyx_k_decode, sizeof(__pyx_k_decode), 0, 0, 1, 1},
  {&__pyx_n_s_description, __pyx_k_description, sizeof(__pyx_k_description), 0, 0, 1, 1},
  {&__pyx_n_s_get, __pyx_k_get, sizeof(__pyx_k_get), 0, 0, 1, 1},
  {&__pyx_n_s_get_column_length, __pyx_k_get_column_length, sizeof(__pyx_k_get_column_length), 0, 0, 1, 1},
  {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
  {&__pyx_n_s_init, __pyx_k_init, sizeof(__pyx_k_init), 0, 0, 1, 1},
  {&__pyx_n_s_is_eof_and_status, __pyx_k_is_eof_and_status, sizeof(__pyx_k_is_eof_and_status), 0, 0, 1, 1},
  {&__pyx_n_s_is_eof_packet, __pyx_k_is_eof_packet, sizeof(__pyx_k_is_eof_packet), 0, 0, 1, 1},
  {&__pyx_n_s_is_ok_packet, __pyx_k_is_ok_packet, sizeof(__pyx_k_is_ok_packet), 0, 0, 1, 1},
  {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
  {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
  {&__pyx_n_s_ord, __pyx_k_ord, sizeof(__pyx_k_ord), 0, 0, 1, 1},
  {&__pyx_n_s_parse_field_descriptor, __pyx_k_parse_field_descriptor, sizeof(__pyx_k_parse_field_descriptor), 0, 0, 1, 1},
  {&__pyx_n_s_proxy, __pyx_k_proxy, sizeof(__pyx_k_proxy), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_vtable, __pyx_k_pyx_vtable, sizeof(__pyx_k_pyx_vtable), 0, 0, 1, 1},
  {&__pyx_n_s_raise_mysql_exception, __pyx_k_raise_mysql_exception, sizeof(__pyx_k_raise_mysql_exception), 0, 0, 1, 1},
  {&__pyx_n_s_range, __pyx_k_range, sizeof(__pyx_k_range), 0, 0, 1, 1},
  {&__pyx_n_s_read, __pyx_k_read, sizeof(__pyx_k_read), 0, 0, 1, 1},
  {&__pyx_n_s_read_ok_packet, __pyx_k_read_ok_packet, sizeof(__pyx_k_read_ok_packet), 0, 0, 1, 1},
  {&__pyx_n_s_read_rest_rowdata_packet, __pyx_k_read_rest_rowdata_packet, sizeof(__pyx_k_read_rest_rowdata_packet), 0, 0, 1, 1},
  {&__pyx_n_s_recv, __pyx_k_recv, sizeof(__pyx_k_recv), 0, 0, 1, 1},
  {&__pyx_kp_s_s_s_s_s_type_s, __pyx_k_s_s_s_s_type_s, sizeof(__pyx_k_s_s_s_s_type_s), 0, 0, 1, 0},
  {&__pyx_n_s_socket, __pyx_k_socket, sizeof(__pyx_k_socket), 0, 0, 1, 1},
  {&__pyx_n_s_struct, __pyx_k_struct, sizeof(__pyx_k_struct), 0, 0, 1, 1},
  {&__pyx_n_s_sys, __pyx_k_sys, sizeof(__pyx_k_sys), 0, 0, 1, 1},
  {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
  {&__pyx_n_s_type_code, __pyx_k_type_code, sizeof(__pyx_k_type_code), 0, 0, 1, 1},
  {&__pyx_n_s_unpack, __pyx_k_unpack, sizeof(__pyx_k_unpack), 0, 0, 1, 1},
  {&__pyx_n_s_use_unicode, __pyx_k_use_unicode, sizeof(__pyx_k_use_unicode), 0, 0, 1, 1},
  {&__pyx_n_s_version_info, __pyx_k_version_info, sizeof(__pyx_k_version_info), 0, 0, 1, 1},
  {&__pyx_n_s_weakref, __pyx_k_weakref, sizeof(__pyx_k_weakref), 0, 0, 1, 1},
  {0, 0, 0, 0, 0, 0, 0}
};
static int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_ord = __Pyx_GetBuiltinName(__pyx_n_s_ord); if (!__pyx_builtin_ord) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 216; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_range = __Pyx_GetBuiltinName(__pyx_n_s_range); if (!__pyx_builtin_range) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 312; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  return 0;
  __pyx_L1_error:;
  return -1;
}

static int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "cymysql/packet.pyx":85
 *         cdef bytes packet_header, r, recv_data
 *         cdef int size
 *         packet_header = self._socket.recv(4)             # <<<<<<<<<<<<<<
 *         if len(packet_header) < 4:
 *             raise OperationalError(2013, "Lost connection to MySQL server during query")
 */
  __pyx_tuple__2 = PyTuple_Pack(1, __pyx_int_4); if (unlikely(!__pyx_tuple__2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 85; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__2);
  __Pyx_GIVEREF(__pyx_tuple__2);

  /* "cymysql/packet.pyx":87
 *         packet_header = self._socket.recv(4)
 *         if len(packet_header) < 4:
 *             raise OperationalError(2013, "Lost connection to MySQL server during query")             # <<<<<<<<<<<<<<
 * 
 *         size = unpack_uint24(packet_header)
 */
  __pyx_tuple__3 = PyTuple_Pack(2, __pyx_int_2013, __pyx_kp_s_Lost_connection_to_MySQL_server); if (unlikely(!__pyx_tuple__3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 87; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__3);
  __Pyx_GIVEREF(__pyx_tuple__3);

  /* "cymysql/packet.pyx":94
 *             recv_data = self._socket.recv(size)
 *             if not recv_data:
 *                 raise OperationalError(2013, "Lost connection to MySQL server during query")             # <<<<<<<<<<<<<<
 *             size -= len(recv_data)
 *             r += recv_data
 */
  __pyx_tuple__4 = PyTuple_Pack(2, __pyx_int_2013, __pyx_kp_s_Lost_connection_to_MySQL_server); if (unlikely(!__pyx_tuple__4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 94; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__4);
  __Pyx_GIVEREF(__pyx_tuple__4);

  /* "cymysql/packet.pyx":170
 *     cpdef is_eof_and_status(self):
 *         if (<unsigned char>(self.__data[0])) != 0xfe:
 *            return False, 0, 0             # <<<<<<<<<<<<<<
 *         return True, unpack_uint16(self._read(2)), unpack_uint16(self._read(2))
 * 
 */
  __pyx_tuple__5 = PyTuple_Pack(3, Py_False, __pyx_int_0, __pyx_int_0); if (unlikely(!__pyx_tuple__5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 170; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__5);
  __Pyx_GIVEREF(__pyx_tuple__5);

  /* "cymysql/packet.pyx":282
 *             self.has_result = False
 *         else:
 *             self.field_count = ord(self.first_packet.read(1))             # <<<<<<<<<<<<<<
 *             self._get_descriptions()
 *             self.has_result = True
 */
  __pyx_tuple__6 = PyTuple_Pack(1, __pyx_int_1); if (unlikely(!__pyx_tuple__6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 282; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__6);
  __Pyx_GIVEREF(__pyx_tuple__6);
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_InitGlobals(void) {
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_0 = PyInt_FromLong(0); if (unlikely(!__pyx_int_0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_2 = PyInt_FromLong(2); if (unlikely(!__pyx_int_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_3 = PyInt_FromLong(3); if (unlikely(!__pyx_int_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_4 = PyInt_FromLong(4); if (unlikely(!__pyx_int_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_8 = PyInt_FromLong(8); if (unlikely(!__pyx_int_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_33 = PyInt_FromLong(33); if (unlikely(!__pyx_int_33)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_88 = PyInt_FromLong(88); if (unlikely(!__pyx_int_88)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_91 = PyInt_FromLong(91); if (unlikely(!__pyx_int_91)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_2013 = PyInt_FromLong(2013); if (unlikely(!__pyx_int_2013)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  return 0;
  __pyx_L1_error:;
  return -1;
}

#if PY_MAJOR_VERSION < 3
PyMODINIT_FUNC initpacket(void); /*proto*/
PyMODINIT_FUNC initpacket(void)
#else
PyMODINIT_FUNC PyInit_packet(void); /*proto*/
PyMODINIT_FUNC PyInit_packet(void)
#endif
{
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_REFNANNY
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
  if (!__Pyx_RefNanny) {
      PyErr_Clear();
      __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
      if (!__Pyx_RefNanny)
          Py_FatalError("failed to import 'refnanny' module");
  }
  #endif
  __Pyx_RefNannySetupContext("PyMODINIT_FUNC PyInit_packet(void)", 0);
  if ( __Pyx_check_binary_version() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #ifdef __Pyx_CyFunction_USED
  if (__Pyx_CyFunction_init() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  #ifdef WITH_THREAD /* Python build with threading support? */
  PyEval_InitThreads();
  #endif
  #endif
  /*--- Module creation code ---*/
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("packet", __pyx_methods, 0, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (unlikely(!__pyx_m)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  Py_INCREF(__pyx_d);
  __pyx_b = PyImport_AddModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #if CYTHON_COMPILING_IN_PYPY
  Py_INCREF(__pyx_b);
  #endif
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  /*--- Initialize various global constants etc. ---*/
  if (unlikely(__Pyx_InitGlobals() < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  if (__pyx_module_is_main_cymysql__packet) {
    if (PyObject_SetAttrString(__pyx_m, "__name__", __pyx_n_s_main) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    if (!PyDict_GetItemString(modules, "cymysql.packet")) {
      if (unlikely(PyDict_SetItemString(modules, "cymysql.packet", __pyx_m) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (unlikely(__Pyx_InitCachedBuiltins() < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Constants init code ---*/
  if (unlikely(__Pyx_InitCachedConstants() < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Global init code ---*/
  /*--- Variable export code ---*/
  /*--- Function export code ---*/
  /*--- Type init code ---*/
  __pyx_vtabptr_7cymysql_6packet_MysqlPacket = &__pyx_vtable_7cymysql_6packet_MysqlPacket;
  __pyx_vtable_7cymysql_6packet_MysqlPacket.__pyx___recv_from_socket = (PyObject *(*)(struct __pyx_obj_7cymysql_6packet_MysqlPacket *, int))__pyx_f_7cymysql_6packet_11MysqlPacket___recv_from_socket;
  __pyx_vtable_7cymysql_6packet_MysqlPacket.__pyx___recv_packet = (PyObject *(*)(struct __pyx_obj_7cymysql_6packet_MysqlPacket *))__pyx_f_7cymysql_6packet_11MysqlPacket___recv_packet;
  __pyx_vtable_7cymysql_6packet_MysqlPacket.read = (PyObject *(*)(struct __pyx_obj_7cymysql_6packet_MysqlPacket *, PyObject *, int __pyx_skip_dispatch))__pyx_f_7cymysql_6packet_11MysqlPacket_read;
  __pyx_vtable_7cymysql_6packet_MysqlPacket._read = (PyObject *(*)(struct __pyx_obj_7cymysql_6packet_MysqlPacket *, int))__pyx_f_7cymysql_6packet_11MysqlPacket__read;
  __pyx_vtable_7cymysql_6packet_MysqlPacket._skip = (void (*)(struct __pyx_obj_7cymysql_6packet_MysqlPacket *, int))__pyx_f_7cymysql_6packet_11MysqlPacket__skip;
  __pyx_vtable_7cymysql_6packet_MysqlPacket._read_all = (PyObject *(*)(struct __pyx_obj_7cymysql_6packet_MysqlPacket *))__pyx_f_7cymysql_6packet_11MysqlPacket__read_all;
  __pyx_vtable_7cymysql_6packet_MysqlPacket.read_length_coded_binary = (int (*)(struct __pyx_obj_7cymysql_6packet_MysqlPacket *))__pyx_f_7cymysql_6packet_11MysqlPacket_read_length_coded_binary;
  __pyx_vtable_7cymysql_6packet_MysqlPacket._read_length_coded_string = (PyObject *(*)(struct __pyx_obj_7cymysql_6packet_MysqlPacket *))__pyx_f_7cymysql_6packet_11MysqlPacket__read_length_coded_string;
  __pyx_vtable_7cymysql_6packet_MysqlPacket.read_decode_data = (PyObject *(*)(struct __pyx_obj_7cymysql_6packet_MysqlPacket *, PyObject *, PyObject *))__pyx_f_7cymysql_6packet_11MysqlPacket_read_decode_data;
  __pyx_vtable_7cymysql_6packet_MysqlPacket.is_ok_packet = (PyObject *(*)(struct __pyx_obj_7cymysql_6packet_MysqlPacket *, int __pyx_skip_dispatch))__pyx_f_7cymysql_6packet_11MysqlPacket_is_ok_packet;
  __pyx_vtable_7cymysql_6packet_MysqlPacket.is_eof_packet = (PyObject *(*)(struct __pyx_obj_7cymysql_6packet_MysqlPacket *, int __pyx_skip_dispatch))__pyx_f_7cymysql_6packet_11MysqlPacket_is_eof_packet;
  __pyx_vtable_7cymysql_6packet_MysqlPacket.is_eof_and_status = (PyObject *(*)(struct __pyx_obj_7cymysql_6packet_MysqlPacket *, int __pyx_skip_dispatch))__pyx_f_7cymysql_6packet_11MysqlPacket_is_eof_and_status;
  __pyx_vtable_7cymysql_6packet_MysqlPacket.read_ok_packet = (PyObject *(*)(struct __pyx_obj_7cymysql_6packet_MysqlPacket *, int __pyx_skip_dispatch))__pyx_f_7cymysql_6packet_11MysqlPacket_read_ok_packet;
  if (PyType_Ready(&__pyx_type_7cymysql_6packet_MysqlPacket) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 45; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_type_7cymysql_6packet_MysqlPacket.tp_print = 0;
  if (__Pyx_SetVtable(__pyx_type_7cymysql_6packet_MysqlPacket.tp_dict, __pyx_vtabptr_7cymysql_6packet_MysqlPacket) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 45; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (PyObject_SetAttrString(__pyx_m, "MysqlPacket", (PyObject *)&__pyx_type_7cymysql_6packet_MysqlPacket) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 45; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_7cymysql_6packet_MysqlPacket = &__pyx_type_7cymysql_6packet_MysqlPacket;
  __pyx_vtabptr_7cymysql_6packet_FieldDescriptorPacket = &__pyx_vtable_7cymysql_6packet_FieldDescriptorPacket;
  __pyx_vtable_7cymysql_6packet_FieldDescriptorPacket.__pyx_base = *__pyx_vtabptr_7cymysql_6packet_MysqlPacket;
  __pyx_type_7cymysql_6packet_FieldDescriptorPacket.tp_base = __pyx_ptype_7cymysql_6packet_MysqlPacket;
  if (PyType_Ready(&__pyx_type_7cymysql_6packet_FieldDescriptorPacket) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 187; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_type_7cymysql_6packet_FieldDescriptorPacket.tp_print = 0;
  if (__Pyx_SetVtable(__pyx_type_7cymysql_6packet_FieldDescriptorPacket.tp_dict, __pyx_vtabptr_7cymysql_6packet_FieldDescriptorPacket) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 187; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (PyObject_SetAttrString(__pyx_m, "FieldDescriptorPacket", (PyObject *)&__pyx_type_7cymysql_6packet_FieldDescriptorPacket) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 187; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_7cymysql_6packet_FieldDescriptorPacket = &__pyx_type_7cymysql_6packet_FieldDescriptorPacket;
  __pyx_vtabptr_7cymysql_6packet_MySQLResult = &__pyx_vtable_7cymysql_6packet_MySQLResult;
  __pyx_vtable_7cymysql_6packet_MySQLResult._get_descriptions = (void (*)(struct __pyx_obj_7cymysql_6packet_MySQLResult *))__pyx_f_7cymysql_6packet_11MySQLResult__get_descriptions;
  if (PyType_Ready(&__pyx_type_7cymysql_6packet_MySQLResult) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 253; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_type_7cymysql_6packet_MySQLResult.tp_print = 0;
  if (__Pyx_SetVtable(__pyx_type_7cymysql_6packet_MySQLResult.tp_dict, __pyx_vtabptr_7cymysql_6packet_MySQLResult) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 253; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (PyObject_SetAttrString(__pyx_m, "MySQLResult", (PyObject *)&__pyx_type_7cymysql_6packet_MySQLResult) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 253; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_7cymysql_6packet_MySQLResult = &__pyx_type_7cymysql_6packet_MySQLResult;
  /*--- Type import code ---*/
  /*--- Variable import code ---*/
  /*--- Function import code ---*/
  /*--- Execution code ---*/

  /* "cymysql/packet.pyx":4
 * #   http://forge.mysql.com/wiki/MySQL_Internals_ClientServer_Protocol
 * 
 * import sys             # <<<<<<<<<<<<<<
 * import struct
 * from cymysql.err import raise_mysql_exception, OperationalError
 */
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_sys, 0, -1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 4; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_sys, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 4; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/packet.pyx":5
 * 
 * import sys
 * import struct             # <<<<<<<<<<<<<<
 * from cymysql.err import raise_mysql_exception, OperationalError
 * from cymysql.constants import SERVER_STATUS, FLAG
 */
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_struct, 0, -1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 5; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_struct, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 5; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/packet.pyx":6
 * import sys
 * import struct
 * from cymysql.err import raise_mysql_exception, OperationalError             # <<<<<<<<<<<<<<
 * from cymysql.constants import SERVER_STATUS, FLAG
 * from cymysql.converters import convert_characters
 */
  __pyx_t_1 = PyList_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 6; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_raise_mysql_exception);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_raise_mysql_exception);
  __Pyx_GIVEREF(__pyx_n_s_raise_mysql_exception);
  __Pyx_INCREF(__pyx_n_s_OperationalError);
  PyList_SET_ITEM(__pyx_t_1, 1, __pyx_n_s_OperationalError);
  __Pyx_GIVEREF(__pyx_n_s_OperationalError);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_cymysql_err, __pyx_t_1, -1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 6; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_raise_mysql_exception); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 6; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_raise_mysql_exception, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 6; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_OperationalError); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 6; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_OperationalError, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 6; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/packet.pyx":7
 * import struct
 * from cymysql.err import raise_mysql_exception, OperationalError
 * from cymysql.constants import SERVER_STATUS, FLAG             # <<<<<<<<<<<<<<
 * from cymysql.converters import convert_characters
 * from cymysql.charset import charset_by_id
 */
  __pyx_t_2 = PyList_New(2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 7; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_SERVER_STATUS);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_SERVER_STATUS);
  __Pyx_GIVEREF(__pyx_n_s_SERVER_STATUS);
  __Pyx_INCREF(__pyx_n_s_FLAG);
  PyList_SET_ITEM(__pyx_t_2, 1, __pyx_n_s_FLAG);
  __Pyx_GIVEREF(__pyx_n_s_FLAG);
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_cymysql_constants, __pyx_t_2, -1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 7; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_SERVER_STATUS); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 7; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_SERVER_STATUS, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 7; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_FLAG); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 7; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_FLAG, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 7; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/packet.pyx":8
 * from cymysql.err import raise_mysql_exception, OperationalError
 * from cymysql.constants import SERVER_STATUS, FLAG
 * from cymysql.converters import convert_characters             # <<<<<<<<<<<<<<
 * from cymysql.charset import charset_by_id
 * 
 */
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 8; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_convert_characters);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_convert_characters);
  __Pyx_GIVEREF(__pyx_n_s_convert_characters);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_cymysql_converters, __pyx_t_1, -1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 8; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_convert_characters); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 8; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_convert_characters, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 8; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/packet.pyx":9
 * from cymysql.constants import SERVER_STATUS, FLAG
 * from cymysql.converters import convert_characters
 * from cymysql.charset import charset_by_id             # <<<<<<<<<<<<<<
 * 
 * from libc.stdint cimport uint16_t, uint32_t
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 9; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_charset_by_id);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_charset_by_id);
  __Pyx_GIVEREF(__pyx_n_s_charset_by_id);
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_cymysql_charset, __pyx_t_2, -1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 9; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_charset_by_id); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 9; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_charset_by_id, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 9; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/packet.pyx":12
 * 
 * from libc.stdint cimport uint16_t, uint32_t
 * cdef int PYTHON3 = sys.version_info[0] > 2             # <<<<<<<<<<<<<<
 * 
 * MBLENGTH = {
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_sys); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 12; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_version_info); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 12; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_2, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(__pyx_t_1 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 12; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_RichCompare(__pyx_t_1, __pyx_int_2, Py_GT); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 12; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 12; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_7cymysql_6packet_PYTHON3 = __pyx_t_3;

  /* "cymysql/packet.pyx":14
 * cdef int PYTHON3 = sys.version_info[0] > 2
 * 
 * MBLENGTH = {             # <<<<<<<<<<<<<<
 *         8:1,
 *         33:3,
 */
  __pyx_t_2 = PyDict_New(); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 14; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_int_8, __pyx_int_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 14; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (PyDict_SetItem(__pyx_t_2, __pyx_int_33, __pyx_int_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 14; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (PyDict_SetItem(__pyx_t_2, __pyx_int_88, __pyx_int_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 14; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (PyDict_SetItem(__pyx_t_2, __pyx_int_91, __pyx_int_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 14; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_MBLENGTH, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 14; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/packet.pyx":21
 *         }
 * 
 * cdef int FIELD_TYPE_VAR_STRING=253             # <<<<<<<<<<<<<<
 * 
 * cdef int UNSIGNED_CHAR_COLUMN = 251
 */
  __pyx_v_7cymysql_6packet_FIELD_TYPE_VAR_STRING = 253;

  /* "cymysql/packet.pyx":23
 * cdef int FIELD_TYPE_VAR_STRING=253
 * 
 * cdef int UNSIGNED_CHAR_COLUMN = 251             # <<<<<<<<<<<<<<
 * cdef int UNSIGNED_SHORT_COLUMN = 252
 * cdef int UNSIGNED_INT24_COLUMN = 253
 */
  __pyx_v_7cymysql_6packet_UNSIGNED_CHAR_COLUMN = 251;

  /* "cymysql/packet.pyx":24
 * 
 * cdef int UNSIGNED_CHAR_COLUMN = 251
 * cdef int UNSIGNED_SHORT_COLUMN = 252             # <<<<<<<<<<<<<<
 * cdef int UNSIGNED_INT24_COLUMN = 253
 * cdef int UNSIGNED_INT64_COLUMN = 254
 */
  __pyx_v_7cymysql_6packet_UNSIGNED_SHORT_COLUMN = 252;

  /* "cymysql/packet.pyx":25
 * cdef int UNSIGNED_CHAR_COLUMN = 251
 * cdef int UNSIGNED_SHORT_COLUMN = 252
 * cdef int UNSIGNED_INT24_COLUMN = 253             # <<<<<<<<<<<<<<
 * cdef int UNSIGNED_INT64_COLUMN = 254
 * 
 */
  __pyx_v_7cymysql_6packet_UNSIGNED_INT24_COLUMN = 253;

  /* "cymysql/packet.pyx":26
 * cdef int UNSIGNED_SHORT_COLUMN = 252
 * cdef int UNSIGNED_INT24_COLUMN = 253
 * cdef int UNSIGNED_INT64_COLUMN = 254             # <<<<<<<<<<<<<<
 * 
 * cdef int SERVER_MORE_RESULTS_EXISTS = SERVER_STATUS.SERVER_MORE_RESULTS_EXISTS
 */
  __pyx_v_7cymysql_6packet_UNSIGNED_INT64_COLUMN = 254;

  /* "cymysql/packet.pyx":28
 * cdef int UNSIGNED_INT64_COLUMN = 254
 * 
 * cdef int SERVER_MORE_RESULTS_EXISTS = SERVER_STATUS.SERVER_MORE_RESULTS_EXISTS             # <<<<<<<<<<<<<<
 * 
 * cdef uint16_t unpack_uint16(bytes s):
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_SERVER_STATUS); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 28; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_SERVER_MORE_RESULTS_EXISTS); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 28; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_3 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 28; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_7cymysql_6packet_SERVER_MORE_RESULTS_EXISTS = __pyx_t_3;

  /* "cymysql/packet.pyx":1
 * # Python implementation of the MySQL client-server protocol             # <<<<<<<<<<<<<<
 * #   http://forge.mysql.com/wiki/MySQL_Internals_ClientServer_Protocol
 * 
 */
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  if (__pyx_m) {
    if (__pyx_d) {
      __Pyx_AddTraceback("init cymysql.packet", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    Py_DECREF(__pyx_m); __pyx_m = 0;
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init cymysql.packet");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if PY_MAJOR_VERSION < 3
  return;
  #else
  return __pyx_m;
  #endif
}

/* --- Runtime support code --- */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule((char *)modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, (char *)"RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStr(__pyx_b, name);
    if (unlikely(!result)) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

static CYTHON_INLINE void __Pyx_ErrRestore(PyObject *type, PyObject *value, PyObject *tb) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyThreadState *tstate = PyThreadState_GET();
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_Restore(type, value, tb);
#endif
}
static CYTHON_INLINE void __Pyx_ErrFetch(PyObject **type, PyObject **value, PyObject **tb) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyThreadState *tstate = PyThreadState_GET();
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#else
    PyErr_Fetch(type, value, tb);
#endif
}

static void __Pyx_WriteUnraisable(const char *name, CYTHON_UNUSED int clineno,
                                  CYTHON_UNUSED int lineno, CYTHON_UNUSED const char *filename,
                                  int full_traceback) {
    PyObject *old_exc, *old_val, *old_tb;
    PyObject *ctx;
    __Pyx_ErrFetch(&old_exc, &old_val, &old_tb);
    if (full_traceback) {
        Py_XINCREF(old_exc);
        Py_XINCREF(old_val);
        Py_XINCREF(old_tb);
        __Pyx_ErrRestore(old_exc, old_val, old_tb);
        PyErr_PrintEx(1);
    }
    #if PY_MAJOR_VERSION < 3
    ctx = PyString_FromString(name);
    #else
    ctx = PyUnicode_FromString(name);
    #endif
    __Pyx_ErrRestore(old_exc, old_val, old_tb);
    if (!ctx) {
        PyErr_WriteUnraisable(Py_None);
    } else {
        PyErr_WriteUnraisable(ctx);
        Py_DECREF(ctx);
    }
}

static CYTHON_INLINE PyObject *__Pyx_GetModuleGlobalName(PyObject *name) {
    PyObject *result;
#if CYTHON_COMPILING_IN_CPYTHON
    result = PyDict_GetItem(__pyx_d, name);
    if (likely(result)) {
        Py_INCREF(result);
    } else {
#else
    result = PyObject_GetItem(__pyx_d, name);
    if (!result) {
        PyErr_Clear();
#endif
        result = __Pyx_GetBuiltinName(name);
    }
    return result;
}

#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = func->ob_type->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (!j) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck) {
#if CYTHON_COMPILING_IN_CPYTHON
    if (wraparound & unlikely(i < 0)) i += PyList_GET_SIZE(o);
    if ((!boundscheck) || likely((0 <= i) & (i < PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck) {
#if CYTHON_COMPILING_IN_CPYTHON
    if (wraparound & unlikely(i < 0)) i += PyTuple_GET_SIZE(o);
    if ((!boundscheck) || likely((0 <= i) & (i < PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck) {
#if CYTHON_COMPILING_IN_CPYTHON
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((!boundscheck) || (likely((n >= 0) & (n < PyList_GET_SIZE(o))))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely((n >= 0) & (n < PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {
        PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
        if (likely(m && m->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(m->sq_length)) {
                Py_ssize_t l = m->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (PyErr_ExceptionMatches(PyExc_OverflowError))
                        PyErr_Clear();
                    else
                        return NULL;
                }
            }
            return m->sq_item(o, i);
        }
    }
#else
    if (is_list || PySequence_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    while (PyDict_Next(kwds, &pos, &key, &value)) {
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
            continue;
        }
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_CheckExact(key)) || likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (**name == key) ? 0 :
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (PyUnicode_GET_SIZE(**name) != PyUnicode_GET_SIZE(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key);
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (PyUnicode_GET_SIZE(**argname) != PyUnicode_GET_SIZE(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    return -1;
}

static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = PyCFunction_GET_FUNCTION(func);
    self = PyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

#if CYTHON_COMPILING_IN_CPYTHON
static PyObject* __Pyx__PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_New(1);
    if (unlikely(!args)) return NULL;
    Py_INCREF(arg);
    PyTuple_SET_ITEM(args, 0, arg);
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
#ifdef __Pyx_CyFunction_USED
    if (likely(PyCFunction_Check(func) || PyObject_TypeCheck(func, __pyx_CyFunctionType))) {
#else
    if (likely(PyCFunction_Check(func))) {
#endif
        if (likely(PyCFunction_GET_FLAGS(func) & METH_O)) {
            return __Pyx_PyObject_CallMethO(func, arg);
        }
    }
    return __Pyx__PyObject_CallOneArg(func, arg);
}
#else
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject* args = PyTuple_Pack(1, arg);
    return (likely(args)) ? __Pyx_PyObject_Call(func, args, NULL) : NULL;
}
#endif

#if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb,
                        CYTHON_UNUSED PyObject *cause) {
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    if (PyType_Check(type)) {
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
    }
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                if (PyObject_IsSubclass(instance_class, type)) {
                    type = instance_class;
                } else {
                    instance_class = NULL;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
#if PY_VERSION_HEX >= 0x03030000
    if (cause) {
#else
    if (cause && cause != Py_None) {
#endif
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
#if CYTHON_COMPILING_IN_PYPY
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(tmp_type, tmp_value, tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#else
        PyThreadState *tstate = PyThreadState_GET();
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

static CYTHON_INLINE int __Pyx_IterFinish(void) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyThreadState *tstate = PyThreadState_GET();
    PyObject* exc_type = tstate->curexc_type;
    if (unlikely(exc_type)) {
        if (likely(exc_type == PyExc_StopIteration) || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)) {
            PyObject *exc_value, *exc_tb;
            exc_value = tstate->curexc_value;
            exc_tb = tstate->curexc_traceback;
            tstate->curexc_type = 0;
            tstate->curexc_value = 0;
            tstate->curexc_traceback = 0;
            Py_DECREF(exc_type);
            Py_XDECREF(exc_value);
            Py_XDECREF(exc_tb);
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#else
    if (unlikely(PyErr_Occurred())) {
        if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) {
            PyErr_Clear();
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#endif
}

static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    } else {
        return __Pyx_IterFinish();
    }
    return 0;
}

#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
#ifdef __Pyx_CyFunction_USED
    if (likely(PyCFunction_Check(func) || PyObject_TypeCheck(func, __pyx_CyFunctionType))) {
#else
    if (likely(PyCFunction_Check(func))) {
#endif
        if (likely(PyCFunction_GET_FLAGS(func) & METH_NOARGS)) {
            return __Pyx_PyObject_CallMethO(func, NULL);
        }
    }
    return __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL);
}
#endif

static CYTHON_INLINE int __Pyx_CheckKeywordStrings(
    PyObject *kwdict,
    const char* function_name,
    int kw_allowed)
{
    PyObject* key = 0;
    Py_ssize_t pos = 0;
#if CYTHON_COMPILING_IN_PYPY
    if (!kw_allowed && PyDict_Next(kwdict, &pos, &key, 0))
        goto invalid_keyword;
    return 1;
#else
    while (PyDict_Next(kwdict, &pos, &key, 0)) {
        #if PY_MAJOR_VERSION < 3
        if (unlikely(!PyString_CheckExact(key)) && unlikely(!PyString_Check(key)))
        #endif
            if (unlikely(!PyUnicode_Check(key)))
                goto invalid_keyword_type;
    }
    if ((!kw_allowed) && unlikely(key))
        goto invalid_keyword;
    return 1;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    return 0;
#endif
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
    return 0;
}

static CYTHON_INLINE long __Pyx_mod_long(long a, long b) {
    long r = a % b;
    r += ((r != 0) & ((r ^ b) < 0)) * b;
    return r;
}

static CYTHON_INLINE int __Pyx_div_int(int a, int b) {
    int q = a / b;
    int r = a - q*b;
    q -= ((r != 0) & ((r ^ b) < 0));
    return q;
}

static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg) {
    PyObject *method, *result = NULL;
    method = __Pyx_PyObject_GetAttrStr(obj, method_name);
    if (unlikely(!method)) goto bad;
#if CYTHON_COMPILING_IN_CPYTHON
    if (likely(PyMethod_Check(method))) {
        PyObject *self = PyMethod_GET_SELF(method);
        if (likely(self)) {
            PyObject *args;
            PyObject *function = PyMethod_GET_FUNCTION(method);
            args = PyTuple_New(2);
            if (unlikely(!args)) goto bad;
            Py_INCREF(self);
            PyTuple_SET_ITEM(args, 0, self);
            Py_INCREF(arg);
            PyTuple_SET_ITEM(args, 1, arg);
            Py_INCREF(function);
            Py_DECREF(method); method = NULL;
            result = __Pyx_PyObject_Call(function, args, NULL);
            Py_DECREF(args);
            Py_DECREF(function);
            return result;
        }
    }
#endif
    result = __Pyx_PyObject_CallOneArg(method, arg);
bad:
    Py_XDECREF(method);
    return result;
}

static CYTHON_INLINE int __Pyx_PyObject_Append(PyObject* L, PyObject* x) {
    if (likely(PyList_CheckExact(L))) {
        if (unlikely(__Pyx_PyList_Append(L, x) < 0)) return -1;
    } else {
        PyObject* retval = __Pyx_PyObject_CallMethod1(L, __pyx_n_s_append, x);
        if (unlikely(!retval))
            return -1;
        Py_DECREF(retval);
    }
    return 0;
}

static int __Pyx_SetVtable(PyObject *dict, void *vtable) {
#if PY_VERSION_HEX >= 0x02070000
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
#else
    PyObject *ob = PyCObject_FromVoidPtr(vtable, 0);
#endif
    if (!ob)
        goto bad;
    if (PyDict_SetItem(dict, __pyx_n_s_pyx_vtable, ob) < 0)
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = (start + end) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, (size_t)new_max*sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    #if PY_MAJOR_VERSION < 3
    py_srcfile = PyString_FromString(filename);
    #else
    py_srcfile = PyUnicode_FromString(filename);
    #endif
    if (!py_srcfile) goto bad;
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        #else
        py_funcname = PyUnicode_FromString(funcname);
        #endif
    }
    if (!py_funcname) goto bad;
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    Py_DECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    py_code = __pyx_find_code_object(c_line ? c_line : py_line);
    if (!py_code) {
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) goto bad;
        __pyx_insert_code_object(c_line ? c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        PyThreadState_GET(), /*PyThreadState *tstate,*/
        py_code,             /*PyCodeObject *code,*/
        __pyx_d,      /*PyObject *globals,*/
        0                    /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    py_frame->f_lineno = py_line;
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *empty_list = 0;
    PyObject *module = 0;
    PyObject *global_dict = 0;
    PyObject *empty_dict = 0;
    PyObject *list;
    #if PY_VERSION_HEX < 0x03030000
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (!py_import)
        goto bad;
    #endif
    if (from_list)
        list = from_list;
    else {
        empty_list = PyList_New(0);
        if (!empty_list)
            goto bad;
        list = empty_list;
    }
    global_dict = PyModule_GetDict(__pyx_m);
    if (!global_dict)
        goto bad;
    empty_dict = PyDict_New();
    if (!empty_dict)
        goto bad;
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if (strchr(__Pyx_MODULE_NAME, '.')) {
                #if PY_VERSION_HEX < 0x03030000
                PyObject *py_level = PyInt_FromLong(1);
                if (!py_level)
                    goto bad;
                module = PyObject_CallFunctionObjArgs(py_import,
                    name, global_dict, empty_dict, list, py_level, NULL);
                Py_DECREF(py_level);
                #else
                module = PyImport_ImportModuleLevelObject(
                    name, global_dict, empty_dict, list, 1);
                #endif
                if (!module) {
                    if (!PyErr_ExceptionMatches(PyExc_ImportError))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0;
        }
        #endif
        if (!module) {
            #if PY_VERSION_HEX < 0x03030000
            PyObject *py_level = PyInt_FromLong(level);
            if (!py_level)
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, global_dict, empty_dict, list, py_level, NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, global_dict, empty_dict, list, level);
            #endif
        }
    }
bad:
    #if PY_VERSION_HEX < 0x03030000
    Py_XDECREF(py_import);
    #endif
    Py_XDECREF(empty_list);
    Py_XDECREF(empty_dict);
    return module;
}

static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
    const long neg_one = (long) -1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
        } else if (sizeof(long) <= sizeof(unsigned long long)) {
            return PyLong_FromUnsignedLongLong((unsigned long long) value);
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(long long)) {
            return PyLong_FromLongLong((long long) value);
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
    }
}

#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)       \
    {                                                                     \
        func_type value = func_value;                                     \
        if (sizeof(target_type) < sizeof(func_type)) {                    \
            if (unlikely(value != (func_type) (target_type) value)) {     \
                func_type zero = 0;                                       \
                if (is_unsigned && unlikely(value < zero))                \
                    goto raise_neg_overflow;                              \
                else                                                      \
                    goto raise_overflow;                                  \
            }                                                             \
        }                                                                 \
        return (target_type) value;                                       \
    }

#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
 #if CYTHON_USE_PYLONG_INTERNALS
  #include "longintrepr.h"
 #endif
#endif

static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
    const int neg_one = (int) -1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(int) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
 #if CYTHON_USE_PYLONG_INTERNALS
            switch (Py_SIZE(x)) {
                case  0: return 0;
                case  1: __PYX_VERIFY_RETURN_INT(int, digit, ((PyLongObject*)x)->ob_digit[0]);
            }
 #endif
#endif
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
            if (sizeof(int) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT(int, unsigned long, PyLong_AsUnsignedLong(x))
            } else if (sizeof(int) <= sizeof(unsigned long long)) {
                __PYX_VERIFY_RETURN_INT(int, unsigned long long, PyLong_AsUnsignedLongLong(x))
            }
        } else {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
 #if CYTHON_USE_PYLONG_INTERNALS
            switch (Py_SIZE(x)) {
                case  0: return 0;
                case  1: __PYX_VERIFY_RETURN_INT(int,  digit, +(((PyLongObject*)x)->ob_digit[0]));
                case -1: __PYX_VERIFY_RETURN_INT(int, sdigit, -(sdigit) ((PyLongObject*)x)->ob_digit[0]);
            }
 #endif
#endif
            if (sizeof(int) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT(int, long, PyLong_AsLong(x))
            } else if (sizeof(int) <= sizeof(long long)) {
                __PYX_VERIFY_RETURN_INT(int, long long, PyLong_AsLongLong(x))
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            int val;
            PyObject *v = __Pyx_PyNumber_Int(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

static CYTHON_INLINE PY_LONG_LONG __Pyx_PyInt_As_PY_LONG_LONG(PyObject *x) {
    const PY_LONG_LONG neg_one = (PY_LONG_LONG) -1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(PY_LONG_LONG) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (PY_LONG_LONG) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
 #if CYTHON_USE_PYLONG_INTERNALS
            switch (Py_SIZE(x)) {
                case  0: return 0;
                case  1: __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, digit, ((PyLongObject*)x)->ob_digit[0]);
            }
 #endif
#endif
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
            if (sizeof(PY_LONG_LONG) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, unsigned long, PyLong_AsUnsignedLong(x))
            } else if (sizeof(PY_LONG_LONG) <= sizeof(unsigned long long)) {
                __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, unsigned long long, PyLong_AsUnsignedLongLong(x))
            }
        } else {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
 #if CYTHON_USE_PYLONG_INTERNALS
            switch (Py_SIZE(x)) {
                case  0: return 0;
                case  1: __PYX_VERIFY_RETURN_INT(PY_LONG_LONG,  digit, +(((PyLongObject*)x)->ob_digit[0]));
                case -1: __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, sdigit, -(sdigit) ((PyLongObject*)x)->ob_digit[0]);
            }
 #endif
#endif
            if (sizeof(PY_LONG_LONG) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, long, PyLong_AsLong(x))
            } else if (sizeof(PY_LONG_LONG) <= sizeof(long long)) {
                __PYX_VERIFY_RETURN_INT(PY_LONG_LONG, long long, PyLong_AsLongLong(x))
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            PY_LONG_LONG val;
            PyObject *v = __Pyx_PyNumber_Int(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (PY_LONG_LONG) -1;
        }
    } else {
        PY_LONG_LONG val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (PY_LONG_LONG) -1;
        val = __Pyx_PyInt_As_PY_LONG_LONG(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to PY_LONG_LONG");
    return (PY_LONG_LONG) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to PY_LONG_LONG");
    return (PY_LONG_LONG) -1;
}

static CYTHON_INLINE unsigned char __Pyx_PyInt_As_unsigned_char(PyObject *x) {
    const unsigned char neg_one = (unsigned char) -1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(unsigned char) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(unsigned char, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (unsigned char) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
 #if CYTHON_USE_PYLONG_INTERNALS
            switch (Py_SIZE(x)) {
                case  0: return 0;
                case  1: __PYX_VERIFY_RETURN_INT(unsigned char, digit, ((PyLongObject*)x)->ob_digit[0]);
            }
 #endif
#endif
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
            if (sizeof(unsigned char) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT(unsigned char, unsigned long, PyLong_AsUnsignedLong(x))
            } else if (sizeof(unsigned char) <= sizeof(unsigned long long)) {
                __PYX_VERIFY_RETURN_INT(unsigned char, unsigned long long, PyLong_AsUnsignedLongLong(x))
            }
        } else {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
 #if CYTHON_USE_PYLONG_INTERNALS
            switch (Py_SIZE(x)) {
                case  0: return 0;
                case  1: __PYX_VERIFY_RETURN_INT(unsigned char,  digit, +(((PyLongObject*)x)->ob_digit[0]));
                case -1: __PYX_VERIFY_RETURN_INT(unsigned char, sdigit, -(sdigit) ((PyLongObject*)x)->ob_digit[0]);
            }
 #endif
#endif
            if (sizeof(unsigned char) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT(unsigned char, long, PyLong_AsLong(x))
            } else if (sizeof(unsigned char) <= sizeof(long long)) {
                __PYX_VERIFY_RETURN_INT(unsigned char, long long, PyLong_AsLongLong(x))
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            unsigned char val;
            PyObject *v = __Pyx_PyNumber_Int(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (unsigned char) -1;
        }
    } else {
        unsigned char val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (unsigned char) -1;
        val = __Pyx_PyInt_As_unsigned_char(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to unsigned char");
    return (unsigned char) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to unsigned char");
    return (unsigned char) -1;
}

static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value) {
    const int neg_one = (int) -1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(int) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
        } else if (sizeof(int) <= sizeof(unsigned long long)) {
            return PyLong_FromUnsignedLongLong((unsigned long long) value);
        }
    } else {
        if (sizeof(int) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(long long)) {
            return PyLong_FromLongLong((long long) value);
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(int),
                                     little, !is_unsigned);
    }
}

static CYTHON_INLINE PyObject* __Pyx_PyInt_From_uint16_t(uint16_t value) {
    const uint16_t neg_one = (uint16_t) -1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(uint16_t) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(uint16_t) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
        } else if (sizeof(uint16_t) <= sizeof(unsigned long long)) {
            return PyLong_FromUnsignedLongLong((unsigned long long) value);
        }
    } else {
        if (sizeof(uint16_t) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(uint16_t) <= sizeof(long long)) {
            return PyLong_FromLongLong((long long) value);
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(uint16_t),
                                     little, !is_unsigned);
    }
}

static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
    const long neg_one = (long) -1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(long) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
 #if CYTHON_USE_PYLONG_INTERNALS
            switch (Py_SIZE(x)) {
                case  0: return 0;
                case  1: __PYX_VERIFY_RETURN_INT(long, digit, ((PyLongObject*)x)->ob_digit[0]);
            }
 #endif
#endif
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
            if (sizeof(long) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT(long, unsigned long, PyLong_AsUnsignedLong(x))
            } else if (sizeof(long) <= sizeof(unsigned long long)) {
                __PYX_VERIFY_RETURN_INT(long, unsigned long long, PyLong_AsUnsignedLongLong(x))
            }
        } else {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
 #if CYTHON_USE_PYLONG_INTERNALS
            switch (Py_SIZE(x)) {
                case  0: return 0;
                case  1: __PYX_VERIFY_RETURN_INT(long,  digit, +(((PyLongObject*)x)->ob_digit[0]));
                case -1: __PYX_VERIFY_RETURN_INT(long, sdigit, -(sdigit) ((PyLongObject*)x)->ob_digit[0]);
            }
 #endif
#endif
            if (sizeof(long) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT(long, long, PyLong_AsLong(x))
            } else if (sizeof(long) <= sizeof(long long)) {
                __PYX_VERIFY_RETURN_INT(long, long long, PyLong_AsLongLong(x))
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            long val;
            PyObject *v = __Pyx_PyNumber_Int(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

static int __Pyx_check_binary_version(void) {
    char ctversion[4], rtversion[4];
    PyOS_snprintf(ctversion, 4, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    PyOS_snprintf(rtversion, 4, "%s", Py_GetVersion());
    if (ctversion[0] != rtversion[0] || ctversion[2] != rtversion[2]) {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        return PyErr_WarnEx(NULL, message, 1);
    }
    return 0;
}

static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        ++t;
    }
    return 0;
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    return __Pyx_PyUnicode_FromStringAndSize(c_str, (Py_ssize_t)strlen(c_str));
}
static CYTHON_INLINE char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
static CYTHON_INLINE char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
#if PY_VERSION_HEX < 0x03030000
        char* defenc_c;
        PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
        if (!defenc) return NULL;
        defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        {
            char* end = defenc_c + PyBytes_GET_SIZE(defenc);
            char* c;
            for (c = defenc_c; c < end; c++) {
                if ((unsigned char) (*c) >= 128) {
                    PyUnicode_AsASCIIString(o);
                    return NULL;
                }
            }
        }
#endif
        *length = PyBytes_GET_SIZE(defenc);
        return defenc_c;
#else
        if (__Pyx_PyUnicode_READY(o) == -1) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        if (PyUnicode_IS_ASCII(o)) {
            *length = PyUnicode_GET_LENGTH(o);
            return PyUnicode_AsUTF8(o);
        } else {
            PyUnicode_AsASCIIString(o);
            return NULL;
        }
#else
        return PyUnicode_AsUTF8AndSize(o, length);
#endif
#endif
    } else
#endif
#if !CYTHON_COMPILING_IN_PYPY
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Int(PyObject* x) {
  PyNumberMethods *m;
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (PyInt_Check(x) || PyLong_Check(x))
#else
  if (PyLong_Check(x))
#endif
    return Py_INCREF(x), x;
  m = Py_TYPE(x)->tp_as_number;
#if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = PyNumber_Int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = PyNumber_Long(x);
  }
#else
  if (m && m->nb_int) {
    name = "int";
    res = PyNumber_Long(x);
  }
#endif
  if (res) {
#if PY_MAJOR_VERSION < 3
    if (!PyInt_Check(res) && !PyLong_Check(res)) {
#else
    if (!PyLong_Check(res)) {
#endif
      PyErr_Format(PyExc_TypeError,
                   "__%.4s__ returned non-%.4s (type %.200s)",
                   name, name, Py_TYPE(res)->tp_name);
      Py_DECREF(res);
      return NULL;
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b)))
      return PyInt_AS_LONG(b);
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
     #if CYTHON_USE_PYLONG_INTERNALS
       switch (Py_SIZE(b)) {
       case -1: return -(sdigit)((PyLongObject*)b)->ob_digit[0];
       case  0: return 0;
       case  1: return ((PyLongObject*)b)->ob_digit[0];
       }
     #endif
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


#endif /* Py_PYTHON_H */
