/* Generated by Cython 0.22 */

/* BEGIN: Cython Metadata
{
    "distutils": {}
}
END: Cython Metadata */

#define PY_SSIZE_T_CLEAN
#ifndef CYTHON_USE_PYLONG_INTERNALS
#ifdef PYLONG_BITS_IN_DIGIT
#define CYTHON_USE_PYLONG_INTERNALS 0
#else
#include "pyconfig.h"
#ifdef PYLONG_BITS_IN_DIGIT
#define CYTHON_USE_PYLONG_INTERNALS 1
#else
#define CYTHON_USE_PYLONG_INTERNALS 0
#endif
#endif
#endif
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02060000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03020000)
    #error Cython requires Python 2.6+ or Python 3.2+.
#else
#define CYTHON_ABI "0_22"
#include <stddef.h>
#ifndef offsetof
#define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
#define CYTHON_COMPILING_IN_PYPY 1
#define CYTHON_COMPILING_IN_CPYTHON 0
#else
#define CYTHON_COMPILING_IN_PYPY 0
#define CYTHON_COMPILING_IN_CPYTHON 1
#endif
#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x02070600 && !defined(Py_OptimizeFlag)
#define Py_OptimizeFlag 0
#endif
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos) \
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyClass_Type
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos) \
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyType_Type
#endif
#if PY_MAJOR_VERSION >= 3
  #define Py_TPFLAGS_CHECKTYPES 0
  #define Py_TPFLAGS_HAVE_INDEX 0
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#if PY_VERSION_HEX < 0x030400a1 && !defined(Py_TPFLAGS_HAVE_FINALIZE)
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ? \
                                              0 : _PyUnicode_Ready((PyObject *)(op)))
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_KIND(u)         PyUnicode_KIND(u)
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
#else
  #define CYTHON_PEP393_ENABLED 0
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_KIND(u)         (sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
  #define __Pyx_PyFrozenSet_Size(s)         PyObject_Size(s)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ? \
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
  #define __Pyx_PyFrozenSet_Size(s)         PySet_Size(s)
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None)) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None)) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   PyInt_AsLong
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   PyInt_AsSsize_t
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyMethod_New(func, self, klass) ((self) ? PyMethod_New(func, self) : PyInstanceMethod_New(func))
#else
  #define __Pyx_PyMethod_New(func, self, klass) PyMethod_New(func, self, klass)
#endif
#ifndef CYTHON_INLINE
  #if defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  /* Initialize NaN. The sign is irrelevant, an exponent with all bits 1 and
   a nonzero mantissa means NaN. If the first bit in the mantissa is 1, it is
   a quiet NaN. */
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#define __Pyx_void_to_None(void_result) (void_result, Py_INCREF(Py_None), Py_None)
#ifdef __cplusplus
template<typename T>
void __Pyx_call_destructor(T* x) {
    x->~T();
}
template<typename T>
class __Pyx_FakeReference {
  public:
    __Pyx_FakeReference() : ptr(NULL) { }
    __Pyx_FakeReference(T& ref) : ptr(&ref) { }
    T *operator->() { return ptr; }
    operator T&() { return *ptr; }
  private:
    T *ptr;
};
#endif


#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#if defined(WIN32) || defined(MS_WINDOWS)
#define _USE_MATH_DEFINES
#endif
#include <math.h>
#define __PYX_HAVE__cymysql__charset
#define __PYX_HAVE_API__cymysql__charset
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#ifdef PYREX_WITHOUT_ASSERTIONS
#define CYTHON_WITHOUT_ASSERTIONS
#endif

#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
typedef struct {PyObject **p; char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT 0
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (    \
    (sizeof(type) < sizeof(Py_ssize_t))  ||             \
    (sizeof(type) > sizeof(Py_ssize_t) &&               \
          likely(v < (type)PY_SSIZE_T_MAX ||            \
                 v == (type)PY_SSIZE_T_MAX)  &&         \
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||       \
                                v == (type)PY_SSIZE_T_MIN)))  ||  \
    (sizeof(type) == sizeof(Py_ssize_t) &&              \
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||        \
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
#define __Pyx_PyByteArray_FromString(s) PyByteArray_FromStringAndSize((const char*)s, strlen((const char*)s))
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyObject_AsSString(s)    ((signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
#if PY_MAJOR_VERSION < 3
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u)
{
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#else
#define __Pyx_Py_UNICODE_strlen Py_UNICODE_strlen
#endif
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_Owned_Py_None(b) (Py_INCREF(Py_None), Py_None)
#define __Pyx_PyBool_FromLong(b) ((b) ? (Py_INCREF(Py_True), Py_True) : (Py_INCREF(Py_False), Py_False))
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Int(PyObject* x);
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
#if CYTHON_COMPILING_IN_CPYTHON
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c));
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */

static PyObject *__pyx_m;
static PyObject *__pyx_d;
static PyObject *__pyx_b;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;


static const char *__pyx_f[] = {
  "cymysql/charset.py",
  "cymysql/charset.pxd",
};

/*--- Type declarations ---*/
struct __pyx_obj_7cymysql_7charset_Charset;
struct __pyx_obj_7cymysql_7charset_Charsets;

/* "cymysql/charset.pxd":3
 * import cython
 * 
 * cdef class Charset(object):             # <<<<<<<<<<<<<<
 *     cdef public int id
 *     cdef public str name, collation
 */
struct __pyx_obj_7cymysql_7charset_Charset {
  PyObject_HEAD
  int id;
  PyObject *name;
  PyObject *collation;
  int is_default;
};


/* "cymysql/charset.pxd":8
 *     cdef public bint is_default
 * 
 * cdef class Charsets(object):             # <<<<<<<<<<<<<<
 *     cdef dict _by_id
 *     cdef add(self, Charset c)
 */
struct __pyx_obj_7cymysql_7charset_Charsets {
  PyObject_HEAD
  struct __pyx_vtabstruct_7cymysql_7charset_Charsets *__pyx_vtab;
  PyObject *_by_id;
};



/* "cymysql/charset.py":6
 *         self.is_default = is_default == 'Yes'
 * 
 * class Charsets(object):             # <<<<<<<<<<<<<<
 *     def __init__(self):
 *         self._by_id = {}
 */

struct __pyx_vtabstruct_7cymysql_7charset_Charsets {
  PyObject *(*add)(struct __pyx_obj_7cymysql_7charset_Charsets *, struct __pyx_obj_7cymysql_7charset_Charset *);
  PyObject *(*by_name)(struct __pyx_obj_7cymysql_7charset_Charsets *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*by_id)(struct __pyx_obj_7cymysql_7charset_Charsets *, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_7cymysql_7charset_Charsets *__pyx_vtabptr_7cymysql_7charset_Charsets;

/* --- Runtime support code (head) --- */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil) \
          if (acquire_gil) { \
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure(); \
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__); \
              PyGILState_Release(__pyx_gilstate_save); \
          } else { \
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__); \
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil) \
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext() \
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_XDECREF_SET(r, v) do {                            \
        PyObject *tmp = (PyObject *) r;                         \
        r = v; __Pyx_XDECREF(tmp);                              \
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {                             \
        PyObject *tmp = (PyObject *) r;                         \
        r = v; __Pyx_DECREF(tmp);                               \
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject **argnames[], \
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args, \
    const char* function_name);

static CYTHON_INLINE int __Pyx_CheckKeywordStrings(PyObject *kwdict, const char* function_name, int kw_allowed);

#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg);

static CYTHON_INLINE PyObject* __Pyx_PyDict_Values(PyObject* d);

static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type);

#include <string.h>

static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyString_Equals __Pyx_PyUnicode_Equals
#else
#define __Pyx_PyString_Equals __Pyx_PyBytes_Equals
#endif

#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (!PyErr_Occurred()) {
            PyObject* args = PyTuple_Pack(1, key);
            if (likely(args))
                PyErr_SetObject(PyExc_KeyError, args);
            Py_XDECREF(args);
        }
        return NULL;
    }
    Py_INCREF(value);
    return value;
}
#else
    #define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#endif

static int __Pyx_SetVtable(PyObject *dict, void *vtable);

typedef struct {
    int code_line;
    PyCodeObject* code_object;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value);

static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

static int __Pyx_check_binary_version(void);

#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o,n,NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_setattr))
        return tp->tp_setattr(obj, PyString_AS_STRING(attr_name), value);
#endif
    return PyObject_SetAttr(obj, attr_name, value);
}
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

static int __Pyx_ExportVoidPtr(PyObject *name, void *p, const char *sig);

static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);

static PyObject *__pyx_f_7cymysql_7charset_8Charsets_add(struct __pyx_obj_7cymysql_7charset_Charsets *__pyx_v_self, struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_c); /* proto*/
static PyObject *__pyx_f_7cymysql_7charset_8Charsets_by_name(struct __pyx_obj_7cymysql_7charset_Charsets *__pyx_v_self, PyObject *__pyx_v_name, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_7cymysql_7charset_8Charsets_by_id(struct __pyx_obj_7cymysql_7charset_Charsets *__pyx_v_self, PyObject *__pyx_v_id, int __pyx_skip_dispatch); /* proto*/

/* Module declarations from 'cython' */

/* Module declarations from 'cymysql.charset' */
static PyTypeObject *__pyx_ptype_7cymysql_7charset_Charset = 0;
static PyTypeObject *__pyx_ptype_7cymysql_7charset_Charsets = 0;
static struct __pyx_obj_7cymysql_7charset_Charsets *__pyx_v_7cymysql_7charset__charsets = 0;
#define __Pyx_MODULE_NAME "cymysql.charset"
int __pyx_module_is_main_cymysql__charset = 0;

/* Implementation of 'cymysql.charset' */
static int __pyx_pf_7cymysql_7charset_7Charset___init__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self, PyObject *__pyx_v_id, PyObject *__pyx_v_name, PyObject *__pyx_v_collation, PyObject *__pyx_v_is_default); /* proto */
static PyObject *__pyx_pf_7cymysql_7charset_7Charset_2id___get__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self); /* proto */
static int __pyx_pf_7cymysql_7charset_7Charset_2id_2__set__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_7cymysql_7charset_7Charset_4name___get__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self); /* proto */
static int __pyx_pf_7cymysql_7charset_7Charset_4name_2__set__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_7cymysql_7charset_7Charset_4name_4__del__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7cymysql_7charset_7Charset_9collation___get__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self); /* proto */
static int __pyx_pf_7cymysql_7charset_7Charset_9collation_2__set__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_7cymysql_7charset_7Charset_9collation_4__del__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7cymysql_7charset_7Charset_10is_default___get__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self); /* proto */
static int __pyx_pf_7cymysql_7charset_7Charset_10is_default_2__set__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_7cymysql_7charset_8Charsets___init__(struct __pyx_obj_7cymysql_7charset_Charsets *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_7cymysql_7charset_8Charsets_2by_name(struct __pyx_obj_7cymysql_7charset_Charsets *__pyx_v_self, PyObject *__pyx_v_name); /* proto */
static PyObject *__pyx_pf_7cymysql_7charset_8Charsets_4by_id(struct __pyx_obj_7cymysql_7charset_Charsets *__pyx_v_self, PyObject *__pyx_v_id); /* proto */
static PyObject *__pyx_tp_new_7cymysql_7charset_Charset(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_7cymysql_7charset_Charsets(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static char __pyx_k__2[] = "";
static char __pyx_k_id[] = "id";
static char __pyx_k_Yes[] = "Yes";
static char __pyx_k_gbk[] = "gbk";
static char __pyx_k_hp8[] = "hp8";
static char __pyx_k_big5[] = "big5";
static char __pyx_k_dec8[] = "dec8";
static char __pyx_k_main[] = "__main__";
static char __pyx_k_name[] = "name";
static char __pyx_k_sjis[] = "sjis";
static char __pyx_k_swe7[] = "swe7";
static char __pyx_k_test[] = "__test__";
static char __pyx_k_ucs2[] = "ucs2";
static char __pyx_k_ujis[] = "ujis";
static char __pyx_k_utf8[] = "utf8";
static char __pyx_k_ascii[] = "ascii";
static char __pyx_k_by_id[] = "by_id";
static char __pyx_k_cp850[] = "cp850";
static char __pyx_k_cp852[] = "cp852";
static char __pyx_k_cp866[] = "cp866";
static char __pyx_k_cp932[] = "cp932";
static char __pyx_k_euckr[] = "euckr";
static char __pyx_k_greek[] = "greek";
static char __pyx_k_koi8r[] = "koi8r";
static char __pyx_k_koi8u[] = "koi8u";
static char __pyx_k_macce[] = "macce";
static char __pyx_k_binary[] = "binary";
static char __pyx_k_cp1250[] = "cp1250";
static char __pyx_k_cp1251[] = "cp1251";
static char __pyx_k_cp1256[] = "cp1256";
static char __pyx_k_cp1257[] = "cp1257";
static char __pyx_k_gb2312[] = "gb2312";
static char __pyx_k_hebrew[] = "hebrew";
static char __pyx_k_latin1[] = "latin1";
static char __pyx_k_latin2[] = "latin2";
static char __pyx_k_latin5[] = "latin5";
static char __pyx_k_latin7[] = "latin7";
static char __pyx_k_tis620[] = "tis620";
static char __pyx_k_values[] = "values";
static char __pyx_k_by_name[] = "by_name";
static char __pyx_k_eucjpms[] = "eucjpms";
static char __pyx_k_gbk_bin[] = "gbk_bin";
static char __pyx_k_geostd8[] = "geostd8";
static char __pyx_k_hp8_bin[] = "hp8_bin";
static char __pyx_k_keybcs2[] = "keybcs2";
static char __pyx_k_utf8mb4[] = "utf8mb4";
static char __pyx_k_armscii8[] = "armscii8";
static char __pyx_k_big5_bin[] = "big5_bin";
static char __pyx_k_charsets[] = "_charsets";
static char __pyx_k_dec8_bin[] = "dec8_bin";
static char __pyx_k_macroman[] = "macroman";
static char __pyx_k_pyx_capi[] = "__pyx_capi__";
static char __pyx_k_sjis_bin[] = "sjis_bin";
static char __pyx_k_swe7_bin[] = "swe7_bin";
static char __pyx_k_ucs2_bin[] = "ucs2_bin";
static char __pyx_k_ujis_bin[] = "ujis_bin";
static char __pyx_k_utf8_bin[] = "utf8_bin";
static char __pyx_k_ascii_bin[] = "ascii_bin";
static char __pyx_k_collation[] = "collation";
static char __pyx_k_cp850_bin[] = "cp850_bin";
static char __pyx_k_cp852_bin[] = "cp852_bin";
static char __pyx_k_cp866_bin[] = "cp866_bin";
static char __pyx_k_cp932_bin[] = "cp932_bin";
static char __pyx_k_euckr_bin[] = "euckr_bin";
static char __pyx_k_greek_bin[] = "greek_bin";
static char __pyx_k_koi8r_bin[] = "koi8r_bin";
static char __pyx_k_koi8u_bin[] = "koi8u_bin";
static char __pyx_k_macce_bin[] = "macce_bin";
static char __pyx_k_cp1250_bin[] = "cp1250_bin";
static char __pyx_k_cp1251_bin[] = "cp1251_bin";
static char __pyx_k_cp1256_bin[] = "cp1256_bin";
static char __pyx_k_cp1257_bin[] = "cp1257_bin";
static char __pyx_k_gb2312_bin[] = "gb2312_bin";
static char __pyx_k_hebrew_bin[] = "hebrew_bin";
static char __pyx_k_is_default[] = "is_default";
static char __pyx_k_latin1_bin[] = "latin1_bin";
static char __pyx_k_latin2_bin[] = "latin2_bin";
static char __pyx_k_latin5_bin[] = "latin5_bin";
static char __pyx_k_latin7_bin[] = "latin7_bin";
static char __pyx_k_pyx_vtable[] = "__pyx_vtable__";
static char __pyx_k_tis620_bin[] = "tis620_bin";
static char __pyx_k_eucjpms_bin[] = "eucjpms_bin";
static char __pyx_k_geostd8_bin[] = "geostd8_bin";
static char __pyx_k_keybcs2_bin[] = "keybcs2_bin";
static char __pyx_k_armscii8_bin[] = "armscii8_bin";
static char __pyx_k_macroman_bin[] = "macroman_bin";
static char __pyx_k_charset_by_id[] = "charset_by_id";
static char __pyx_k_ucs2_czech_ci[] = "ucs2_czech_ci";
static char __pyx_k_ucs2_roman_ci[] = "ucs2_roman_ci";
static char __pyx_k_utf8_czech_ci[] = "utf8_czech_ci";
static char __pyx_k_utf8_roman_ci[] = "utf8_roman_ci";
static char __pyx_k_gbk_chinese_ci[] = "gbk_chinese_ci";
static char __pyx_k_hp8_english_ci[] = "hp8_english_ci";
static char __pyx_k_tis620_thai_ci[] = "tis620_thai_ci";
static char __pyx_k_ucs2_danish_ci[] = "ucs2_danish_ci";
static char __pyx_k_ucs2_polish_ci[] = "ucs2_polish_ci";
static char __pyx_k_ucs2_slovak_ci[] = "ucs2_slovak_ci";
static char __pyx_k_utf8_danish_ci[] = "utf8_danish_ci";
static char __pyx_k_utf8_polish_ci[] = "utf8_polish_ci";
static char __pyx_k_utf8_slovak_ci[] = "utf8_slovak_ci";
static char __pyx_k_big5_chinese_ci[] = "big5_chinese_ci";
static char __pyx_k_charset_by_name[] = "charset_by_name";
static char __pyx_k_cp1250_czech_cs[] = "cp1250_czech_cs";
static char __pyx_k_dec8_swedish_ci[] = "dec8_swedish_ci";
static char __pyx_k_euckr_korean_ci[] = "euckr_korean_ci";
static char __pyx_k_latin2_czech_cs[] = "latin2_czech_cs";
static char __pyx_k_swe7_swedish_ci[] = "swe7_swedish_ci";
static char __pyx_k_ucs2_general_ci[] = "ucs2_general_ci";
static char __pyx_k_ucs2_latvian_ci[] = "ucs2_latvian_ci";
static char __pyx_k_ucs2_persian_ci[] = "ucs2_persian_ci";
static char __pyx_k_ucs2_spanish_ci[] = "ucs2_spanish_ci";
static char __pyx_k_ucs2_swedish_ci[] = "ucs2_swedish_ci";
static char __pyx_k_ucs2_turkish_ci[] = "ucs2_turkish_ci";
static char __pyx_k_ucs2_unicode_ci[] = "ucs2_unicode_ci";
static char __pyx_k_utf8_general_ci[] = "utf8_general_ci";
static char __pyx_k_utf8_latvian_ci[] = "utf8_latvian_ci";
static char __pyx_k_utf8_persian_ci[] = "utf8_persian_ci";
static char __pyx_k_utf8_spanish_ci[] = "utf8_spanish_ci";
static char __pyx_k_utf8_swedish_ci[] = "utf8_swedish_ci";
static char __pyx_k_utf8_turkish_ci[] = "utf8_turkish_ci";
static char __pyx_k_utf8_unicode_ci[] = "utf8_unicode_ci";
static char __pyx_k_ascii_general_ci[] = "ascii_general_ci";
static char __pyx_k_cp1250_polish_ci[] = "cp1250_polish_ci";
static char __pyx_k_cp850_general_ci[] = "cp850_general_ci";
static char __pyx_k_cp852_general_ci[] = "cp852_general_ci";
static char __pyx_k_cp866_general_ci[] = "cp866_general_ci";
static char __pyx_k_greek_general_ci[] = "greek_general_ci";
static char __pyx_k_koi8r_general_ci[] = "koi8r_general_ci";
static char __pyx_k_koi8u_general_ci[] = "koi8u_general_ci";
static char __pyx_k_latin1_danish_ci[] = "latin1_danish_ci";
static char __pyx_k_macce_general_ci[] = "macce_general_ci";
static char __pyx_k_sjis_japanese_ci[] = "sjis_japanese_ci";
static char __pyx_k_ucs2_estonian_ci[] = "ucs2_estonian_ci";
static char __pyx_k_ucs2_romanian_ci[] = "ucs2_romanian_ci";
static char __pyx_k_ucs2_spanish2_ci[] = "ucs2_spanish2_ci";
static char __pyx_k_ujis_japanese_ci[] = "ujis_japanese_ci";
static char __pyx_k_utf8_estonian_ci[] = "utf8_estonian_ci";
static char __pyx_k_utf8_romanian_ci[] = "utf8_romanian_ci";
static char __pyx_k_utf8_spanish2_ci[] = "utf8_spanish2_ci";
static char __pyx_k_cp1250_general_ci[] = "cp1250_general_ci";
static char __pyx_k_cp1251_general_ci[] = "cp1251_general_ci";
static char __pyx_k_cp1251_general_cs[] = "cp1251_general_cs";
static char __pyx_k_cp1256_general_ci[] = "cp1256_general_ci";
static char __pyx_k_cp1257_general_ci[] = "cp1257_general_ci";
static char __pyx_k_cp932_japanese_ci[] = "cp932_japanese_ci";
static char __pyx_k_gb2312_chinese_ci[] = "gb2312_chinese_ci";
static char __pyx_k_hebrew_general_ci[] = "hebrew_general_ci";
static char __pyx_k_latin1_general_ci[] = "latin1_general_ci";
static char __pyx_k_latin1_general_cs[] = "latin1_general_cs";
static char __pyx_k_latin1_german1_ci[] = "latin1_german1_ci";
static char __pyx_k_latin1_german2_ci[] = "latin1_german2_ci";
static char __pyx_k_latin1_spanish_ci[] = "latin1_spanish_ci";
static char __pyx_k_latin1_swedish_ci[] = "latin1_swedish_ci";
static char __pyx_k_latin2_general_ci[] = "latin2_general_ci";
static char __pyx_k_latin5_turkish_ci[] = "latin5_turkish_ci";
static char __pyx_k_latin7_general_ci[] = "latin7_general_ci";
static char __pyx_k_latin7_general_cs[] = "latin7_general_cs";
static char __pyx_k_ucs2_esperanto_ci[] = "ucs2_esperanto_ci";
static char __pyx_k_ucs2_hungarian_ci[] = "ucs2_hungarian_ci";
static char __pyx_k_ucs2_icelandic_ci[] = "ucs2_icelandic_ci";
static char __pyx_k_ucs2_slovenian_ci[] = "ucs2_slovenian_ci";
static char __pyx_k_utf8_esperanto_ci[] = "utf8_esperanto_ci";
static char __pyx_k_utf8_hungarian_ci[] = "utf8_hungarian_ci";
static char __pyx_k_utf8_icelandic_ci[] = "utf8_icelandic_ci";
static char __pyx_k_utf8_slovenian_ci[] = "utf8_slovenian_ci";
static char __pyx_k_cp1250_croatian_ci[] = "cp1250_croatian_ci";
static char __pyx_k_geostd8_general_ci[] = "geostd8_general_ci";
static char __pyx_k_keybcs2_general_ci[] = "keybcs2_general_ci";
static char __pyx_k_latin2_croatian_ci[] = "latin2_croatian_ci";
static char __pyx_k_latin7_estonian_cs[] = "latin7_estonian_cs";
static char __pyx_k_ucs2_lithuanian_ci[] = "ucs2_lithuanian_ci";
static char __pyx_k_utf8_lithuanian_ci[] = "utf8_lithuanian_ci";
static char __pyx_k_utf8mb4_general_ci[] = "utf8mb4_general_ci";
static char __pyx_k_armscii8_general_ci[] = "armscii8_general_ci";
static char __pyx_k_cp1251_bulgarian_ci[] = "cp1251_bulgarian_ci";
static char __pyx_k_cp1251_ukrainian_ci[] = "cp1251_ukrainian_ci";
static char __pyx_k_eucjpms_japanese_ci[] = "eucjpms_japanese_ci";
static char __pyx_k_latin2_hungarian_ci[] = "latin2_hungarian_ci";
static char __pyx_k_macroman_general_ci[] = "macroman_general_ci";
static char __pyx_k_cp1257_lithuanian_ci[] = "cp1257_lithuanian_ci";
static PyObject *__pyx_n_s_Yes;
static PyObject *__pyx_kp_s__2;
static PyObject *__pyx_n_s_armscii8;
static PyObject *__pyx_n_s_armscii8_bin;
static PyObject *__pyx_n_s_armscii8_general_ci;
static PyObject *__pyx_n_s_ascii;
static PyObject *__pyx_n_s_ascii_bin;
static PyObject *__pyx_n_s_ascii_general_ci;
static PyObject *__pyx_n_s_big5;
static PyObject *__pyx_n_s_big5_bin;
static PyObject *__pyx_n_s_big5_chinese_ci;
static PyObject *__pyx_n_s_binary;
static PyObject *__pyx_n_s_by_id;
static PyObject *__pyx_n_s_by_name;
static PyObject *__pyx_n_s_charset_by_id;
static PyObject *__pyx_n_s_charset_by_name;
static PyObject *__pyx_n_s_charsets;
static PyObject *__pyx_n_s_collation;
static PyObject *__pyx_n_s_cp1250;
static PyObject *__pyx_n_s_cp1250_bin;
static PyObject *__pyx_n_s_cp1250_croatian_ci;
static PyObject *__pyx_n_s_cp1250_czech_cs;
static PyObject *__pyx_n_s_cp1250_general_ci;
static PyObject *__pyx_n_s_cp1250_polish_ci;
static PyObject *__pyx_n_s_cp1251;
static PyObject *__pyx_n_s_cp1251_bin;
static PyObject *__pyx_n_s_cp1251_bulgarian_ci;
static PyObject *__pyx_n_s_cp1251_general_ci;
static PyObject *__pyx_n_s_cp1251_general_cs;
static PyObject *__pyx_n_s_cp1251_ukrainian_ci;
static PyObject *__pyx_n_s_cp1256;
static PyObject *__pyx_n_s_cp1256_bin;
static PyObject *__pyx_n_s_cp1256_general_ci;
static PyObject *__pyx_n_s_cp1257;
static PyObject *__pyx_n_s_cp1257_bin;
static PyObject *__pyx_n_s_cp1257_general_ci;
static PyObject *__pyx_n_s_cp1257_lithuanian_ci;
static PyObject *__pyx_n_s_cp850;
static PyObject *__pyx_n_s_cp850_bin;
static PyObject *__pyx_n_s_cp850_general_ci;
static PyObject *__pyx_n_s_cp852;
static PyObject *__pyx_n_s_cp852_bin;
static PyObject *__pyx_n_s_cp852_general_ci;
static PyObject *__pyx_n_s_cp866;
static PyObject *__pyx_n_s_cp866_bin;
static PyObject *__pyx_n_s_cp866_general_ci;
static PyObject *__pyx_n_s_cp932;
static PyObject *__pyx_n_s_cp932_bin;
static PyObject *__pyx_n_s_cp932_japanese_ci;
static PyObject *__pyx_n_s_dec8;
static PyObject *__pyx_n_s_dec8_bin;
static PyObject *__pyx_n_s_dec8_swedish_ci;
static PyObject *__pyx_n_s_eucjpms;
static PyObject *__pyx_n_s_eucjpms_bin;
static PyObject *__pyx_n_s_eucjpms_japanese_ci;
static PyObject *__pyx_n_s_euckr;
static PyObject *__pyx_n_s_euckr_bin;
static PyObject *__pyx_n_s_euckr_korean_ci;
static PyObject *__pyx_n_s_gb2312;
static PyObject *__pyx_n_s_gb2312_bin;
static PyObject *__pyx_n_s_gb2312_chinese_ci;
static PyObject *__pyx_n_s_gbk;
static PyObject *__pyx_n_s_gbk_bin;
static PyObject *__pyx_n_s_gbk_chinese_ci;
static PyObject *__pyx_n_s_geostd8;
static PyObject *__pyx_n_s_geostd8_bin;
static PyObject *__pyx_n_s_geostd8_general_ci;
static PyObject *__pyx_n_s_greek;
static PyObject *__pyx_n_s_greek_bin;
static PyObject *__pyx_n_s_greek_general_ci;
static PyObject *__pyx_n_s_hebrew;
static PyObject *__pyx_n_s_hebrew_bin;
static PyObject *__pyx_n_s_hebrew_general_ci;
static PyObject *__pyx_n_s_hp8;
static PyObject *__pyx_n_s_hp8_bin;
static PyObject *__pyx_n_s_hp8_english_ci;
static PyObject *__pyx_n_s_id;
static PyObject *__pyx_n_s_is_default;
static PyObject *__pyx_n_s_keybcs2;
static PyObject *__pyx_n_s_keybcs2_bin;
static PyObject *__pyx_n_s_keybcs2_general_ci;
static PyObject *__pyx_n_s_koi8r;
static PyObject *__pyx_n_s_koi8r_bin;
static PyObject *__pyx_n_s_koi8r_general_ci;
static PyObject *__pyx_n_s_koi8u;
static PyObject *__pyx_n_s_koi8u_bin;
static PyObject *__pyx_n_s_koi8u_general_ci;
static PyObject *__pyx_n_s_latin1;
static PyObject *__pyx_n_s_latin1_bin;
static PyObject *__pyx_n_s_latin1_danish_ci;
static PyObject *__pyx_n_s_latin1_general_ci;
static PyObject *__pyx_n_s_latin1_general_cs;
static PyObject *__pyx_n_s_latin1_german1_ci;
static PyObject *__pyx_n_s_latin1_german2_ci;
static PyObject *__pyx_n_s_latin1_spanish_ci;
static PyObject *__pyx_n_s_latin1_swedish_ci;
static PyObject *__pyx_n_s_latin2;
static PyObject *__pyx_n_s_latin2_bin;
static PyObject *__pyx_n_s_latin2_croatian_ci;
static PyObject *__pyx_n_s_latin2_czech_cs;
static PyObject *__pyx_n_s_latin2_general_ci;
static PyObject *__pyx_n_s_latin2_hungarian_ci;
static PyObject *__pyx_n_s_latin5;
static PyObject *__pyx_n_s_latin5_bin;
static PyObject *__pyx_n_s_latin5_turkish_ci;
static PyObject *__pyx_n_s_latin7;
static PyObject *__pyx_n_s_latin7_bin;
static PyObject *__pyx_n_s_latin7_estonian_cs;
static PyObject *__pyx_n_s_latin7_general_ci;
static PyObject *__pyx_n_s_latin7_general_cs;
static PyObject *__pyx_n_s_macce;
static PyObject *__pyx_n_s_macce_bin;
static PyObject *__pyx_n_s_macce_general_ci;
static PyObject *__pyx_n_s_macroman;
static PyObject *__pyx_n_s_macroman_bin;
static PyObject *__pyx_n_s_macroman_general_ci;
static PyObject *__pyx_n_s_main;
static PyObject *__pyx_n_s_name;
static PyObject *__pyx_n_s_pyx_capi;
static PyObject *__pyx_n_s_pyx_vtable;
static PyObject *__pyx_n_s_sjis;
static PyObject *__pyx_n_s_sjis_bin;
static PyObject *__pyx_n_s_sjis_japanese_ci;
static PyObject *__pyx_n_s_swe7;
static PyObject *__pyx_n_s_swe7_bin;
static PyObject *__pyx_n_s_swe7_swedish_ci;
static PyObject *__pyx_n_s_test;
static PyObject *__pyx_n_s_tis620;
static PyObject *__pyx_n_s_tis620_bin;
static PyObject *__pyx_n_s_tis620_thai_ci;
static PyObject *__pyx_n_s_ucs2;
static PyObject *__pyx_n_s_ucs2_bin;
static PyObject *__pyx_n_s_ucs2_czech_ci;
static PyObject *__pyx_n_s_ucs2_danish_ci;
static PyObject *__pyx_n_s_ucs2_esperanto_ci;
static PyObject *__pyx_n_s_ucs2_estonian_ci;
static PyObject *__pyx_n_s_ucs2_general_ci;
static PyObject *__pyx_n_s_ucs2_hungarian_ci;
static PyObject *__pyx_n_s_ucs2_icelandic_ci;
static PyObject *__pyx_n_s_ucs2_latvian_ci;
static PyObject *__pyx_n_s_ucs2_lithuanian_ci;
static PyObject *__pyx_n_s_ucs2_persian_ci;
static PyObject *__pyx_n_s_ucs2_polish_ci;
static PyObject *__pyx_n_s_ucs2_roman_ci;
static PyObject *__pyx_n_s_ucs2_romanian_ci;
static PyObject *__pyx_n_s_ucs2_slovak_ci;
static PyObject *__pyx_n_s_ucs2_slovenian_ci;
static PyObject *__pyx_n_s_ucs2_spanish2_ci;
static PyObject *__pyx_n_s_ucs2_spanish_ci;
static PyObject *__pyx_n_s_ucs2_swedish_ci;
static PyObject *__pyx_n_s_ucs2_turkish_ci;
static PyObject *__pyx_n_s_ucs2_unicode_ci;
static PyObject *__pyx_n_s_ujis;
static PyObject *__pyx_n_s_ujis_bin;
static PyObject *__pyx_n_s_ujis_japanese_ci;
static PyObject *__pyx_n_s_utf8;
static PyObject *__pyx_n_s_utf8_bin;
static PyObject *__pyx_n_s_utf8_czech_ci;
static PyObject *__pyx_n_s_utf8_danish_ci;
static PyObject *__pyx_n_s_utf8_esperanto_ci;
static PyObject *__pyx_n_s_utf8_estonian_ci;
static PyObject *__pyx_n_s_utf8_general_ci;
static PyObject *__pyx_n_s_utf8_hungarian_ci;
static PyObject *__pyx_n_s_utf8_icelandic_ci;
static PyObject *__pyx_n_s_utf8_latvian_ci;
static PyObject *__pyx_n_s_utf8_lithuanian_ci;
static PyObject *__pyx_n_s_utf8_persian_ci;
static PyObject *__pyx_n_s_utf8_polish_ci;
static PyObject *__pyx_n_s_utf8_roman_ci;
static PyObject *__pyx_n_s_utf8_romanian_ci;
static PyObject *__pyx_n_s_utf8_slovak_ci;
static PyObject *__pyx_n_s_utf8_slovenian_ci;
static PyObject *__pyx_n_s_utf8_spanish2_ci;
static PyObject *__pyx_n_s_utf8_spanish_ci;
static PyObject *__pyx_n_s_utf8_swedish_ci;
static PyObject *__pyx_n_s_utf8_turkish_ci;
static PyObject *__pyx_n_s_utf8_unicode_ci;
static PyObject *__pyx_n_s_utf8mb4;
static PyObject *__pyx_n_s_utf8mb4_general_ci;
static PyObject *__pyx_n_s_values;
static PyObject *__pyx_int_1;
static PyObject *__pyx_int_2;
static PyObject *__pyx_int_3;
static PyObject *__pyx_int_4;
static PyObject *__pyx_int_5;
static PyObject *__pyx_int_6;
static PyObject *__pyx_int_7;
static PyObject *__pyx_int_8;
static PyObject *__pyx_int_9;
static PyObject *__pyx_int_10;
static PyObject *__pyx_int_11;
static PyObject *__pyx_int_12;
static PyObject *__pyx_int_13;
static PyObject *__pyx_int_14;
static PyObject *__pyx_int_15;
static PyObject *__pyx_int_16;
static PyObject *__pyx_int_18;
static PyObject *__pyx_int_19;
static PyObject *__pyx_int_20;
static PyObject *__pyx_int_21;
static PyObject *__pyx_int_22;
static PyObject *__pyx_int_23;
static PyObject *__pyx_int_24;
static PyObject *__pyx_int_25;
static PyObject *__pyx_int_26;
static PyObject *__pyx_int_27;
static PyObject *__pyx_int_28;
static PyObject *__pyx_int_29;
static PyObject *__pyx_int_30;
static PyObject *__pyx_int_31;
static PyObject *__pyx_int_32;
static PyObject *__pyx_int_33;
static PyObject *__pyx_int_34;
static PyObject *__pyx_int_35;
static PyObject *__pyx_int_36;
static PyObject *__pyx_int_37;
static PyObject *__pyx_int_38;
static PyObject *__pyx_int_39;
static PyObject *__pyx_int_40;
static PyObject *__pyx_int_41;
static PyObject *__pyx_int_42;
static PyObject *__pyx_int_43;
static PyObject *__pyx_int_44;
static PyObject *__pyx_int_45;
static PyObject *__pyx_int_47;
static PyObject *__pyx_int_48;
static PyObject *__pyx_int_49;
static PyObject *__pyx_int_50;
static PyObject *__pyx_int_51;
static PyObject *__pyx_int_52;
static PyObject *__pyx_int_53;
static PyObject *__pyx_int_57;
static PyObject *__pyx_int_58;
static PyObject *__pyx_int_59;
static PyObject *__pyx_int_63;
static PyObject *__pyx_int_64;
static PyObject *__pyx_int_65;
static PyObject *__pyx_int_66;
static PyObject *__pyx_int_67;
static PyObject *__pyx_int_68;
static PyObject *__pyx_int_69;
static PyObject *__pyx_int_70;
static PyObject *__pyx_int_71;
static PyObject *__pyx_int_72;
static PyObject *__pyx_int_73;
static PyObject *__pyx_int_74;
static PyObject *__pyx_int_75;
static PyObject *__pyx_int_77;
static PyObject *__pyx_int_78;
static PyObject *__pyx_int_79;
static PyObject *__pyx_int_80;
static PyObject *__pyx_int_81;
static PyObject *__pyx_int_82;
static PyObject *__pyx_int_83;
static PyObject *__pyx_int_84;
static PyObject *__pyx_int_85;
static PyObject *__pyx_int_86;
static PyObject *__pyx_int_87;
static PyObject *__pyx_int_88;
static PyObject *__pyx_int_89;
static PyObject *__pyx_int_90;
static PyObject *__pyx_int_91;
static PyObject *__pyx_int_92;
static PyObject *__pyx_int_93;
static PyObject *__pyx_int_94;
static PyObject *__pyx_int_95;
static PyObject *__pyx_int_96;
static PyObject *__pyx_int_97;
static PyObject *__pyx_int_98;
static PyObject *__pyx_int_99;
static PyObject *__pyx_int_128;
static PyObject *__pyx_int_129;
static PyObject *__pyx_int_130;
static PyObject *__pyx_int_131;
static PyObject *__pyx_int_132;
static PyObject *__pyx_int_133;
static PyObject *__pyx_int_134;
static PyObject *__pyx_int_135;
static PyObject *__pyx_int_136;
static PyObject *__pyx_int_137;
static PyObject *__pyx_int_138;
static PyObject *__pyx_int_139;
static PyObject *__pyx_int_140;
static PyObject *__pyx_int_141;
static PyObject *__pyx_int_142;
static PyObject *__pyx_int_143;
static PyObject *__pyx_int_144;
static PyObject *__pyx_int_145;
static PyObject *__pyx_int_146;
static PyObject *__pyx_int_192;
static PyObject *__pyx_int_193;
static PyObject *__pyx_int_194;
static PyObject *__pyx_int_195;
static PyObject *__pyx_int_196;
static PyObject *__pyx_int_197;
static PyObject *__pyx_int_198;
static PyObject *__pyx_int_199;
static PyObject *__pyx_int_200;
static PyObject *__pyx_int_201;
static PyObject *__pyx_int_202;
static PyObject *__pyx_int_203;
static PyObject *__pyx_int_204;
static PyObject *__pyx_int_205;
static PyObject *__pyx_int_206;
static PyObject *__pyx_int_207;
static PyObject *__pyx_int_208;
static PyObject *__pyx_int_209;
static PyObject *__pyx_int_210;
static PyObject *__pyx_tuple_;
static PyObject *__pyx_tuple__3;
static PyObject *__pyx_tuple__4;
static PyObject *__pyx_tuple__5;
static PyObject *__pyx_tuple__6;
static PyObject *__pyx_tuple__7;
static PyObject *__pyx_tuple__8;
static PyObject *__pyx_tuple__9;
static PyObject *__pyx_tuple__10;
static PyObject *__pyx_tuple__11;
static PyObject *__pyx_tuple__12;
static PyObject *__pyx_tuple__13;
static PyObject *__pyx_tuple__14;
static PyObject *__pyx_tuple__15;
static PyObject *__pyx_tuple__16;
static PyObject *__pyx_tuple__17;
static PyObject *__pyx_tuple__18;
static PyObject *__pyx_tuple__19;
static PyObject *__pyx_tuple__20;
static PyObject *__pyx_tuple__21;
static PyObject *__pyx_tuple__22;
static PyObject *__pyx_tuple__23;
static PyObject *__pyx_tuple__24;
static PyObject *__pyx_tuple__25;
static PyObject *__pyx_tuple__26;
static PyObject *__pyx_tuple__27;
static PyObject *__pyx_tuple__28;
static PyObject *__pyx_tuple__29;
static PyObject *__pyx_tuple__30;
static PyObject *__pyx_tuple__31;
static PyObject *__pyx_tuple__32;
static PyObject *__pyx_tuple__33;
static PyObject *__pyx_tuple__34;
static PyObject *__pyx_tuple__35;
static PyObject *__pyx_tuple__36;
static PyObject *__pyx_tuple__37;
static PyObject *__pyx_tuple__38;
static PyObject *__pyx_tuple__39;
static PyObject *__pyx_tuple__40;
static PyObject *__pyx_tuple__41;
static PyObject *__pyx_tuple__42;
static PyObject *__pyx_tuple__43;
static PyObject *__pyx_tuple__44;
static PyObject *__pyx_tuple__45;
static PyObject *__pyx_tuple__46;
static PyObject *__pyx_tuple__47;
static PyObject *__pyx_tuple__48;
static PyObject *__pyx_tuple__49;
static PyObject *__pyx_tuple__50;
static PyObject *__pyx_tuple__51;
static PyObject *__pyx_tuple__52;
static PyObject *__pyx_tuple__53;
static PyObject *__pyx_tuple__54;
static PyObject *__pyx_tuple__55;
static PyObject *__pyx_tuple__56;
static PyObject *__pyx_tuple__57;
static PyObject *__pyx_tuple__58;
static PyObject *__pyx_tuple__59;
static PyObject *__pyx_tuple__60;
static PyObject *__pyx_tuple__61;
static PyObject *__pyx_tuple__62;
static PyObject *__pyx_tuple__63;
static PyObject *__pyx_tuple__64;
static PyObject *__pyx_tuple__65;
static PyObject *__pyx_tuple__66;
static PyObject *__pyx_tuple__67;
static PyObject *__pyx_tuple__68;
static PyObject *__pyx_tuple__69;
static PyObject *__pyx_tuple__70;
static PyObject *__pyx_tuple__71;
static PyObject *__pyx_tuple__72;
static PyObject *__pyx_tuple__73;
static PyObject *__pyx_tuple__74;
static PyObject *__pyx_tuple__75;
static PyObject *__pyx_tuple__76;
static PyObject *__pyx_tuple__77;
static PyObject *__pyx_tuple__78;
static PyObject *__pyx_tuple__79;
static PyObject *__pyx_tuple__80;
static PyObject *__pyx_tuple__81;
static PyObject *__pyx_tuple__82;
static PyObject *__pyx_tuple__83;
static PyObject *__pyx_tuple__84;
static PyObject *__pyx_tuple__85;
static PyObject *__pyx_tuple__86;
static PyObject *__pyx_tuple__87;
static PyObject *__pyx_tuple__88;
static PyObject *__pyx_tuple__89;
static PyObject *__pyx_tuple__90;
static PyObject *__pyx_tuple__91;
static PyObject *__pyx_tuple__92;
static PyObject *__pyx_tuple__93;
static PyObject *__pyx_tuple__94;
static PyObject *__pyx_tuple__95;
static PyObject *__pyx_tuple__96;
static PyObject *__pyx_tuple__97;
static PyObject *__pyx_tuple__98;
static PyObject *__pyx_tuple__99;
static PyObject *__pyx_tuple__100;
static PyObject *__pyx_tuple__101;
static PyObject *__pyx_tuple__102;
static PyObject *__pyx_tuple__103;
static PyObject *__pyx_tuple__104;
static PyObject *__pyx_tuple__105;
static PyObject *__pyx_tuple__106;
static PyObject *__pyx_tuple__107;
static PyObject *__pyx_tuple__108;
static PyObject *__pyx_tuple__109;
static PyObject *__pyx_tuple__110;
static PyObject *__pyx_tuple__111;
static PyObject *__pyx_tuple__112;
static PyObject *__pyx_tuple__113;
static PyObject *__pyx_tuple__114;
static PyObject *__pyx_tuple__115;
static PyObject *__pyx_tuple__116;
static PyObject *__pyx_tuple__117;
static PyObject *__pyx_tuple__118;
static PyObject *__pyx_tuple__119;
static PyObject *__pyx_tuple__120;
static PyObject *__pyx_tuple__121;
static PyObject *__pyx_tuple__122;
static PyObject *__pyx_tuple__123;
static PyObject *__pyx_tuple__124;
static PyObject *__pyx_tuple__125;
static PyObject *__pyx_tuple__126;
static PyObject *__pyx_tuple__127;
static PyObject *__pyx_tuple__128;
static PyObject *__pyx_tuple__129;

/* "cymysql/charset.py":2
 * class Charset(object):
 *     def __init__(self, id, name, collation, is_default):             # <<<<<<<<<<<<<<
 *         self.id, self.name, self.collation = id, name, collation
 *         self.is_default = is_default == 'Yes'
 */

/* Python wrapper */
static int __pyx_pw_7cymysql_7charset_7Charset_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_7cymysql_7charset_7Charset_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_id = 0;
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_collation = 0;
  PyObject *__pyx_v_is_default = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_id,&__pyx_n_s_name,&__pyx_n_s_collation,&__pyx_n_s_is_default,0};
    PyObject* values[4] = {0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_id)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_name)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 4, 4, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_collation)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 4, 4, 2); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  3:
        if (likely((values[3] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_is_default)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 4, 4, 3); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 4) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
    }
    __pyx_v_id = values[0];
    __pyx_v_name = values[1];
    __pyx_v_collation = values[2];
    __pyx_v_is_default = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 4, 4, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("cymysql.charset.Charset.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_7cymysql_7charset_7Charset___init__(((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_v_self), __pyx_v_id, __pyx_v_name, __pyx_v_collation, __pyx_v_is_default);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_7charset_7Charset___init__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self, PyObject *__pyx_v_id, PyObject *__pyx_v_name, PyObject *__pyx_v_collation, PyObject *__pyx_v_is_default) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cymysql/charset.py":3
 * class Charset(object):
 *     def __init__(self, id, name, collation, is_default):
 *         self.id, self.name, self.collation = id, name, collation             # <<<<<<<<<<<<<<
 *         self.is_default = is_default == 'Yes'
 * 
 */
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_id); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 3; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (!(likely(PyString_CheckExact(__pyx_v_name))||((__pyx_v_name) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_v_name)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 3; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = __pyx_v_name;
  __Pyx_INCREF(__pyx_t_2);
  if (!(likely(PyString_CheckExact(__pyx_v_collation))||((__pyx_v_collation) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_v_collation)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 3; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_3 = __pyx_v_collation;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_v_self->id = __pyx_t_1;
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(__pyx_v_self->name);
  __pyx_v_self->name = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;
  __Pyx_GIVEREF(__pyx_t_3);
  __Pyx_GOTREF(__pyx_v_self->collation);
  __Pyx_DECREF(__pyx_v_self->collation);
  __pyx_v_self->collation = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "cymysql/charset.py":4
 *     def __init__(self, id, name, collation, is_default):
 *         self.id, self.name, self.collation = id, name, collation
 *         self.is_default = is_default == 'Yes'             # <<<<<<<<<<<<<<
 * 
 * class Charsets(object):
 */
  __pyx_t_3 = PyObject_RichCompare(__pyx_v_is_default, __pyx_n_s_Yes, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 4; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 4; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_self->is_default = __pyx_t_4;

  /* "cymysql/charset.py":2
 * class Charset(object):
 *     def __init__(self, id, name, collation, is_default):             # <<<<<<<<<<<<<<
 *         self.id, self.name, self.collation = id, name, collation
 *         self.is_default = is_default == 'Yes'
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cymysql.charset.Charset.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/charset.pxd":4
 * 
 * cdef class Charset(object):
 *     cdef public int id             # <<<<<<<<<<<<<<
 *     cdef public str name, collation
 *     cdef public bint is_default
 */

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_7charset_7Charset_2id_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_7cymysql_7charset_7Charset_2id_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_7charset_7Charset_2id___get__(((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_7charset_7Charset_2id___get__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->id); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 4; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cymysql.charset.Charset.id.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_7charset_7Charset_2id_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_7cymysql_7charset_7Charset_2id_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_7charset_7Charset_2id_2__set__(((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_7charset_7Charset_2id_2__set__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 4; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_self->id = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cymysql.charset.Charset.id.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/charset.pxd":5
 * cdef class Charset(object):
 *     cdef public int id
 *     cdef public str name, collation             # <<<<<<<<<<<<<<
 *     cdef public bint is_default
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_7charset_7Charset_4name_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_7cymysql_7charset_7Charset_4name_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_7charset_7Charset_4name___get__(((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_7charset_7Charset_4name___get__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->name);
  __pyx_r = __pyx_v_self->name;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_7charset_7Charset_4name_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_7cymysql_7charset_7Charset_4name_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_7charset_7Charset_4name_2__set__(((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_7charset_7Charset_4name_2__set__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(PyString_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_v_value)->tp_name), 0))) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 5; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(__pyx_v_self->name);
  __pyx_v_self->name = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cymysql.charset.Charset.name.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_7charset_7Charset_4name_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_7cymysql_7charset_7Charset_4name_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_7charset_7Charset_4name_4__del__(((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_7charset_7Charset_4name_4__del__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(__pyx_v_self->name);
  __pyx_v_self->name = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_7charset_7Charset_9collation_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_7cymysql_7charset_7Charset_9collation_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_7charset_7Charset_9collation___get__(((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_7charset_7Charset_9collation___get__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->collation);
  __pyx_r = __pyx_v_self->collation;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_7charset_7Charset_9collation_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_7cymysql_7charset_7Charset_9collation_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_7charset_7Charset_9collation_2__set__(((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_7charset_7Charset_9collation_2__set__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(PyString_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "str", Py_TYPE(__pyx_v_value)->tp_name), 0))) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 5; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->collation);
  __Pyx_DECREF(__pyx_v_self->collation);
  __pyx_v_self->collation = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cymysql.charset.Charset.collation.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_7charset_7Charset_9collation_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_7cymysql_7charset_7Charset_9collation_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_7charset_7Charset_9collation_4__del__(((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_7charset_7Charset_9collation_4__del__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->collation);
  __Pyx_DECREF(__pyx_v_self->collation);
  __pyx_v_self->collation = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/charset.pxd":6
 *     cdef public int id
 *     cdef public str name, collation
 *     cdef public bint is_default             # <<<<<<<<<<<<<<
 * 
 * cdef class Charsets(object):
 */

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_7charset_7Charset_10is_default_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_7cymysql_7charset_7Charset_10is_default_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_7charset_7Charset_10is_default___get__(((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_7charset_7Charset_10is_default___get__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->is_default); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 6; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cymysql.charset.Charset.is_default.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_7cymysql_7charset_7Charset_10is_default_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_7cymysql_7charset_7Charset_10is_default_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_7charset_7Charset_10is_default_2__set__(((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_7charset_7Charset_10is_default_2__set__(struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 6; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_self->is_default = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("cymysql.charset.Charset.is_default.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/charset.py":7
 * 
 * class Charsets(object):
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self._by_id = {}
 * 
 */

/* Python wrapper */
static int __pyx_pw_7cymysql_7charset_8Charsets_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_7cymysql_7charset_8Charsets_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  if (unlikely(PyTuple_GET_SIZE(__pyx_args) > 0)) {
    __Pyx_RaiseArgtupleInvalid("__init__", 1, 0, 0, PyTuple_GET_SIZE(__pyx_args)); return -1;}
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__init__", 0))) return -1;
  __pyx_r = __pyx_pf_7cymysql_7charset_8Charsets___init__(((struct __pyx_obj_7cymysql_7charset_Charsets *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cymysql_7charset_8Charsets___init__(struct __pyx_obj_7cymysql_7charset_Charsets *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "cymysql/charset.py":8
 * class Charsets(object):
 *     def __init__(self):
 *         self._by_id = {}             # <<<<<<<<<<<<<<
 * 
 *     def add(self, c):
 */
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 8; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_by_id);
  __Pyx_DECREF(__pyx_v_self->_by_id);
  __pyx_v_self->_by_id = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "cymysql/charset.py":7
 * 
 * class Charsets(object):
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self._by_id = {}
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cymysql.charset.Charsets.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/charset.py":10
 *         self._by_id = {}
 * 
 *     def add(self, c):             # <<<<<<<<<<<<<<
 *         self._by_id[c.id] = c
 * 
 */

static PyObject *__pyx_f_7cymysql_7charset_8Charsets_add(struct __pyx_obj_7cymysql_7charset_Charsets *__pyx_v_self, struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_c) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("add", 0);

  /* "cymysql/charset.py":11
 * 
 *     def add(self, c):
 *         self._by_id[c.id] = c             # <<<<<<<<<<<<<<
 * 
 *     def by_name(self, name):
 */
  if (unlikely(__pyx_v_self->_by_id == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 11; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_c->id); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 11; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely(PyDict_SetItem(__pyx_v_self->_by_id, __pyx_t_1, ((PyObject *)__pyx_v_c)) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 11; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":10
 *         self._by_id = {}
 * 
 *     def add(self, c):             # <<<<<<<<<<<<<<
 *         self._by_id[c.id] = c
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cymysql.charset.Charsets.add", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/charset.py":13
 *         self._by_id[c.id] = c
 * 
 *     def by_name(self, name):             # <<<<<<<<<<<<<<
 *         for c in self._by_id.values():
 *             if c.name == name and c.is_default:
 */

static PyObject *__pyx_pw_7cymysql_7charset_8Charsets_3by_name(PyObject *__pyx_v_self, PyObject *__pyx_v_name); /*proto*/
static PyObject *__pyx_f_7cymysql_7charset_8Charsets_by_name(struct __pyx_obj_7cymysql_7charset_Charsets *__pyx_v_self, PyObject *__pyx_v_name, int __pyx_skip_dispatch) {
  struct __pyx_obj_7cymysql_7charset_Charset *__pyx_v_c = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("by_name", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0)) {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_by_name); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 13; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)__pyx_pw_7cymysql_7charset_8Charsets_3by_name)) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
      if (CYTHON_COMPILING_IN_CPYTHON && unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      if (!__pyx_t_4) {
        __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_name); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 13; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_2);
      } else {
        __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 13; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __Pyx_GIVEREF(__pyx_t_4); __pyx_t_4 = NULL;
        __Pyx_INCREF(__pyx_v_name);
        PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_v_name);
        __Pyx_GIVEREF(__pyx_v_name);
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 13; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "cymysql/charset.py":14
 * 
 *     def by_name(self, name):
 *         for c in self._by_id.values():             # <<<<<<<<<<<<<<
 *             if c.name == name and c.is_default:
 *                 return c
 */
  if (unlikely(__pyx_v_self->_by_id == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "values");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 14; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyDict_Values(__pyx_v_self->_by_id); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 14; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2); __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
  } else {
    __pyx_t_6 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 14; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 14; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_7)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_COMPILING_IN_CPYTHON
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_6); __Pyx_INCREF(__pyx_t_1); __pyx_t_6++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 14; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 14; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #endif
      } else {
        if (__pyx_t_6 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_COMPILING_IN_CPYTHON
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_6); __Pyx_INCREF(__pyx_t_1); __pyx_t_6++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 14; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 14; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_7(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 14; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_7cymysql_7charset_Charset))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 14; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_XDECREF_SET(__pyx_v_c, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "cymysql/charset.py":15
 *     def by_name(self, name):
 *         for c in self._by_id.values():
 *             if c.name == name and c.is_default:             # <<<<<<<<<<<<<<
 *                 return c
 * 
 */
    __pyx_t_9 = (__Pyx_PyString_Equals(__pyx_v_c->name, __pyx_v_name, Py_EQ)); if (unlikely(__pyx_t_9 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 15; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    if (__pyx_t_9) {
    } else {
      __pyx_t_8 = __pyx_t_9;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_9 = (__pyx_v_c->is_default != 0);
    __pyx_t_8 = __pyx_t_9;
    __pyx_L6_bool_binop_done:;
    if (__pyx_t_8) {

      /* "cymysql/charset.py":16
 *         for c in self._by_id.values():
 *             if c.name == name and c.is_default:
 *                 return c             # <<<<<<<<<<<<<<
 * 
 *     def by_id(self, id):
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(((PyObject *)__pyx_v_c));
      __pyx_r = ((PyObject *)__pyx_v_c);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      goto __pyx_L0;
    }

    /* "cymysql/charset.py":14
 * 
 *     def by_name(self, name):
 *         for c in self._by_id.values():             # <<<<<<<<<<<<<<
 *             if c.name == name and c.is_default:
 *                 return c
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":13
 *         self._by_id[c.id] = c
 * 
 *     def by_name(self, name):             # <<<<<<<<<<<<<<
 *         for c in self._by_id.values():
 *             if c.name == name and c.is_default:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cymysql.charset.Charsets.by_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_c);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_7charset_8Charsets_3by_name(PyObject *__pyx_v_self, PyObject *__pyx_v_name); /*proto*/
static PyObject *__pyx_pw_7cymysql_7charset_8Charsets_3by_name(PyObject *__pyx_v_self, PyObject *__pyx_v_name) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("by_name (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_7charset_8Charsets_2by_name(((struct __pyx_obj_7cymysql_7charset_Charsets *)__pyx_v_self), ((PyObject *)__pyx_v_name));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_7charset_8Charsets_2by_name(struct __pyx_obj_7cymysql_7charset_Charsets *__pyx_v_self, PyObject *__pyx_v_name) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("by_name", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_7cymysql_7charset_8Charsets_by_name(__pyx_v_self, __pyx_v_name, 1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 13; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cymysql.charset.Charsets.by_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cymysql/charset.py":18
 *                 return c
 * 
 *     def by_id(self, id):             # <<<<<<<<<<<<<<
 *         return self._by_id[id]
 * 
 */

static PyObject *__pyx_pw_7cymysql_7charset_8Charsets_5by_id(PyObject *__pyx_v_self, PyObject *__pyx_v_id); /*proto*/
static PyObject *__pyx_f_7cymysql_7charset_8Charsets_by_id(struct __pyx_obj_7cymysql_7charset_Charsets *__pyx_v_self, PyObject *__pyx_v_id, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("by_id", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0)) {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_by_id); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 18; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)__pyx_pw_7cymysql_7charset_8Charsets_5by_id)) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
      if (CYTHON_COMPILING_IN_CPYTHON && unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      if (!__pyx_t_4) {
        __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_id); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 18; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_2);
      } else {
        __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 18; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __Pyx_GIVEREF(__pyx_t_4); __pyx_t_4 = NULL;
        __Pyx_INCREF(__pyx_v_id);
        PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_v_id);
        __Pyx_GIVEREF(__pyx_v_id);
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 18; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "cymysql/charset.py":19
 * 
 *     def by_id(self, id):
 *         return self._by_id[id]             # <<<<<<<<<<<<<<
 * 
 * _charsets = Charsets()
 */
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(__pyx_v_self->_by_id == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 19; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_self->_by_id, __pyx_v_id); if (unlikely(__pyx_t_1 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 19; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cymysql/charset.py":18
 *                 return c
 * 
 *     def by_id(self, id):             # <<<<<<<<<<<<<<
 *         return self._by_id[id]
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cymysql.charset.Charsets.by_id", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_7cymysql_7charset_8Charsets_5by_id(PyObject *__pyx_v_self, PyObject *__pyx_v_id); /*proto*/
static PyObject *__pyx_pw_7cymysql_7charset_8Charsets_5by_id(PyObject *__pyx_v_self, PyObject *__pyx_v_id) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("by_id (wrapper)", 0);
  __pyx_r = __pyx_pf_7cymysql_7charset_8Charsets_4by_id(((struct __pyx_obj_7cymysql_7charset_Charsets *)__pyx_v_self), ((PyObject *)__pyx_v_id));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_7cymysql_7charset_8Charsets_4by_id(struct __pyx_obj_7cymysql_7charset_Charsets *__pyx_v_self, PyObject *__pyx_v_id) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("by_id", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_7cymysql_7charset_8Charsets_by_id(__pyx_v_self, __pyx_v_id, 1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 18; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cymysql.charset.Charsets.by_id", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_tp_new_7cymysql_7charset_Charset(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_7cymysql_7charset_Charset *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_7cymysql_7charset_Charset *)o);
  p->name = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->collation = ((PyObject*)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_7cymysql_7charset_Charset(PyObject *o) {
  struct __pyx_obj_7cymysql_7charset_Charset *p = (struct __pyx_obj_7cymysql_7charset_Charset *)o;
  #if PY_VERSION_HEX >= 0x030400a1
  if (unlikely(Py_TYPE(o)->tp_finalize) && (!PyType_IS_GC(Py_TYPE(o)) || !_PyGC_FINALIZED(o))) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  Py_CLEAR(p->name);
  Py_CLEAR(p->collation);
  (*Py_TYPE(o)->tp_free)(o);
}

static PyObject *__pyx_getprop_7cymysql_7charset_7Charset_id(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_7cymysql_7charset_7Charset_2id_1__get__(o);
}

static int __pyx_setprop_7cymysql_7charset_7Charset_id(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_7cymysql_7charset_7Charset_2id_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_7cymysql_7charset_7Charset_name(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_7cymysql_7charset_7Charset_4name_1__get__(o);
}

static int __pyx_setprop_7cymysql_7charset_7Charset_name(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_7cymysql_7charset_7Charset_4name_3__set__(o, v);
  }
  else {
    return __pyx_pw_7cymysql_7charset_7Charset_4name_5__del__(o);
  }
}

static PyObject *__pyx_getprop_7cymysql_7charset_7Charset_collation(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_7cymysql_7charset_7Charset_9collation_1__get__(o);
}

static int __pyx_setprop_7cymysql_7charset_7Charset_collation(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_7cymysql_7charset_7Charset_9collation_3__set__(o, v);
  }
  else {
    return __pyx_pw_7cymysql_7charset_7Charset_9collation_5__del__(o);
  }
}

static PyObject *__pyx_getprop_7cymysql_7charset_7Charset_is_default(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_7cymysql_7charset_7Charset_10is_default_1__get__(o);
}

static int __pyx_setprop_7cymysql_7charset_7Charset_is_default(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_7cymysql_7charset_7Charset_10is_default_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyMethodDef __pyx_methods_7cymysql_7charset_Charset[] = {
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_7cymysql_7charset_Charset[] = {
  {(char *)"id", __pyx_getprop_7cymysql_7charset_7Charset_id, __pyx_setprop_7cymysql_7charset_7Charset_id, 0, 0},
  {(char *)"name", __pyx_getprop_7cymysql_7charset_7Charset_name, __pyx_setprop_7cymysql_7charset_7Charset_name, 0, 0},
  {(char *)"collation", __pyx_getprop_7cymysql_7charset_7Charset_collation, __pyx_setprop_7cymysql_7charset_7Charset_collation, 0, 0},
  {(char *)"is_default", __pyx_getprop_7cymysql_7charset_7Charset_is_default, __pyx_setprop_7cymysql_7charset_7Charset_is_default, 0, 0},
  {0, 0, 0, 0, 0}
};

static PyTypeObject __pyx_type_7cymysql_7charset_Charset = {
  PyVarObject_HEAD_INIT(0, 0)
  "cymysql.charset.Charset", /*tp_name*/
  sizeof(struct __pyx_obj_7cymysql_7charset_Charset), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_7cymysql_7charset_Charset, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_7cymysql_7charset_Charset, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_7cymysql_7charset_Charset, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_7cymysql_7charset_7Charset_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_7cymysql_7charset_Charset, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_7cymysql_7charset_Charsets __pyx_vtable_7cymysql_7charset_Charsets;

static PyObject *__pyx_tp_new_7cymysql_7charset_Charsets(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_7cymysql_7charset_Charsets *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_7cymysql_7charset_Charsets *)o);
  p->__pyx_vtab = __pyx_vtabptr_7cymysql_7charset_Charsets;
  p->_by_id = ((PyObject*)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_7cymysql_7charset_Charsets(PyObject *o) {
  struct __pyx_obj_7cymysql_7charset_Charsets *p = (struct __pyx_obj_7cymysql_7charset_Charsets *)o;
  #if PY_VERSION_HEX >= 0x030400a1
  if (unlikely(Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->_by_id);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_7cymysql_7charset_Charsets(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_7cymysql_7charset_Charsets *p = (struct __pyx_obj_7cymysql_7charset_Charsets *)o;
  if (p->_by_id) {
    e = (*v)(p->_by_id, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_7cymysql_7charset_Charsets(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_7cymysql_7charset_Charsets *p = (struct __pyx_obj_7cymysql_7charset_Charsets *)o;
  tmp = ((PyObject*)p->_by_id);
  p->_by_id = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_7cymysql_7charset_Charsets[] = {
  {"by_name", (PyCFunction)__pyx_pw_7cymysql_7charset_8Charsets_3by_name, METH_O, 0},
  {"by_id", (PyCFunction)__pyx_pw_7cymysql_7charset_8Charsets_5by_id, METH_O, 0},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_7cymysql_7charset_Charsets = {
  PyVarObject_HEAD_INIT(0, 0)
  "cymysql.charset.Charsets", /*tp_name*/
  sizeof(struct __pyx_obj_7cymysql_7charset_Charsets), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_7cymysql_7charset_Charsets, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_7cymysql_7charset_Charsets, /*tp_traverse*/
  __pyx_tp_clear_7cymysql_7charset_Charsets, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_7cymysql_7charset_Charsets, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_7cymysql_7charset_8Charsets_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_7cymysql_7charset_Charsets, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
static struct PyModuleDef __pyx_moduledef = {
  #if PY_VERSION_HEX < 0x03020000
    { PyObject_HEAD_INIT(NULL) NULL, 0, NULL },
  #else
    PyModuleDef_HEAD_INIT,
  #endif
    "charset",
    0, /* m_doc */
    -1, /* m_size */
    __pyx_methods /* m_methods */,
    NULL, /* m_reload */
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_n_s_Yes, __pyx_k_Yes, sizeof(__pyx_k_Yes), 0, 0, 1, 1},
  {&__pyx_kp_s__2, __pyx_k__2, sizeof(__pyx_k__2), 0, 0, 1, 0},
  {&__pyx_n_s_armscii8, __pyx_k_armscii8, sizeof(__pyx_k_armscii8), 0, 0, 1, 1},
  {&__pyx_n_s_armscii8_bin, __pyx_k_armscii8_bin, sizeof(__pyx_k_armscii8_bin), 0, 0, 1, 1},
  {&__pyx_n_s_armscii8_general_ci, __pyx_k_armscii8_general_ci, sizeof(__pyx_k_armscii8_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ascii, __pyx_k_ascii, sizeof(__pyx_k_ascii), 0, 0, 1, 1},
  {&__pyx_n_s_ascii_bin, __pyx_k_ascii_bin, sizeof(__pyx_k_ascii_bin), 0, 0, 1, 1},
  {&__pyx_n_s_ascii_general_ci, __pyx_k_ascii_general_ci, sizeof(__pyx_k_ascii_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_big5, __pyx_k_big5, sizeof(__pyx_k_big5), 0, 0, 1, 1},
  {&__pyx_n_s_big5_bin, __pyx_k_big5_bin, sizeof(__pyx_k_big5_bin), 0, 0, 1, 1},
  {&__pyx_n_s_big5_chinese_ci, __pyx_k_big5_chinese_ci, sizeof(__pyx_k_big5_chinese_ci), 0, 0, 1, 1},
  {&__pyx_n_s_binary, __pyx_k_binary, sizeof(__pyx_k_binary), 0, 0, 1, 1},
  {&__pyx_n_s_by_id, __pyx_k_by_id, sizeof(__pyx_k_by_id), 0, 0, 1, 1},
  {&__pyx_n_s_by_name, __pyx_k_by_name, sizeof(__pyx_k_by_name), 0, 0, 1, 1},
  {&__pyx_n_s_charset_by_id, __pyx_k_charset_by_id, sizeof(__pyx_k_charset_by_id), 0, 0, 1, 1},
  {&__pyx_n_s_charset_by_name, __pyx_k_charset_by_name, sizeof(__pyx_k_charset_by_name), 0, 0, 1, 1},
  {&__pyx_n_s_charsets, __pyx_k_charsets, sizeof(__pyx_k_charsets), 0, 0, 1, 1},
  {&__pyx_n_s_collation, __pyx_k_collation, sizeof(__pyx_k_collation), 0, 0, 1, 1},
  {&__pyx_n_s_cp1250, __pyx_k_cp1250, sizeof(__pyx_k_cp1250), 0, 0, 1, 1},
  {&__pyx_n_s_cp1250_bin, __pyx_k_cp1250_bin, sizeof(__pyx_k_cp1250_bin), 0, 0, 1, 1},
  {&__pyx_n_s_cp1250_croatian_ci, __pyx_k_cp1250_croatian_ci, sizeof(__pyx_k_cp1250_croatian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_cp1250_czech_cs, __pyx_k_cp1250_czech_cs, sizeof(__pyx_k_cp1250_czech_cs), 0, 0, 1, 1},
  {&__pyx_n_s_cp1250_general_ci, __pyx_k_cp1250_general_ci, sizeof(__pyx_k_cp1250_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_cp1250_polish_ci, __pyx_k_cp1250_polish_ci, sizeof(__pyx_k_cp1250_polish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_cp1251, __pyx_k_cp1251, sizeof(__pyx_k_cp1251), 0, 0, 1, 1},
  {&__pyx_n_s_cp1251_bin, __pyx_k_cp1251_bin, sizeof(__pyx_k_cp1251_bin), 0, 0, 1, 1},
  {&__pyx_n_s_cp1251_bulgarian_ci, __pyx_k_cp1251_bulgarian_ci, sizeof(__pyx_k_cp1251_bulgarian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_cp1251_general_ci, __pyx_k_cp1251_general_ci, sizeof(__pyx_k_cp1251_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_cp1251_general_cs, __pyx_k_cp1251_general_cs, sizeof(__pyx_k_cp1251_general_cs), 0, 0, 1, 1},
  {&__pyx_n_s_cp1251_ukrainian_ci, __pyx_k_cp1251_ukrainian_ci, sizeof(__pyx_k_cp1251_ukrainian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_cp1256, __pyx_k_cp1256, sizeof(__pyx_k_cp1256), 0, 0, 1, 1},
  {&__pyx_n_s_cp1256_bin, __pyx_k_cp1256_bin, sizeof(__pyx_k_cp1256_bin), 0, 0, 1, 1},
  {&__pyx_n_s_cp1256_general_ci, __pyx_k_cp1256_general_ci, sizeof(__pyx_k_cp1256_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_cp1257, __pyx_k_cp1257, sizeof(__pyx_k_cp1257), 0, 0, 1, 1},
  {&__pyx_n_s_cp1257_bin, __pyx_k_cp1257_bin, sizeof(__pyx_k_cp1257_bin), 0, 0, 1, 1},
  {&__pyx_n_s_cp1257_general_ci, __pyx_k_cp1257_general_ci, sizeof(__pyx_k_cp1257_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_cp1257_lithuanian_ci, __pyx_k_cp1257_lithuanian_ci, sizeof(__pyx_k_cp1257_lithuanian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_cp850, __pyx_k_cp850, sizeof(__pyx_k_cp850), 0, 0, 1, 1},
  {&__pyx_n_s_cp850_bin, __pyx_k_cp850_bin, sizeof(__pyx_k_cp850_bin), 0, 0, 1, 1},
  {&__pyx_n_s_cp850_general_ci, __pyx_k_cp850_general_ci, sizeof(__pyx_k_cp850_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_cp852, __pyx_k_cp852, sizeof(__pyx_k_cp852), 0, 0, 1, 1},
  {&__pyx_n_s_cp852_bin, __pyx_k_cp852_bin, sizeof(__pyx_k_cp852_bin), 0, 0, 1, 1},
  {&__pyx_n_s_cp852_general_ci, __pyx_k_cp852_general_ci, sizeof(__pyx_k_cp852_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_cp866, __pyx_k_cp866, sizeof(__pyx_k_cp866), 0, 0, 1, 1},
  {&__pyx_n_s_cp866_bin, __pyx_k_cp866_bin, sizeof(__pyx_k_cp866_bin), 0, 0, 1, 1},
  {&__pyx_n_s_cp866_general_ci, __pyx_k_cp866_general_ci, sizeof(__pyx_k_cp866_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_cp932, __pyx_k_cp932, sizeof(__pyx_k_cp932), 0, 0, 1, 1},
  {&__pyx_n_s_cp932_bin, __pyx_k_cp932_bin, sizeof(__pyx_k_cp932_bin), 0, 0, 1, 1},
  {&__pyx_n_s_cp932_japanese_ci, __pyx_k_cp932_japanese_ci, sizeof(__pyx_k_cp932_japanese_ci), 0, 0, 1, 1},
  {&__pyx_n_s_dec8, __pyx_k_dec8, sizeof(__pyx_k_dec8), 0, 0, 1, 1},
  {&__pyx_n_s_dec8_bin, __pyx_k_dec8_bin, sizeof(__pyx_k_dec8_bin), 0, 0, 1, 1},
  {&__pyx_n_s_dec8_swedish_ci, __pyx_k_dec8_swedish_ci, sizeof(__pyx_k_dec8_swedish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_eucjpms, __pyx_k_eucjpms, sizeof(__pyx_k_eucjpms), 0, 0, 1, 1},
  {&__pyx_n_s_eucjpms_bin, __pyx_k_eucjpms_bin, sizeof(__pyx_k_eucjpms_bin), 0, 0, 1, 1},
  {&__pyx_n_s_eucjpms_japanese_ci, __pyx_k_eucjpms_japanese_ci, sizeof(__pyx_k_eucjpms_japanese_ci), 0, 0, 1, 1},
  {&__pyx_n_s_euckr, __pyx_k_euckr, sizeof(__pyx_k_euckr), 0, 0, 1, 1},
  {&__pyx_n_s_euckr_bin, __pyx_k_euckr_bin, sizeof(__pyx_k_euckr_bin), 0, 0, 1, 1},
  {&__pyx_n_s_euckr_korean_ci, __pyx_k_euckr_korean_ci, sizeof(__pyx_k_euckr_korean_ci), 0, 0, 1, 1},
  {&__pyx_n_s_gb2312, __pyx_k_gb2312, sizeof(__pyx_k_gb2312), 0, 0, 1, 1},
  {&__pyx_n_s_gb2312_bin, __pyx_k_gb2312_bin, sizeof(__pyx_k_gb2312_bin), 0, 0, 1, 1},
  {&__pyx_n_s_gb2312_chinese_ci, __pyx_k_gb2312_chinese_ci, sizeof(__pyx_k_gb2312_chinese_ci), 0, 0, 1, 1},
  {&__pyx_n_s_gbk, __pyx_k_gbk, sizeof(__pyx_k_gbk), 0, 0, 1, 1},
  {&__pyx_n_s_gbk_bin, __pyx_k_gbk_bin, sizeof(__pyx_k_gbk_bin), 0, 0, 1, 1},
  {&__pyx_n_s_gbk_chinese_ci, __pyx_k_gbk_chinese_ci, sizeof(__pyx_k_gbk_chinese_ci), 0, 0, 1, 1},
  {&__pyx_n_s_geostd8, __pyx_k_geostd8, sizeof(__pyx_k_geostd8), 0, 0, 1, 1},
  {&__pyx_n_s_geostd8_bin, __pyx_k_geostd8_bin, sizeof(__pyx_k_geostd8_bin), 0, 0, 1, 1},
  {&__pyx_n_s_geostd8_general_ci, __pyx_k_geostd8_general_ci, sizeof(__pyx_k_geostd8_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_greek, __pyx_k_greek, sizeof(__pyx_k_greek), 0, 0, 1, 1},
  {&__pyx_n_s_greek_bin, __pyx_k_greek_bin, sizeof(__pyx_k_greek_bin), 0, 0, 1, 1},
  {&__pyx_n_s_greek_general_ci, __pyx_k_greek_general_ci, sizeof(__pyx_k_greek_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_hebrew, __pyx_k_hebrew, sizeof(__pyx_k_hebrew), 0, 0, 1, 1},
  {&__pyx_n_s_hebrew_bin, __pyx_k_hebrew_bin, sizeof(__pyx_k_hebrew_bin), 0, 0, 1, 1},
  {&__pyx_n_s_hebrew_general_ci, __pyx_k_hebrew_general_ci, sizeof(__pyx_k_hebrew_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_hp8, __pyx_k_hp8, sizeof(__pyx_k_hp8), 0, 0, 1, 1},
  {&__pyx_n_s_hp8_bin, __pyx_k_hp8_bin, sizeof(__pyx_k_hp8_bin), 0, 0, 1, 1},
  {&__pyx_n_s_hp8_english_ci, __pyx_k_hp8_english_ci, sizeof(__pyx_k_hp8_english_ci), 0, 0, 1, 1},
  {&__pyx_n_s_id, __pyx_k_id, sizeof(__pyx_k_id), 0, 0, 1, 1},
  {&__pyx_n_s_is_default, __pyx_k_is_default, sizeof(__pyx_k_is_default), 0, 0, 1, 1},
  {&__pyx_n_s_keybcs2, __pyx_k_keybcs2, sizeof(__pyx_k_keybcs2), 0, 0, 1, 1},
  {&__pyx_n_s_keybcs2_bin, __pyx_k_keybcs2_bin, sizeof(__pyx_k_keybcs2_bin), 0, 0, 1, 1},
  {&__pyx_n_s_keybcs2_general_ci, __pyx_k_keybcs2_general_ci, sizeof(__pyx_k_keybcs2_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_koi8r, __pyx_k_koi8r, sizeof(__pyx_k_koi8r), 0, 0, 1, 1},
  {&__pyx_n_s_koi8r_bin, __pyx_k_koi8r_bin, sizeof(__pyx_k_koi8r_bin), 0, 0, 1, 1},
  {&__pyx_n_s_koi8r_general_ci, __pyx_k_koi8r_general_ci, sizeof(__pyx_k_koi8r_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_koi8u, __pyx_k_koi8u, sizeof(__pyx_k_koi8u), 0, 0, 1, 1},
  {&__pyx_n_s_koi8u_bin, __pyx_k_koi8u_bin, sizeof(__pyx_k_koi8u_bin), 0, 0, 1, 1},
  {&__pyx_n_s_koi8u_general_ci, __pyx_k_koi8u_general_ci, sizeof(__pyx_k_koi8u_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_latin1, __pyx_k_latin1, sizeof(__pyx_k_latin1), 0, 0, 1, 1},
  {&__pyx_n_s_latin1_bin, __pyx_k_latin1_bin, sizeof(__pyx_k_latin1_bin), 0, 0, 1, 1},
  {&__pyx_n_s_latin1_danish_ci, __pyx_k_latin1_danish_ci, sizeof(__pyx_k_latin1_danish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_latin1_general_ci, __pyx_k_latin1_general_ci, sizeof(__pyx_k_latin1_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_latin1_general_cs, __pyx_k_latin1_general_cs, sizeof(__pyx_k_latin1_general_cs), 0, 0, 1, 1},
  {&__pyx_n_s_latin1_german1_ci, __pyx_k_latin1_german1_ci, sizeof(__pyx_k_latin1_german1_ci), 0, 0, 1, 1},
  {&__pyx_n_s_latin1_german2_ci, __pyx_k_latin1_german2_ci, sizeof(__pyx_k_latin1_german2_ci), 0, 0, 1, 1},
  {&__pyx_n_s_latin1_spanish_ci, __pyx_k_latin1_spanish_ci, sizeof(__pyx_k_latin1_spanish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_latin1_swedish_ci, __pyx_k_latin1_swedish_ci, sizeof(__pyx_k_latin1_swedish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_latin2, __pyx_k_latin2, sizeof(__pyx_k_latin2), 0, 0, 1, 1},
  {&__pyx_n_s_latin2_bin, __pyx_k_latin2_bin, sizeof(__pyx_k_latin2_bin), 0, 0, 1, 1},
  {&__pyx_n_s_latin2_croatian_ci, __pyx_k_latin2_croatian_ci, sizeof(__pyx_k_latin2_croatian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_latin2_czech_cs, __pyx_k_latin2_czech_cs, sizeof(__pyx_k_latin2_czech_cs), 0, 0, 1, 1},
  {&__pyx_n_s_latin2_general_ci, __pyx_k_latin2_general_ci, sizeof(__pyx_k_latin2_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_latin2_hungarian_ci, __pyx_k_latin2_hungarian_ci, sizeof(__pyx_k_latin2_hungarian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_latin5, __pyx_k_latin5, sizeof(__pyx_k_latin5), 0, 0, 1, 1},
  {&__pyx_n_s_latin5_bin, __pyx_k_latin5_bin, sizeof(__pyx_k_latin5_bin), 0, 0, 1, 1},
  {&__pyx_n_s_latin5_turkish_ci, __pyx_k_latin5_turkish_ci, sizeof(__pyx_k_latin5_turkish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_latin7, __pyx_k_latin7, sizeof(__pyx_k_latin7), 0, 0, 1, 1},
  {&__pyx_n_s_latin7_bin, __pyx_k_latin7_bin, sizeof(__pyx_k_latin7_bin), 0, 0, 1, 1},
  {&__pyx_n_s_latin7_estonian_cs, __pyx_k_latin7_estonian_cs, sizeof(__pyx_k_latin7_estonian_cs), 0, 0, 1, 1},
  {&__pyx_n_s_latin7_general_ci, __pyx_k_latin7_general_ci, sizeof(__pyx_k_latin7_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_latin7_general_cs, __pyx_k_latin7_general_cs, sizeof(__pyx_k_latin7_general_cs), 0, 0, 1, 1},
  {&__pyx_n_s_macce, __pyx_k_macce, sizeof(__pyx_k_macce), 0, 0, 1, 1},
  {&__pyx_n_s_macce_bin, __pyx_k_macce_bin, sizeof(__pyx_k_macce_bin), 0, 0, 1, 1},
  {&__pyx_n_s_macce_general_ci, __pyx_k_macce_general_ci, sizeof(__pyx_k_macce_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_macroman, __pyx_k_macroman, sizeof(__pyx_k_macroman), 0, 0, 1, 1},
  {&__pyx_n_s_macroman_bin, __pyx_k_macroman_bin, sizeof(__pyx_k_macroman_bin), 0, 0, 1, 1},
  {&__pyx_n_s_macroman_general_ci, __pyx_k_macroman_general_ci, sizeof(__pyx_k_macroman_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
  {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_capi, __pyx_k_pyx_capi, sizeof(__pyx_k_pyx_capi), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_vtable, __pyx_k_pyx_vtable, sizeof(__pyx_k_pyx_vtable), 0, 0, 1, 1},
  {&__pyx_n_s_sjis, __pyx_k_sjis, sizeof(__pyx_k_sjis), 0, 0, 1, 1},
  {&__pyx_n_s_sjis_bin, __pyx_k_sjis_bin, sizeof(__pyx_k_sjis_bin), 0, 0, 1, 1},
  {&__pyx_n_s_sjis_japanese_ci, __pyx_k_sjis_japanese_ci, sizeof(__pyx_k_sjis_japanese_ci), 0, 0, 1, 1},
  {&__pyx_n_s_swe7, __pyx_k_swe7, sizeof(__pyx_k_swe7), 0, 0, 1, 1},
  {&__pyx_n_s_swe7_bin, __pyx_k_swe7_bin, sizeof(__pyx_k_swe7_bin), 0, 0, 1, 1},
  {&__pyx_n_s_swe7_swedish_ci, __pyx_k_swe7_swedish_ci, sizeof(__pyx_k_swe7_swedish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
  {&__pyx_n_s_tis620, __pyx_k_tis620, sizeof(__pyx_k_tis620), 0, 0, 1, 1},
  {&__pyx_n_s_tis620_bin, __pyx_k_tis620_bin, sizeof(__pyx_k_tis620_bin), 0, 0, 1, 1},
  {&__pyx_n_s_tis620_thai_ci, __pyx_k_tis620_thai_ci, sizeof(__pyx_k_tis620_thai_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2, __pyx_k_ucs2, sizeof(__pyx_k_ucs2), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_bin, __pyx_k_ucs2_bin, sizeof(__pyx_k_ucs2_bin), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_czech_ci, __pyx_k_ucs2_czech_ci, sizeof(__pyx_k_ucs2_czech_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_danish_ci, __pyx_k_ucs2_danish_ci, sizeof(__pyx_k_ucs2_danish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_esperanto_ci, __pyx_k_ucs2_esperanto_ci, sizeof(__pyx_k_ucs2_esperanto_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_estonian_ci, __pyx_k_ucs2_estonian_ci, sizeof(__pyx_k_ucs2_estonian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_general_ci, __pyx_k_ucs2_general_ci, sizeof(__pyx_k_ucs2_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_hungarian_ci, __pyx_k_ucs2_hungarian_ci, sizeof(__pyx_k_ucs2_hungarian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_icelandic_ci, __pyx_k_ucs2_icelandic_ci, sizeof(__pyx_k_ucs2_icelandic_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_latvian_ci, __pyx_k_ucs2_latvian_ci, sizeof(__pyx_k_ucs2_latvian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_lithuanian_ci, __pyx_k_ucs2_lithuanian_ci, sizeof(__pyx_k_ucs2_lithuanian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_persian_ci, __pyx_k_ucs2_persian_ci, sizeof(__pyx_k_ucs2_persian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_polish_ci, __pyx_k_ucs2_polish_ci, sizeof(__pyx_k_ucs2_polish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_roman_ci, __pyx_k_ucs2_roman_ci, sizeof(__pyx_k_ucs2_roman_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_romanian_ci, __pyx_k_ucs2_romanian_ci, sizeof(__pyx_k_ucs2_romanian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_slovak_ci, __pyx_k_ucs2_slovak_ci, sizeof(__pyx_k_ucs2_slovak_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_slovenian_ci, __pyx_k_ucs2_slovenian_ci, sizeof(__pyx_k_ucs2_slovenian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_spanish2_ci, __pyx_k_ucs2_spanish2_ci, sizeof(__pyx_k_ucs2_spanish2_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_spanish_ci, __pyx_k_ucs2_spanish_ci, sizeof(__pyx_k_ucs2_spanish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_swedish_ci, __pyx_k_ucs2_swedish_ci, sizeof(__pyx_k_ucs2_swedish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_turkish_ci, __pyx_k_ucs2_turkish_ci, sizeof(__pyx_k_ucs2_turkish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ucs2_unicode_ci, __pyx_k_ucs2_unicode_ci, sizeof(__pyx_k_ucs2_unicode_ci), 0, 0, 1, 1},
  {&__pyx_n_s_ujis, __pyx_k_ujis, sizeof(__pyx_k_ujis), 0, 0, 1, 1},
  {&__pyx_n_s_ujis_bin, __pyx_k_ujis_bin, sizeof(__pyx_k_ujis_bin), 0, 0, 1, 1},
  {&__pyx_n_s_ujis_japanese_ci, __pyx_k_ujis_japanese_ci, sizeof(__pyx_k_ujis_japanese_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8, __pyx_k_utf8, sizeof(__pyx_k_utf8), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_bin, __pyx_k_utf8_bin, sizeof(__pyx_k_utf8_bin), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_czech_ci, __pyx_k_utf8_czech_ci, sizeof(__pyx_k_utf8_czech_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_danish_ci, __pyx_k_utf8_danish_ci, sizeof(__pyx_k_utf8_danish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_esperanto_ci, __pyx_k_utf8_esperanto_ci, sizeof(__pyx_k_utf8_esperanto_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_estonian_ci, __pyx_k_utf8_estonian_ci, sizeof(__pyx_k_utf8_estonian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_general_ci, __pyx_k_utf8_general_ci, sizeof(__pyx_k_utf8_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_hungarian_ci, __pyx_k_utf8_hungarian_ci, sizeof(__pyx_k_utf8_hungarian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_icelandic_ci, __pyx_k_utf8_icelandic_ci, sizeof(__pyx_k_utf8_icelandic_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_latvian_ci, __pyx_k_utf8_latvian_ci, sizeof(__pyx_k_utf8_latvian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_lithuanian_ci, __pyx_k_utf8_lithuanian_ci, sizeof(__pyx_k_utf8_lithuanian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_persian_ci, __pyx_k_utf8_persian_ci, sizeof(__pyx_k_utf8_persian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_polish_ci, __pyx_k_utf8_polish_ci, sizeof(__pyx_k_utf8_polish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_roman_ci, __pyx_k_utf8_roman_ci, sizeof(__pyx_k_utf8_roman_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_romanian_ci, __pyx_k_utf8_romanian_ci, sizeof(__pyx_k_utf8_romanian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_slovak_ci, __pyx_k_utf8_slovak_ci, sizeof(__pyx_k_utf8_slovak_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_slovenian_ci, __pyx_k_utf8_slovenian_ci, sizeof(__pyx_k_utf8_slovenian_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_spanish2_ci, __pyx_k_utf8_spanish2_ci, sizeof(__pyx_k_utf8_spanish2_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_spanish_ci, __pyx_k_utf8_spanish_ci, sizeof(__pyx_k_utf8_spanish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_swedish_ci, __pyx_k_utf8_swedish_ci, sizeof(__pyx_k_utf8_swedish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_turkish_ci, __pyx_k_utf8_turkish_ci, sizeof(__pyx_k_utf8_turkish_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8_unicode_ci, __pyx_k_utf8_unicode_ci, sizeof(__pyx_k_utf8_unicode_ci), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4, __pyx_k_utf8mb4, sizeof(__pyx_k_utf8mb4), 0, 0, 1, 1},
  {&__pyx_n_s_utf8mb4_general_ci, __pyx_k_utf8mb4_general_ci, sizeof(__pyx_k_utf8mb4_general_ci), 0, 0, 1, 1},
  {&__pyx_n_s_values, __pyx_k_values, sizeof(__pyx_k_values), 0, 0, 1, 1},
  {0, 0, 0, 0, 0, 0, 0}
};
static int __Pyx_InitCachedBuiltins(void) {
  return 0;
}

static int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "cymysql/charset.py":37
 * 
 * """
 * _charsets.add(Charset(1, 'big5', 'big5_chinese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(2, 'latin2', 'latin2_czech_cs', ''))
 * _charsets.add(Charset(3, 'dec8', 'dec8_swedish_ci', 'Yes'))
 */
  __pyx_tuple_ = PyTuple_Pack(4, __pyx_int_1, __pyx_n_s_big5, __pyx_n_s_big5_chinese_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple_)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 37; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple_);
  __Pyx_GIVEREF(__pyx_tuple_);

  /* "cymysql/charset.py":38
 * """
 * _charsets.add(Charset(1, 'big5', 'big5_chinese_ci', 'Yes'))
 * _charsets.add(Charset(2, 'latin2', 'latin2_czech_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(3, 'dec8', 'dec8_swedish_ci', 'Yes'))
 * _charsets.add(Charset(4, 'cp850', 'cp850_general_ci', 'Yes'))
 */
  __pyx_tuple__3 = PyTuple_Pack(4, __pyx_int_2, __pyx_n_s_latin2, __pyx_n_s_latin2_czech_cs, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 38; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__3);
  __Pyx_GIVEREF(__pyx_tuple__3);

  /* "cymysql/charset.py":39
 * _charsets.add(Charset(1, 'big5', 'big5_chinese_ci', 'Yes'))
 * _charsets.add(Charset(2, 'latin2', 'latin2_czech_cs', ''))
 * _charsets.add(Charset(3, 'dec8', 'dec8_swedish_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(4, 'cp850', 'cp850_general_ci', 'Yes'))
 * _charsets.add(Charset(5, 'latin1', 'latin1_german1_ci', ''))
 */
  __pyx_tuple__4 = PyTuple_Pack(4, __pyx_int_3, __pyx_n_s_dec8, __pyx_n_s_dec8_swedish_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 39; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__4);
  __Pyx_GIVEREF(__pyx_tuple__4);

  /* "cymysql/charset.py":40
 * _charsets.add(Charset(2, 'latin2', 'latin2_czech_cs', ''))
 * _charsets.add(Charset(3, 'dec8', 'dec8_swedish_ci', 'Yes'))
 * _charsets.add(Charset(4, 'cp850', 'cp850_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(5, 'latin1', 'latin1_german1_ci', ''))
 * _charsets.add(Charset(6, 'hp8', 'hp8_english_ci', 'Yes'))
 */
  __pyx_tuple__5 = PyTuple_Pack(4, __pyx_int_4, __pyx_n_s_cp850, __pyx_n_s_cp850_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 40; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__5);
  __Pyx_GIVEREF(__pyx_tuple__5);

  /* "cymysql/charset.py":41
 * _charsets.add(Charset(3, 'dec8', 'dec8_swedish_ci', 'Yes'))
 * _charsets.add(Charset(4, 'cp850', 'cp850_general_ci', 'Yes'))
 * _charsets.add(Charset(5, 'latin1', 'latin1_german1_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(6, 'hp8', 'hp8_english_ci', 'Yes'))
 * _charsets.add(Charset(7, 'koi8r', 'koi8r_general_ci', 'Yes'))
 */
  __pyx_tuple__6 = PyTuple_Pack(4, __pyx_int_5, __pyx_n_s_latin1, __pyx_n_s_latin1_german1_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 41; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__6);
  __Pyx_GIVEREF(__pyx_tuple__6);

  /* "cymysql/charset.py":42
 * _charsets.add(Charset(4, 'cp850', 'cp850_general_ci', 'Yes'))
 * _charsets.add(Charset(5, 'latin1', 'latin1_german1_ci', ''))
 * _charsets.add(Charset(6, 'hp8', 'hp8_english_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(7, 'koi8r', 'koi8r_general_ci', 'Yes'))
 * _charsets.add(Charset(8, 'latin1', 'latin1_swedish_ci', 'Yes'))
 */
  __pyx_tuple__7 = PyTuple_Pack(4, __pyx_int_6, __pyx_n_s_hp8, __pyx_n_s_hp8_english_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 42; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__7);
  __Pyx_GIVEREF(__pyx_tuple__7);

  /* "cymysql/charset.py":43
 * _charsets.add(Charset(5, 'latin1', 'latin1_german1_ci', ''))
 * _charsets.add(Charset(6, 'hp8', 'hp8_english_ci', 'Yes'))
 * _charsets.add(Charset(7, 'koi8r', 'koi8r_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(8, 'latin1', 'latin1_swedish_ci', 'Yes'))
 * _charsets.add(Charset(9, 'latin2', 'latin2_general_ci', 'Yes'))
 */
  __pyx_tuple__8 = PyTuple_Pack(4, __pyx_int_7, __pyx_n_s_koi8r, __pyx_n_s_koi8r_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 43; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__8);
  __Pyx_GIVEREF(__pyx_tuple__8);

  /* "cymysql/charset.py":44
 * _charsets.add(Charset(6, 'hp8', 'hp8_english_ci', 'Yes'))
 * _charsets.add(Charset(7, 'koi8r', 'koi8r_general_ci', 'Yes'))
 * _charsets.add(Charset(8, 'latin1', 'latin1_swedish_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(9, 'latin2', 'latin2_general_ci', 'Yes'))
 * _charsets.add(Charset(10, 'swe7', 'swe7_swedish_ci', 'Yes'))
 */
  __pyx_tuple__9 = PyTuple_Pack(4, __pyx_int_8, __pyx_n_s_latin1, __pyx_n_s_latin1_swedish_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 44; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__9);
  __Pyx_GIVEREF(__pyx_tuple__9);

  /* "cymysql/charset.py":45
 * _charsets.add(Charset(7, 'koi8r', 'koi8r_general_ci', 'Yes'))
 * _charsets.add(Charset(8, 'latin1', 'latin1_swedish_ci', 'Yes'))
 * _charsets.add(Charset(9, 'latin2', 'latin2_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(10, 'swe7', 'swe7_swedish_ci', 'Yes'))
 * _charsets.add(Charset(11, 'ascii', 'ascii_general_ci', 'Yes'))
 */
  __pyx_tuple__10 = PyTuple_Pack(4, __pyx_int_9, __pyx_n_s_latin2, __pyx_n_s_latin2_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 45; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__10);
  __Pyx_GIVEREF(__pyx_tuple__10);

  /* "cymysql/charset.py":46
 * _charsets.add(Charset(8, 'latin1', 'latin1_swedish_ci', 'Yes'))
 * _charsets.add(Charset(9, 'latin2', 'latin2_general_ci', 'Yes'))
 * _charsets.add(Charset(10, 'swe7', 'swe7_swedish_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(11, 'ascii', 'ascii_general_ci', 'Yes'))
 * _charsets.add(Charset(12, 'ujis', 'ujis_japanese_ci', 'Yes'))
 */
  __pyx_tuple__11 = PyTuple_Pack(4, __pyx_int_10, __pyx_n_s_swe7, __pyx_n_s_swe7_swedish_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 46; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__11);
  __Pyx_GIVEREF(__pyx_tuple__11);

  /* "cymysql/charset.py":47
 * _charsets.add(Charset(9, 'latin2', 'latin2_general_ci', 'Yes'))
 * _charsets.add(Charset(10, 'swe7', 'swe7_swedish_ci', 'Yes'))
 * _charsets.add(Charset(11, 'ascii', 'ascii_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(12, 'ujis', 'ujis_japanese_ci', 'Yes'))
 * _charsets.add(Charset(13, 'sjis', 'sjis_japanese_ci', 'Yes'))
 */
  __pyx_tuple__12 = PyTuple_Pack(4, __pyx_int_11, __pyx_n_s_ascii, __pyx_n_s_ascii_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__12)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 47; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__12);
  __Pyx_GIVEREF(__pyx_tuple__12);

  /* "cymysql/charset.py":48
 * _charsets.add(Charset(10, 'swe7', 'swe7_swedish_ci', 'Yes'))
 * _charsets.add(Charset(11, 'ascii', 'ascii_general_ci', 'Yes'))
 * _charsets.add(Charset(12, 'ujis', 'ujis_japanese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(13, 'sjis', 'sjis_japanese_ci', 'Yes'))
 * _charsets.add(Charset(14, 'cp1251', 'cp1251_bulgarian_ci', ''))
 */
  __pyx_tuple__13 = PyTuple_Pack(4, __pyx_int_12, __pyx_n_s_ujis, __pyx_n_s_ujis_japanese_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__13)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 48; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__13);
  __Pyx_GIVEREF(__pyx_tuple__13);

  /* "cymysql/charset.py":49
 * _charsets.add(Charset(11, 'ascii', 'ascii_general_ci', 'Yes'))
 * _charsets.add(Charset(12, 'ujis', 'ujis_japanese_ci', 'Yes'))
 * _charsets.add(Charset(13, 'sjis', 'sjis_japanese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(14, 'cp1251', 'cp1251_bulgarian_ci', ''))
 * _charsets.add(Charset(15, 'latin1', 'latin1_danish_ci', ''))
 */
  __pyx_tuple__14 = PyTuple_Pack(4, __pyx_int_13, __pyx_n_s_sjis, __pyx_n_s_sjis_japanese_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__14)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 49; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__14);
  __Pyx_GIVEREF(__pyx_tuple__14);

  /* "cymysql/charset.py":50
 * _charsets.add(Charset(12, 'ujis', 'ujis_japanese_ci', 'Yes'))
 * _charsets.add(Charset(13, 'sjis', 'sjis_japanese_ci', 'Yes'))
 * _charsets.add(Charset(14, 'cp1251', 'cp1251_bulgarian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(15, 'latin1', 'latin1_danish_ci', ''))
 * _charsets.add(Charset(16, 'hebrew', 'hebrew_general_ci', 'Yes'))
 */
  __pyx_tuple__15 = PyTuple_Pack(4, __pyx_int_14, __pyx_n_s_cp1251, __pyx_n_s_cp1251_bulgarian_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__15)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 50; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__15);
  __Pyx_GIVEREF(__pyx_tuple__15);

  /* "cymysql/charset.py":51
 * _charsets.add(Charset(13, 'sjis', 'sjis_japanese_ci', 'Yes'))
 * _charsets.add(Charset(14, 'cp1251', 'cp1251_bulgarian_ci', ''))
 * _charsets.add(Charset(15, 'latin1', 'latin1_danish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(16, 'hebrew', 'hebrew_general_ci', 'Yes'))
 * _charsets.add(Charset(18, 'tis620', 'tis620_thai_ci', 'Yes'))
 */
  __pyx_tuple__16 = PyTuple_Pack(4, __pyx_int_15, __pyx_n_s_latin1, __pyx_n_s_latin1_danish_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__16)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 51; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__16);
  __Pyx_GIVEREF(__pyx_tuple__16);

  /* "cymysql/charset.py":52
 * _charsets.add(Charset(14, 'cp1251', 'cp1251_bulgarian_ci', ''))
 * _charsets.add(Charset(15, 'latin1', 'latin1_danish_ci', ''))
 * _charsets.add(Charset(16, 'hebrew', 'hebrew_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(18, 'tis620', 'tis620_thai_ci', 'Yes'))
 * _charsets.add(Charset(19, 'euckr', 'euckr_korean_ci', 'Yes'))
 */
  __pyx_tuple__17 = PyTuple_Pack(4, __pyx_int_16, __pyx_n_s_hebrew, __pyx_n_s_hebrew_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__17)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 52; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__17);
  __Pyx_GIVEREF(__pyx_tuple__17);

  /* "cymysql/charset.py":53
 * _charsets.add(Charset(15, 'latin1', 'latin1_danish_ci', ''))
 * _charsets.add(Charset(16, 'hebrew', 'hebrew_general_ci', 'Yes'))
 * _charsets.add(Charset(18, 'tis620', 'tis620_thai_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(19, 'euckr', 'euckr_korean_ci', 'Yes'))
 * _charsets.add(Charset(20, 'latin7', 'latin7_estonian_cs', ''))
 */
  __pyx_tuple__18 = PyTuple_Pack(4, __pyx_int_18, __pyx_n_s_tis620, __pyx_n_s_tis620_thai_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__18)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 53; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__18);
  __Pyx_GIVEREF(__pyx_tuple__18);

  /* "cymysql/charset.py":54
 * _charsets.add(Charset(16, 'hebrew', 'hebrew_general_ci', 'Yes'))
 * _charsets.add(Charset(18, 'tis620', 'tis620_thai_ci', 'Yes'))
 * _charsets.add(Charset(19, 'euckr', 'euckr_korean_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(20, 'latin7', 'latin7_estonian_cs', ''))
 * _charsets.add(Charset(21, 'latin2', 'latin2_hungarian_ci', ''))
 */
  __pyx_tuple__19 = PyTuple_Pack(4, __pyx_int_19, __pyx_n_s_euckr, __pyx_n_s_euckr_korean_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__19)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 54; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__19);
  __Pyx_GIVEREF(__pyx_tuple__19);

  /* "cymysql/charset.py":55
 * _charsets.add(Charset(18, 'tis620', 'tis620_thai_ci', 'Yes'))
 * _charsets.add(Charset(19, 'euckr', 'euckr_korean_ci', 'Yes'))
 * _charsets.add(Charset(20, 'latin7', 'latin7_estonian_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(21, 'latin2', 'latin2_hungarian_ci', ''))
 * _charsets.add(Charset(22, 'koi8u', 'koi8u_general_ci', 'Yes'))
 */
  __pyx_tuple__20 = PyTuple_Pack(4, __pyx_int_20, __pyx_n_s_latin7, __pyx_n_s_latin7_estonian_cs, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__20)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 55; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__20);
  __Pyx_GIVEREF(__pyx_tuple__20);

  /* "cymysql/charset.py":56
 * _charsets.add(Charset(19, 'euckr', 'euckr_korean_ci', 'Yes'))
 * _charsets.add(Charset(20, 'latin7', 'latin7_estonian_cs', ''))
 * _charsets.add(Charset(21, 'latin2', 'latin2_hungarian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(22, 'koi8u', 'koi8u_general_ci', 'Yes'))
 * _charsets.add(Charset(23, 'cp1251', 'cp1251_ukrainian_ci', ''))
 */
  __pyx_tuple__21 = PyTuple_Pack(4, __pyx_int_21, __pyx_n_s_latin2, __pyx_n_s_latin2_hungarian_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__21)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 56; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__21);
  __Pyx_GIVEREF(__pyx_tuple__21);

  /* "cymysql/charset.py":57
 * _charsets.add(Charset(20, 'latin7', 'latin7_estonian_cs', ''))
 * _charsets.add(Charset(21, 'latin2', 'latin2_hungarian_ci', ''))
 * _charsets.add(Charset(22, 'koi8u', 'koi8u_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(23, 'cp1251', 'cp1251_ukrainian_ci', ''))
 * _charsets.add(Charset(24, 'gb2312', 'gb2312_chinese_ci', 'Yes'))
 */
  __pyx_tuple__22 = PyTuple_Pack(4, __pyx_int_22, __pyx_n_s_koi8u, __pyx_n_s_koi8u_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__22)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 57; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__22);
  __Pyx_GIVEREF(__pyx_tuple__22);

  /* "cymysql/charset.py":58
 * _charsets.add(Charset(21, 'latin2', 'latin2_hungarian_ci', ''))
 * _charsets.add(Charset(22, 'koi8u', 'koi8u_general_ci', 'Yes'))
 * _charsets.add(Charset(23, 'cp1251', 'cp1251_ukrainian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(24, 'gb2312', 'gb2312_chinese_ci', 'Yes'))
 * _charsets.add(Charset(25, 'greek', 'greek_general_ci', 'Yes'))
 */
  __pyx_tuple__23 = PyTuple_Pack(4, __pyx_int_23, __pyx_n_s_cp1251, __pyx_n_s_cp1251_ukrainian_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__23)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 58; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__23);
  __Pyx_GIVEREF(__pyx_tuple__23);

  /* "cymysql/charset.py":59
 * _charsets.add(Charset(22, 'koi8u', 'koi8u_general_ci', 'Yes'))
 * _charsets.add(Charset(23, 'cp1251', 'cp1251_ukrainian_ci', ''))
 * _charsets.add(Charset(24, 'gb2312', 'gb2312_chinese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(25, 'greek', 'greek_general_ci', 'Yes'))
 * _charsets.add(Charset(26, 'cp1250', 'cp1250_general_ci', 'Yes'))
 */
  __pyx_tuple__24 = PyTuple_Pack(4, __pyx_int_24, __pyx_n_s_gb2312, __pyx_n_s_gb2312_chinese_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__24)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 59; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__24);
  __Pyx_GIVEREF(__pyx_tuple__24);

  /* "cymysql/charset.py":60
 * _charsets.add(Charset(23, 'cp1251', 'cp1251_ukrainian_ci', ''))
 * _charsets.add(Charset(24, 'gb2312', 'gb2312_chinese_ci', 'Yes'))
 * _charsets.add(Charset(25, 'greek', 'greek_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(26, 'cp1250', 'cp1250_general_ci', 'Yes'))
 * _charsets.add(Charset(27, 'latin2', 'latin2_croatian_ci', ''))
 */
  __pyx_tuple__25 = PyTuple_Pack(4, __pyx_int_25, __pyx_n_s_greek, __pyx_n_s_greek_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__25)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 60; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__25);
  __Pyx_GIVEREF(__pyx_tuple__25);

  /* "cymysql/charset.py":61
 * _charsets.add(Charset(24, 'gb2312', 'gb2312_chinese_ci', 'Yes'))
 * _charsets.add(Charset(25, 'greek', 'greek_general_ci', 'Yes'))
 * _charsets.add(Charset(26, 'cp1250', 'cp1250_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(27, 'latin2', 'latin2_croatian_ci', ''))
 * _charsets.add(Charset(28, 'gbk', 'gbk_chinese_ci', 'Yes'))
 */
  __pyx_tuple__26 = PyTuple_Pack(4, __pyx_int_26, __pyx_n_s_cp1250, __pyx_n_s_cp1250_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__26)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 61; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__26);
  __Pyx_GIVEREF(__pyx_tuple__26);

  /* "cymysql/charset.py":62
 * _charsets.add(Charset(25, 'greek', 'greek_general_ci', 'Yes'))
 * _charsets.add(Charset(26, 'cp1250', 'cp1250_general_ci', 'Yes'))
 * _charsets.add(Charset(27, 'latin2', 'latin2_croatian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(28, 'gbk', 'gbk_chinese_ci', 'Yes'))
 * _charsets.add(Charset(29, 'cp1257', 'cp1257_lithuanian_ci', ''))
 */
  __pyx_tuple__27 = PyTuple_Pack(4, __pyx_int_27, __pyx_n_s_latin2, __pyx_n_s_latin2_croatian_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__27)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 62; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__27);
  __Pyx_GIVEREF(__pyx_tuple__27);

  /* "cymysql/charset.py":63
 * _charsets.add(Charset(26, 'cp1250', 'cp1250_general_ci', 'Yes'))
 * _charsets.add(Charset(27, 'latin2', 'latin2_croatian_ci', ''))
 * _charsets.add(Charset(28, 'gbk', 'gbk_chinese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(29, 'cp1257', 'cp1257_lithuanian_ci', ''))
 * _charsets.add(Charset(30, 'latin5', 'latin5_turkish_ci', 'Yes'))
 */
  __pyx_tuple__28 = PyTuple_Pack(4, __pyx_int_28, __pyx_n_s_gbk, __pyx_n_s_gbk_chinese_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__28)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 63; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__28);
  __Pyx_GIVEREF(__pyx_tuple__28);

  /* "cymysql/charset.py":64
 * _charsets.add(Charset(27, 'latin2', 'latin2_croatian_ci', ''))
 * _charsets.add(Charset(28, 'gbk', 'gbk_chinese_ci', 'Yes'))
 * _charsets.add(Charset(29, 'cp1257', 'cp1257_lithuanian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(30, 'latin5', 'latin5_turkish_ci', 'Yes'))
 * _charsets.add(Charset(31, 'latin1', 'latin1_german2_ci', ''))
 */
  __pyx_tuple__29 = PyTuple_Pack(4, __pyx_int_29, __pyx_n_s_cp1257, __pyx_n_s_cp1257_lithuanian_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__29)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 64; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__29);
  __Pyx_GIVEREF(__pyx_tuple__29);

  /* "cymysql/charset.py":65
 * _charsets.add(Charset(28, 'gbk', 'gbk_chinese_ci', 'Yes'))
 * _charsets.add(Charset(29, 'cp1257', 'cp1257_lithuanian_ci', ''))
 * _charsets.add(Charset(30, 'latin5', 'latin5_turkish_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(31, 'latin1', 'latin1_german2_ci', ''))
 * _charsets.add(Charset(32, 'armscii8', 'armscii8_general_ci', 'Yes'))
 */
  __pyx_tuple__30 = PyTuple_Pack(4, __pyx_int_30, __pyx_n_s_latin5, __pyx_n_s_latin5_turkish_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__30)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 65; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__30);
  __Pyx_GIVEREF(__pyx_tuple__30);

  /* "cymysql/charset.py":66
 * _charsets.add(Charset(29, 'cp1257', 'cp1257_lithuanian_ci', ''))
 * _charsets.add(Charset(30, 'latin5', 'latin5_turkish_ci', 'Yes'))
 * _charsets.add(Charset(31, 'latin1', 'latin1_german2_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(32, 'armscii8', 'armscii8_general_ci', 'Yes'))
 * _charsets.add(Charset(33, 'utf8', 'utf8_general_ci', 'Yes'))
 */
  __pyx_tuple__31 = PyTuple_Pack(4, __pyx_int_31, __pyx_n_s_latin1, __pyx_n_s_latin1_german2_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__31)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 66; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__31);
  __Pyx_GIVEREF(__pyx_tuple__31);

  /* "cymysql/charset.py":67
 * _charsets.add(Charset(30, 'latin5', 'latin5_turkish_ci', 'Yes'))
 * _charsets.add(Charset(31, 'latin1', 'latin1_german2_ci', ''))
 * _charsets.add(Charset(32, 'armscii8', 'armscii8_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(33, 'utf8', 'utf8_general_ci', 'Yes'))
 * _charsets.add(Charset(34, 'cp1250', 'cp1250_czech_cs', ''))
 */
  __pyx_tuple__32 = PyTuple_Pack(4, __pyx_int_32, __pyx_n_s_armscii8, __pyx_n_s_armscii8_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__32)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 67; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__32);
  __Pyx_GIVEREF(__pyx_tuple__32);

  /* "cymysql/charset.py":68
 * _charsets.add(Charset(31, 'latin1', 'latin1_german2_ci', ''))
 * _charsets.add(Charset(32, 'armscii8', 'armscii8_general_ci', 'Yes'))
 * _charsets.add(Charset(33, 'utf8', 'utf8_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(34, 'cp1250', 'cp1250_czech_cs', ''))
 * _charsets.add(Charset(35, 'ucs2', 'ucs2_general_ci', 'Yes'))
 */
  __pyx_tuple__33 = PyTuple_Pack(4, __pyx_int_33, __pyx_n_s_utf8, __pyx_n_s_utf8_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__33)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 68; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__33);
  __Pyx_GIVEREF(__pyx_tuple__33);

  /* "cymysql/charset.py":69
 * _charsets.add(Charset(32, 'armscii8', 'armscii8_general_ci', 'Yes'))
 * _charsets.add(Charset(33, 'utf8', 'utf8_general_ci', 'Yes'))
 * _charsets.add(Charset(34, 'cp1250', 'cp1250_czech_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(35, 'ucs2', 'ucs2_general_ci', 'Yes'))
 * _charsets.add(Charset(36, 'cp866', 'cp866_general_ci', 'Yes'))
 */
  __pyx_tuple__34 = PyTuple_Pack(4, __pyx_int_34, __pyx_n_s_cp1250, __pyx_n_s_cp1250_czech_cs, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__34)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 69; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__34);
  __Pyx_GIVEREF(__pyx_tuple__34);

  /* "cymysql/charset.py":70
 * _charsets.add(Charset(33, 'utf8', 'utf8_general_ci', 'Yes'))
 * _charsets.add(Charset(34, 'cp1250', 'cp1250_czech_cs', ''))
 * _charsets.add(Charset(35, 'ucs2', 'ucs2_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(36, 'cp866', 'cp866_general_ci', 'Yes'))
 * _charsets.add(Charset(37, 'keybcs2', 'keybcs2_general_ci', 'Yes'))
 */
  __pyx_tuple__35 = PyTuple_Pack(4, __pyx_int_35, __pyx_n_s_ucs2, __pyx_n_s_ucs2_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__35)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 70; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__35);
  __Pyx_GIVEREF(__pyx_tuple__35);

  /* "cymysql/charset.py":71
 * _charsets.add(Charset(34, 'cp1250', 'cp1250_czech_cs', ''))
 * _charsets.add(Charset(35, 'ucs2', 'ucs2_general_ci', 'Yes'))
 * _charsets.add(Charset(36, 'cp866', 'cp866_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(37, 'keybcs2', 'keybcs2_general_ci', 'Yes'))
 * _charsets.add(Charset(38, 'macce', 'macce_general_ci', 'Yes'))
 */
  __pyx_tuple__36 = PyTuple_Pack(4, __pyx_int_36, __pyx_n_s_cp866, __pyx_n_s_cp866_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__36)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 71; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__36);
  __Pyx_GIVEREF(__pyx_tuple__36);

  /* "cymysql/charset.py":72
 * _charsets.add(Charset(35, 'ucs2', 'ucs2_general_ci', 'Yes'))
 * _charsets.add(Charset(36, 'cp866', 'cp866_general_ci', 'Yes'))
 * _charsets.add(Charset(37, 'keybcs2', 'keybcs2_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(38, 'macce', 'macce_general_ci', 'Yes'))
 * _charsets.add(Charset(39, 'macroman', 'macroman_general_ci', 'Yes'))
 */
  __pyx_tuple__37 = PyTuple_Pack(4, __pyx_int_37, __pyx_n_s_keybcs2, __pyx_n_s_keybcs2_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__37)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 72; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__37);
  __Pyx_GIVEREF(__pyx_tuple__37);

  /* "cymysql/charset.py":73
 * _charsets.add(Charset(36, 'cp866', 'cp866_general_ci', 'Yes'))
 * _charsets.add(Charset(37, 'keybcs2', 'keybcs2_general_ci', 'Yes'))
 * _charsets.add(Charset(38, 'macce', 'macce_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(39, 'macroman', 'macroman_general_ci', 'Yes'))
 * _charsets.add(Charset(40, 'cp852', 'cp852_general_ci', 'Yes'))
 */
  __pyx_tuple__38 = PyTuple_Pack(4, __pyx_int_38, __pyx_n_s_macce, __pyx_n_s_macce_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__38)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 73; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__38);
  __Pyx_GIVEREF(__pyx_tuple__38);

  /* "cymysql/charset.py":74
 * _charsets.add(Charset(37, 'keybcs2', 'keybcs2_general_ci', 'Yes'))
 * _charsets.add(Charset(38, 'macce', 'macce_general_ci', 'Yes'))
 * _charsets.add(Charset(39, 'macroman', 'macroman_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(40, 'cp852', 'cp852_general_ci', 'Yes'))
 * _charsets.add(Charset(41, 'latin7', 'latin7_general_ci', 'Yes'))
 */
  __pyx_tuple__39 = PyTuple_Pack(4, __pyx_int_39, __pyx_n_s_macroman, __pyx_n_s_macroman_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__39)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 74; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__39);
  __Pyx_GIVEREF(__pyx_tuple__39);

  /* "cymysql/charset.py":75
 * _charsets.add(Charset(38, 'macce', 'macce_general_ci', 'Yes'))
 * _charsets.add(Charset(39, 'macroman', 'macroman_general_ci', 'Yes'))
 * _charsets.add(Charset(40, 'cp852', 'cp852_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(41, 'latin7', 'latin7_general_ci', 'Yes'))
 * _charsets.add(Charset(42, 'latin7', 'latin7_general_cs', ''))
 */
  __pyx_tuple__40 = PyTuple_Pack(4, __pyx_int_40, __pyx_n_s_cp852, __pyx_n_s_cp852_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__40)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 75; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__40);
  __Pyx_GIVEREF(__pyx_tuple__40);

  /* "cymysql/charset.py":76
 * _charsets.add(Charset(39, 'macroman', 'macroman_general_ci', 'Yes'))
 * _charsets.add(Charset(40, 'cp852', 'cp852_general_ci', 'Yes'))
 * _charsets.add(Charset(41, 'latin7', 'latin7_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(42, 'latin7', 'latin7_general_cs', ''))
 * _charsets.add(Charset(43, 'macce', 'macce_bin', ''))
 */
  __pyx_tuple__41 = PyTuple_Pack(4, __pyx_int_41, __pyx_n_s_latin7, __pyx_n_s_latin7_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__41)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 76; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__41);
  __Pyx_GIVEREF(__pyx_tuple__41);

  /* "cymysql/charset.py":77
 * _charsets.add(Charset(40, 'cp852', 'cp852_general_ci', 'Yes'))
 * _charsets.add(Charset(41, 'latin7', 'latin7_general_ci', 'Yes'))
 * _charsets.add(Charset(42, 'latin7', 'latin7_general_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(43, 'macce', 'macce_bin', ''))
 * _charsets.add(Charset(44, 'cp1250', 'cp1250_croatian_ci', ''))
 */
  __pyx_tuple__42 = PyTuple_Pack(4, __pyx_int_42, __pyx_n_s_latin7, __pyx_n_s_latin7_general_cs, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__42)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 77; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__42);
  __Pyx_GIVEREF(__pyx_tuple__42);

  /* "cymysql/charset.py":78
 * _charsets.add(Charset(41, 'latin7', 'latin7_general_ci', 'Yes'))
 * _charsets.add(Charset(42, 'latin7', 'latin7_general_cs', ''))
 * _charsets.add(Charset(43, 'macce', 'macce_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(44, 'cp1250', 'cp1250_croatian_ci', ''))
 * _charsets.add(Charset(45, 'utf8mb4', 'utf8mb4_general_ci', 'Yes'))
 */
  __pyx_tuple__43 = PyTuple_Pack(4, __pyx_int_43, __pyx_n_s_macce, __pyx_n_s_macce_bin, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__43)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 78; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__43);
  __Pyx_GIVEREF(__pyx_tuple__43);

  /* "cymysql/charset.py":79
 * _charsets.add(Charset(42, 'latin7', 'latin7_general_cs', ''))
 * _charsets.add(Charset(43, 'macce', 'macce_bin', ''))
 * _charsets.add(Charset(44, 'cp1250', 'cp1250_croatian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(45, 'utf8mb4', 'utf8mb4_general_ci', 'Yes'))
 * _charsets.add(Charset(47, 'latin1', 'latin1_bin', ''))
 */
  __pyx_tuple__44 = PyTuple_Pack(4, __pyx_int_44, __pyx_n_s_cp1250, __pyx_n_s_cp1250_croatian_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__44)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 79; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__44);
  __Pyx_GIVEREF(__pyx_tuple__44);

  /* "cymysql/charset.py":80
 * _charsets.add(Charset(43, 'macce', 'macce_bin', ''))
 * _charsets.add(Charset(44, 'cp1250', 'cp1250_croatian_ci', ''))
 * _charsets.add(Charset(45, 'utf8mb4', 'utf8mb4_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(47, 'latin1', 'latin1_bin', ''))
 * _charsets.add(Charset(48, 'latin1', 'latin1_general_ci', ''))
 */
  __pyx_tuple__45 = PyTuple_Pack(4, __pyx_int_45, __pyx_n_s_utf8mb4, __pyx_n_s_utf8mb4_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__45)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 80; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__45);
  __Pyx_GIVEREF(__pyx_tuple__45);

  /* "cymysql/charset.py":81
 * _charsets.add(Charset(44, 'cp1250', 'cp1250_croatian_ci', ''))
 * _charsets.add(Charset(45, 'utf8mb4', 'utf8mb4_general_ci', 'Yes'))
 * _charsets.add(Charset(47, 'latin1', 'latin1_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(48, 'latin1', 'latin1_general_ci', ''))
 * _charsets.add(Charset(49, 'latin1', 'latin1_general_cs', ''))
 */
  __pyx_tuple__46 = PyTuple_Pack(4, __pyx_int_47, __pyx_n_s_latin1, __pyx_n_s_latin1_bin, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__46)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 81; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__46);
  __Pyx_GIVEREF(__pyx_tuple__46);

  /* "cymysql/charset.py":82
 * _charsets.add(Charset(45, 'utf8mb4', 'utf8mb4_general_ci', 'Yes'))
 * _charsets.add(Charset(47, 'latin1', 'latin1_bin', ''))
 * _charsets.add(Charset(48, 'latin1', 'latin1_general_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(49, 'latin1', 'latin1_general_cs', ''))
 * _charsets.add(Charset(50, 'cp1251', 'cp1251_bin', ''))
 */
  __pyx_tuple__47 = PyTuple_Pack(4, __pyx_int_48, __pyx_n_s_latin1, __pyx_n_s_latin1_general_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__47)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 82; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__47);
  __Pyx_GIVEREF(__pyx_tuple__47);

  /* "cymysql/charset.py":83
 * _charsets.add(Charset(47, 'latin1', 'latin1_bin', ''))
 * _charsets.add(Charset(48, 'latin1', 'latin1_general_ci', ''))
 * _charsets.add(Charset(49, 'latin1', 'latin1_general_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(50, 'cp1251', 'cp1251_bin', ''))
 * _charsets.add(Charset(51, 'cp1251', 'cp1251_general_ci', 'Yes'))
 */
  __pyx_tuple__48 = PyTuple_Pack(4, __pyx_int_49, __pyx_n_s_latin1, __pyx_n_s_latin1_general_cs, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__48)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 83; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__48);
  __Pyx_GIVEREF(__pyx_tuple__48);

  /* "cymysql/charset.py":84
 * _charsets.add(Charset(48, 'latin1', 'latin1_general_ci', ''))
 * _charsets.add(Charset(49, 'latin1', 'latin1_general_cs', ''))
 * _charsets.add(Charset(50, 'cp1251', 'cp1251_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(51, 'cp1251', 'cp1251_general_ci', 'Yes'))
 * _charsets.add(Charset(52, 'cp1251', 'cp1251_general_cs', ''))
 */
  __pyx_tuple__49 = PyTuple_Pack(4, __pyx_int_50, __pyx_n_s_cp1251, __pyx_n_s_cp1251_bin, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__49)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 84; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__49);
  __Pyx_GIVEREF(__pyx_tuple__49);

  /* "cymysql/charset.py":85
 * _charsets.add(Charset(49, 'latin1', 'latin1_general_cs', ''))
 * _charsets.add(Charset(50, 'cp1251', 'cp1251_bin', ''))
 * _charsets.add(Charset(51, 'cp1251', 'cp1251_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(52, 'cp1251', 'cp1251_general_cs', ''))
 * _charsets.add(Charset(53, 'macroman', 'macroman_bin', ''))
 */
  __pyx_tuple__50 = PyTuple_Pack(4, __pyx_int_51, __pyx_n_s_cp1251, __pyx_n_s_cp1251_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__50)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 85; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__50);
  __Pyx_GIVEREF(__pyx_tuple__50);

  /* "cymysql/charset.py":86
 * _charsets.add(Charset(50, 'cp1251', 'cp1251_bin', ''))
 * _charsets.add(Charset(51, 'cp1251', 'cp1251_general_ci', 'Yes'))
 * _charsets.add(Charset(52, 'cp1251', 'cp1251_general_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(53, 'macroman', 'macroman_bin', ''))
 * _charsets.add(Charset(57, 'cp1256', 'cp1256_general_ci', 'Yes'))
 */
  __pyx_tuple__51 = PyTuple_Pack(4, __pyx_int_52, __pyx_n_s_cp1251, __pyx_n_s_cp1251_general_cs, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__51)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 86; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__51);
  __Pyx_GIVEREF(__pyx_tuple__51);

  /* "cymysql/charset.py":87
 * _charsets.add(Charset(51, 'cp1251', 'cp1251_general_ci', 'Yes'))
 * _charsets.add(Charset(52, 'cp1251', 'cp1251_general_cs', ''))
 * _charsets.add(Charset(53, 'macroman', 'macroman_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(57, 'cp1256', 'cp1256_general_ci', 'Yes'))
 * _charsets.add(Charset(58, 'cp1257', 'cp1257_bin', ''))
 */
  __pyx_tuple__52 = PyTuple_Pack(4, __pyx_int_53, __pyx_n_s_macroman, __pyx_n_s_macroman_bin, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__52)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 87; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__52);
  __Pyx_GIVEREF(__pyx_tuple__52);

  /* "cymysql/charset.py":88
 * _charsets.add(Charset(52, 'cp1251', 'cp1251_general_cs', ''))
 * _charsets.add(Charset(53, 'macroman', 'macroman_bin', ''))
 * _charsets.add(Charset(57, 'cp1256', 'cp1256_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(58, 'cp1257', 'cp1257_bin', ''))
 * _charsets.add(Charset(59, 'cp1257', 'cp1257_general_ci', 'Yes'))
 */
  __pyx_tuple__53 = PyTuple_Pack(4, __pyx_int_57, __pyx_n_s_cp1256, __pyx_n_s_cp1256_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__53)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 88; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__53);
  __Pyx_GIVEREF(__pyx_tuple__53);

  /* "cymysql/charset.py":89
 * _charsets.add(Charset(53, 'macroman', 'macroman_bin', ''))
 * _charsets.add(Charset(57, 'cp1256', 'cp1256_general_ci', 'Yes'))
 * _charsets.add(Charset(58, 'cp1257', 'cp1257_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(59, 'cp1257', 'cp1257_general_ci', 'Yes'))
 * _charsets.add(Charset(63, 'binary', 'binary', 'Yes'))
 */
  __pyx_tuple__54 = PyTuple_Pack(4, __pyx_int_58, __pyx_n_s_cp1257, __pyx_n_s_cp1257_bin, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__54)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 89; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__54);
  __Pyx_GIVEREF(__pyx_tuple__54);

  /* "cymysql/charset.py":90
 * _charsets.add(Charset(57, 'cp1256', 'cp1256_general_ci', 'Yes'))
 * _charsets.add(Charset(58, 'cp1257', 'cp1257_bin', ''))
 * _charsets.add(Charset(59, 'cp1257', 'cp1257_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(63, 'binary', 'binary', 'Yes'))
 * _charsets.add(Charset(64, 'armscii8', 'armscii8_bin', ''))
 */
  __pyx_tuple__55 = PyTuple_Pack(4, __pyx_int_59, __pyx_n_s_cp1257, __pyx_n_s_cp1257_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__55)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 90; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__55);
  __Pyx_GIVEREF(__pyx_tuple__55);

  /* "cymysql/charset.py":91
 * _charsets.add(Charset(58, 'cp1257', 'cp1257_bin', ''))
 * _charsets.add(Charset(59, 'cp1257', 'cp1257_general_ci', 'Yes'))
 * _charsets.add(Charset(63, 'binary', 'binary', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(64, 'armscii8', 'armscii8_bin', ''))
 * _charsets.add(Charset(65, 'ascii', 'ascii_bin', ''))
 */
  __pyx_tuple__56 = PyTuple_Pack(4, __pyx_int_63, __pyx_n_s_binary, __pyx_n_s_binary, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__56)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 91; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__56);
  __Pyx_GIVEREF(__pyx_tuple__56);

  /* "cymysql/charset.py":92
 * _charsets.add(Charset(59, 'cp1257', 'cp1257_general_ci', 'Yes'))
 * _charsets.add(Charset(63, 'binary', 'binary', 'Yes'))
 * _charsets.add(Charset(64, 'armscii8', 'armscii8_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(65, 'ascii', 'ascii_bin', ''))
 * _charsets.add(Charset(66, 'cp1250', 'cp1250_bin', ''))
 */
  __pyx_tuple__57 = PyTuple_Pack(4, __pyx_int_64, __pyx_n_s_armscii8, __pyx_n_s_armscii8_bin, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__57)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 92; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__57);
  __Pyx_GIVEREF(__pyx_tuple__57);

  /* "cymysql/charset.py":93
 * _charsets.add(Charset(63, 'binary', 'binary', 'Yes'))
 * _charsets.add(Charset(64, 'armscii8', 'armscii8_bin', ''))
 * _charsets.add(Charset(65, 'ascii', 'ascii_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(66, 'cp1250', 'cp1250_bin', ''))
 * _charsets.add(Charset(67, 'cp1256', 'cp1256_bin', ''))
 */
  __pyx_tuple__58 = PyTuple_Pack(4, __pyx_int_65, __pyx_n_s_ascii, __pyx_n_s_ascii_bin, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__58)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 93; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__58);
  __Pyx_GIVEREF(__pyx_tuple__58);

  /* "cymysql/charset.py":94
 * _charsets.add(Charset(64, 'armscii8', 'armscii8_bin', ''))
 * _charsets.add(Charset(65, 'ascii', 'ascii_bin', ''))
 * _charsets.add(Charset(66, 'cp1250', 'cp1250_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(67, 'cp1256', 'cp1256_bin', ''))
 * _charsets.add(Charset(68, 'cp866', 'cp866_bin', ''))
 */
  __pyx_tuple__59 = PyTuple_Pack(4, __pyx_int_66, __pyx_n_s_cp1250, __pyx_n_s_cp1250_bin, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__59)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 94; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__59);
  __Pyx_GIVEREF(__pyx_tuple__59);

  /* "cymysql/charset.py":95
 * _charsets.add(Charset(65, 'ascii', 'ascii_bin', ''))
 * _charsets.add(Charset(66, 'cp1250', 'cp1250_bin', ''))
 * _charsets.add(Charset(67, 'cp1256', 'cp1256_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(68, 'cp866', 'cp866_bin', ''))
 * _charsets.add(Charset(69, 'dec8', 'dec8_bin', ''))
 */
  __pyx_tuple__60 = PyTuple_Pack(4, __pyx_int_67, __pyx_n_s_cp1256, __pyx_n_s_cp1256_bin, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__60)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 95; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__60);
  __Pyx_GIVEREF(__pyx_tuple__60);

  /* "cymysql/charset.py":96
 * _charsets.add(Charset(66, 'cp1250', 'cp1250_bin', ''))
 * _charsets.add(Charset(67, 'cp1256', 'cp1256_bin', ''))
 * _charsets.add(Charset(68, 'cp866', 'cp866_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(69, 'dec8', 'dec8_bin', ''))
 * _charsets.add(Charset(70, 'greek', 'greek_bin', ''))
 */
  __pyx_tuple__61 = PyTuple_Pack(4, __pyx_int_68, __pyx_n_s_cp866, __pyx_n_s_cp866_bin, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__61)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 96; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__61);
  __Pyx_GIVEREF(__pyx_tuple__61);

  /* "cymysql/charset.py":97
 * _charsets.add(Charset(67, 'cp1256', 'cp1256_bin', ''))
 * _charsets.add(Charset(68, 'cp866', 'cp866_bin', ''))
 * _charsets.add(Charset(69, 'dec8', 'dec8_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(70, 'greek', 'greek_bin', ''))
 * _charsets.add(Charset(71, 'hebrew', 'hebrew_bin', ''))
 */
  __pyx_tuple__62 = PyTuple_Pack(4, __pyx_int_69, __pyx_n_s_dec8, __pyx_n_s_dec8_bin, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__62)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 97; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__62);
  __Pyx_GIVEREF(__pyx_tuple__62);

  /* "cymysql/charset.py":98
 * _charsets.add(Charset(68, 'cp866', 'cp866_bin', ''))
 * _charsets.add(Charset(69, 'dec8', 'dec8_bin', ''))
 * _charsets.add(Charset(70, 'greek', 'greek_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(71, 'hebrew', 'hebrew_bin', ''))
 * _charsets.add(Charset(72, 'hp8', 'hp8_bin', ''))
 */
  __pyx_tuple__63 = PyTuple_Pack(4, __pyx_int_70, __pyx_n_s_greek, __pyx_n_s_greek_bin, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__63)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 98; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__63);
  __Pyx_GIVEREF(__pyx_tuple__63);

  /* "cymysql/charset.py":99
 * _charsets.add(Charset(69, 'dec8', 'dec8_bin', ''))
 * _charsets.add(Charset(70, 'greek', 'greek_bin', ''))
 * _charsets.add(Charset(71, 'hebrew', 'hebrew_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(72, 'hp8', 'hp8_bin', ''))
 * _charsets.add(Charset(73, 'keybcs2', 'keybcs2_bin', ''))
 */
  __pyx_tuple__64 = PyTuple_Pack(4, __pyx_int_71, __pyx_n_s_hebrew, __pyx_n_s_hebrew_bin, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__64)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 99; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__64);
  __Pyx_GIVEREF(__pyx_tuple__64);

  /* "cymysql/charset.py":100
 * _charsets.add(Charset(70, 'greek', 'greek_bin', ''))
 * _charsets.add(Charset(71, 'hebrew', 'hebrew_bin', ''))
 * _charsets.add(Charset(72, 'hp8', 'hp8_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(73, 'keybcs2', 'keybcs2_bin', ''))
 * _charsets.add(Charset(74, 'koi8r', 'koi8r_bin', ''))
 */
  __pyx_tuple__65 = PyTuple_Pack(4, __pyx_int_72, __pyx_n_s_hp8, __pyx_n_s_hp8_bin, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__65)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 100; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__65);
  __Pyx_GIVEREF(__pyx_tuple__65);

  /* "cymysql/charset.py":101
 * _charsets.add(Charset(71, 'hebrew', 'hebrew_bin', ''))
 * _charsets.add(Charset(72, 'hp8', 'hp8_bin', ''))
 * _charsets.add(Charset(73, 'keybcs2', 'keybcs2_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(74, 'koi8r', 'koi8r_bin', ''))
 * _charsets.add(Charset(75, 'koi8u', 'koi8u_bin', ''))
 */
  __pyx_tuple__66 = PyTuple_Pack(4, __pyx_int_73, __pyx_n_s_keybcs2, __pyx_n_s_keybcs2_bin, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__66)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 101; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__66);
  __Pyx_GIVEREF(__pyx_tuple__66);

  /* "cymysql/charset.py":102
 * _charsets.add(Charset(72, 'hp8', 'hp8_bin', ''))
 * _charsets.add(Charset(73, 'keybcs2', 'keybcs2_bin', ''))
 * _charsets.add(Charset(74, 'koi8r', 'koi8r_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(75, 'koi8u', 'koi8u_bin', ''))
 * _charsets.add(Charset(77, 'latin2', 'latin2_bin', ''))
 */
  __pyx_tuple__67 = PyTuple_Pack(4, __pyx_int_74, __pyx_n_s_koi8r, __pyx_n_s_koi8r_bin, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__67)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 102; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__67);
  __Pyx_GIVEREF(__pyx_tuple__67);

  /* "cymysql/charset.py":103
 * _charsets.add(Charset(73, 'keybcs2', 'keybcs2_bin', ''))
 * _charsets.add(Charset(74, 'koi8r', 'koi8r_bin', ''))
 * _charsets.add(Charset(75, 'koi8u', 'koi8u_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(77, 'latin2', 'latin2_bin', ''))
 * _charsets.add(Charset(78, 'latin5', 'latin5_bin', ''))
 */
  __pyx_tuple__68 = PyTuple_Pack(4, __pyx_int_75, __pyx_n_s_koi8u, __pyx_n_s_koi8u_bin, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__68)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 103; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__68);
  __Pyx_GIVEREF(__pyx_tuple__68);

  /* "cymysql/charset.py":104
 * _charsets.add(Charset(74, 'koi8r', 'koi8r_bin', ''))
 * _charsets.add(Charset(75, 'koi8u', 'koi8u_bin', ''))
 * _charsets.add(Charset(77, 'latin2', 'latin2_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(78, 'latin5', 'latin5_bin', ''))
 * _charsets.add(Charset(79, 'latin7', 'latin7_bin', ''))
 */
  __pyx_tuple__69 = PyTuple_Pack(4, __pyx_int_77, __pyx_n_s_latin2, __pyx_n_s_latin2_bin, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__69)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 104; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__69);
  __Pyx_GIVEREF(__pyx_tuple__69);

  /* "cymysql/charset.py":105
 * _charsets.add(Charset(75, 'koi8u', 'koi8u_bin', ''))
 * _charsets.add(Charset(77, 'latin2', 'latin2_bin', ''))
 * _charsets.add(Charset(78, 'latin5', 'latin5_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(79, 'latin7', 'latin7_bin', ''))
 * _charsets.add(Charset(80, 'cp850', 'cp850_bin', ''))
 */
  __pyx_tuple__70 = PyTuple_Pack(4, __pyx_int_78, __pyx_n_s_latin5, __pyx_n_s_latin5_bin, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__70)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 105; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__70);
  __Pyx_GIVEREF(__pyx_tuple__70);

  /* "cymysql/charset.py":106
 * _charsets.add(Charset(77, 'latin2', 'latin2_bin', ''))
 * _charsets.add(Charset(78, 'latin5', 'latin5_bin', ''))
 * _charsets.add(Charset(79, 'latin7', 'latin7_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(80, 'cp850', 'cp850_bin', ''))
 * _charsets.add(Charset(81, 'cp852', 'cp852_bin', ''))
 */
  __pyx_tuple__71 = PyTuple_Pack(4, __pyx_int_79, __pyx_n_s_latin7, __pyx_n_s_latin7_bin, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__71)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 106; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__71);
  __Pyx_GIVEREF(__pyx_tuple__71);

  /* "cymysql/charset.py":107
 * _charsets.add(Charset(78, 'latin5', 'latin5_bin', ''))
 * _charsets.add(Charset(79, 'latin7', 'latin7_bin', ''))
 * _charsets.add(Charset(80, 'cp850', 'cp850_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(81, 'cp852', 'cp852_bin', ''))
 * _charsets.add(Charset(82, 'swe7', 'swe7_bin', ''))
 */
  __pyx_tuple__72 = PyTuple_Pack(4, __pyx_int_80, __pyx_n_s_cp850, __pyx_n_s_cp850_bin, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__72)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 107; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__72);
  __Pyx_GIVEREF(__pyx_tuple__72);

  /* "cymysql/charset.py":108
 * _charsets.add(Charset(79, 'latin7', 'latin7_bin', ''))
 * _charsets.add(Charset(80, 'cp850', 'cp850_bin', ''))
 * _charsets.add(Charset(81, 'cp852', 'cp852_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(82, 'swe7', 'swe7_bin', ''))
 * _charsets.add(Charset(83, 'utf8', 'utf8_bin', ''))
 */
  __pyx_tuple__73 = PyTuple_Pack(4, __pyx_int_81, __pyx_n_s_cp852, __pyx_n_s_cp852_bin, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__73)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 108; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__73);
  __Pyx_GIVEREF(__pyx_tuple__73);

  /* "cymysql/charset.py":109
 * _charsets.add(Charset(80, 'cp850', 'cp850_bin', ''))
 * _charsets.add(Charset(81, 'cp852', 'cp852_bin', ''))
 * _charsets.add(Charset(82, 'swe7', 'swe7_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(83, 'utf8', 'utf8_bin', ''))
 * _charsets.add(Charset(84, 'big5', 'big5_bin', ''))
 */
  __pyx_tuple__74 = PyTuple_Pack(4, __pyx_int_82, __pyx_n_s_swe7, __pyx_n_s_swe7_bin, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__74)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 109; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__74);
  __Pyx_GIVEREF(__pyx_tuple__74);

  /* "cymysql/charset.py":110
 * _charsets.add(Charset(81, 'cp852', 'cp852_bin', ''))
 * _charsets.add(Charset(82, 'swe7', 'swe7_bin', ''))
 * _charsets.add(Charset(83, 'utf8', 'utf8_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(84, 'big5', 'big5_bin', ''))
 * _charsets.add(Charset(85, 'euckr', 'euckr_bin', ''))
 */
  __pyx_tuple__75 = PyTuple_Pack(4, __pyx_int_83, __pyx_n_s_utf8, __pyx_n_s_utf8_bin, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__75)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 110; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__75);
  __Pyx_GIVEREF(__pyx_tuple__75);

  /* "cymysql/charset.py":111
 * _charsets.add(Charset(82, 'swe7', 'swe7_bin', ''))
 * _charsets.add(Charset(83, 'utf8', 'utf8_bin', ''))
 * _charsets.add(Charset(84, 'big5', 'big5_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(85, 'euckr', 'euckr_bin', ''))
 * _charsets.add(Charset(86, 'gb2312', 'gb2312_bin', ''))
 */
  __pyx_tuple__76 = PyTuple_Pack(4, __pyx_int_84, __pyx_n_s_big5, __pyx_n_s_big5_bin, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__76)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 111; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__76);
  __Pyx_GIVEREF(__pyx_tuple__76);

  /* "cymysql/charset.py":112
 * _charsets.add(Charset(83, 'utf8', 'utf8_bin', ''))
 * _charsets.add(Charset(84, 'big5', 'big5_bin', ''))
 * _charsets.add(Charset(85, 'euckr', 'euckr_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(86, 'gb2312', 'gb2312_bin', ''))
 * _charsets.add(Charset(87, 'gbk', 'gbk_bin', ''))
 */
  __pyx_tuple__77 = PyTuple_Pack(4, __pyx_int_85, __pyx_n_s_euckr, __pyx_n_s_euckr_bin, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__77)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 112; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__77);
  __Pyx_GIVEREF(__pyx_tuple__77);

  /* "cymysql/charset.py":113
 * _charsets.add(Charset(84, 'big5', 'big5_bin', ''))
 * _charsets.add(Charset(85, 'euckr', 'euckr_bin', ''))
 * _charsets.add(Charset(86, 'gb2312', 'gb2312_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(87, 'gbk', 'gbk_bin', ''))
 * _charsets.add(Charset(88, 'sjis', 'sjis_bin', ''))
 */
  __pyx_tuple__78 = PyTuple_Pack(4, __pyx_int_86, __pyx_n_s_gb2312, __pyx_n_s_gb2312_bin, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__78)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 113; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__78);
  __Pyx_GIVEREF(__pyx_tuple__78);

  /* "cymysql/charset.py":114
 * _charsets.add(Charset(85, 'euckr', 'euckr_bin', ''))
 * _charsets.add(Charset(86, 'gb2312', 'gb2312_bin', ''))
 * _charsets.add(Charset(87, 'gbk', 'gbk_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(88, 'sjis', 'sjis_bin', ''))
 * _charsets.add(Charset(89, 'tis620', 'tis620_bin', ''))
 */
  __pyx_tuple__79 = PyTuple_Pack(4, __pyx_int_87, __pyx_n_s_gbk, __pyx_n_s_gbk_bin, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__79)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 114; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__79);
  __Pyx_GIVEREF(__pyx_tuple__79);

  /* "cymysql/charset.py":115
 * _charsets.add(Charset(86, 'gb2312', 'gb2312_bin', ''))
 * _charsets.add(Charset(87, 'gbk', 'gbk_bin', ''))
 * _charsets.add(Charset(88, 'sjis', 'sjis_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(89, 'tis620', 'tis620_bin', ''))
 * _charsets.add(Charset(90, 'ucs2', 'ucs2_bin', ''))
 */
  __pyx_tuple__80 = PyTuple_Pack(4, __pyx_int_88, __pyx_n_s_sjis, __pyx_n_s_sjis_bin, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__80)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 115; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__80);
  __Pyx_GIVEREF(__pyx_tuple__80);

  /* "cymysql/charset.py":116
 * _charsets.add(Charset(87, 'gbk', 'gbk_bin', ''))
 * _charsets.add(Charset(88, 'sjis', 'sjis_bin', ''))
 * _charsets.add(Charset(89, 'tis620', 'tis620_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(90, 'ucs2', 'ucs2_bin', ''))
 * _charsets.add(Charset(91, 'ujis', 'ujis_bin', ''))
 */
  __pyx_tuple__81 = PyTuple_Pack(4, __pyx_int_89, __pyx_n_s_tis620, __pyx_n_s_tis620_bin, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__81)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 116; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__81);
  __Pyx_GIVEREF(__pyx_tuple__81);

  /* "cymysql/charset.py":117
 * _charsets.add(Charset(88, 'sjis', 'sjis_bin', ''))
 * _charsets.add(Charset(89, 'tis620', 'tis620_bin', ''))
 * _charsets.add(Charset(90, 'ucs2', 'ucs2_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(91, 'ujis', 'ujis_bin', ''))
 * _charsets.add(Charset(92, 'geostd8', 'geostd8_general_ci', 'Yes'))
 */
  __pyx_tuple__82 = PyTuple_Pack(4, __pyx_int_90, __pyx_n_s_ucs2, __pyx_n_s_ucs2_bin, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__82)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 117; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__82);
  __Pyx_GIVEREF(__pyx_tuple__82);

  /* "cymysql/charset.py":118
 * _charsets.add(Charset(89, 'tis620', 'tis620_bin', ''))
 * _charsets.add(Charset(90, 'ucs2', 'ucs2_bin', ''))
 * _charsets.add(Charset(91, 'ujis', 'ujis_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(92, 'geostd8', 'geostd8_general_ci', 'Yes'))
 * _charsets.add(Charset(93, 'geostd8', 'geostd8_bin', ''))
 */
  __pyx_tuple__83 = PyTuple_Pack(4, __pyx_int_91, __pyx_n_s_ujis, __pyx_n_s_ujis_bin, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__83)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 118; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__83);
  __Pyx_GIVEREF(__pyx_tuple__83);

  /* "cymysql/charset.py":119
 * _charsets.add(Charset(90, 'ucs2', 'ucs2_bin', ''))
 * _charsets.add(Charset(91, 'ujis', 'ujis_bin', ''))
 * _charsets.add(Charset(92, 'geostd8', 'geostd8_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(93, 'geostd8', 'geostd8_bin', ''))
 * _charsets.add(Charset(94, 'latin1', 'latin1_spanish_ci', ''))
 */
  __pyx_tuple__84 = PyTuple_Pack(4, __pyx_int_92, __pyx_n_s_geostd8, __pyx_n_s_geostd8_general_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__84)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 119; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__84);
  __Pyx_GIVEREF(__pyx_tuple__84);

  /* "cymysql/charset.py":120
 * _charsets.add(Charset(91, 'ujis', 'ujis_bin', ''))
 * _charsets.add(Charset(92, 'geostd8', 'geostd8_general_ci', 'Yes'))
 * _charsets.add(Charset(93, 'geostd8', 'geostd8_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(94, 'latin1', 'latin1_spanish_ci', ''))
 * _charsets.add(Charset(95, 'cp932', 'cp932_japanese_ci', 'Yes'))
 */
  __pyx_tuple__85 = PyTuple_Pack(4, __pyx_int_93, __pyx_n_s_geostd8, __pyx_n_s_geostd8_bin, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__85)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 120; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__85);
  __Pyx_GIVEREF(__pyx_tuple__85);

  /* "cymysql/charset.py":121
 * _charsets.add(Charset(92, 'geostd8', 'geostd8_general_ci', 'Yes'))
 * _charsets.add(Charset(93, 'geostd8', 'geostd8_bin', ''))
 * _charsets.add(Charset(94, 'latin1', 'latin1_spanish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(95, 'cp932', 'cp932_japanese_ci', 'Yes'))
 * _charsets.add(Charset(96, 'cp932', 'cp932_bin', ''))
 */
  __pyx_tuple__86 = PyTuple_Pack(4, __pyx_int_94, __pyx_n_s_latin1, __pyx_n_s_latin1_spanish_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__86)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 121; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__86);
  __Pyx_GIVEREF(__pyx_tuple__86);

  /* "cymysql/charset.py":122
 * _charsets.add(Charset(93, 'geostd8', 'geostd8_bin', ''))
 * _charsets.add(Charset(94, 'latin1', 'latin1_spanish_ci', ''))
 * _charsets.add(Charset(95, 'cp932', 'cp932_japanese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(96, 'cp932', 'cp932_bin', ''))
 * _charsets.add(Charset(97, 'eucjpms', 'eucjpms_japanese_ci', 'Yes'))
 */
  __pyx_tuple__87 = PyTuple_Pack(4, __pyx_int_95, __pyx_n_s_cp932, __pyx_n_s_cp932_japanese_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__87)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 122; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__87);
  __Pyx_GIVEREF(__pyx_tuple__87);

  /* "cymysql/charset.py":123
 * _charsets.add(Charset(94, 'latin1', 'latin1_spanish_ci', ''))
 * _charsets.add(Charset(95, 'cp932', 'cp932_japanese_ci', 'Yes'))
 * _charsets.add(Charset(96, 'cp932', 'cp932_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(97, 'eucjpms', 'eucjpms_japanese_ci', 'Yes'))
 * _charsets.add(Charset(98, 'eucjpms', 'eucjpms_bin', ''))
 */
  __pyx_tuple__88 = PyTuple_Pack(4, __pyx_int_96, __pyx_n_s_cp932, __pyx_n_s_cp932_bin, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__88)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 123; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__88);
  __Pyx_GIVEREF(__pyx_tuple__88);

  /* "cymysql/charset.py":124
 * _charsets.add(Charset(95, 'cp932', 'cp932_japanese_ci', 'Yes'))
 * _charsets.add(Charset(96, 'cp932', 'cp932_bin', ''))
 * _charsets.add(Charset(97, 'eucjpms', 'eucjpms_japanese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(98, 'eucjpms', 'eucjpms_bin', ''))
 * _charsets.add(Charset(99, 'cp1250', 'cp1250_polish_ci', ''))
 */
  __pyx_tuple__89 = PyTuple_Pack(4, __pyx_int_97, __pyx_n_s_eucjpms, __pyx_n_s_eucjpms_japanese_ci, __pyx_n_s_Yes); if (unlikely(!__pyx_tuple__89)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 124; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__89);
  __Pyx_GIVEREF(__pyx_tuple__89);

  /* "cymysql/charset.py":125
 * _charsets.add(Charset(96, 'cp932', 'cp932_bin', ''))
 * _charsets.add(Charset(97, 'eucjpms', 'eucjpms_japanese_ci', 'Yes'))
 * _charsets.add(Charset(98, 'eucjpms', 'eucjpms_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(99, 'cp1250', 'cp1250_polish_ci', ''))
 * _charsets.add(Charset(128, 'ucs2', 'ucs2_unicode_ci', ''))
 */
  __pyx_tuple__90 = PyTuple_Pack(4, __pyx_int_98, __pyx_n_s_eucjpms, __pyx_n_s_eucjpms_bin, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__90)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 125; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__90);
  __Pyx_GIVEREF(__pyx_tuple__90);

  /* "cymysql/charset.py":126
 * _charsets.add(Charset(97, 'eucjpms', 'eucjpms_japanese_ci', 'Yes'))
 * _charsets.add(Charset(98, 'eucjpms', 'eucjpms_bin', ''))
 * _charsets.add(Charset(99, 'cp1250', 'cp1250_polish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(128, 'ucs2', 'ucs2_unicode_ci', ''))
 * _charsets.add(Charset(129, 'ucs2', 'ucs2_icelandic_ci', ''))
 */
  __pyx_tuple__91 = PyTuple_Pack(4, __pyx_int_99, __pyx_n_s_cp1250, __pyx_n_s_cp1250_polish_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__91)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 126; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__91);
  __Pyx_GIVEREF(__pyx_tuple__91);

  /* "cymysql/charset.py":127
 * _charsets.add(Charset(98, 'eucjpms', 'eucjpms_bin', ''))
 * _charsets.add(Charset(99, 'cp1250', 'cp1250_polish_ci', ''))
 * _charsets.add(Charset(128, 'ucs2', 'ucs2_unicode_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(129, 'ucs2', 'ucs2_icelandic_ci', ''))
 * _charsets.add(Charset(130, 'ucs2', 'ucs2_latvian_ci', ''))
 */
  __pyx_tuple__92 = PyTuple_Pack(4, __pyx_int_128, __pyx_n_s_ucs2, __pyx_n_s_ucs2_unicode_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__92)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 127; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__92);
  __Pyx_GIVEREF(__pyx_tuple__92);

  /* "cymysql/charset.py":128
 * _charsets.add(Charset(99, 'cp1250', 'cp1250_polish_ci', ''))
 * _charsets.add(Charset(128, 'ucs2', 'ucs2_unicode_ci', ''))
 * _charsets.add(Charset(129, 'ucs2', 'ucs2_icelandic_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(130, 'ucs2', 'ucs2_latvian_ci', ''))
 * _charsets.add(Charset(131, 'ucs2', 'ucs2_romanian_ci', ''))
 */
  __pyx_tuple__93 = PyTuple_Pack(4, __pyx_int_129, __pyx_n_s_ucs2, __pyx_n_s_ucs2_icelandic_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__93)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 128; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__93);
  __Pyx_GIVEREF(__pyx_tuple__93);

  /* "cymysql/charset.py":129
 * _charsets.add(Charset(128, 'ucs2', 'ucs2_unicode_ci', ''))
 * _charsets.add(Charset(129, 'ucs2', 'ucs2_icelandic_ci', ''))
 * _charsets.add(Charset(130, 'ucs2', 'ucs2_latvian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(131, 'ucs2', 'ucs2_romanian_ci', ''))
 * _charsets.add(Charset(132, 'ucs2', 'ucs2_slovenian_ci', ''))
 */
  __pyx_tuple__94 = PyTuple_Pack(4, __pyx_int_130, __pyx_n_s_ucs2, __pyx_n_s_ucs2_latvian_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__94)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 129; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__94);
  __Pyx_GIVEREF(__pyx_tuple__94);

  /* "cymysql/charset.py":130
 * _charsets.add(Charset(129, 'ucs2', 'ucs2_icelandic_ci', ''))
 * _charsets.add(Charset(130, 'ucs2', 'ucs2_latvian_ci', ''))
 * _charsets.add(Charset(131, 'ucs2', 'ucs2_romanian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(132, 'ucs2', 'ucs2_slovenian_ci', ''))
 * _charsets.add(Charset(133, 'ucs2', 'ucs2_polish_ci', ''))
 */
  __pyx_tuple__95 = PyTuple_Pack(4, __pyx_int_131, __pyx_n_s_ucs2, __pyx_n_s_ucs2_romanian_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__95)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 130; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__95);
  __Pyx_GIVEREF(__pyx_tuple__95);

  /* "cymysql/charset.py":131
 * _charsets.add(Charset(130, 'ucs2', 'ucs2_latvian_ci', ''))
 * _charsets.add(Charset(131, 'ucs2', 'ucs2_romanian_ci', ''))
 * _charsets.add(Charset(132, 'ucs2', 'ucs2_slovenian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(133, 'ucs2', 'ucs2_polish_ci', ''))
 * _charsets.add(Charset(134, 'ucs2', 'ucs2_estonian_ci', ''))
 */
  __pyx_tuple__96 = PyTuple_Pack(4, __pyx_int_132, __pyx_n_s_ucs2, __pyx_n_s_ucs2_slovenian_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__96)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 131; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__96);
  __Pyx_GIVEREF(__pyx_tuple__96);

  /* "cymysql/charset.py":132
 * _charsets.add(Charset(131, 'ucs2', 'ucs2_romanian_ci', ''))
 * _charsets.add(Charset(132, 'ucs2', 'ucs2_slovenian_ci', ''))
 * _charsets.add(Charset(133, 'ucs2', 'ucs2_polish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(134, 'ucs2', 'ucs2_estonian_ci', ''))
 * _charsets.add(Charset(135, 'ucs2', 'ucs2_spanish_ci', ''))
 */
  __pyx_tuple__97 = PyTuple_Pack(4, __pyx_int_133, __pyx_n_s_ucs2, __pyx_n_s_ucs2_polish_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__97)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 132; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__97);
  __Pyx_GIVEREF(__pyx_tuple__97);

  /* "cymysql/charset.py":133
 * _charsets.add(Charset(132, 'ucs2', 'ucs2_slovenian_ci', ''))
 * _charsets.add(Charset(133, 'ucs2', 'ucs2_polish_ci', ''))
 * _charsets.add(Charset(134, 'ucs2', 'ucs2_estonian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(135, 'ucs2', 'ucs2_spanish_ci', ''))
 * _charsets.add(Charset(136, 'ucs2', 'ucs2_swedish_ci', ''))
 */
  __pyx_tuple__98 = PyTuple_Pack(4, __pyx_int_134, __pyx_n_s_ucs2, __pyx_n_s_ucs2_estonian_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__98)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 133; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__98);
  __Pyx_GIVEREF(__pyx_tuple__98);

  /* "cymysql/charset.py":134
 * _charsets.add(Charset(133, 'ucs2', 'ucs2_polish_ci', ''))
 * _charsets.add(Charset(134, 'ucs2', 'ucs2_estonian_ci', ''))
 * _charsets.add(Charset(135, 'ucs2', 'ucs2_spanish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(136, 'ucs2', 'ucs2_swedish_ci', ''))
 * _charsets.add(Charset(137, 'ucs2', 'ucs2_turkish_ci', ''))
 */
  __pyx_tuple__99 = PyTuple_Pack(4, __pyx_int_135, __pyx_n_s_ucs2, __pyx_n_s_ucs2_spanish_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__99)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 134; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__99);
  __Pyx_GIVEREF(__pyx_tuple__99);

  /* "cymysql/charset.py":135
 * _charsets.add(Charset(134, 'ucs2', 'ucs2_estonian_ci', ''))
 * _charsets.add(Charset(135, 'ucs2', 'ucs2_spanish_ci', ''))
 * _charsets.add(Charset(136, 'ucs2', 'ucs2_swedish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(137, 'ucs2', 'ucs2_turkish_ci', ''))
 * _charsets.add(Charset(138, 'ucs2', 'ucs2_czech_ci', ''))
 */
  __pyx_tuple__100 = PyTuple_Pack(4, __pyx_int_136, __pyx_n_s_ucs2, __pyx_n_s_ucs2_swedish_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__100)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 135; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__100);
  __Pyx_GIVEREF(__pyx_tuple__100);

  /* "cymysql/charset.py":136
 * _charsets.add(Charset(135, 'ucs2', 'ucs2_spanish_ci', ''))
 * _charsets.add(Charset(136, 'ucs2', 'ucs2_swedish_ci', ''))
 * _charsets.add(Charset(137, 'ucs2', 'ucs2_turkish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(138, 'ucs2', 'ucs2_czech_ci', ''))
 * _charsets.add(Charset(139, 'ucs2', 'ucs2_danish_ci', ''))
 */
  __pyx_tuple__101 = PyTuple_Pack(4, __pyx_int_137, __pyx_n_s_ucs2, __pyx_n_s_ucs2_turkish_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__101)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 136; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__101);
  __Pyx_GIVEREF(__pyx_tuple__101);

  /* "cymysql/charset.py":137
 * _charsets.add(Charset(136, 'ucs2', 'ucs2_swedish_ci', ''))
 * _charsets.add(Charset(137, 'ucs2', 'ucs2_turkish_ci', ''))
 * _charsets.add(Charset(138, 'ucs2', 'ucs2_czech_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(139, 'ucs2', 'ucs2_danish_ci', ''))
 * _charsets.add(Charset(140, 'ucs2', 'ucs2_lithuanian_ci', ''))
 */
  __pyx_tuple__102 = PyTuple_Pack(4, __pyx_int_138, __pyx_n_s_ucs2, __pyx_n_s_ucs2_czech_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__102)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 137; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__102);
  __Pyx_GIVEREF(__pyx_tuple__102);

  /* "cymysql/charset.py":138
 * _charsets.add(Charset(137, 'ucs2', 'ucs2_turkish_ci', ''))
 * _charsets.add(Charset(138, 'ucs2', 'ucs2_czech_ci', ''))
 * _charsets.add(Charset(139, 'ucs2', 'ucs2_danish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(140, 'ucs2', 'ucs2_lithuanian_ci', ''))
 * _charsets.add(Charset(141, 'ucs2', 'ucs2_slovak_ci', ''))
 */
  __pyx_tuple__103 = PyTuple_Pack(4, __pyx_int_139, __pyx_n_s_ucs2, __pyx_n_s_ucs2_danish_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__103)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 138; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__103);
  __Pyx_GIVEREF(__pyx_tuple__103);

  /* "cymysql/charset.py":139
 * _charsets.add(Charset(138, 'ucs2', 'ucs2_czech_ci', ''))
 * _charsets.add(Charset(139, 'ucs2', 'ucs2_danish_ci', ''))
 * _charsets.add(Charset(140, 'ucs2', 'ucs2_lithuanian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(141, 'ucs2', 'ucs2_slovak_ci', ''))
 * _charsets.add(Charset(142, 'ucs2', 'ucs2_spanish2_ci', ''))
 */
  __pyx_tuple__104 = PyTuple_Pack(4, __pyx_int_140, __pyx_n_s_ucs2, __pyx_n_s_ucs2_lithuanian_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__104)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 139; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__104);
  __Pyx_GIVEREF(__pyx_tuple__104);

  /* "cymysql/charset.py":140
 * _charsets.add(Charset(139, 'ucs2', 'ucs2_danish_ci', ''))
 * _charsets.add(Charset(140, 'ucs2', 'ucs2_lithuanian_ci', ''))
 * _charsets.add(Charset(141, 'ucs2', 'ucs2_slovak_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(142, 'ucs2', 'ucs2_spanish2_ci', ''))
 * _charsets.add(Charset(143, 'ucs2', 'ucs2_roman_ci', ''))
 */
  __pyx_tuple__105 = PyTuple_Pack(4, __pyx_int_141, __pyx_n_s_ucs2, __pyx_n_s_ucs2_slovak_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__105)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 140; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__105);
  __Pyx_GIVEREF(__pyx_tuple__105);

  /* "cymysql/charset.py":141
 * _charsets.add(Charset(140, 'ucs2', 'ucs2_lithuanian_ci', ''))
 * _charsets.add(Charset(141, 'ucs2', 'ucs2_slovak_ci', ''))
 * _charsets.add(Charset(142, 'ucs2', 'ucs2_spanish2_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(143, 'ucs2', 'ucs2_roman_ci', ''))
 * _charsets.add(Charset(144, 'ucs2', 'ucs2_persian_ci', ''))
 */
  __pyx_tuple__106 = PyTuple_Pack(4, __pyx_int_142, __pyx_n_s_ucs2, __pyx_n_s_ucs2_spanish2_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__106)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 141; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__106);
  __Pyx_GIVEREF(__pyx_tuple__106);

  /* "cymysql/charset.py":142
 * _charsets.add(Charset(141, 'ucs2', 'ucs2_slovak_ci', ''))
 * _charsets.add(Charset(142, 'ucs2', 'ucs2_spanish2_ci', ''))
 * _charsets.add(Charset(143, 'ucs2', 'ucs2_roman_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(144, 'ucs2', 'ucs2_persian_ci', ''))
 * _charsets.add(Charset(145, 'ucs2', 'ucs2_esperanto_ci', ''))
 */
  __pyx_tuple__107 = PyTuple_Pack(4, __pyx_int_143, __pyx_n_s_ucs2, __pyx_n_s_ucs2_roman_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__107)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 142; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__107);
  __Pyx_GIVEREF(__pyx_tuple__107);

  /* "cymysql/charset.py":143
 * _charsets.add(Charset(142, 'ucs2', 'ucs2_spanish2_ci', ''))
 * _charsets.add(Charset(143, 'ucs2', 'ucs2_roman_ci', ''))
 * _charsets.add(Charset(144, 'ucs2', 'ucs2_persian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(145, 'ucs2', 'ucs2_esperanto_ci', ''))
 * _charsets.add(Charset(146, 'ucs2', 'ucs2_hungarian_ci', ''))
 */
  __pyx_tuple__108 = PyTuple_Pack(4, __pyx_int_144, __pyx_n_s_ucs2, __pyx_n_s_ucs2_persian_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__108)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 143; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__108);
  __Pyx_GIVEREF(__pyx_tuple__108);

  /* "cymysql/charset.py":144
 * _charsets.add(Charset(143, 'ucs2', 'ucs2_roman_ci', ''))
 * _charsets.add(Charset(144, 'ucs2', 'ucs2_persian_ci', ''))
 * _charsets.add(Charset(145, 'ucs2', 'ucs2_esperanto_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(146, 'ucs2', 'ucs2_hungarian_ci', ''))
 * _charsets.add(Charset(192, 'utf8', 'utf8_unicode_ci', ''))
 */
  __pyx_tuple__109 = PyTuple_Pack(4, __pyx_int_145, __pyx_n_s_ucs2, __pyx_n_s_ucs2_esperanto_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__109)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 144; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__109);
  __Pyx_GIVEREF(__pyx_tuple__109);

  /* "cymysql/charset.py":145
 * _charsets.add(Charset(144, 'ucs2', 'ucs2_persian_ci', ''))
 * _charsets.add(Charset(145, 'ucs2', 'ucs2_esperanto_ci', ''))
 * _charsets.add(Charset(146, 'ucs2', 'ucs2_hungarian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(192, 'utf8', 'utf8_unicode_ci', ''))
 * _charsets.add(Charset(193, 'utf8', 'utf8_icelandic_ci', ''))
 */
  __pyx_tuple__110 = PyTuple_Pack(4, __pyx_int_146, __pyx_n_s_ucs2, __pyx_n_s_ucs2_hungarian_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__110)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 145; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__110);
  __Pyx_GIVEREF(__pyx_tuple__110);

  /* "cymysql/charset.py":146
 * _charsets.add(Charset(145, 'ucs2', 'ucs2_esperanto_ci', ''))
 * _charsets.add(Charset(146, 'ucs2', 'ucs2_hungarian_ci', ''))
 * _charsets.add(Charset(192, 'utf8', 'utf8_unicode_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(193, 'utf8', 'utf8_icelandic_ci', ''))
 * _charsets.add(Charset(194, 'utf8', 'utf8_latvian_ci', ''))
 */
  __pyx_tuple__111 = PyTuple_Pack(4, __pyx_int_192, __pyx_n_s_utf8, __pyx_n_s_utf8_unicode_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__111)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 146; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__111);
  __Pyx_GIVEREF(__pyx_tuple__111);

  /* "cymysql/charset.py":147
 * _charsets.add(Charset(146, 'ucs2', 'ucs2_hungarian_ci', ''))
 * _charsets.add(Charset(192, 'utf8', 'utf8_unicode_ci', ''))
 * _charsets.add(Charset(193, 'utf8', 'utf8_icelandic_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(194, 'utf8', 'utf8_latvian_ci', ''))
 * _charsets.add(Charset(195, 'utf8', 'utf8_romanian_ci', ''))
 */
  __pyx_tuple__112 = PyTuple_Pack(4, __pyx_int_193, __pyx_n_s_utf8, __pyx_n_s_utf8_icelandic_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__112)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 147; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__112);
  __Pyx_GIVEREF(__pyx_tuple__112);

  /* "cymysql/charset.py":148
 * _charsets.add(Charset(192, 'utf8', 'utf8_unicode_ci', ''))
 * _charsets.add(Charset(193, 'utf8', 'utf8_icelandic_ci', ''))
 * _charsets.add(Charset(194, 'utf8', 'utf8_latvian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(195, 'utf8', 'utf8_romanian_ci', ''))
 * _charsets.add(Charset(196, 'utf8', 'utf8_slovenian_ci', ''))
 */
  __pyx_tuple__113 = PyTuple_Pack(4, __pyx_int_194, __pyx_n_s_utf8, __pyx_n_s_utf8_latvian_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__113)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 148; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__113);
  __Pyx_GIVEREF(__pyx_tuple__113);

  /* "cymysql/charset.py":149
 * _charsets.add(Charset(193, 'utf8', 'utf8_icelandic_ci', ''))
 * _charsets.add(Charset(194, 'utf8', 'utf8_latvian_ci', ''))
 * _charsets.add(Charset(195, 'utf8', 'utf8_romanian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(196, 'utf8', 'utf8_slovenian_ci', ''))
 * _charsets.add(Charset(197, 'utf8', 'utf8_polish_ci', ''))
 */
  __pyx_tuple__114 = PyTuple_Pack(4, __pyx_int_195, __pyx_n_s_utf8, __pyx_n_s_utf8_romanian_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__114)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 149; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__114);
  __Pyx_GIVEREF(__pyx_tuple__114);

  /* "cymysql/charset.py":150
 * _charsets.add(Charset(194, 'utf8', 'utf8_latvian_ci', ''))
 * _charsets.add(Charset(195, 'utf8', 'utf8_romanian_ci', ''))
 * _charsets.add(Charset(196, 'utf8', 'utf8_slovenian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(197, 'utf8', 'utf8_polish_ci', ''))
 * _charsets.add(Charset(198, 'utf8', 'utf8_estonian_ci', ''))
 */
  __pyx_tuple__115 = PyTuple_Pack(4, __pyx_int_196, __pyx_n_s_utf8, __pyx_n_s_utf8_slovenian_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__115)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 150; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__115);
  __Pyx_GIVEREF(__pyx_tuple__115);

  /* "cymysql/charset.py":151
 * _charsets.add(Charset(195, 'utf8', 'utf8_romanian_ci', ''))
 * _charsets.add(Charset(196, 'utf8', 'utf8_slovenian_ci', ''))
 * _charsets.add(Charset(197, 'utf8', 'utf8_polish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(198, 'utf8', 'utf8_estonian_ci', ''))
 * _charsets.add(Charset(199, 'utf8', 'utf8_spanish_ci', ''))
 */
  __pyx_tuple__116 = PyTuple_Pack(4, __pyx_int_197, __pyx_n_s_utf8, __pyx_n_s_utf8_polish_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__116)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 151; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__116);
  __Pyx_GIVEREF(__pyx_tuple__116);

  /* "cymysql/charset.py":152
 * _charsets.add(Charset(196, 'utf8', 'utf8_slovenian_ci', ''))
 * _charsets.add(Charset(197, 'utf8', 'utf8_polish_ci', ''))
 * _charsets.add(Charset(198, 'utf8', 'utf8_estonian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(199, 'utf8', 'utf8_spanish_ci', ''))
 * _charsets.add(Charset(200, 'utf8', 'utf8_swedish_ci', ''))
 */
  __pyx_tuple__117 = PyTuple_Pack(4, __pyx_int_198, __pyx_n_s_utf8, __pyx_n_s_utf8_estonian_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__117)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 152; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__117);
  __Pyx_GIVEREF(__pyx_tuple__117);

  /* "cymysql/charset.py":153
 * _charsets.add(Charset(197, 'utf8', 'utf8_polish_ci', ''))
 * _charsets.add(Charset(198, 'utf8', 'utf8_estonian_ci', ''))
 * _charsets.add(Charset(199, 'utf8', 'utf8_spanish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(200, 'utf8', 'utf8_swedish_ci', ''))
 * _charsets.add(Charset(201, 'utf8', 'utf8_turkish_ci', ''))
 */
  __pyx_tuple__118 = PyTuple_Pack(4, __pyx_int_199, __pyx_n_s_utf8, __pyx_n_s_utf8_spanish_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__118)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 153; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__118);
  __Pyx_GIVEREF(__pyx_tuple__118);

  /* "cymysql/charset.py":154
 * _charsets.add(Charset(198, 'utf8', 'utf8_estonian_ci', ''))
 * _charsets.add(Charset(199, 'utf8', 'utf8_spanish_ci', ''))
 * _charsets.add(Charset(200, 'utf8', 'utf8_swedish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(201, 'utf8', 'utf8_turkish_ci', ''))
 * _charsets.add(Charset(202, 'utf8', 'utf8_czech_ci', ''))
 */
  __pyx_tuple__119 = PyTuple_Pack(4, __pyx_int_200, __pyx_n_s_utf8, __pyx_n_s_utf8_swedish_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__119)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 154; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__119);
  __Pyx_GIVEREF(__pyx_tuple__119);

  /* "cymysql/charset.py":155
 * _charsets.add(Charset(199, 'utf8', 'utf8_spanish_ci', ''))
 * _charsets.add(Charset(200, 'utf8', 'utf8_swedish_ci', ''))
 * _charsets.add(Charset(201, 'utf8', 'utf8_turkish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(202, 'utf8', 'utf8_czech_ci', ''))
 * _charsets.add(Charset(203, 'utf8', 'utf8_danish_ci', ''))
 */
  __pyx_tuple__120 = PyTuple_Pack(4, __pyx_int_201, __pyx_n_s_utf8, __pyx_n_s_utf8_turkish_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__120)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 155; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__120);
  __Pyx_GIVEREF(__pyx_tuple__120);

  /* "cymysql/charset.py":156
 * _charsets.add(Charset(200, 'utf8', 'utf8_swedish_ci', ''))
 * _charsets.add(Charset(201, 'utf8', 'utf8_turkish_ci', ''))
 * _charsets.add(Charset(202, 'utf8', 'utf8_czech_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(203, 'utf8', 'utf8_danish_ci', ''))
 * _charsets.add(Charset(204, 'utf8', 'utf8_lithuanian_ci', ''))
 */
  __pyx_tuple__121 = PyTuple_Pack(4, __pyx_int_202, __pyx_n_s_utf8, __pyx_n_s_utf8_czech_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__121)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 156; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__121);
  __Pyx_GIVEREF(__pyx_tuple__121);

  /* "cymysql/charset.py":157
 * _charsets.add(Charset(201, 'utf8', 'utf8_turkish_ci', ''))
 * _charsets.add(Charset(202, 'utf8', 'utf8_czech_ci', ''))
 * _charsets.add(Charset(203, 'utf8', 'utf8_danish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(204, 'utf8', 'utf8_lithuanian_ci', ''))
 * _charsets.add(Charset(205, 'utf8', 'utf8_slovak_ci', ''))
 */
  __pyx_tuple__122 = PyTuple_Pack(4, __pyx_int_203, __pyx_n_s_utf8, __pyx_n_s_utf8_danish_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__122)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 157; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__122);
  __Pyx_GIVEREF(__pyx_tuple__122);

  /* "cymysql/charset.py":158
 * _charsets.add(Charset(202, 'utf8', 'utf8_czech_ci', ''))
 * _charsets.add(Charset(203, 'utf8', 'utf8_danish_ci', ''))
 * _charsets.add(Charset(204, 'utf8', 'utf8_lithuanian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(205, 'utf8', 'utf8_slovak_ci', ''))
 * _charsets.add(Charset(206, 'utf8', 'utf8_spanish2_ci', ''))
 */
  __pyx_tuple__123 = PyTuple_Pack(4, __pyx_int_204, __pyx_n_s_utf8, __pyx_n_s_utf8_lithuanian_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__123)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 158; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__123);
  __Pyx_GIVEREF(__pyx_tuple__123);

  /* "cymysql/charset.py":159
 * _charsets.add(Charset(203, 'utf8', 'utf8_danish_ci', ''))
 * _charsets.add(Charset(204, 'utf8', 'utf8_lithuanian_ci', ''))
 * _charsets.add(Charset(205, 'utf8', 'utf8_slovak_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(206, 'utf8', 'utf8_spanish2_ci', ''))
 * _charsets.add(Charset(207, 'utf8', 'utf8_roman_ci', ''))
 */
  __pyx_tuple__124 = PyTuple_Pack(4, __pyx_int_205, __pyx_n_s_utf8, __pyx_n_s_utf8_slovak_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__124)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 159; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__124);
  __Pyx_GIVEREF(__pyx_tuple__124);

  /* "cymysql/charset.py":160
 * _charsets.add(Charset(204, 'utf8', 'utf8_lithuanian_ci', ''))
 * _charsets.add(Charset(205, 'utf8', 'utf8_slovak_ci', ''))
 * _charsets.add(Charset(206, 'utf8', 'utf8_spanish2_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(207, 'utf8', 'utf8_roman_ci', ''))
 * _charsets.add(Charset(208, 'utf8', 'utf8_persian_ci', ''))
 */
  __pyx_tuple__125 = PyTuple_Pack(4, __pyx_int_206, __pyx_n_s_utf8, __pyx_n_s_utf8_spanish2_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__125)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 160; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__125);
  __Pyx_GIVEREF(__pyx_tuple__125);

  /* "cymysql/charset.py":161
 * _charsets.add(Charset(205, 'utf8', 'utf8_slovak_ci', ''))
 * _charsets.add(Charset(206, 'utf8', 'utf8_spanish2_ci', ''))
 * _charsets.add(Charset(207, 'utf8', 'utf8_roman_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(208, 'utf8', 'utf8_persian_ci', ''))
 * _charsets.add(Charset(209, 'utf8', 'utf8_esperanto_ci', ''))
 */
  __pyx_tuple__126 = PyTuple_Pack(4, __pyx_int_207, __pyx_n_s_utf8, __pyx_n_s_utf8_roman_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__126)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 161; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__126);
  __Pyx_GIVEREF(__pyx_tuple__126);

  /* "cymysql/charset.py":162
 * _charsets.add(Charset(206, 'utf8', 'utf8_spanish2_ci', ''))
 * _charsets.add(Charset(207, 'utf8', 'utf8_roman_ci', ''))
 * _charsets.add(Charset(208, 'utf8', 'utf8_persian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(209, 'utf8', 'utf8_esperanto_ci', ''))
 * _charsets.add(Charset(210, 'utf8', 'utf8_hungarian_ci', ''))
 */
  __pyx_tuple__127 = PyTuple_Pack(4, __pyx_int_208, __pyx_n_s_utf8, __pyx_n_s_utf8_persian_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__127)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 162; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__127);
  __Pyx_GIVEREF(__pyx_tuple__127);

  /* "cymysql/charset.py":163
 * _charsets.add(Charset(207, 'utf8', 'utf8_roman_ci', ''))
 * _charsets.add(Charset(208, 'utf8', 'utf8_persian_ci', ''))
 * _charsets.add(Charset(209, 'utf8', 'utf8_esperanto_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(210, 'utf8', 'utf8_hungarian_ci', ''))
 * 
 */
  __pyx_tuple__128 = PyTuple_Pack(4, __pyx_int_209, __pyx_n_s_utf8, __pyx_n_s_utf8_esperanto_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__128)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 163; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__128);
  __Pyx_GIVEREF(__pyx_tuple__128);

  /* "cymysql/charset.py":164
 * _charsets.add(Charset(208, 'utf8', 'utf8_persian_ci', ''))
 * _charsets.add(Charset(209, 'utf8', 'utf8_esperanto_ci', ''))
 * _charsets.add(Charset(210, 'utf8', 'utf8_hungarian_ci', ''))             # <<<<<<<<<<<<<<
 * 
 */
  __pyx_tuple__129 = PyTuple_Pack(4, __pyx_int_210, __pyx_n_s_utf8, __pyx_n_s_utf8_hungarian_ci, __pyx_kp_s__2); if (unlikely(!__pyx_tuple__129)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 164; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__129);
  __Pyx_GIVEREF(__pyx_tuple__129);
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_InitGlobals(void) {
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_2 = PyInt_FromLong(2); if (unlikely(!__pyx_int_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_3 = PyInt_FromLong(3); if (unlikely(!__pyx_int_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_4 = PyInt_FromLong(4); if (unlikely(!__pyx_int_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_5 = PyInt_FromLong(5); if (unlikely(!__pyx_int_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_6 = PyInt_FromLong(6); if (unlikely(!__pyx_int_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_7 = PyInt_FromLong(7); if (unlikely(!__pyx_int_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_8 = PyInt_FromLong(8); if (unlikely(!__pyx_int_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_9 = PyInt_FromLong(9); if (unlikely(!__pyx_int_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_10 = PyInt_FromLong(10); if (unlikely(!__pyx_int_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_11 = PyInt_FromLong(11); if (unlikely(!__pyx_int_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_12 = PyInt_FromLong(12); if (unlikely(!__pyx_int_12)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_13 = PyInt_FromLong(13); if (unlikely(!__pyx_int_13)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_14 = PyInt_FromLong(14); if (unlikely(!__pyx_int_14)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_15 = PyInt_FromLong(15); if (unlikely(!__pyx_int_15)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_16 = PyInt_FromLong(16); if (unlikely(!__pyx_int_16)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_18 = PyInt_FromLong(18); if (unlikely(!__pyx_int_18)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_19 = PyInt_FromLong(19); if (unlikely(!__pyx_int_19)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_20 = PyInt_FromLong(20); if (unlikely(!__pyx_int_20)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_21 = PyInt_FromLong(21); if (unlikely(!__pyx_int_21)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_22 = PyInt_FromLong(22); if (unlikely(!__pyx_int_22)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_23 = PyInt_FromLong(23); if (unlikely(!__pyx_int_23)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_24 = PyInt_FromLong(24); if (unlikely(!__pyx_int_24)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_25 = PyInt_FromLong(25); if (unlikely(!__pyx_int_25)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_26 = PyInt_FromLong(26); if (unlikely(!__pyx_int_26)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_27 = PyInt_FromLong(27); if (unlikely(!__pyx_int_27)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_28 = PyInt_FromLong(28); if (unlikely(!__pyx_int_28)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_29 = PyInt_FromLong(29); if (unlikely(!__pyx_int_29)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_30 = PyInt_FromLong(30); if (unlikely(!__pyx_int_30)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_31 = PyInt_FromLong(31); if (unlikely(!__pyx_int_31)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_32 = PyInt_FromLong(32); if (unlikely(!__pyx_int_32)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_33 = PyInt_FromLong(33); if (unlikely(!__pyx_int_33)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_34 = PyInt_FromLong(34); if (unlikely(!__pyx_int_34)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_35 = PyInt_FromLong(35); if (unlikely(!__pyx_int_35)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_36 = PyInt_FromLong(36); if (unlikely(!__pyx_int_36)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_37 = PyInt_FromLong(37); if (unlikely(!__pyx_int_37)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_38 = PyInt_FromLong(38); if (unlikely(!__pyx_int_38)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_39 = PyInt_FromLong(39); if (unlikely(!__pyx_int_39)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_40 = PyInt_FromLong(40); if (unlikely(!__pyx_int_40)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_41 = PyInt_FromLong(41); if (unlikely(!__pyx_int_41)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_42 = PyInt_FromLong(42); if (unlikely(!__pyx_int_42)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_43 = PyInt_FromLong(43); if (unlikely(!__pyx_int_43)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_44 = PyInt_FromLong(44); if (unlikely(!__pyx_int_44)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_45 = PyInt_FromLong(45); if (unlikely(!__pyx_int_45)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_47 = PyInt_FromLong(47); if (unlikely(!__pyx_int_47)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_48 = PyInt_FromLong(48); if (unlikely(!__pyx_int_48)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_49 = PyInt_FromLong(49); if (unlikely(!__pyx_int_49)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_50 = PyInt_FromLong(50); if (unlikely(!__pyx_int_50)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_51 = PyInt_FromLong(51); if (unlikely(!__pyx_int_51)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_52 = PyInt_FromLong(52); if (unlikely(!__pyx_int_52)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_53 = PyInt_FromLong(53); if (unlikely(!__pyx_int_53)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_57 = PyInt_FromLong(57); if (unlikely(!__pyx_int_57)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_58 = PyInt_FromLong(58); if (unlikely(!__pyx_int_58)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_59 = PyInt_FromLong(59); if (unlikely(!__pyx_int_59)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_63 = PyInt_FromLong(63); if (unlikely(!__pyx_int_63)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_64 = PyInt_FromLong(64); if (unlikely(!__pyx_int_64)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_65 = PyInt_FromLong(65); if (unlikely(!__pyx_int_65)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_66 = PyInt_FromLong(66); if (unlikely(!__pyx_int_66)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_67 = PyInt_FromLong(67); if (unlikely(!__pyx_int_67)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_68 = PyInt_FromLong(68); if (unlikely(!__pyx_int_68)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_69 = PyInt_FromLong(69); if (unlikely(!__pyx_int_69)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_70 = PyInt_FromLong(70); if (unlikely(!__pyx_int_70)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_71 = PyInt_FromLong(71); if (unlikely(!__pyx_int_71)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_72 = PyInt_FromLong(72); if (unlikely(!__pyx_int_72)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_73 = PyInt_FromLong(73); if (unlikely(!__pyx_int_73)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_74 = PyInt_FromLong(74); if (unlikely(!__pyx_int_74)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_75 = PyInt_FromLong(75); if (unlikely(!__pyx_int_75)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_77 = PyInt_FromLong(77); if (unlikely(!__pyx_int_77)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_78 = PyInt_FromLong(78); if (unlikely(!__pyx_int_78)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_79 = PyInt_FromLong(79); if (unlikely(!__pyx_int_79)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_80 = PyInt_FromLong(80); if (unlikely(!__pyx_int_80)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_81 = PyInt_FromLong(81); if (unlikely(!__pyx_int_81)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_82 = PyInt_FromLong(82); if (unlikely(!__pyx_int_82)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_83 = PyInt_FromLong(83); if (unlikely(!__pyx_int_83)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_84 = PyInt_FromLong(84); if (unlikely(!__pyx_int_84)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_85 = PyInt_FromLong(85); if (unlikely(!__pyx_int_85)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_86 = PyInt_FromLong(86); if (unlikely(!__pyx_int_86)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_87 = PyInt_FromLong(87); if (unlikely(!__pyx_int_87)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_88 = PyInt_FromLong(88); if (unlikely(!__pyx_int_88)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_89 = PyInt_FromLong(89); if (unlikely(!__pyx_int_89)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_90 = PyInt_FromLong(90); if (unlikely(!__pyx_int_90)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_91 = PyInt_FromLong(91); if (unlikely(!__pyx_int_91)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_92 = PyInt_FromLong(92); if (unlikely(!__pyx_int_92)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_93 = PyInt_FromLong(93); if (unlikely(!__pyx_int_93)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_94 = PyInt_FromLong(94); if (unlikely(!__pyx_int_94)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_95 = PyInt_FromLong(95); if (unlikely(!__pyx_int_95)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_96 = PyInt_FromLong(96); if (unlikely(!__pyx_int_96)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_97 = PyInt_FromLong(97); if (unlikely(!__pyx_int_97)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_98 = PyInt_FromLong(98); if (unlikely(!__pyx_int_98)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_99 = PyInt_FromLong(99); if (unlikely(!__pyx_int_99)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_128 = PyInt_FromLong(128); if (unlikely(!__pyx_int_128)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_129 = PyInt_FromLong(129); if (unlikely(!__pyx_int_129)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_130 = PyInt_FromLong(130); if (unlikely(!__pyx_int_130)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_131 = PyInt_FromLong(131); if (unlikely(!__pyx_int_131)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_132 = PyInt_FromLong(132); if (unlikely(!__pyx_int_132)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_133 = PyInt_FromLong(133); if (unlikely(!__pyx_int_133)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_134 = PyInt_FromLong(134); if (unlikely(!__pyx_int_134)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_135 = PyInt_FromLong(135); if (unlikely(!__pyx_int_135)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_136 = PyInt_FromLong(136); if (unlikely(!__pyx_int_136)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_137 = PyInt_FromLong(137); if (unlikely(!__pyx_int_137)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_138 = PyInt_FromLong(138); if (unlikely(!__pyx_int_138)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_139 = PyInt_FromLong(139); if (unlikely(!__pyx_int_139)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_140 = PyInt_FromLong(140); if (unlikely(!__pyx_int_140)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_141 = PyInt_FromLong(141); if (unlikely(!__pyx_int_141)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_142 = PyInt_FromLong(142); if (unlikely(!__pyx_int_142)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_143 = PyInt_FromLong(143); if (unlikely(!__pyx_int_143)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_144 = PyInt_FromLong(144); if (unlikely(!__pyx_int_144)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_145 = PyInt_FromLong(145); if (unlikely(!__pyx_int_145)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_146 = PyInt_FromLong(146); if (unlikely(!__pyx_int_146)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_192 = PyInt_FromLong(192); if (unlikely(!__pyx_int_192)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_193 = PyInt_FromLong(193); if (unlikely(!__pyx_int_193)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_194 = PyInt_FromLong(194); if (unlikely(!__pyx_int_194)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_195 = PyInt_FromLong(195); if (unlikely(!__pyx_int_195)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_196 = PyInt_FromLong(196); if (unlikely(!__pyx_int_196)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_197 = PyInt_FromLong(197); if (unlikely(!__pyx_int_197)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_198 = PyInt_FromLong(198); if (unlikely(!__pyx_int_198)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_199 = PyInt_FromLong(199); if (unlikely(!__pyx_int_199)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_200 = PyInt_FromLong(200); if (unlikely(!__pyx_int_200)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_201 = PyInt_FromLong(201); if (unlikely(!__pyx_int_201)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_202 = PyInt_FromLong(202); if (unlikely(!__pyx_int_202)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_203 = PyInt_FromLong(203); if (unlikely(!__pyx_int_203)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_204 = PyInt_FromLong(204); if (unlikely(!__pyx_int_204)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_205 = PyInt_FromLong(205); if (unlikely(!__pyx_int_205)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_206 = PyInt_FromLong(206); if (unlikely(!__pyx_int_206)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_207 = PyInt_FromLong(207); if (unlikely(!__pyx_int_207)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_208 = PyInt_FromLong(208); if (unlikely(!__pyx_int_208)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_209 = PyInt_FromLong(209); if (unlikely(!__pyx_int_209)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_210 = PyInt_FromLong(210); if (unlikely(!__pyx_int_210)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  return 0;
  __pyx_L1_error:;
  return -1;
}

#if PY_MAJOR_VERSION < 3
PyMODINIT_FUNC initcharset(void); /*proto*/
PyMODINIT_FUNC initcharset(void)
#else
PyMODINIT_FUNC PyInit_charset(void); /*proto*/
PyMODINIT_FUNC PyInit_charset(void)
#endif
{
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_REFNANNY
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
  if (!__Pyx_RefNanny) {
      PyErr_Clear();
      __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
      if (!__Pyx_RefNanny)
          Py_FatalError("failed to import 'refnanny' module");
  }
  #endif
  __Pyx_RefNannySetupContext("PyMODINIT_FUNC PyInit_charset(void)", 0);
  if ( __Pyx_check_binary_version() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #ifdef __Pyx_CyFunction_USED
  if (__Pyx_CyFunction_init() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  #ifdef WITH_THREAD /* Python build with threading support? */
  PyEval_InitThreads();
  #endif
  #endif
  /*--- Module creation code ---*/
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("charset", __pyx_methods, 0, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (unlikely(!__pyx_m)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  Py_INCREF(__pyx_d);
  __pyx_b = PyImport_AddModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #if CYTHON_COMPILING_IN_PYPY
  Py_INCREF(__pyx_b);
  #endif
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  /*--- Initialize various global constants etc. ---*/
  if (unlikely(__Pyx_InitGlobals() < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  if (__pyx_module_is_main_cymysql__charset) {
    if (PyObject_SetAttrString(__pyx_m, "__name__", __pyx_n_s_main) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    if (!PyDict_GetItemString(modules, "cymysql.charset")) {
      if (unlikely(PyDict_SetItemString(modules, "cymysql.charset", __pyx_m) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (unlikely(__Pyx_InitCachedBuiltins() < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Constants init code ---*/
  if (unlikely(__Pyx_InitCachedConstants() < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Global init code ---*/
  __pyx_v_7cymysql_7charset__charsets = ((struct __pyx_obj_7cymysql_7charset_Charsets *)Py_None); Py_INCREF(Py_None);
  /*--- Variable export code ---*/
  if (__Pyx_ExportVoidPtr(__pyx_n_s_charsets, (void *)&__pyx_v_7cymysql_7charset__charsets, "struct __pyx_obj_7cymysql_7charset_Charsets *") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Function export code ---*/
  /*--- Type init code ---*/
  if (PyType_Ready(&__pyx_type_7cymysql_7charset_Charset) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_type_7cymysql_7charset_Charset.tp_print = 0;
  if (PyObject_SetAttrString(__pyx_m, "Charset", (PyObject *)&__pyx_type_7cymysql_7charset_Charset) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_7cymysql_7charset_Charset = &__pyx_type_7cymysql_7charset_Charset;
  __pyx_vtabptr_7cymysql_7charset_Charsets = &__pyx_vtable_7cymysql_7charset_Charsets;
  __pyx_vtable_7cymysql_7charset_Charsets.add = (PyObject *(*)(struct __pyx_obj_7cymysql_7charset_Charsets *, struct __pyx_obj_7cymysql_7charset_Charset *))__pyx_f_7cymysql_7charset_8Charsets_add;
  __pyx_vtable_7cymysql_7charset_Charsets.by_name = (PyObject *(*)(struct __pyx_obj_7cymysql_7charset_Charsets *, PyObject *, int __pyx_skip_dispatch))__pyx_f_7cymysql_7charset_8Charsets_by_name;
  __pyx_vtable_7cymysql_7charset_Charsets.by_id = (PyObject *(*)(struct __pyx_obj_7cymysql_7charset_Charsets *, PyObject *, int __pyx_skip_dispatch))__pyx_f_7cymysql_7charset_8Charsets_by_id;
  if (PyType_Ready(&__pyx_type_7cymysql_7charset_Charsets) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 6; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_type_7cymysql_7charset_Charsets.tp_print = 0;
  if (__Pyx_SetVtable(__pyx_type_7cymysql_7charset_Charsets.tp_dict, __pyx_vtabptr_7cymysql_7charset_Charsets) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 6; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (PyObject_SetAttrString(__pyx_m, "Charsets", (PyObject *)&__pyx_type_7cymysql_7charset_Charsets) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 6; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_7cymysql_7charset_Charsets = &__pyx_type_7cymysql_7charset_Charsets;
  /*--- Type import code ---*/
  /*--- Variable import code ---*/
  /*--- Function import code ---*/
  /*--- Execution code ---*/

  /* "cymysql/charset.py":21
 *         return self._by_id[id]
 * 
 * _charsets = Charsets()             # <<<<<<<<<<<<<<
 * charset_by_name = _charsets.by_name
 * charset_by_id = _charsets.by_id
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charsets)), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 21; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_XGOTREF(((PyObject *)__pyx_v_7cymysql_7charset__charsets));
  __Pyx_DECREF_SET(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charsets *)__pyx_t_1));
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "cymysql/charset.py":22
 * 
 * _charsets = Charsets()
 * charset_by_name = _charsets.by_name             # <<<<<<<<<<<<<<
 * charset_by_id = _charsets.by_id
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_7cymysql_7charset__charsets), __pyx_n_s_by_name); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 22; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_charset_by_name, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 22; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":23
 * _charsets = Charsets()
 * charset_by_name = _charsets.by_name
 * charset_by_id = _charsets.by_id             # <<<<<<<<<<<<<<
 * 
 * """
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_7cymysql_7charset__charsets), __pyx_n_s_by_id); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 23; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_charset_by_id, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 23; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":37
 * 
 * """
 * _charsets.add(Charset(1, 'big5', 'big5_chinese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(2, 'latin2', 'latin2_czech_cs', ''))
 * _charsets.add(Charset(3, 'dec8', 'dec8_swedish_ci', 'Yes'))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple_, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 37; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 37; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":38
 * """
 * _charsets.add(Charset(1, 'big5', 'big5_chinese_ci', 'Yes'))
 * _charsets.add(Charset(2, 'latin2', 'latin2_czech_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(3, 'dec8', 'dec8_swedish_ci', 'Yes'))
 * _charsets.add(Charset(4, 'cp850', 'cp850_general_ci', 'Yes'))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__3, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 38; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 38; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":39
 * _charsets.add(Charset(1, 'big5', 'big5_chinese_ci', 'Yes'))
 * _charsets.add(Charset(2, 'latin2', 'latin2_czech_cs', ''))
 * _charsets.add(Charset(3, 'dec8', 'dec8_swedish_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(4, 'cp850', 'cp850_general_ci', 'Yes'))
 * _charsets.add(Charset(5, 'latin1', 'latin1_german1_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__4, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 39; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 39; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":40
 * _charsets.add(Charset(2, 'latin2', 'latin2_czech_cs', ''))
 * _charsets.add(Charset(3, 'dec8', 'dec8_swedish_ci', 'Yes'))
 * _charsets.add(Charset(4, 'cp850', 'cp850_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(5, 'latin1', 'latin1_german1_ci', ''))
 * _charsets.add(Charset(6, 'hp8', 'hp8_english_ci', 'Yes'))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__5, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 40; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 40; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":41
 * _charsets.add(Charset(3, 'dec8', 'dec8_swedish_ci', 'Yes'))
 * _charsets.add(Charset(4, 'cp850', 'cp850_general_ci', 'Yes'))
 * _charsets.add(Charset(5, 'latin1', 'latin1_german1_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(6, 'hp8', 'hp8_english_ci', 'Yes'))
 * _charsets.add(Charset(7, 'koi8r', 'koi8r_general_ci', 'Yes'))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__6, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 41; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 41; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":42
 * _charsets.add(Charset(4, 'cp850', 'cp850_general_ci', 'Yes'))
 * _charsets.add(Charset(5, 'latin1', 'latin1_german1_ci', ''))
 * _charsets.add(Charset(6, 'hp8', 'hp8_english_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(7, 'koi8r', 'koi8r_general_ci', 'Yes'))
 * _charsets.add(Charset(8, 'latin1', 'latin1_swedish_ci', 'Yes'))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__7, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 42; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 42; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":43
 * _charsets.add(Charset(5, 'latin1', 'latin1_german1_ci', ''))
 * _charsets.add(Charset(6, 'hp8', 'hp8_english_ci', 'Yes'))
 * _charsets.add(Charset(7, 'koi8r', 'koi8r_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(8, 'latin1', 'latin1_swedish_ci', 'Yes'))
 * _charsets.add(Charset(9, 'latin2', 'latin2_general_ci', 'Yes'))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__8, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 43; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 43; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":44
 * _charsets.add(Charset(6, 'hp8', 'hp8_english_ci', 'Yes'))
 * _charsets.add(Charset(7, 'koi8r', 'koi8r_general_ci', 'Yes'))
 * _charsets.add(Charset(8, 'latin1', 'latin1_swedish_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(9, 'latin2', 'latin2_general_ci', 'Yes'))
 * _charsets.add(Charset(10, 'swe7', 'swe7_swedish_ci', 'Yes'))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__9, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 44; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 44; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":45
 * _charsets.add(Charset(7, 'koi8r', 'koi8r_general_ci', 'Yes'))
 * _charsets.add(Charset(8, 'latin1', 'latin1_swedish_ci', 'Yes'))
 * _charsets.add(Charset(9, 'latin2', 'latin2_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(10, 'swe7', 'swe7_swedish_ci', 'Yes'))
 * _charsets.add(Charset(11, 'ascii', 'ascii_general_ci', 'Yes'))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__10, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 45; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 45; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":46
 * _charsets.add(Charset(8, 'latin1', 'latin1_swedish_ci', 'Yes'))
 * _charsets.add(Charset(9, 'latin2', 'latin2_general_ci', 'Yes'))
 * _charsets.add(Charset(10, 'swe7', 'swe7_swedish_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(11, 'ascii', 'ascii_general_ci', 'Yes'))
 * _charsets.add(Charset(12, 'ujis', 'ujis_japanese_ci', 'Yes'))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__11, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 46; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 46; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":47
 * _charsets.add(Charset(9, 'latin2', 'latin2_general_ci', 'Yes'))
 * _charsets.add(Charset(10, 'swe7', 'swe7_swedish_ci', 'Yes'))
 * _charsets.add(Charset(11, 'ascii', 'ascii_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(12, 'ujis', 'ujis_japanese_ci', 'Yes'))
 * _charsets.add(Charset(13, 'sjis', 'sjis_japanese_ci', 'Yes'))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__12, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 47; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 47; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":48
 * _charsets.add(Charset(10, 'swe7', 'swe7_swedish_ci', 'Yes'))
 * _charsets.add(Charset(11, 'ascii', 'ascii_general_ci', 'Yes'))
 * _charsets.add(Charset(12, 'ujis', 'ujis_japanese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(13, 'sjis', 'sjis_japanese_ci', 'Yes'))
 * _charsets.add(Charset(14, 'cp1251', 'cp1251_bulgarian_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__13, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 48; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 48; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":49
 * _charsets.add(Charset(11, 'ascii', 'ascii_general_ci', 'Yes'))
 * _charsets.add(Charset(12, 'ujis', 'ujis_japanese_ci', 'Yes'))
 * _charsets.add(Charset(13, 'sjis', 'sjis_japanese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(14, 'cp1251', 'cp1251_bulgarian_ci', ''))
 * _charsets.add(Charset(15, 'latin1', 'latin1_danish_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__14, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 49; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 49; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":50
 * _charsets.add(Charset(12, 'ujis', 'ujis_japanese_ci', 'Yes'))
 * _charsets.add(Charset(13, 'sjis', 'sjis_japanese_ci', 'Yes'))
 * _charsets.add(Charset(14, 'cp1251', 'cp1251_bulgarian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(15, 'latin1', 'latin1_danish_ci', ''))
 * _charsets.add(Charset(16, 'hebrew', 'hebrew_general_ci', 'Yes'))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__15, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 50; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 50; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":51
 * _charsets.add(Charset(13, 'sjis', 'sjis_japanese_ci', 'Yes'))
 * _charsets.add(Charset(14, 'cp1251', 'cp1251_bulgarian_ci', ''))
 * _charsets.add(Charset(15, 'latin1', 'latin1_danish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(16, 'hebrew', 'hebrew_general_ci', 'Yes'))
 * _charsets.add(Charset(18, 'tis620', 'tis620_thai_ci', 'Yes'))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 51; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 51; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":52
 * _charsets.add(Charset(14, 'cp1251', 'cp1251_bulgarian_ci', ''))
 * _charsets.add(Charset(15, 'latin1', 'latin1_danish_ci', ''))
 * _charsets.add(Charset(16, 'hebrew', 'hebrew_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(18, 'tis620', 'tis620_thai_ci', 'Yes'))
 * _charsets.add(Charset(19, 'euckr', 'euckr_korean_ci', 'Yes'))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__17, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 52; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 52; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":53
 * _charsets.add(Charset(15, 'latin1', 'latin1_danish_ci', ''))
 * _charsets.add(Charset(16, 'hebrew', 'hebrew_general_ci', 'Yes'))
 * _charsets.add(Charset(18, 'tis620', 'tis620_thai_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(19, 'euckr', 'euckr_korean_ci', 'Yes'))
 * _charsets.add(Charset(20, 'latin7', 'latin7_estonian_cs', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__18, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 53; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 53; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":54
 * _charsets.add(Charset(16, 'hebrew', 'hebrew_general_ci', 'Yes'))
 * _charsets.add(Charset(18, 'tis620', 'tis620_thai_ci', 'Yes'))
 * _charsets.add(Charset(19, 'euckr', 'euckr_korean_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(20, 'latin7', 'latin7_estonian_cs', ''))
 * _charsets.add(Charset(21, 'latin2', 'latin2_hungarian_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__19, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 54; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 54; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":55
 * _charsets.add(Charset(18, 'tis620', 'tis620_thai_ci', 'Yes'))
 * _charsets.add(Charset(19, 'euckr', 'euckr_korean_ci', 'Yes'))
 * _charsets.add(Charset(20, 'latin7', 'latin7_estonian_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(21, 'latin2', 'latin2_hungarian_ci', ''))
 * _charsets.add(Charset(22, 'koi8u', 'koi8u_general_ci', 'Yes'))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__20, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 55; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 55; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":56
 * _charsets.add(Charset(19, 'euckr', 'euckr_korean_ci', 'Yes'))
 * _charsets.add(Charset(20, 'latin7', 'latin7_estonian_cs', ''))
 * _charsets.add(Charset(21, 'latin2', 'latin2_hungarian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(22, 'koi8u', 'koi8u_general_ci', 'Yes'))
 * _charsets.add(Charset(23, 'cp1251', 'cp1251_ukrainian_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__21, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 56; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 56; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":57
 * _charsets.add(Charset(20, 'latin7', 'latin7_estonian_cs', ''))
 * _charsets.add(Charset(21, 'latin2', 'latin2_hungarian_ci', ''))
 * _charsets.add(Charset(22, 'koi8u', 'koi8u_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(23, 'cp1251', 'cp1251_ukrainian_ci', ''))
 * _charsets.add(Charset(24, 'gb2312', 'gb2312_chinese_ci', 'Yes'))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__22, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 57; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 57; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":58
 * _charsets.add(Charset(21, 'latin2', 'latin2_hungarian_ci', ''))
 * _charsets.add(Charset(22, 'koi8u', 'koi8u_general_ci', 'Yes'))
 * _charsets.add(Charset(23, 'cp1251', 'cp1251_ukrainian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(24, 'gb2312', 'gb2312_chinese_ci', 'Yes'))
 * _charsets.add(Charset(25, 'greek', 'greek_general_ci', 'Yes'))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__23, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 58; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 58; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":59
 * _charsets.add(Charset(22, 'koi8u', 'koi8u_general_ci', 'Yes'))
 * _charsets.add(Charset(23, 'cp1251', 'cp1251_ukrainian_ci', ''))
 * _charsets.add(Charset(24, 'gb2312', 'gb2312_chinese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(25, 'greek', 'greek_general_ci', 'Yes'))
 * _charsets.add(Charset(26, 'cp1250', 'cp1250_general_ci', 'Yes'))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__24, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 59; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 59; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":60
 * _charsets.add(Charset(23, 'cp1251', 'cp1251_ukrainian_ci', ''))
 * _charsets.add(Charset(24, 'gb2312', 'gb2312_chinese_ci', 'Yes'))
 * _charsets.add(Charset(25, 'greek', 'greek_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(26, 'cp1250', 'cp1250_general_ci', 'Yes'))
 * _charsets.add(Charset(27, 'latin2', 'latin2_croatian_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__25, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 60; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 60; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":61
 * _charsets.add(Charset(24, 'gb2312', 'gb2312_chinese_ci', 'Yes'))
 * _charsets.add(Charset(25, 'greek', 'greek_general_ci', 'Yes'))
 * _charsets.add(Charset(26, 'cp1250', 'cp1250_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(27, 'latin2', 'latin2_croatian_ci', ''))
 * _charsets.add(Charset(28, 'gbk', 'gbk_chinese_ci', 'Yes'))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__26, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 61; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 61; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":62
 * _charsets.add(Charset(25, 'greek', 'greek_general_ci', 'Yes'))
 * _charsets.add(Charset(26, 'cp1250', 'cp1250_general_ci', 'Yes'))
 * _charsets.add(Charset(27, 'latin2', 'latin2_croatian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(28, 'gbk', 'gbk_chinese_ci', 'Yes'))
 * _charsets.add(Charset(29, 'cp1257', 'cp1257_lithuanian_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__27, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 62; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 62; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":63
 * _charsets.add(Charset(26, 'cp1250', 'cp1250_general_ci', 'Yes'))
 * _charsets.add(Charset(27, 'latin2', 'latin2_croatian_ci', ''))
 * _charsets.add(Charset(28, 'gbk', 'gbk_chinese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(29, 'cp1257', 'cp1257_lithuanian_ci', ''))
 * _charsets.add(Charset(30, 'latin5', 'latin5_turkish_ci', 'Yes'))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__28, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 63; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 63; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":64
 * _charsets.add(Charset(27, 'latin2', 'latin2_croatian_ci', ''))
 * _charsets.add(Charset(28, 'gbk', 'gbk_chinese_ci', 'Yes'))
 * _charsets.add(Charset(29, 'cp1257', 'cp1257_lithuanian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(30, 'latin5', 'latin5_turkish_ci', 'Yes'))
 * _charsets.add(Charset(31, 'latin1', 'latin1_german2_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__29, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 64; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 64; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":65
 * _charsets.add(Charset(28, 'gbk', 'gbk_chinese_ci', 'Yes'))
 * _charsets.add(Charset(29, 'cp1257', 'cp1257_lithuanian_ci', ''))
 * _charsets.add(Charset(30, 'latin5', 'latin5_turkish_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(31, 'latin1', 'latin1_german2_ci', ''))
 * _charsets.add(Charset(32, 'armscii8', 'armscii8_general_ci', 'Yes'))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__30, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 65; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 65; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":66
 * _charsets.add(Charset(29, 'cp1257', 'cp1257_lithuanian_ci', ''))
 * _charsets.add(Charset(30, 'latin5', 'latin5_turkish_ci', 'Yes'))
 * _charsets.add(Charset(31, 'latin1', 'latin1_german2_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(32, 'armscii8', 'armscii8_general_ci', 'Yes'))
 * _charsets.add(Charset(33, 'utf8', 'utf8_general_ci', 'Yes'))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__31, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 66; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 66; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":67
 * _charsets.add(Charset(30, 'latin5', 'latin5_turkish_ci', 'Yes'))
 * _charsets.add(Charset(31, 'latin1', 'latin1_german2_ci', ''))
 * _charsets.add(Charset(32, 'armscii8', 'armscii8_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(33, 'utf8', 'utf8_general_ci', 'Yes'))
 * _charsets.add(Charset(34, 'cp1250', 'cp1250_czech_cs', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__32, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 67; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 67; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":68
 * _charsets.add(Charset(31, 'latin1', 'latin1_german2_ci', ''))
 * _charsets.add(Charset(32, 'armscii8', 'armscii8_general_ci', 'Yes'))
 * _charsets.add(Charset(33, 'utf8', 'utf8_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(34, 'cp1250', 'cp1250_czech_cs', ''))
 * _charsets.add(Charset(35, 'ucs2', 'ucs2_general_ci', 'Yes'))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__33, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 68; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 68; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":69
 * _charsets.add(Charset(32, 'armscii8', 'armscii8_general_ci', 'Yes'))
 * _charsets.add(Charset(33, 'utf8', 'utf8_general_ci', 'Yes'))
 * _charsets.add(Charset(34, 'cp1250', 'cp1250_czech_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(35, 'ucs2', 'ucs2_general_ci', 'Yes'))
 * _charsets.add(Charset(36, 'cp866', 'cp866_general_ci', 'Yes'))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__34, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 69; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 69; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":70
 * _charsets.add(Charset(33, 'utf8', 'utf8_general_ci', 'Yes'))
 * _charsets.add(Charset(34, 'cp1250', 'cp1250_czech_cs', ''))
 * _charsets.add(Charset(35, 'ucs2', 'ucs2_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(36, 'cp866', 'cp866_general_ci', 'Yes'))
 * _charsets.add(Charset(37, 'keybcs2', 'keybcs2_general_ci', 'Yes'))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__35, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 70; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 70; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":71
 * _charsets.add(Charset(34, 'cp1250', 'cp1250_czech_cs', ''))
 * _charsets.add(Charset(35, 'ucs2', 'ucs2_general_ci', 'Yes'))
 * _charsets.add(Charset(36, 'cp866', 'cp866_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(37, 'keybcs2', 'keybcs2_general_ci', 'Yes'))
 * _charsets.add(Charset(38, 'macce', 'macce_general_ci', 'Yes'))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__36, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 71; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 71; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":72
 * _charsets.add(Charset(35, 'ucs2', 'ucs2_general_ci', 'Yes'))
 * _charsets.add(Charset(36, 'cp866', 'cp866_general_ci', 'Yes'))
 * _charsets.add(Charset(37, 'keybcs2', 'keybcs2_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(38, 'macce', 'macce_general_ci', 'Yes'))
 * _charsets.add(Charset(39, 'macroman', 'macroman_general_ci', 'Yes'))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__37, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 72; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 72; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":73
 * _charsets.add(Charset(36, 'cp866', 'cp866_general_ci', 'Yes'))
 * _charsets.add(Charset(37, 'keybcs2', 'keybcs2_general_ci', 'Yes'))
 * _charsets.add(Charset(38, 'macce', 'macce_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(39, 'macroman', 'macroman_general_ci', 'Yes'))
 * _charsets.add(Charset(40, 'cp852', 'cp852_general_ci', 'Yes'))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__38, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 73; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 73; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":74
 * _charsets.add(Charset(37, 'keybcs2', 'keybcs2_general_ci', 'Yes'))
 * _charsets.add(Charset(38, 'macce', 'macce_general_ci', 'Yes'))
 * _charsets.add(Charset(39, 'macroman', 'macroman_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(40, 'cp852', 'cp852_general_ci', 'Yes'))
 * _charsets.add(Charset(41, 'latin7', 'latin7_general_ci', 'Yes'))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__39, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 74; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 74; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":75
 * _charsets.add(Charset(38, 'macce', 'macce_general_ci', 'Yes'))
 * _charsets.add(Charset(39, 'macroman', 'macroman_general_ci', 'Yes'))
 * _charsets.add(Charset(40, 'cp852', 'cp852_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(41, 'latin7', 'latin7_general_ci', 'Yes'))
 * _charsets.add(Charset(42, 'latin7', 'latin7_general_cs', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__40, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 75; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 75; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":76
 * _charsets.add(Charset(39, 'macroman', 'macroman_general_ci', 'Yes'))
 * _charsets.add(Charset(40, 'cp852', 'cp852_general_ci', 'Yes'))
 * _charsets.add(Charset(41, 'latin7', 'latin7_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(42, 'latin7', 'latin7_general_cs', ''))
 * _charsets.add(Charset(43, 'macce', 'macce_bin', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__41, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 76; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 76; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":77
 * _charsets.add(Charset(40, 'cp852', 'cp852_general_ci', 'Yes'))
 * _charsets.add(Charset(41, 'latin7', 'latin7_general_ci', 'Yes'))
 * _charsets.add(Charset(42, 'latin7', 'latin7_general_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(43, 'macce', 'macce_bin', ''))
 * _charsets.add(Charset(44, 'cp1250', 'cp1250_croatian_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__42, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 77; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 77; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":78
 * _charsets.add(Charset(41, 'latin7', 'latin7_general_ci', 'Yes'))
 * _charsets.add(Charset(42, 'latin7', 'latin7_general_cs', ''))
 * _charsets.add(Charset(43, 'macce', 'macce_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(44, 'cp1250', 'cp1250_croatian_ci', ''))
 * _charsets.add(Charset(45, 'utf8mb4', 'utf8mb4_general_ci', 'Yes'))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__43, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 78; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 78; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":79
 * _charsets.add(Charset(42, 'latin7', 'latin7_general_cs', ''))
 * _charsets.add(Charset(43, 'macce', 'macce_bin', ''))
 * _charsets.add(Charset(44, 'cp1250', 'cp1250_croatian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(45, 'utf8mb4', 'utf8mb4_general_ci', 'Yes'))
 * _charsets.add(Charset(47, 'latin1', 'latin1_bin', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__44, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 79; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 79; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":80
 * _charsets.add(Charset(43, 'macce', 'macce_bin', ''))
 * _charsets.add(Charset(44, 'cp1250', 'cp1250_croatian_ci', ''))
 * _charsets.add(Charset(45, 'utf8mb4', 'utf8mb4_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(47, 'latin1', 'latin1_bin', ''))
 * _charsets.add(Charset(48, 'latin1', 'latin1_general_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__45, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 80; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 80; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":81
 * _charsets.add(Charset(44, 'cp1250', 'cp1250_croatian_ci', ''))
 * _charsets.add(Charset(45, 'utf8mb4', 'utf8mb4_general_ci', 'Yes'))
 * _charsets.add(Charset(47, 'latin1', 'latin1_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(48, 'latin1', 'latin1_general_ci', ''))
 * _charsets.add(Charset(49, 'latin1', 'latin1_general_cs', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__46, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 81; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 81; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":82
 * _charsets.add(Charset(45, 'utf8mb4', 'utf8mb4_general_ci', 'Yes'))
 * _charsets.add(Charset(47, 'latin1', 'latin1_bin', ''))
 * _charsets.add(Charset(48, 'latin1', 'latin1_general_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(49, 'latin1', 'latin1_general_cs', ''))
 * _charsets.add(Charset(50, 'cp1251', 'cp1251_bin', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__47, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 82; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 82; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":83
 * _charsets.add(Charset(47, 'latin1', 'latin1_bin', ''))
 * _charsets.add(Charset(48, 'latin1', 'latin1_general_ci', ''))
 * _charsets.add(Charset(49, 'latin1', 'latin1_general_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(50, 'cp1251', 'cp1251_bin', ''))
 * _charsets.add(Charset(51, 'cp1251', 'cp1251_general_ci', 'Yes'))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__48, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 83; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 83; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":84
 * _charsets.add(Charset(48, 'latin1', 'latin1_general_ci', ''))
 * _charsets.add(Charset(49, 'latin1', 'latin1_general_cs', ''))
 * _charsets.add(Charset(50, 'cp1251', 'cp1251_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(51, 'cp1251', 'cp1251_general_ci', 'Yes'))
 * _charsets.add(Charset(52, 'cp1251', 'cp1251_general_cs', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__49, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 84; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 84; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":85
 * _charsets.add(Charset(49, 'latin1', 'latin1_general_cs', ''))
 * _charsets.add(Charset(50, 'cp1251', 'cp1251_bin', ''))
 * _charsets.add(Charset(51, 'cp1251', 'cp1251_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(52, 'cp1251', 'cp1251_general_cs', ''))
 * _charsets.add(Charset(53, 'macroman', 'macroman_bin', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__50, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 85; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 85; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":86
 * _charsets.add(Charset(50, 'cp1251', 'cp1251_bin', ''))
 * _charsets.add(Charset(51, 'cp1251', 'cp1251_general_ci', 'Yes'))
 * _charsets.add(Charset(52, 'cp1251', 'cp1251_general_cs', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(53, 'macroman', 'macroman_bin', ''))
 * _charsets.add(Charset(57, 'cp1256', 'cp1256_general_ci', 'Yes'))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__51, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 86; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 86; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":87
 * _charsets.add(Charset(51, 'cp1251', 'cp1251_general_ci', 'Yes'))
 * _charsets.add(Charset(52, 'cp1251', 'cp1251_general_cs', ''))
 * _charsets.add(Charset(53, 'macroman', 'macroman_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(57, 'cp1256', 'cp1256_general_ci', 'Yes'))
 * _charsets.add(Charset(58, 'cp1257', 'cp1257_bin', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__52, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 87; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 87; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":88
 * _charsets.add(Charset(52, 'cp1251', 'cp1251_general_cs', ''))
 * _charsets.add(Charset(53, 'macroman', 'macroman_bin', ''))
 * _charsets.add(Charset(57, 'cp1256', 'cp1256_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(58, 'cp1257', 'cp1257_bin', ''))
 * _charsets.add(Charset(59, 'cp1257', 'cp1257_general_ci', 'Yes'))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__53, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 88; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 88; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":89
 * _charsets.add(Charset(53, 'macroman', 'macroman_bin', ''))
 * _charsets.add(Charset(57, 'cp1256', 'cp1256_general_ci', 'Yes'))
 * _charsets.add(Charset(58, 'cp1257', 'cp1257_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(59, 'cp1257', 'cp1257_general_ci', 'Yes'))
 * _charsets.add(Charset(63, 'binary', 'binary', 'Yes'))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__54, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 89; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 89; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":90
 * _charsets.add(Charset(57, 'cp1256', 'cp1256_general_ci', 'Yes'))
 * _charsets.add(Charset(58, 'cp1257', 'cp1257_bin', ''))
 * _charsets.add(Charset(59, 'cp1257', 'cp1257_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(63, 'binary', 'binary', 'Yes'))
 * _charsets.add(Charset(64, 'armscii8', 'armscii8_bin', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__55, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 90; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 90; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":91
 * _charsets.add(Charset(58, 'cp1257', 'cp1257_bin', ''))
 * _charsets.add(Charset(59, 'cp1257', 'cp1257_general_ci', 'Yes'))
 * _charsets.add(Charset(63, 'binary', 'binary', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(64, 'armscii8', 'armscii8_bin', ''))
 * _charsets.add(Charset(65, 'ascii', 'ascii_bin', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__56, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 91; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 91; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":92
 * _charsets.add(Charset(59, 'cp1257', 'cp1257_general_ci', 'Yes'))
 * _charsets.add(Charset(63, 'binary', 'binary', 'Yes'))
 * _charsets.add(Charset(64, 'armscii8', 'armscii8_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(65, 'ascii', 'ascii_bin', ''))
 * _charsets.add(Charset(66, 'cp1250', 'cp1250_bin', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__57, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 92; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 92; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":93
 * _charsets.add(Charset(63, 'binary', 'binary', 'Yes'))
 * _charsets.add(Charset(64, 'armscii8', 'armscii8_bin', ''))
 * _charsets.add(Charset(65, 'ascii', 'ascii_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(66, 'cp1250', 'cp1250_bin', ''))
 * _charsets.add(Charset(67, 'cp1256', 'cp1256_bin', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__58, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 93; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 93; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":94
 * _charsets.add(Charset(64, 'armscii8', 'armscii8_bin', ''))
 * _charsets.add(Charset(65, 'ascii', 'ascii_bin', ''))
 * _charsets.add(Charset(66, 'cp1250', 'cp1250_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(67, 'cp1256', 'cp1256_bin', ''))
 * _charsets.add(Charset(68, 'cp866', 'cp866_bin', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__59, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 94; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 94; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":95
 * _charsets.add(Charset(65, 'ascii', 'ascii_bin', ''))
 * _charsets.add(Charset(66, 'cp1250', 'cp1250_bin', ''))
 * _charsets.add(Charset(67, 'cp1256', 'cp1256_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(68, 'cp866', 'cp866_bin', ''))
 * _charsets.add(Charset(69, 'dec8', 'dec8_bin', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__60, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 95; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 95; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":96
 * _charsets.add(Charset(66, 'cp1250', 'cp1250_bin', ''))
 * _charsets.add(Charset(67, 'cp1256', 'cp1256_bin', ''))
 * _charsets.add(Charset(68, 'cp866', 'cp866_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(69, 'dec8', 'dec8_bin', ''))
 * _charsets.add(Charset(70, 'greek', 'greek_bin', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__61, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 96; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 96; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":97
 * _charsets.add(Charset(67, 'cp1256', 'cp1256_bin', ''))
 * _charsets.add(Charset(68, 'cp866', 'cp866_bin', ''))
 * _charsets.add(Charset(69, 'dec8', 'dec8_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(70, 'greek', 'greek_bin', ''))
 * _charsets.add(Charset(71, 'hebrew', 'hebrew_bin', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__62, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 97; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 97; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":98
 * _charsets.add(Charset(68, 'cp866', 'cp866_bin', ''))
 * _charsets.add(Charset(69, 'dec8', 'dec8_bin', ''))
 * _charsets.add(Charset(70, 'greek', 'greek_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(71, 'hebrew', 'hebrew_bin', ''))
 * _charsets.add(Charset(72, 'hp8', 'hp8_bin', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__63, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 98; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 98; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":99
 * _charsets.add(Charset(69, 'dec8', 'dec8_bin', ''))
 * _charsets.add(Charset(70, 'greek', 'greek_bin', ''))
 * _charsets.add(Charset(71, 'hebrew', 'hebrew_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(72, 'hp8', 'hp8_bin', ''))
 * _charsets.add(Charset(73, 'keybcs2', 'keybcs2_bin', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__64, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 99; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 99; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":100
 * _charsets.add(Charset(70, 'greek', 'greek_bin', ''))
 * _charsets.add(Charset(71, 'hebrew', 'hebrew_bin', ''))
 * _charsets.add(Charset(72, 'hp8', 'hp8_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(73, 'keybcs2', 'keybcs2_bin', ''))
 * _charsets.add(Charset(74, 'koi8r', 'koi8r_bin', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__65, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 100; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 100; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":101
 * _charsets.add(Charset(71, 'hebrew', 'hebrew_bin', ''))
 * _charsets.add(Charset(72, 'hp8', 'hp8_bin', ''))
 * _charsets.add(Charset(73, 'keybcs2', 'keybcs2_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(74, 'koi8r', 'koi8r_bin', ''))
 * _charsets.add(Charset(75, 'koi8u', 'koi8u_bin', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__66, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 101; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 101; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":102
 * _charsets.add(Charset(72, 'hp8', 'hp8_bin', ''))
 * _charsets.add(Charset(73, 'keybcs2', 'keybcs2_bin', ''))
 * _charsets.add(Charset(74, 'koi8r', 'koi8r_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(75, 'koi8u', 'koi8u_bin', ''))
 * _charsets.add(Charset(77, 'latin2', 'latin2_bin', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__67, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 102; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 102; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":103
 * _charsets.add(Charset(73, 'keybcs2', 'keybcs2_bin', ''))
 * _charsets.add(Charset(74, 'koi8r', 'koi8r_bin', ''))
 * _charsets.add(Charset(75, 'koi8u', 'koi8u_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(77, 'latin2', 'latin2_bin', ''))
 * _charsets.add(Charset(78, 'latin5', 'latin5_bin', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__68, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 103; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 103; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":104
 * _charsets.add(Charset(74, 'koi8r', 'koi8r_bin', ''))
 * _charsets.add(Charset(75, 'koi8u', 'koi8u_bin', ''))
 * _charsets.add(Charset(77, 'latin2', 'latin2_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(78, 'latin5', 'latin5_bin', ''))
 * _charsets.add(Charset(79, 'latin7', 'latin7_bin', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__69, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 104; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 104; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":105
 * _charsets.add(Charset(75, 'koi8u', 'koi8u_bin', ''))
 * _charsets.add(Charset(77, 'latin2', 'latin2_bin', ''))
 * _charsets.add(Charset(78, 'latin5', 'latin5_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(79, 'latin7', 'latin7_bin', ''))
 * _charsets.add(Charset(80, 'cp850', 'cp850_bin', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__70, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 105; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 105; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":106
 * _charsets.add(Charset(77, 'latin2', 'latin2_bin', ''))
 * _charsets.add(Charset(78, 'latin5', 'latin5_bin', ''))
 * _charsets.add(Charset(79, 'latin7', 'latin7_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(80, 'cp850', 'cp850_bin', ''))
 * _charsets.add(Charset(81, 'cp852', 'cp852_bin', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__71, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 106; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 106; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":107
 * _charsets.add(Charset(78, 'latin5', 'latin5_bin', ''))
 * _charsets.add(Charset(79, 'latin7', 'latin7_bin', ''))
 * _charsets.add(Charset(80, 'cp850', 'cp850_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(81, 'cp852', 'cp852_bin', ''))
 * _charsets.add(Charset(82, 'swe7', 'swe7_bin', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__72, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 107; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 107; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":108
 * _charsets.add(Charset(79, 'latin7', 'latin7_bin', ''))
 * _charsets.add(Charset(80, 'cp850', 'cp850_bin', ''))
 * _charsets.add(Charset(81, 'cp852', 'cp852_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(82, 'swe7', 'swe7_bin', ''))
 * _charsets.add(Charset(83, 'utf8', 'utf8_bin', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__73, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 108; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 108; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":109
 * _charsets.add(Charset(80, 'cp850', 'cp850_bin', ''))
 * _charsets.add(Charset(81, 'cp852', 'cp852_bin', ''))
 * _charsets.add(Charset(82, 'swe7', 'swe7_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(83, 'utf8', 'utf8_bin', ''))
 * _charsets.add(Charset(84, 'big5', 'big5_bin', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__74, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 109; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 109; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":110
 * _charsets.add(Charset(81, 'cp852', 'cp852_bin', ''))
 * _charsets.add(Charset(82, 'swe7', 'swe7_bin', ''))
 * _charsets.add(Charset(83, 'utf8', 'utf8_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(84, 'big5', 'big5_bin', ''))
 * _charsets.add(Charset(85, 'euckr', 'euckr_bin', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__75, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 110; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 110; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":111
 * _charsets.add(Charset(82, 'swe7', 'swe7_bin', ''))
 * _charsets.add(Charset(83, 'utf8', 'utf8_bin', ''))
 * _charsets.add(Charset(84, 'big5', 'big5_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(85, 'euckr', 'euckr_bin', ''))
 * _charsets.add(Charset(86, 'gb2312', 'gb2312_bin', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__76, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 111; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 111; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":112
 * _charsets.add(Charset(83, 'utf8', 'utf8_bin', ''))
 * _charsets.add(Charset(84, 'big5', 'big5_bin', ''))
 * _charsets.add(Charset(85, 'euckr', 'euckr_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(86, 'gb2312', 'gb2312_bin', ''))
 * _charsets.add(Charset(87, 'gbk', 'gbk_bin', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__77, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 112; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 112; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":113
 * _charsets.add(Charset(84, 'big5', 'big5_bin', ''))
 * _charsets.add(Charset(85, 'euckr', 'euckr_bin', ''))
 * _charsets.add(Charset(86, 'gb2312', 'gb2312_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(87, 'gbk', 'gbk_bin', ''))
 * _charsets.add(Charset(88, 'sjis', 'sjis_bin', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__78, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 113; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 113; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":114
 * _charsets.add(Charset(85, 'euckr', 'euckr_bin', ''))
 * _charsets.add(Charset(86, 'gb2312', 'gb2312_bin', ''))
 * _charsets.add(Charset(87, 'gbk', 'gbk_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(88, 'sjis', 'sjis_bin', ''))
 * _charsets.add(Charset(89, 'tis620', 'tis620_bin', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__79, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 114; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 114; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":115
 * _charsets.add(Charset(86, 'gb2312', 'gb2312_bin', ''))
 * _charsets.add(Charset(87, 'gbk', 'gbk_bin', ''))
 * _charsets.add(Charset(88, 'sjis', 'sjis_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(89, 'tis620', 'tis620_bin', ''))
 * _charsets.add(Charset(90, 'ucs2', 'ucs2_bin', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__80, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 115; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 115; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":116
 * _charsets.add(Charset(87, 'gbk', 'gbk_bin', ''))
 * _charsets.add(Charset(88, 'sjis', 'sjis_bin', ''))
 * _charsets.add(Charset(89, 'tis620', 'tis620_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(90, 'ucs2', 'ucs2_bin', ''))
 * _charsets.add(Charset(91, 'ujis', 'ujis_bin', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__81, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 116; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 116; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":117
 * _charsets.add(Charset(88, 'sjis', 'sjis_bin', ''))
 * _charsets.add(Charset(89, 'tis620', 'tis620_bin', ''))
 * _charsets.add(Charset(90, 'ucs2', 'ucs2_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(91, 'ujis', 'ujis_bin', ''))
 * _charsets.add(Charset(92, 'geostd8', 'geostd8_general_ci', 'Yes'))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__82, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 117; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 117; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":118
 * _charsets.add(Charset(89, 'tis620', 'tis620_bin', ''))
 * _charsets.add(Charset(90, 'ucs2', 'ucs2_bin', ''))
 * _charsets.add(Charset(91, 'ujis', 'ujis_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(92, 'geostd8', 'geostd8_general_ci', 'Yes'))
 * _charsets.add(Charset(93, 'geostd8', 'geostd8_bin', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__83, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 118; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 118; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":119
 * _charsets.add(Charset(90, 'ucs2', 'ucs2_bin', ''))
 * _charsets.add(Charset(91, 'ujis', 'ujis_bin', ''))
 * _charsets.add(Charset(92, 'geostd8', 'geostd8_general_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(93, 'geostd8', 'geostd8_bin', ''))
 * _charsets.add(Charset(94, 'latin1', 'latin1_spanish_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__84, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 119; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 119; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":120
 * _charsets.add(Charset(91, 'ujis', 'ujis_bin', ''))
 * _charsets.add(Charset(92, 'geostd8', 'geostd8_general_ci', 'Yes'))
 * _charsets.add(Charset(93, 'geostd8', 'geostd8_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(94, 'latin1', 'latin1_spanish_ci', ''))
 * _charsets.add(Charset(95, 'cp932', 'cp932_japanese_ci', 'Yes'))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__85, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 120; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 120; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":121
 * _charsets.add(Charset(92, 'geostd8', 'geostd8_general_ci', 'Yes'))
 * _charsets.add(Charset(93, 'geostd8', 'geostd8_bin', ''))
 * _charsets.add(Charset(94, 'latin1', 'latin1_spanish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(95, 'cp932', 'cp932_japanese_ci', 'Yes'))
 * _charsets.add(Charset(96, 'cp932', 'cp932_bin', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__86, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 121; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 121; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":122
 * _charsets.add(Charset(93, 'geostd8', 'geostd8_bin', ''))
 * _charsets.add(Charset(94, 'latin1', 'latin1_spanish_ci', ''))
 * _charsets.add(Charset(95, 'cp932', 'cp932_japanese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(96, 'cp932', 'cp932_bin', ''))
 * _charsets.add(Charset(97, 'eucjpms', 'eucjpms_japanese_ci', 'Yes'))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__87, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 122; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 122; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":123
 * _charsets.add(Charset(94, 'latin1', 'latin1_spanish_ci', ''))
 * _charsets.add(Charset(95, 'cp932', 'cp932_japanese_ci', 'Yes'))
 * _charsets.add(Charset(96, 'cp932', 'cp932_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(97, 'eucjpms', 'eucjpms_japanese_ci', 'Yes'))
 * _charsets.add(Charset(98, 'eucjpms', 'eucjpms_bin', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__88, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 123; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 123; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":124
 * _charsets.add(Charset(95, 'cp932', 'cp932_japanese_ci', 'Yes'))
 * _charsets.add(Charset(96, 'cp932', 'cp932_bin', ''))
 * _charsets.add(Charset(97, 'eucjpms', 'eucjpms_japanese_ci', 'Yes'))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(98, 'eucjpms', 'eucjpms_bin', ''))
 * _charsets.add(Charset(99, 'cp1250', 'cp1250_polish_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__89, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 124; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 124; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":125
 * _charsets.add(Charset(96, 'cp932', 'cp932_bin', ''))
 * _charsets.add(Charset(97, 'eucjpms', 'eucjpms_japanese_ci', 'Yes'))
 * _charsets.add(Charset(98, 'eucjpms', 'eucjpms_bin', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(99, 'cp1250', 'cp1250_polish_ci', ''))
 * _charsets.add(Charset(128, 'ucs2', 'ucs2_unicode_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__90, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 125; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 125; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":126
 * _charsets.add(Charset(97, 'eucjpms', 'eucjpms_japanese_ci', 'Yes'))
 * _charsets.add(Charset(98, 'eucjpms', 'eucjpms_bin', ''))
 * _charsets.add(Charset(99, 'cp1250', 'cp1250_polish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(128, 'ucs2', 'ucs2_unicode_ci', ''))
 * _charsets.add(Charset(129, 'ucs2', 'ucs2_icelandic_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__91, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 126; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 126; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":127
 * _charsets.add(Charset(98, 'eucjpms', 'eucjpms_bin', ''))
 * _charsets.add(Charset(99, 'cp1250', 'cp1250_polish_ci', ''))
 * _charsets.add(Charset(128, 'ucs2', 'ucs2_unicode_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(129, 'ucs2', 'ucs2_icelandic_ci', ''))
 * _charsets.add(Charset(130, 'ucs2', 'ucs2_latvian_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__92, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 127; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 127; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":128
 * _charsets.add(Charset(99, 'cp1250', 'cp1250_polish_ci', ''))
 * _charsets.add(Charset(128, 'ucs2', 'ucs2_unicode_ci', ''))
 * _charsets.add(Charset(129, 'ucs2', 'ucs2_icelandic_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(130, 'ucs2', 'ucs2_latvian_ci', ''))
 * _charsets.add(Charset(131, 'ucs2', 'ucs2_romanian_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__93, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 128; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 128; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":129
 * _charsets.add(Charset(128, 'ucs2', 'ucs2_unicode_ci', ''))
 * _charsets.add(Charset(129, 'ucs2', 'ucs2_icelandic_ci', ''))
 * _charsets.add(Charset(130, 'ucs2', 'ucs2_latvian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(131, 'ucs2', 'ucs2_romanian_ci', ''))
 * _charsets.add(Charset(132, 'ucs2', 'ucs2_slovenian_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__94, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 129; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 129; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":130
 * _charsets.add(Charset(129, 'ucs2', 'ucs2_icelandic_ci', ''))
 * _charsets.add(Charset(130, 'ucs2', 'ucs2_latvian_ci', ''))
 * _charsets.add(Charset(131, 'ucs2', 'ucs2_romanian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(132, 'ucs2', 'ucs2_slovenian_ci', ''))
 * _charsets.add(Charset(133, 'ucs2', 'ucs2_polish_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__95, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 130; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 130; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":131
 * _charsets.add(Charset(130, 'ucs2', 'ucs2_latvian_ci', ''))
 * _charsets.add(Charset(131, 'ucs2', 'ucs2_romanian_ci', ''))
 * _charsets.add(Charset(132, 'ucs2', 'ucs2_slovenian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(133, 'ucs2', 'ucs2_polish_ci', ''))
 * _charsets.add(Charset(134, 'ucs2', 'ucs2_estonian_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__96, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 131; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 131; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":132
 * _charsets.add(Charset(131, 'ucs2', 'ucs2_romanian_ci', ''))
 * _charsets.add(Charset(132, 'ucs2', 'ucs2_slovenian_ci', ''))
 * _charsets.add(Charset(133, 'ucs2', 'ucs2_polish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(134, 'ucs2', 'ucs2_estonian_ci', ''))
 * _charsets.add(Charset(135, 'ucs2', 'ucs2_spanish_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__97, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 132; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 132; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":133
 * _charsets.add(Charset(132, 'ucs2', 'ucs2_slovenian_ci', ''))
 * _charsets.add(Charset(133, 'ucs2', 'ucs2_polish_ci', ''))
 * _charsets.add(Charset(134, 'ucs2', 'ucs2_estonian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(135, 'ucs2', 'ucs2_spanish_ci', ''))
 * _charsets.add(Charset(136, 'ucs2', 'ucs2_swedish_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__98, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 133; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 133; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":134
 * _charsets.add(Charset(133, 'ucs2', 'ucs2_polish_ci', ''))
 * _charsets.add(Charset(134, 'ucs2', 'ucs2_estonian_ci', ''))
 * _charsets.add(Charset(135, 'ucs2', 'ucs2_spanish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(136, 'ucs2', 'ucs2_swedish_ci', ''))
 * _charsets.add(Charset(137, 'ucs2', 'ucs2_turkish_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__99, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 134; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 134; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":135
 * _charsets.add(Charset(134, 'ucs2', 'ucs2_estonian_ci', ''))
 * _charsets.add(Charset(135, 'ucs2', 'ucs2_spanish_ci', ''))
 * _charsets.add(Charset(136, 'ucs2', 'ucs2_swedish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(137, 'ucs2', 'ucs2_turkish_ci', ''))
 * _charsets.add(Charset(138, 'ucs2', 'ucs2_czech_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__100, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 135; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 135; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":136
 * _charsets.add(Charset(135, 'ucs2', 'ucs2_spanish_ci', ''))
 * _charsets.add(Charset(136, 'ucs2', 'ucs2_swedish_ci', ''))
 * _charsets.add(Charset(137, 'ucs2', 'ucs2_turkish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(138, 'ucs2', 'ucs2_czech_ci', ''))
 * _charsets.add(Charset(139, 'ucs2', 'ucs2_danish_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__101, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 136; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 136; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":137
 * _charsets.add(Charset(136, 'ucs2', 'ucs2_swedish_ci', ''))
 * _charsets.add(Charset(137, 'ucs2', 'ucs2_turkish_ci', ''))
 * _charsets.add(Charset(138, 'ucs2', 'ucs2_czech_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(139, 'ucs2', 'ucs2_danish_ci', ''))
 * _charsets.add(Charset(140, 'ucs2', 'ucs2_lithuanian_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__102, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 137; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 137; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":138
 * _charsets.add(Charset(137, 'ucs2', 'ucs2_turkish_ci', ''))
 * _charsets.add(Charset(138, 'ucs2', 'ucs2_czech_ci', ''))
 * _charsets.add(Charset(139, 'ucs2', 'ucs2_danish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(140, 'ucs2', 'ucs2_lithuanian_ci', ''))
 * _charsets.add(Charset(141, 'ucs2', 'ucs2_slovak_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__103, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 138; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 138; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":139
 * _charsets.add(Charset(138, 'ucs2', 'ucs2_czech_ci', ''))
 * _charsets.add(Charset(139, 'ucs2', 'ucs2_danish_ci', ''))
 * _charsets.add(Charset(140, 'ucs2', 'ucs2_lithuanian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(141, 'ucs2', 'ucs2_slovak_ci', ''))
 * _charsets.add(Charset(142, 'ucs2', 'ucs2_spanish2_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__104, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 139; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 139; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":140
 * _charsets.add(Charset(139, 'ucs2', 'ucs2_danish_ci', ''))
 * _charsets.add(Charset(140, 'ucs2', 'ucs2_lithuanian_ci', ''))
 * _charsets.add(Charset(141, 'ucs2', 'ucs2_slovak_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(142, 'ucs2', 'ucs2_spanish2_ci', ''))
 * _charsets.add(Charset(143, 'ucs2', 'ucs2_roman_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__105, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 140; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 140; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":141
 * _charsets.add(Charset(140, 'ucs2', 'ucs2_lithuanian_ci', ''))
 * _charsets.add(Charset(141, 'ucs2', 'ucs2_slovak_ci', ''))
 * _charsets.add(Charset(142, 'ucs2', 'ucs2_spanish2_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(143, 'ucs2', 'ucs2_roman_ci', ''))
 * _charsets.add(Charset(144, 'ucs2', 'ucs2_persian_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__106, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 141; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 141; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":142
 * _charsets.add(Charset(141, 'ucs2', 'ucs2_slovak_ci', ''))
 * _charsets.add(Charset(142, 'ucs2', 'ucs2_spanish2_ci', ''))
 * _charsets.add(Charset(143, 'ucs2', 'ucs2_roman_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(144, 'ucs2', 'ucs2_persian_ci', ''))
 * _charsets.add(Charset(145, 'ucs2', 'ucs2_esperanto_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__107, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 142; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 142; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":143
 * _charsets.add(Charset(142, 'ucs2', 'ucs2_spanish2_ci', ''))
 * _charsets.add(Charset(143, 'ucs2', 'ucs2_roman_ci', ''))
 * _charsets.add(Charset(144, 'ucs2', 'ucs2_persian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(145, 'ucs2', 'ucs2_esperanto_ci', ''))
 * _charsets.add(Charset(146, 'ucs2', 'ucs2_hungarian_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__108, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 143; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 143; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":144
 * _charsets.add(Charset(143, 'ucs2', 'ucs2_roman_ci', ''))
 * _charsets.add(Charset(144, 'ucs2', 'ucs2_persian_ci', ''))
 * _charsets.add(Charset(145, 'ucs2', 'ucs2_esperanto_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(146, 'ucs2', 'ucs2_hungarian_ci', ''))
 * _charsets.add(Charset(192, 'utf8', 'utf8_unicode_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__109, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 144; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 144; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":145
 * _charsets.add(Charset(144, 'ucs2', 'ucs2_persian_ci', ''))
 * _charsets.add(Charset(145, 'ucs2', 'ucs2_esperanto_ci', ''))
 * _charsets.add(Charset(146, 'ucs2', 'ucs2_hungarian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(192, 'utf8', 'utf8_unicode_ci', ''))
 * _charsets.add(Charset(193, 'utf8', 'utf8_icelandic_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__110, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 145; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 145; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":146
 * _charsets.add(Charset(145, 'ucs2', 'ucs2_esperanto_ci', ''))
 * _charsets.add(Charset(146, 'ucs2', 'ucs2_hungarian_ci', ''))
 * _charsets.add(Charset(192, 'utf8', 'utf8_unicode_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(193, 'utf8', 'utf8_icelandic_ci', ''))
 * _charsets.add(Charset(194, 'utf8', 'utf8_latvian_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__111, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 146; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 146; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":147
 * _charsets.add(Charset(146, 'ucs2', 'ucs2_hungarian_ci', ''))
 * _charsets.add(Charset(192, 'utf8', 'utf8_unicode_ci', ''))
 * _charsets.add(Charset(193, 'utf8', 'utf8_icelandic_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(194, 'utf8', 'utf8_latvian_ci', ''))
 * _charsets.add(Charset(195, 'utf8', 'utf8_romanian_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__112, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 147; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 147; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":148
 * _charsets.add(Charset(192, 'utf8', 'utf8_unicode_ci', ''))
 * _charsets.add(Charset(193, 'utf8', 'utf8_icelandic_ci', ''))
 * _charsets.add(Charset(194, 'utf8', 'utf8_latvian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(195, 'utf8', 'utf8_romanian_ci', ''))
 * _charsets.add(Charset(196, 'utf8', 'utf8_slovenian_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__113, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 148; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 148; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":149
 * _charsets.add(Charset(193, 'utf8', 'utf8_icelandic_ci', ''))
 * _charsets.add(Charset(194, 'utf8', 'utf8_latvian_ci', ''))
 * _charsets.add(Charset(195, 'utf8', 'utf8_romanian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(196, 'utf8', 'utf8_slovenian_ci', ''))
 * _charsets.add(Charset(197, 'utf8', 'utf8_polish_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__114, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 149; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 149; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":150
 * _charsets.add(Charset(194, 'utf8', 'utf8_latvian_ci', ''))
 * _charsets.add(Charset(195, 'utf8', 'utf8_romanian_ci', ''))
 * _charsets.add(Charset(196, 'utf8', 'utf8_slovenian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(197, 'utf8', 'utf8_polish_ci', ''))
 * _charsets.add(Charset(198, 'utf8', 'utf8_estonian_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__115, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 150; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 150; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":151
 * _charsets.add(Charset(195, 'utf8', 'utf8_romanian_ci', ''))
 * _charsets.add(Charset(196, 'utf8', 'utf8_slovenian_ci', ''))
 * _charsets.add(Charset(197, 'utf8', 'utf8_polish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(198, 'utf8', 'utf8_estonian_ci', ''))
 * _charsets.add(Charset(199, 'utf8', 'utf8_spanish_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__116, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 151; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 151; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":152
 * _charsets.add(Charset(196, 'utf8', 'utf8_slovenian_ci', ''))
 * _charsets.add(Charset(197, 'utf8', 'utf8_polish_ci', ''))
 * _charsets.add(Charset(198, 'utf8', 'utf8_estonian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(199, 'utf8', 'utf8_spanish_ci', ''))
 * _charsets.add(Charset(200, 'utf8', 'utf8_swedish_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__117, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 152; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 152; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":153
 * _charsets.add(Charset(197, 'utf8', 'utf8_polish_ci', ''))
 * _charsets.add(Charset(198, 'utf8', 'utf8_estonian_ci', ''))
 * _charsets.add(Charset(199, 'utf8', 'utf8_spanish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(200, 'utf8', 'utf8_swedish_ci', ''))
 * _charsets.add(Charset(201, 'utf8', 'utf8_turkish_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__118, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 153; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 153; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":154
 * _charsets.add(Charset(198, 'utf8', 'utf8_estonian_ci', ''))
 * _charsets.add(Charset(199, 'utf8', 'utf8_spanish_ci', ''))
 * _charsets.add(Charset(200, 'utf8', 'utf8_swedish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(201, 'utf8', 'utf8_turkish_ci', ''))
 * _charsets.add(Charset(202, 'utf8', 'utf8_czech_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__119, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 154; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 154; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":155
 * _charsets.add(Charset(199, 'utf8', 'utf8_spanish_ci', ''))
 * _charsets.add(Charset(200, 'utf8', 'utf8_swedish_ci', ''))
 * _charsets.add(Charset(201, 'utf8', 'utf8_turkish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(202, 'utf8', 'utf8_czech_ci', ''))
 * _charsets.add(Charset(203, 'utf8', 'utf8_danish_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__120, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 155; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 155; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":156
 * _charsets.add(Charset(200, 'utf8', 'utf8_swedish_ci', ''))
 * _charsets.add(Charset(201, 'utf8', 'utf8_turkish_ci', ''))
 * _charsets.add(Charset(202, 'utf8', 'utf8_czech_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(203, 'utf8', 'utf8_danish_ci', ''))
 * _charsets.add(Charset(204, 'utf8', 'utf8_lithuanian_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__121, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 156; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 156; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":157
 * _charsets.add(Charset(201, 'utf8', 'utf8_turkish_ci', ''))
 * _charsets.add(Charset(202, 'utf8', 'utf8_czech_ci', ''))
 * _charsets.add(Charset(203, 'utf8', 'utf8_danish_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(204, 'utf8', 'utf8_lithuanian_ci', ''))
 * _charsets.add(Charset(205, 'utf8', 'utf8_slovak_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__122, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 157; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 157; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":158
 * _charsets.add(Charset(202, 'utf8', 'utf8_czech_ci', ''))
 * _charsets.add(Charset(203, 'utf8', 'utf8_danish_ci', ''))
 * _charsets.add(Charset(204, 'utf8', 'utf8_lithuanian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(205, 'utf8', 'utf8_slovak_ci', ''))
 * _charsets.add(Charset(206, 'utf8', 'utf8_spanish2_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__123, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 158; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 158; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":159
 * _charsets.add(Charset(203, 'utf8', 'utf8_danish_ci', ''))
 * _charsets.add(Charset(204, 'utf8', 'utf8_lithuanian_ci', ''))
 * _charsets.add(Charset(205, 'utf8', 'utf8_slovak_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(206, 'utf8', 'utf8_spanish2_ci', ''))
 * _charsets.add(Charset(207, 'utf8', 'utf8_roman_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__124, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 159; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 159; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":160
 * _charsets.add(Charset(204, 'utf8', 'utf8_lithuanian_ci', ''))
 * _charsets.add(Charset(205, 'utf8', 'utf8_slovak_ci', ''))
 * _charsets.add(Charset(206, 'utf8', 'utf8_spanish2_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(207, 'utf8', 'utf8_roman_ci', ''))
 * _charsets.add(Charset(208, 'utf8', 'utf8_persian_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__125, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 160; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 160; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":161
 * _charsets.add(Charset(205, 'utf8', 'utf8_slovak_ci', ''))
 * _charsets.add(Charset(206, 'utf8', 'utf8_spanish2_ci', ''))
 * _charsets.add(Charset(207, 'utf8', 'utf8_roman_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(208, 'utf8', 'utf8_persian_ci', ''))
 * _charsets.add(Charset(209, 'utf8', 'utf8_esperanto_ci', ''))
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__126, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 161; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 161; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":162
 * _charsets.add(Charset(206, 'utf8', 'utf8_spanish2_ci', ''))
 * _charsets.add(Charset(207, 'utf8', 'utf8_roman_ci', ''))
 * _charsets.add(Charset(208, 'utf8', 'utf8_persian_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(209, 'utf8', 'utf8_esperanto_ci', ''))
 * _charsets.add(Charset(210, 'utf8', 'utf8_hungarian_ci', ''))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__127, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 162; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 162; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":163
 * _charsets.add(Charset(207, 'utf8', 'utf8_roman_ci', ''))
 * _charsets.add(Charset(208, 'utf8', 'utf8_persian_ci', ''))
 * _charsets.add(Charset(209, 'utf8', 'utf8_esperanto_ci', ''))             # <<<<<<<<<<<<<<
 * _charsets.add(Charset(210, 'utf8', 'utf8_hungarian_ci', ''))
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__128, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 163; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 163; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cymysql/charset.py":164
 * _charsets.add(Charset(208, 'utf8', 'utf8_persian_ci', ''))
 * _charsets.add(Charset(209, 'utf8', 'utf8_esperanto_ci', ''))
 * _charsets.add(Charset(210, 'utf8', 'utf8_hungarian_ci', ''))             # <<<<<<<<<<<<<<
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_7cymysql_7charset_Charset)), __pyx_tuple__129, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 164; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = ((struct __pyx_vtabstruct_7cymysql_7charset_Charsets *)__pyx_v_7cymysql_7charset__charsets->__pyx_vtab)->add(__pyx_v_7cymysql_7charset__charsets, ((struct __pyx_obj_7cymysql_7charset_Charset *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 164; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "cymysql/charset.py":1
 * class Charset(object):             # <<<<<<<<<<<<<<
 *     def __init__(self, id, name, collation, is_default):
 *         self.id, self.name, self.collation = id, name, collation
 */
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  if (__pyx_m) {
    if (__pyx_d) {
      __Pyx_AddTraceback("init cymysql.charset", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    Py_DECREF(__pyx_m); __pyx_m = 0;
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init cymysql.charset");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if PY_MAJOR_VERSION < 3
  return;
  #else
  return __pyx_m;
  #endif
}

/* --- Runtime support code --- */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule((char *)modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, (char *)"RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    while (PyDict_Next(kwds, &pos, &key, &value)) {
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
            continue;
        }
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_CheckExact(key)) || likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (**name == key) ? 0 :
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (PyUnicode_GET_SIZE(**name) != PyUnicode_GET_SIZE(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key);
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (PyUnicode_GET_SIZE(**argname) != PyUnicode_GET_SIZE(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    return -1;
}

static CYTHON_INLINE int __Pyx_CheckKeywordStrings(
    PyObject *kwdict,
    const char* function_name,
    int kw_allowed)
{
    PyObject* key = 0;
    Py_ssize_t pos = 0;
#if CYTHON_COMPILING_IN_PYPY
    if (!kw_allowed && PyDict_Next(kwdict, &pos, &key, 0))
        goto invalid_keyword;
    return 1;
#else
    while (PyDict_Next(kwdict, &pos, &key, 0)) {
        #if PY_MAJOR_VERSION < 3
        if (unlikely(!PyString_CheckExact(key)) && unlikely(!PyString_Check(key)))
        #endif
            if (unlikely(!PyUnicode_Check(key)))
                goto invalid_keyword_type;
    }
    if ((!kw_allowed) && unlikely(key))
        goto invalid_keyword;
    return 1;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    return 0;
#endif
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
    return 0;
}

#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = func->ob_type->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = PyCFunction_GET_FUNCTION(func);
    self = PyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

#if CYTHON_COMPILING_IN_CPYTHON
static PyObject* __Pyx__PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_New(1);
    if (unlikely(!args)) return NULL;
    Py_INCREF(arg);
    PyTuple_SET_ITEM(args, 0, arg);
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
#ifdef __Pyx_CyFunction_USED
    if (likely(PyCFunction_Check(func) || PyObject_TypeCheck(func, __pyx_CyFunctionType))) {
#else
    if (likely(PyCFunction_Check(func))) {
#endif
        if (likely(PyCFunction_GET_FLAGS(func) & METH_O)) {
            return __Pyx_PyObject_CallMethO(func, arg);
        }
    }
    return __Pyx__PyObject_CallOneArg(func, arg);
}
#else
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject* args = PyTuple_Pack(1, arg);
    return (likely(args)) ? __Pyx_PyObject_Call(func, args, NULL) : NULL;
}
#endif

static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg) {
    PyObject *method, *result = NULL;
    method = __Pyx_PyObject_GetAttrStr(obj, method_name);
    if (unlikely(!method)) goto bad;
#if CYTHON_COMPILING_IN_CPYTHON
    if (likely(PyMethod_Check(method))) {
        PyObject *self = PyMethod_GET_SELF(method);
        if (likely(self)) {
            PyObject *args;
            PyObject *function = PyMethod_GET_FUNCTION(method);
            args = PyTuple_New(2);
            if (unlikely(!args)) goto bad;
            Py_INCREF(self);
            PyTuple_SET_ITEM(args, 0, self);
            Py_INCREF(arg);
            PyTuple_SET_ITEM(args, 1, arg);
            Py_INCREF(function);
            Py_DECREF(method); method = NULL;
            result = __Pyx_PyObject_Call(function, args, NULL);
            Py_DECREF(args);
            Py_DECREF(function);
            return result;
        }
    }
#endif
    result = __Pyx_PyObject_CallOneArg(method, arg);
bad:
    Py_XDECREF(method);
    return result;
}

static CYTHON_INLINE PyObject* __Pyx_PyDict_Values(PyObject* d) {
    if (PY_MAJOR_VERSION >= 3)
        return __Pyx_PyObject_CallMethod1((PyObject*)&PyDict_Type, __pyx_n_s_values, d);
    else
        return PyDict_Values(d);
}

static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(PyObject_TypeCheck(obj, type)))
        return 1;
    PyErr_Format(PyExc_TypeError, "Cannot convert %.200s to %.200s",
                 Py_TYPE(obj)->tp_name, type->tp_name);
    return 0;
}

static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY
    return PyObject_RichCompareBool(s1, s2, equals);
#else
#if PY_MAJOR_VERSION < 3
    PyObject* owned_ref = NULL;
#endif
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
#if PY_MAJOR_VERSION < 3
    if ((s1_is_unicode & (!s2_is_unicode)) && PyString_CheckExact(s2)) {
        owned_ref = PyUnicode_FromObject(s2);
        if (unlikely(!owned_ref))
            return -1;
        s2 = owned_ref;
        s2_is_unicode = 1;
    } else if ((s2_is_unicode & (!s1_is_unicode)) && PyString_CheckExact(s1)) {
        owned_ref = PyUnicode_FromObject(s1);
        if (unlikely(!owned_ref))
            return -1;
        s1 = owned_ref;
        s1_is_unicode = 1;
    } else if (((!s2_is_unicode) & (!s1_is_unicode))) {
        return __Pyx_PyBytes_Equals(s1, s2, equals);
    }
#endif
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length;
        int kind;
        void *data1, *data2;
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        if (length != __Pyx_PyUnicode_GET_LENGTH(s2)) {
            goto return_ne;
        }
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            #if PY_MAJOR_VERSION < 3
            Py_XDECREF(owned_ref);
            #endif
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_EQ);
return_ne:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_NE);
#endif
}

static int __Pyx_SetVtable(PyObject *dict, void *vtable) {
#if PY_VERSION_HEX >= 0x02070000
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
#else
    PyObject *ob = PyCObject_FromVoidPtr(vtable, 0);
#endif
    if (!ob)
        goto bad;
    if (PyDict_SetItem(dict, __pyx_n_s_pyx_vtable, ob) < 0)
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = (start + end) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, (size_t)new_max*sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    #if PY_MAJOR_VERSION < 3
    py_srcfile = PyString_FromString(filename);
    #else
    py_srcfile = PyUnicode_FromString(filename);
    #endif
    if (!py_srcfile) goto bad;
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        #else
        py_funcname = PyUnicode_FromString(funcname);
        #endif
    }
    if (!py_funcname) goto bad;
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    Py_DECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    py_code = __pyx_find_code_object(c_line ? c_line : py_line);
    if (!py_code) {
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) goto bad;
        __pyx_insert_code_object(c_line ? c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        PyThreadState_GET(), /*PyThreadState *tstate,*/
        py_code,             /*PyCodeObject *code,*/
        __pyx_d,      /*PyObject *globals,*/
        0                    /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    py_frame->f_lineno = py_line;
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)       \
    {                                                                     \
        func_type value = func_value;                                     \
        if (sizeof(target_type) < sizeof(func_type)) {                    \
            if (unlikely(value != (func_type) (target_type) value)) {     \
                func_type zero = 0;                                       \
                if (is_unsigned && unlikely(value < zero))                \
                    goto raise_neg_overflow;                              \
                else                                                      \
                    goto raise_overflow;                                  \
            }                                                             \
        }                                                                 \
        return (target_type) value;                                       \
    }

#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
 #if CYTHON_USE_PYLONG_INTERNALS
  #include "longintrepr.h"
 #endif
#endif

static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
    const int neg_one = (int) -1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(int) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
 #if CYTHON_USE_PYLONG_INTERNALS
            switch (Py_SIZE(x)) {
                case  0: return 0;
                case  1: __PYX_VERIFY_RETURN_INT(int, digit, ((PyLongObject*)x)->ob_digit[0]);
            }
 #endif
#endif
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
            if (sizeof(int) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT(int, unsigned long, PyLong_AsUnsignedLong(x))
            } else if (sizeof(int) <= sizeof(unsigned long long)) {
                __PYX_VERIFY_RETURN_INT(int, unsigned long long, PyLong_AsUnsignedLongLong(x))
            }
        } else {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
 #if CYTHON_USE_PYLONG_INTERNALS
            switch (Py_SIZE(x)) {
                case  0: return 0;
                case  1: __PYX_VERIFY_RETURN_INT(int,  digit, +(((PyLongObject*)x)->ob_digit[0]));
                case -1: __PYX_VERIFY_RETURN_INT(int, sdigit, -(sdigit) ((PyLongObject*)x)->ob_digit[0]);
            }
 #endif
#endif
            if (sizeof(int) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT(int, long, PyLong_AsLong(x))
            } else if (sizeof(int) <= sizeof(long long)) {
                __PYX_VERIFY_RETURN_INT(int, long long, PyLong_AsLongLong(x))
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            int val;
            PyObject *v = __Pyx_PyNumber_Int(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value) {
    const int neg_one = (int) -1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(int) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
        } else if (sizeof(int) <= sizeof(unsigned long long)) {
            return PyLong_FromUnsignedLongLong((unsigned long long) value);
        }
    } else {
        if (sizeof(int) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(long long)) {
            return PyLong_FromLongLong((long long) value);
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(int),
                                     little, !is_unsigned);
    }
}

static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
    const long neg_one = (long) -1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
        } else if (sizeof(long) <= sizeof(unsigned long long)) {
            return PyLong_FromUnsignedLongLong((unsigned long long) value);
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(long long)) {
            return PyLong_FromLongLong((long long) value);
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
    }
}

static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
    const long neg_one = (long) -1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(long) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
 #if CYTHON_USE_PYLONG_INTERNALS
            switch (Py_SIZE(x)) {
                case  0: return 0;
                case  1: __PYX_VERIFY_RETURN_INT(long, digit, ((PyLongObject*)x)->ob_digit[0]);
            }
 #endif
#endif
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
            if (sizeof(long) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT(long, unsigned long, PyLong_AsUnsignedLong(x))
            } else if (sizeof(long) <= sizeof(unsigned long long)) {
                __PYX_VERIFY_RETURN_INT(long, unsigned long long, PyLong_AsUnsignedLongLong(x))
            }
        } else {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
 #if CYTHON_USE_PYLONG_INTERNALS
            switch (Py_SIZE(x)) {
                case  0: return 0;
                case  1: __PYX_VERIFY_RETURN_INT(long,  digit, +(((PyLongObject*)x)->ob_digit[0]));
                case -1: __PYX_VERIFY_RETURN_INT(long, sdigit, -(sdigit) ((PyLongObject*)x)->ob_digit[0]);
            }
 #endif
#endif
            if (sizeof(long) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT(long, long, PyLong_AsLong(x))
            } else if (sizeof(long) <= sizeof(long long)) {
                __PYX_VERIFY_RETURN_INT(long, long long, PyLong_AsLongLong(x))
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            long val;
            PyObject *v = __Pyx_PyNumber_Int(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

static int __Pyx_check_binary_version(void) {
    char ctversion[4], rtversion[4];
    PyOS_snprintf(ctversion, 4, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    PyOS_snprintf(rtversion, 4, "%s", Py_GetVersion());
    if (ctversion[0] != rtversion[0] || ctversion[2] != rtversion[2]) {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        return PyErr_WarnEx(NULL, message, 1);
    }
    return 0;
}

static int __Pyx_ExportVoidPtr(PyObject *name, void *p, const char *sig) {
    PyObject *d;
    PyObject *cobj = 0;
    d = PyDict_GetItem(__pyx_d, __pyx_n_s_pyx_capi);
    Py_XINCREF(d);
    if (!d) {
        d = PyDict_New();
        if (!d)
            goto bad;
        if (__Pyx_PyObject_SetAttrStr(__pyx_m, __pyx_n_s_pyx_capi, d) < 0)
            goto bad;
    }
#if PY_VERSION_HEX >= 0x02070000
    cobj = PyCapsule_New(p, sig, 0);
#else
    cobj = PyCObject_FromVoidPtrAndDesc(p, (void *)sig, 0);
#endif
    if (!cobj)
        goto bad;
    if (PyDict_SetItem(d, name, cobj) < 0)
        goto bad;
    Py_DECREF(cobj);
    Py_DECREF(d);
    return 0;
bad:
    Py_XDECREF(cobj);
    Py_XDECREF(d);
    return -1;
}

static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        ++t;
    }
    return 0;
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    return __Pyx_PyUnicode_FromStringAndSize(c_str, (Py_ssize_t)strlen(c_str));
}
static CYTHON_INLINE char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
static CYTHON_INLINE char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
#if PY_VERSION_HEX < 0x03030000
        char* defenc_c;
        PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
        if (!defenc) return NULL;
        defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        {
            char* end = defenc_c + PyBytes_GET_SIZE(defenc);
            char* c;
            for (c = defenc_c; c < end; c++) {
                if ((unsigned char) (*c) >= 128) {
                    PyUnicode_AsASCIIString(o);
                    return NULL;
                }
            }
        }
#endif
        *length = PyBytes_GET_SIZE(defenc);
        return defenc_c;
#else
        if (__Pyx_PyUnicode_READY(o) == -1) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        if (PyUnicode_IS_ASCII(o)) {
            *length = PyUnicode_GET_LENGTH(o);
            return PyUnicode_AsUTF8(o);
        } else {
            PyUnicode_AsASCIIString(o);
            return NULL;
        }
#else
        return PyUnicode_AsUTF8AndSize(o, length);
#endif
#endif
    } else
#endif
#if !CYTHON_COMPILING_IN_PYPY
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Int(PyObject* x) {
  PyNumberMethods *m;
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (PyInt_Check(x) || PyLong_Check(x))
#else
  if (PyLong_Check(x))
#endif
    return Py_INCREF(x), x;
  m = Py_TYPE(x)->tp_as_number;
#if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = PyNumber_Int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = PyNumber_Long(x);
  }
#else
  if (m && m->nb_int) {
    name = "int";
    res = PyNumber_Long(x);
  }
#endif
  if (res) {
#if PY_MAJOR_VERSION < 3
    if (!PyInt_Check(res) && !PyLong_Check(res)) {
#else
    if (!PyLong_Check(res)) {
#endif
      PyErr_Format(PyExc_TypeError,
                   "__%.4s__ returned non-%.4s (type %.200s)",
                   name, name, Py_TYPE(res)->tp_name);
      Py_DECREF(res);
      return NULL;
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b)))
      return PyInt_AS_LONG(b);
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
     #if CYTHON_USE_PYLONG_INTERNALS
       switch (Py_SIZE(b)) {
       case -1: return -(sdigit)((PyLongObject*)b)->ob_digit[0];
       case  0: return 0;
       case  1: return ((PyLongObject*)b)->ob_digit[0];
       }
     #endif
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


#endif /* Py_PYTHON_H */
